<?php


/*
   ===========================================================
   This function computes the apparent geocentric equatorial
   coordinates of Venus for the moment indicated by the given
   JD argument.

   Corrections for light time, aberration, precession and
   nutation (IAU 2000-B series), are applied to the raw
   coordinates to obtain the true, apparent coordinates.

   This program is built around PHP code written by the Multi-
   Language VSOP87 Source Code Generator Tool

   NOTES:
   Radius vector subscript codes.
   Rps = Radius vector from planet to sun
   Res = Radius vector from Earth to sun
   Rep = Radius vector from Earth to planet

   Author  : Jay Tanner
   License : Public Domain

   ===========================================================
*/

   function Geocentric_Venus($JDTT)
{

// ----------------------------------------------
// Time in Julian centuries reckoned from J2000.0
// and corresponding to the JD number.

   $T = (trim($JDTT) - 2451545) / 36525;

// ------------------------------------------
// Define light-time constant.  This is the
// light-time, as a fraction of a Julian day,
// for light to travel 1.0 AU.

   $k = 149597870691 / 299792458 / 86400;

// ---------------------------------------
// Compute heliocentric X,Y,Z,R for Earth.

   list ($Xe,$Ye,$Ze,$Res) = Preg_Split("[ ]", Earth_C_hXYZR($JDTT));

// ---------------------------------------
// Compute heliocentric X,Y,Z,R for Venus.

   list ($Xp,$Yp,$Zp,$Rps) = Preg_Split("[ ]", Venus_C_hXYZR($JDTT));

// --------------------------------------------------------
// Compute geocentric (x,y,z) for the planet (Venus) based
// on the differences between the heliocentric coordinates
// of Venus and Earth in the context (Venus - Earth).

   $x = $Xp - $Xe;
   $y = $Yp - $Ye;
   $z = $Zp - $Ze;

// ----------------------------------------------
// Compute true distance between Earth and Venus.

   $D = $DistAU = SqRt($x*$x + $y*$y + $z*$z);

// ----------------------------------
// Compute starting approximation for
// light time between Earth and Venus
// as a fraction of a day equal to
// the time taken by light to span
// 1.0 AU. The subsequent light-time
// correction loop will refine this
// starting value during each cycle.

   $LTCurr = $D * $k;



// ***************************************************
// ***************************************************
// BEGIN LIGHT-TIME CORRECTION ITERATION LOOP PROCESS.


// -------------------------------
// Initialize light-time iteration
// loop control variables.

   $LTPrev = $PrecisionLimit = 0.000000000001;

   while (abs($LTCurr - $LTPrev) > $PrecisionLimit)
{
   $LTPrev = $LTCurr;

// ---------------------------------------------
// Compute new heliocentric (X,Y,Z,R) for Earth.

   list ($Xe,$Ye,$Ze,$Res)
   = preg_split("[ ]", Earth_C_hXYZR($JDTT - $LTCurr));

// ---------------------------------------------
// Compute new heliocentric (X,Y,Z,R) for Venus.

   list ($Xp,$Yp,$Zp,$Rps)
   = preg_split("[ ]", Venus_C_hXYZR($JDTT - $LTCurr));

// -----------------------------------------
// Compute new geocentric (x,y,z) for Venus.

   $x = $Xp - $Xe;
   $y = $Yp - $Ye;
   $z = $Zp - $Ze;

// ---------------------------------------------
// Compute new distance between Earth and Venus.

   $Rep = SqRt($x*$x + $y*$y + $z*$z);

// ------------------------------------
// Compute new LTCurr approximation, or
// finished if precision limit reached.

   $LTCurr = $Rep * $k;

} // End of  while()

// ******************************************
// ******************************************
// DROP THROUGH HERE AND CONTINUE BELOW AFTER
// LIGHT-TIME ITERATION LOOP HAS FINISHED


// -----------------------------------------------------
// Compute raw geocentric ecliptical longitude of Venus.

   $EclLonDeg = Rad2Deg(atan2($y, $x));

   if ($EclLonDeg < 0) {$EclLonDeg += 360;}

// -----------------------------------------
// Compute raw geocentric latitude of Venus.

   $EclLatDeg = Rad2Deg(atan2($z, SqRt($x*$x + $y*$y)));

// --------------------------------------------------------------
// Apply FK5 correction to raw ecliptical longitude and latitude.

   $u = Deg2Rad($EclLatDeg);
   $Lprime = Deg2Rad($EclLonDeg - 1.397*$T - 0.00031*$T*$T);
   $w = $EclLonDeg + (0.03916*(cos($Lprime)
      + sin($Lprime))*tan($u) - 0.09033) / 3600;

   $u = Deg2Rad($EclLonDeg - 1.397*$T - 0.00031*$T*$T);
   $EclLatDeg += (0.03916*(cos($u) - sin($u)) / 3600);
   $EclLonDeg = $w;

// -------------------------------------------
// Apply correction for nutation in longitude.

   $EclLonDeg += Delta_Psi_2000B($JDTT);

// ---------------------------------------
// Compute true obliquity of the ecliptic.

   $eTrue = Epsilon_Mean($JDTT) + Delta_Eps_2000B($JDTT);

// -----------------------------------------------
// Compute the equatorial RA in degrees and hours.

   $u = Deg2Rad($EclLonDeg);
   $w = Deg2Rad($EclLatDeg);
   $eps = Deg2Rad($eTrue);
   $y = sin($u)*cos($eps) - tan($w)*sin($eps);
   $x = cos($u);
   $RADeg = Rad2Deg(atan2($y, $x));
   $RADeg += ($RADeg < 0)? 360:0;
   $RAHrs = $RADeg / 15;

// ----------------------------------------------
// Compute the equatorial declination in degrees.

   $w = asin(sin($w)*cos($eps) + cos($w)*sin($u)*sin($eps));
   $DeclDeg = Rad2Deg($w);

// --------------------------
// Compute Venus phase angle.
//
// Where:
// Rps = Venus to Sun distance
// Res = Earth to Sun distance
// Rep = Earth to Venus distance

   $u = $Rps*$Rps + $Rep*$Rep - $Res*$Res;
   $w = $u / (2*$Rps*$Rep);
   $PhAngDeg = Rad2Deg(acos($w));

// ---------------------------------------------
// Compute square and cube of phase angle value.

   $PhAng2   = $PhAngDeg*$PhAngDeg;
   $PhAng3   = $PhAngDeg*$PhAng2;

// -----------------------------------------------
// Compute illuminated fraction of planetary disc.
// Where:  New = 0.00   and   Full = 1.00

   $IllumFrac = (1 + $w) / 2;

// ---------------------------------------------
// Compute angular diameter of Venus in degrees.

   $AngDiamDeg = 8.41 / (1800 * $Rep);

// ----------------------------------
// Compute visual magnitude of Venus.

   $VisMag = 5*Log10($Rps * $Rep)
           + 0.0009*$PhAngDeg
           + 0.000239*$PhAng2
           - 0.00000065*$PhAng3
           - 4.4;

// ----------------------------------------------------------------
// Return the RA, declination, distance, phase angle, illum, visual
// magnitude and ecliptical longitude and latitude in a space-
// delimited string (exactly one single space between the elements).

   return "$RAHrs $DeclDeg $DistAU $AngDiamDeg $VisMag $PhAngDeg $IllumFrac $EclLonDeg $EclLatDeg";

} // End of  Geocentric_Venus()



?>


