
<?php

/*
   *********************************************************
   This program is a test/demo using the functions generated
   by The Multi-Language VSOP87 Source Code Generator Tool
   to help compute a basic geocentric equatorial Venus
   ephemeris built around VSOP87 series C.

   Author  : Jay Tanner - 2023
   License : Public Domain
   *********************************************************
*/

   $cYear = GMDate('Y'); // Current year UTC
   $DemoNum = 'Demo 2';

// Attach the required modules.
   Include_Once('VSOP87C-Venus-hXYZ.php');
   Include_Once('VSOP87C-Earth-hXYZ.php');
   Include_Once('VSOP87C-Geocentric-Equatorial-Venus.php');
   Include_Once('Utilities.php');

// -----------------------------------------
// Define demo date and time test arguments.
// These can be changed for experimentation.
// All input arguments are integer values.
//
// Default date and time = yn mn dn  HH:mm:ss = 1499 12 19  12:00:00
// Should return the following coordinates strings for Venus and Earth:
// -0.04567388896904 -0.72582381397933 -0.01057782927588 0.72733637578857
// -0.11472528482000 +0.97636452649026 -0.00000200035330 0.98308167492309

   $yn = 1499; // Year number
   $mn = 12;   // Month number (1  to 12)
   $dn = 19;   // Day number   (1  to 31)
   $HH = '12'; // Hours        (00 to 23)
   $mm = '00'; // Minutes      (00 to 59)
   $ss = '00'; // Seconds      (00 to 59)

// ------------------------------------------------
// Compute the Julian Day Number for the given date
// according to the default Gregorian calendar.

   $JDNum = GregorianToJD(IntVal($mn), IntVal($dn), IntVal($yn));
   $JGCal = 'Gregorian';

// ---------------------------------------------------------
// Check if (JDNum < 2299161) and if so, compute the Julian
// Day Number for the old-style Julian calendar instead.
//
// All JD Numbers for dates prior to 1582-Oct-15-Fri
// are < 2299161 and reckoned on the Julian calendar.

   if ($JDNum < 2299161)
      {
       $JDNum = JulianToJD(IntVal($mn), IntVal($dn), IntVal($yn));
       $JGCal = 'Julian';
      }

// --------------------------------------------
// Compute full Julian Date value for the given
// date and time (TT) elements and calendar mode.

   $JDTT = $JDNum - 0.5
         + (IntVal($HH)*3600 + IntVal($mm)*60 + IntVal($ss))/86400;

// -----------------------------------------
// Get 3-letter abbreviation for month name.

   $Mmm = ($JGCal == 'Julian')?
           JDMonthName($JDNum, CAL_MONTH_JULIAN_SHORT):
           JDMonthName($JDNum, CAL_MONTH_GREGORIAN_SHORT);

// -----------------------------------------------
// Get 3-letter abbreviation for day of week name.

   $DoW = JDDayOfWeek($JDNum, 2);

// -------------------------------------------------
// Call VSOP87 functions to compute the heliocentric
// rectangular X,Y,Z coordinates of Venus and Earth
// for the moment indicated by the JDTT argument.

   $VenusXYZR = Venus_C_hXYZR($JDTT);
   $EarthXYZR = Earth_C_hXYZR($JDTT);

// -----------------------------------------
// Compute the apparent geocentric ephemeris
// statistics for the planet Venus.

   $GeoVenusStats = Geocentric_Venus($JDTT);

// --------------------------------------------------
// Extract returned apparent geocentric coordinates
// and place them into their corresponding variables.

   list
  (
   $RAHrs,
   $DeclDeg,
   $DistAU,
   $AngDiamDeg,
   $VisMag,
   $PhAngDeg,
   $IllumFrac,
   $EclLonDeg,
   $EclLatDeg
  ) = Preg_Split("[ ]", $GeoVenusStats);


// ---------------------------------------
// Do some formatting for output neatness.

   $dd           = SPrintF("%02d", $dn);
   $JDTT         = SPrintF("%16.8f", $JDTT);
   $RAHMS        = Hours_to_HMS($RAHrs,   2, ''  ,'h');
   $RADeg        = SPrintF(" %14.10f", 15*$RAHrs);
   $RADMS        = Deg_to_DMS(15*$RAHrs, 2, '', 'd');
   $RAHrs        = SPrintF(" %13.10f", $RAHrs);
   $DeclDMS      = trim(Deg_to_DMS($DeclDeg, 2, '+' ,'d'));
   $DistMkm      = SPrintF("% 10.6f", $DistAU * 149.597870691);
   $DistMmi      = SPrintF("% 10.6f", $DistAU * 149597870.691/1609344);
   $DistAU       = SPrintF("%1.10f", $DistAU);

   $w            = Deg_to_DMS(trim($AngDiamDeg), 3, '' ,'d');
   $w            = substr($w, 9, StrLen($w));
   $AngDiamDMS   = Str_Replace("00' ",'', $w);

   $PhAngDeg     = SPrintF("%1.3f", $PhAngDeg);
   $IllumFracPct = SPrintF("%1.3f", 100*$IllumFrac);
   $VisMag       = SPrintF("%+1.2f", $VisMag);
   $EclLonDMS    = trim(Deg_to_DMS(trim($EclLonDeg), 2, ''  ,'d'));
   $EclLatDMS    = trim(Deg_to_DMS(trim($EclLatDeg), 2, '+' ,'d'));


// Construct output geocentric Venus ephemeris text block.
   $ApparentVenusCoords =
"===========================================================================
VSOP87C VENUS HELIOCENTRIC AND GEOCENTRIC EQUATORIAL EPHEMERIS STATISTICS
PHP $DemoNum by Jay Tanner - $cYear


For DATE:  yn Mmm dd DoW =  $yn $Mmm $dd $DoW ($JGCal Calendar)
and TIME:  HH:mm:ss      =  $HH:$mm:$ss TT

Julian Date Value =  $JDTT
Julian Day Number =  $JDNum


===========================================================================
RAW VSOP87C HELIOCENTRIC RECTANGULAR X,Y,Z COORDINATES AND DISTANCES IN AU

Venus hXYZR =
'$VenusXYZR'

Earth hXYZR =
'$EarthXYZR'


===========================================================================
APPARENT GEOCENTRIC EQUATORIAL VENUS EPHEMERIS STATISTICS CORRECTED FOR
PRECESSION, LIGHT-TIME, ABERRATION AND NUTATION (IAU 2000-B)

Right Ascension  = $RADeg&#176;
                 =  $RADMS
                 = $RAHrs h
                 =  $RAHMS

Declination      =  $DeclDeg&deg;
                 =  $DeclDMS

Distance         =  $DistAU AU
                 =  $DistMmi Mmi
                 =  $DistMkm Mkm

Angular Diameter =  $AngDiamDeg&deg;
                 =  $AngDiamDMS

Visual Magnitude =  $VisMag

Phase Angle      =  $PhAngDeg&deg;
Illum Fraction   =  $IllumFracPct%

Ecliptical Lon   =  $EclLonDeg&deg;
                 =  $EclLonDMS

Ecliptical Lat   =  $EclLatDeg&deg;
                 =  $EclLatDMS

===========================================================================











";


// ------------------------------
// Print the computed ephemeris
// statistics to client web page.

   print
"<!DOCTYPE HTML>
<HTML lang='en'>

<b><pre style='font-size:135%;'>
$ApparentVenusCoords
</pre></b>";







// ================================================
// This function computes the VSOP87C heliocentric
// XYZ-coordinates and distance of the planet Venus
// for the moment indicated by the JDTT argument.

  function Venus_C_hXYZR($JDTT)
{
// Time variable = Julian centuries offset from J2000
   $t = ($JDTT - 2451545) / 365250;

// -----------------------------------------------------
// Compute the heliocentric (X,Y,Z) coordinates of Venus
// by evaluating the 6 summation series for each of the
// coordinates.

// Evaluate Venus heliocentric X summations.
   $X = Venus_C_x0($t) + Venus_C_x1($t) + Venus_C_x2($t)
      + Venus_C_x3($t) + Venus_C_x4($t) + Venus_C_x5($t);

// Evaluate Venus heliocentric Y summations.
   $Y = Venus_C_y0($t) + Venus_C_y1($t) + Venus_C_y2($t)
      + Venus_C_y3($t) + Venus_C_y4($t) + Venus_C_y5($t);

// Evaluate Venus heliocentric Z summations.
   $Z = Venus_C_z0($t) + Venus_C_z1($t) + Venus_C_z2($t)
      + Venus_C_z3($t) + Venus_C_z4($t) + Venus_C_z5($t);

// Compute heliocentric radius vector (distance) in AU.
   $R = SqRt($X*$X + $Y*$Y + $Z*$Z);

// Format the computed values to 14 decimals.
   $X = trim(SPrintF("%+18.14f",$X));
   $Y = trim(SPrintF("%+18.14f",$Y));
   $Z = trim(SPrintF("%+18.14f",$Z));
   $R = trim(SPrintF("%18.14f",$R));

  return "$X $Y $Z $R";
}




// ================================================
// This function computes the VSOP87C heliocentric
// XYZ-coordinates and distance of the planet Earth
// for the moment indicated by the JDTT argument.

  function Earth_C_hXYZR($JDTT)
{
// Time variable = Julian centuries offset from J2000
   $t = ($JDTT - 2451545) / 365250;

// -----------------------------------------------------
// Compute the heliocentric (X,Y,Z) coordinates of Earth
// by evaluating the 6 summation series for each of the
// coordinates.

// Evaluate Earth heliocentric X summations.
   $X = Earth_C_x0($t) + Earth_C_x1($t) + Earth_C_x2($t)
      + Earth_C_x3($t) + Earth_C_x4($t) + Earth_C_x5($t);

// Evaluate Earth heliocentric Y summations.
   $Y = Earth_C_y0($t) + Earth_C_y1($t) + Earth_C_y2($t)
      + Earth_C_y3($t) + Earth_C_y4($t) + Earth_C_y5($t);

// Evaluate Earth heliocentric Z summations.
   $Z = Earth_C_z0($t) + Earth_C_z1($t) + Earth_C_z2($t)
      + Earth_C_z3($t) + Earth_C_z4($t) + Earth_C_z5($t);

// Compute heliocentric radius vector (distance) in AU.
   $R = SqRt($X*$X + $Y*$Y + $Z*$Z);

// Format the computed values to 14 decimals.
   $X = trim(SPrintF("%+18.14f",$X));
   $Y = trim(SPrintF("%+18.14f",$Y));
   $Z = trim(SPrintF("%+18.14f",$Z));
   $R = trim(SPrintF("%18.14f", $R));

  return "$X $Y $Z $R";
}





?>

