
<?php

/*
   ***********************************************************
   This program is a test/demo using the functions generated
   by The Multi-Language VSOP87 Source Code Generator Tool
   to help compute a basic geocentric equatorial Venus
   ephemeris built around VSOP87 series C.

   This program computes a basic apparent geocentric Venus
   ephemeris for any given month/year on the modern Gregorian
   calendar. (November 1583 and onward).

   Computations are for 00:00:00 TT on each date.

   It is a stand-alone program with the data built in and
   requires no external resources.

   Author  : Jay Tanner - 2023
   License : Public Domain
   ***********************************************************
*/

   $cYear = GMDate('Y'); // Current year (UTC).
   $DemoNum = 'Demo 4';

// -----------------------------------------
// Define demo year/month test arguments.
// These can be changed for experimentation.

   $yn = 1992; // Year number
   $mn = 12;   // Month number (1  to 12)


// -----------------------------------------------------
// Compute the Julian Day Number for beginning of the
// given year/month according to the Gregorian calendar.
//
// JDNum1 = JD Number of first day of given month.
// JDNum0 = JD Number of last day of previous month.
// mDays  = Days in given month.
// mName  = Full text of English month name.
// JGCal  = Calendar mode = 'Gregorian' = (FIXED DEFAULT).

   $JDNum0 = GregorianToJD(IntVal($mn), 1, IntVal($yn))-1;
   $JDNum1 = $JDNum0 + 1;
   $mDays  = Cal_Days_In_Month(CAL_GREGORIAN, IntVal($mn), IntVal($yn));
   $mName  = JDMonthName($JDNum1, CAL_MONTH_GREGORIAN_LONG);
   $JGCal  = 'Gregorian';

// ------------------------------------------
// Compute the apparent geocentric equatorial
// ephemeris table for the planet Venus at
// 00:00:00 TT on each date of the given
// month.

   $EphemTableBody = '';

   for ($day=1;   $day <= $mDays;   $day++)
{
// ----------------------------------------------
// Compute Julian Date for moment of computation.

   $JDTT = $JDNum0 - 0.5 + $day;

// -----------------------------------------------
// Compute current ephemeris line for Julian Date.

   $GeoVenusStats = Geocentric_Venus($JDTT);

// --------------------------------------------------
// Extract returned apparent geocentric coordinates
// and place them into their corresponding variables.

   list
  (
   $RAHrs,
   $DeclDeg,
   $DistAU,
   $AngDiamDeg,
   $VisMag,
   $PhAngDeg,
   $IllumFrac,
   $EclLonDeg,
   $EclLatDeg
  ) = Preg_Split("[ ]", $GeoVenusStats);

// ---------------------------------------
// Do some formatting for output neatness.

   $dd           = SPrintF("% 2d", $day);
   $JDTT         = SPrintF("%16.8f", $JDTT);
   $RAHMS        = Hours_to_HMS($RAHrs,   2, ''  ,'h');
   $RADeg        = SPrintF(" %14.10f", 15*$RAHrs);
   $RADMS        = Deg_to_DMS(15*$RAHrs, 2, '', 'd');
   $RAHrs        = SPrintF(" %13.10f", $RAHrs);
   $DeclDMS      = trim(Deg_to_DMS($DeclDeg, 2, '+' ,'d'));
   $DistMkm      = SPrintF("% 10.6f", $DistAU * 149.597870691);
   $DistMmi      = SPrintF("% 10.6f", $DistAU * 149597870.691/1609344);
   $DistAU       = SPrintF("%1.10f", $DistAU);

   $w            = Deg_to_DMS(trim($AngDiamDeg), 2, '' ,'d');
   $w            = substr($w, 9, StrLen($w));
   $AngDiamDMS   = Str_Replace("00' ",'', $w);

   $PhAngDeg     = SPrintF("%1.3f", $PhAngDeg);
   $IllumFracPct = SPrintF("%1.3f", 100*$IllumFrac);
   $VisMag       = SPrintF("%+1.2f", $VisMag);
   $EclLonDMS    = trim(Deg_to_DMS(trim($EclLonDeg), 2, ''  ,'d'));
   $EclLatDMS    = trim(Deg_to_DMS(trim($EclLatDeg), 2, '+' ,'d'));

// Append current line to ephemeris table.
   $EphemTableBody .= "$dd  $RAHMS  $DeclDMS  $DistAU  $VisMag  $AngDiamDMS\n";
}
   $EphemTableBody = RTrim($EphemTableBody);

// Construct output geocentric Venus ephemeris text block.
   $ApparentVenusEphemeris =
"VSOP87 Venus Ephemeris $DemoNum in PHP by Jay Tanner - $cYear

Output in  HH mm ss.sss  and  Deg&#176; mm&#39; ss.ss&#34; formats

=================================================================
VENUS
Apparent Geocentric Equatorial Ephemeris  For 00h TT on Each Date

Year  : $yn ($JGCal Calendar)
Month : $mName 1 to $mDays

=================================================================
Day      R.A.         Declination      Dist AU     V Mag  A Diam
=== ==============  ===============  ============  =====  =======
$EphemTableBody
=================================================================
































";


// ------------------------------
// Print the computed ephemeris
// statistics to client web page.

   print
"<!DOCTYPE HTML>
<HTML lang='en'>

<b><pre style='font-size:135%;'>
$ApparentVenusEphemeris
</pre></b>";


// ================================================
// This function computes the VSOP87C heliocentric
// XYZ-coordinates and distance of the planet Venus
// for the moment indicated by the JDTT argument.

  function Venus_C_hXYZR($JDTT)
{
// Time variable = Julian centuries offset from J2000
   $t = ($JDTT - 2451545) / 365250;

// -----------------------------------------------------
// Compute the heliocentric (X,Y,Z) coordinates of Venus
// by evaluating the 6 summation series for each of the
// coordinates.

// Evaluate Venus heliocentric X summations.
   $X = Venus_C_x0($t) + Venus_C_x1($t) + Venus_C_x2($t)
      + Venus_C_x3($t) + Venus_C_x4($t) + Venus_C_x5($t);

// Evaluate Venus heliocentric Y summations.
   $Y = Venus_C_y0($t) + Venus_C_y1($t) + Venus_C_y2($t)
      + Venus_C_y3($t) + Venus_C_y4($t) + Venus_C_y5($t);

// Evaluate Venus heliocentric Z summations.
   $Z = Venus_C_z0($t) + Venus_C_z1($t) + Venus_C_z2($t)
      + Venus_C_z3($t) + Venus_C_z4($t) + Venus_C_z5($t);

// Compute heliocentric radius vector (distance) in AU.
   $R = SqRt($X*$X + $Y*$Y + $Z*$Z);

// Format the computed values to 14 decimals.
   $X = trim(SPrintF("%+18.14f",$X));
   $Y = trim(SPrintF("%+18.14f",$Y));
   $Z = trim(SPrintF("%+18.14f",$Z));
   $R = trim(SPrintF("%18.14f",$R));

  return "$X $Y $Z $R";
}




// ================================================
// This function computes the VSOP87C heliocentric
// XYZ-coordinates and distance of the planet Earth
// for the moment indicated by the JDTT argument.

  function Earth_C_hXYZR($JDTT)
{
// Time variable = Julian centuries offset from J2000
   $t = ($JDTT - 2451545) / 365250;

// -----------------------------------------------------
// Compute the heliocentric (X,Y,Z) coordinates of Earth
// by evaluating the 6 summation series for each of the
// coordinates.

// Evaluate Earth heliocentric X summations.
   $X = Earth_C_x0($t) + Earth_C_x1($t) + Earth_C_x2($t)
      + Earth_C_x3($t) + Earth_C_x4($t) + Earth_C_x5($t);

// Evaluate Earth heliocentric Y summations.
   $Y = Earth_C_y0($t) + Earth_C_y1($t) + Earth_C_y2($t)
      + Earth_C_y3($t) + Earth_C_y4($t) + Earth_C_y5($t);

// Evaluate Earth heliocentric Z summations.
   $Z = Earth_C_z0($t) + Earth_C_z1($t) + Earth_C_z2($t)
      + Earth_C_z3($t) + Earth_C_z4($t) + Earth_C_z5($t);

// Compute heliocentric radius vector (distance) in AU.
   $R = SqRt($X*$X + $Y*$Y + $Z*$Z);

// Format the computed values to 14 decimals.
   $X = trim(SPrintF("%+18.14f",$X));
   $Y = trim(SPrintF("%+18.14f",$Y));
   $Z = trim(SPrintF("%+18.14f",$Z));
   $R = trim(SPrintF("%18.14f", $R));

  return "$X $Y $Z $R";
}




/*
 ----------------------------------------------------------------------------
 Hard-Coded PHP Implementation of the VSOP87 Theory - Series Version C

 Body Name              : Earth
 VSOP87 Series Version  : C
 Coordinates Type/Epoch : Rectangular XYZ-Coordinates
                          HELIOCENTRIC DYNAMICAL ECLIPTIC/EQUINOX OF DATE

 Ephemeris Date Span    : 2000 BC < Date < 6000 AD

 These functions collectively compute the rectangular space-time coordinates
 of the planet Earth according to the VSOP87 theory, series version C.

 JDTT = Standard Julian Date (JD) for any given moment on the TT scale.

    t = Julian millennia reckoned from J2000 (2000-Jan-01-Sat 12:00:00 TT)
      = (JDTT - 2451545.0) / 365250

 Source Code Generator Author:
 Jay Tanner - 2023

 License:
 This PHP program source code is released to the public domain.
 ----------------------------------------------------------------------------
*/


   function Earth_C_X0 ($t)
{
  $X0 =  0.0;
  $X0 += 0.99986069925 * cos(1.75347045757 + 6283.3196674749*$t);
  $X0 += 0.02506324281 * cos(4.93819429098 + 0.2438174835*$t);
  $X0 += 0.00835274807 * cos(1.71033525539 + 12566.3955174663*$t);
  $X0 += 0.00010466796 * cos(1.66721984219 + 18849.4713674577*$t);
  $X0 += 0.00003490608 * cos(4.44373803231 + 6282.83203250789*$t);
  $X0 += 0.00003110838 * cos(0.66875189331 + 83997.09113559539*$t);
  $X0 += 0.00002561408 * cos(0.58588607490 + 529.9347825781*$t);
  $X0 += 0.00002142365 * cos(1.09204474884 + 1577.0997249643*$t);
  $X0 += 0.00001709161 * cos(0.49540863237 + 6279.7965491259*$t);
  $X0 += 0.00001707934 * cos(6.15314019418 + 6286.84278582391*$t);
  $X0 += 0.00001442753 * cos(3.47210398336 + 2353.1099712553*$t);
  $X0 += 0.00001113027 * cos(3.69621650479 + 5223.4501023187*$t);
  $X0 += 0.00000934484 * cos(6.07385378286 + 12036.7045523717*$t);
  $X0 += 0.00000899854 * cos(3.17607463681 + 10213.5293636945*$t);
  $X0 += 0.00000566820 * cos(2.15241946891 + 1059.6257476727*$t);
  $X0 += 0.00000661858 * cos(1.31175222119 + 5753.6287023803*$t);
  $X0 += 0.00000739644 * cos(4.36662524112 + 398.3928208917*$t);
  $X0 += 0.00000681381 * cos(2.21815397940 + 4705.9761250271*$t);
  $X0 += 0.00000611293 * cos(5.38470180335 + 6813.0106325695*$t);
  $X0 += 0.00000451129 * cos(6.09315891204 + 5885.1706640667*$t);
  $X0 += 0.00000451985 * cos(1.27931036318 + 6257.0213476751*$t);
  $X0 += 0.00000449743 * cos(5.36941929064 + 6309.61798727471*$t);
  $X0 += 0.00000406291 * cos(0.54369369385 + 6681.46867088311*$t);
  $X0 += 0.00000541115 * cos(0.78670634299 + 775.7664288075*$t);
  $X0 += 0.00000546682 * cos(1.46109463961 + 14143.7390599141*$t);
  $X0 += 0.00000513780 * cos(4.43695037790 + 7860.6632099227*$t);
  $X0 += 0.00000263916 * cos(5.39551752630 + 5507.7970561509*$t);
  $X0 += 0.00000217220 * cos(4.51265697015 + 11507.0135872771*$t);
  $X0 += 0.00000292146 * cos(2.51372357301 + 5507.3094211839*$t);
  $X0 += 0.00000227915 * cos(1.23940916733 + 7058.8422787989*$t);
  $X0 += 0.00000226835 * cos(3.27356345008 + 4693.75913722409*$t);
  $X0 += 0.00000255833 * cos(2.26545070197 + 12168.2465140581*$t);
  $X0 += 0.00000256157 * cos(1.45478864804 + 710.1768660418*$t);
  $X0 += 0.00000178679 * cos(2.96645630109 + 796.5418242999*$t);
  $X0 += 0.00000178303 * cos(0.40472561766 + 6283.25235717211*$t);
  $X0 += 0.00000178303 * cos(6.24380795499 + 6283.3869777777*$t);
  $X0 += 0.00000155471 * cos(1.62414733243 + 25132.5472174491*$t);
  $X0 += 0.00000155246 * cos(1.41969109555 + 5487.0216606585*$t);
  $X0 += 0.00000207640 * cos(5.85326148962 + 11790.8729061423*$t);
  $X0 += 0.00000199988 * cos(4.07216830110 + 17790.08943726851*$t);
  $X0 += 0.00000128970 * cos(5.21698329136 + 7079.61767429131*$t);
  $X0 += 0.00000128155 * cos(4.80258701251 + 3739.0052475915*$t);
  $X0 += 0.00000152241 * cos(0.86901699174 + 213.5429129215*$t);
  $X0 += 0.00000078109 * cos(1.84890519772 + 8827.6340873583*$t);
  $X0 += 0.00000073503 * cos(2.69517697923 + 1589.3167127673*$t);
  $X0 += 0.00000093001 * cos(3.93777887053 + 9437.5191174035*$t);
  $X0 += 0.00000065526 * cos(3.65568333160 + 11770.0975106499*$t);
  $X0 += 0.00000063240 * cos(2.24124127597 + 6262.5442719825*$t);
  $X0 += 0.00000062961 * cos(4.40729385308 + 6304.0950629673*$t);
  $X0 += 0.00000085870 * cos(3.02430778985 + 167284.00540514899*$t);
  $X0 += 0.00000083233 * cos(6.19780778434 + 3340.8562441833*$t);
  $X0 += 0.00000062850 * cos(2.03823135444 + 7.3573644843*$t);
  $X0 += 0.00000079971 * cos(2.49335782552 + 6070.0205720369*$t);
  $X0 += 0.00000060043 * cos(3.39955163445 + 4137.1542509997*$t);
  $X0 += 0.00000075613 * cos(4.15948190002 + 6496.6187629129*$t);
  $X0 += 0.00000053731 * cos(1.56268892040 + 1194.6908277081*$t);
  $X0 += 0.00000057574 * cos(3.96971590315 + 6284.2999885431*$t);
  $X0 += 0.00000057574 * cos(2.67881766950 + 6282.3393464067*$t);
  $X0 += 0.00000072385 * cos(4.85114866885 + 10976.83498721549*$t);
  $X0 += 0.00000051135 * cos(1.31237333336 + 6290.4332144757*$t);
  $X0 += 0.00000050604 * cos(5.34520074613 + 6276.2061204741*$t);
  $X0 += 0.00000049613 * cos(2.64370047145 + 6127.8992680407*$t);
  $X0 += 0.00000048009 * cos(4.00571885519 + 6438.7400669091*$t);
  $X0 += 0.00000059233 * cos(3.78322753249 + 3154.4432674121*$t);
  $X0 += 0.00000048264 * cos(4.77126143981 + 801.5771136403*$t);
  $X0 += 0.00000047368 * cos(6.10696378485 + 3128.6325825793*$t);
  $X0 += 0.00000039225 * cos(3.25281924495 + 8429.4850839501*$t);
  $X0 += 0.00000051307 * cos(5.78448747277 + 12353.0964220283*$t);
  $X0 += 0.00000050639 * cos(2.05215225623 + 11856.462468908*$t);
  $X0 += 0.00000039555 * cos(4.93022654622 + 5481.4987363511*$t);
  $X0 += 0.00000042757 * cos(3.64063452002 + 17260.3984721739*$t);
  $X0 += 0.00000048941 * cos(0.45355151773 + 9225.7830907665*$t);
  $X0 += 0.00000048302 * cos(0.60366334071 + 2544.07060239989*$t);
  $X0 += 0.00000037971 * cos(3.04093006964 + 426.8420083595*$t);
  $X0 += 0.00000043643 * cos(3.14688065147 + 5856.23384163189*$t);
  $X0 += 0.00000031830 * cos(2.00885127406 + 2145.92159899169*$t);
  $X0 += 0.00000033959 * cos(1.72230567102 + 7085.1405985987*$t);
  $X0 += 0.00000030184 * cos(3.96882361878 + 10977.32262218251*$t);
  $X0 += 0.00000032562 * cos(2.84647033523 + 4164.0681721295*$t);
  $X0 += 0.00000038887 * cos(5.36022568355 + 13367.7288136231*$t);
  $X0 += 0.00000028515 * cos(6.10933021457 + 12569.91863581531*$t);
  $X0 += 0.00000028873 * cos(1.01228967614 + 3930.4535137031*$t);
  $X0 += 0.00000036633 * cos(2.90798803424 + 18073.9487561337*$t);
  $X0 += 0.00000024984 * cos(2.17919076736 + 26.0545023163*$t);
  $X0 += 0.00000026364 * cos(0.54621601823 + 9438.0067523705*$t);
  $X0 += 0.00000030326 * cos(1.99372292658 + 4535.3032544079*$t);
  $X0 += 0.00000028166 * cos(0.48127325062 + 12562.8723991173*$t);
  $X0 += 0.00000028001 * cos(2.82603231075 + 5088.8726572503*$t);
  $X0 += 0.00000021157 * cos(5.07256589577 + 11371.9485072417*$t);
  $X0 += 0.00000023113 * cos(0.85996930170 + 5223.93773728571*$t);
  $X0 += 0.00000021642 * cos(4.63524157818 + 12559.2819704655*$t);
  $X0 += 0.00000019448 * cos(4.40136974621 + 12565.9078824993*$t);
  $X0 += 0.00000026055 * cos(0.30340363466 + 71430.45180064559*$t);
  $X0 += 0.00000018232 * cos(3.41362095130 + 1747.7725955835*$t);
  $X0 += 0.00000023248 * cos(6.19009992884 + 18319.7804023631*$t);
  $X0 += 0.00000022785 * cos(1.16821848960 + 5753.14106741329*$t);
  $X0 += 0.00000017091 * cos(0.58584172932 + 4933.4522578161*$t);
  $X0 += 0.00000019399 * cos(4.43188457477 + 10447.14402212089*$t);
  $X0 += 0.00000021067 * cos(3.80033599994 + 7477.7666776995*$t);
  $X0 += 0.00000021310 * cos(4.65919931667 + 8031.3360805419*$t);
  $X0 += 0.00000014189 * cos(1.30988546287 + 2942.7072407751*$t);
  $X0 += 0.00000013864 * cos(4.59350621319 + 8636.18582124671*$t);
  $X0 += 0.00000018884 * cos(2.42694418444 + 156137.71980228279*$t);
  $X0 += 0.00000017875 * cos(0.15660631596 + 1592.8398311163*$t);
  $X0 += 0.00000018602 * cos(0.50024326019 + 17297.9385098427*$t);
  $X0 += 0.00000013605 * cos(5.19720916665 + 13096.0864825609*$t);
  $X0 += 0.00000015064 * cos(3.12148038350 + 16496.6052136859*$t);
  $X0 += 0.00000012969 * cos(6.06491705231 + 7633.1870771337*$t);
  $X0 += 0.00000014403 * cos(1.43725922780 + 20426.8149099055*$t);
  $X0 += 0.00000013311 * cos(3.60732173221 + 12139.7973265903*$t);
  $X0 += 0.00000013645 * cos(5.14981984839 + 13368.2164485901*$t);
  $X0 += 0.00000011583 * cos(5.46063496654 + 5331.6012612243*$t);
  $X0 += 0.00000011405 * cos(4.40016025355 + 529.44714761109*$t);
  $X0 += 0.00000015057 * cos(5.21434071429 + 7084.6529636317*$t);
  $X0 += 0.00000014330 * cos(6.02775140319 + 7342.7015976641*$t);
  $X0 += 0.00000012375 * cos(3.10941922715 + 6279.72923882311*$t);
  $X0 += 0.00000012366 * cos(3.53911446993 + 6286.9100961267*$t);
  $X0 += 0.00000010016 * cos(2.24542867964 + 397.9051859247*$t);
  $X0 += 0.00000012435 * cos(1.06626484546 + 15110.7099373497*$t);
  $X0 += 0.00000009513 * cos(1.19056065248 + 7235.0380737255*$t);
  $X0 += 0.00000010997 * cos(2.19198404583 + 10989.0519750185*$t);
  $X0 += 0.00000011583 * cos(4.05250824543 + 5729.7502646325*$t);
  $X0 += 0.00000009034 * cos(5.42875830514 + 9623.9320941747*$t);
  $X0 += 0.00000011842 * cos(4.16957446176 + 15721.0826023619*$t);
  $X0 += 0.00000008869 * cos(5.04690919891 + 6148.2545874395*$t);
  $X0 += 0.00000008614 * cos(1.60161199451 + 6418.38474751031*$t);
  $X0 += 0.00000010312 * cos(2.59789642414 + 6836.8890703173*$t);
  $X0 += 0.00000008411 * cos(2.44368872285 + 14712.5609339415*$t);
  $X0 += 0.00000007911 * cos(3.15428722892 + 2119.00767786191*$t);
  $X0 += 0.00000010379 * cos(4.81870974023 + 1349.62359217529*$t);
  $X0 += 0.00000010374 * cos(2.40569215505 + 5486.53402569149*$t);
  $X0 += 0.00000010480 * cos(2.95288921695 + 5999.4603486097*$t);
  $X0 += 0.00000007404 * cos(5.41419049870 + 6040.5910635009*$t);
  $X0 += 0.00000007357 * cos(3.83057351958 + 5088.3850222833*$t);
  $X0 += 0.00000009820 * cos(3.69556241034 + 6567.1789863401*$t);
  $X0 += 0.00000007018 * cos(1.23420241153 + 6526.04827144891*$t);
  $X0 += 0.00000009668 * cos(1.92238869394 + 21228.1482060623*$t);
  $X0 += 0.00000007545 * cos(1.23604547808 + 12540.0971976665*$t);
  $X0 += 0.00000007202 * cos(5.88391537700 + 6245.2919948391*$t);
  $X0 += 0.00000007144 * cos(0.76464656573 + 6321.3473401107*$t);
  $X0 += 0.00000008883 * cos(3.89630774866 + 5642.93474619389*$t);
  $X0 += 0.00000006626 * cos(0.70123567856 + 5327.7199258663*$t);
  $X0 += 0.00000007015 * cos(4.13622360700 + 7860.17557495569*$t);
  $X0 += 0.00000006159 * cos(0.94592300466 + 12964.5445208745*$t);
  $X0 += 0.00000007413 * cos(5.03498725246 + 23543.4743221653*$t);
  $X0 += 0.00000006355 * cos(5.03541099132 + 1990.9888345245*$t);
  $X0 += 0.00000007286 * cos(3.58219614228 + 537.0483295789*$t);
  $X0 += 0.00000006314 * cos(6.22485628824 + 951.4745887671*$t);
  $X0 += 0.00000006257 * cos(4.23208117686 + 4690.7236538421*$t);
  $X0 += 0.00000006484 * cos(3.20813291319 + 16730.70750707931*$t);
  $X0 += 0.00000005803 * cos(6.09476150956 + 955.3559241251*$t);
  $X0 += 0.00000006391 * cos(3.97601526750 + 24073.1652872599*$t);
  $X0 += 0.00000007530 * cos(0.20298795021 + 10973.7995038335*$t);
  $X0 += 0.00000006921 * cos(0.69969701816 + 522.8212355773*$t);
  $X0 += 0.00000007626 * cos(4.29336813013 + 22004.1584523533*$t);
  $X0 += 0.00000007531 * cos(3.51464444079 + 18422.8731765817*$t);
  $X0 += 0.00000006902 * cos(2.75534627331 + 155.17658195069*$t);
  $X0 += 0.00000005434 * cos(5.94625981048 + 7238.9194090835*$t);
  $X0 += 0.00000006223 * cos(2.24396249102 + 18451.3223640495*$t);
  $X0 += 0.00000007296 * cos(5.98982040270 + 16730.21987211229*$t);
  $X0 += 0.00000005833 * cos(2.32930728499 + 640.1411037975*$t);
  $X0 += 0.00000007171 * cos(6.14759594277 + 3929.96587873609*$t);
  $X0 += 0.00000006251 * cos(2.19374266424 + 6277.7967431675*$t);
  $X0 += 0.00000006251 * cos(4.45479090841 + 6288.8425917823*$t);
  $X0 += 0.00000005683 * cos(3.49552871951 + 1551.2890401315*$t);
  $X0 += 0.00000006383 * cos(0.64667497225 + 5216.33655531789*$t);
  $X0 += 0.00000006194 * cos(3.56522608256 + 5230.5636493195*$t);
  $X0 += 0.00000005036 * cos(3.83694551305 + 14314.4119305333*$t);
  $X0 += 0.00000006774 * cos(1.99358309023 + 102.84895673509*$t);
  $X0 += 0.00000006224 * cos(0.35231413534 + 11014.8626598513*$t);
  $X0 += 0.00000004621 * cos(1.34668136864 + 553.32558535889*$t);
  $X0 += 0.00000006293 * cos(2.32035231613 + 5650.5359281617*$t);
  $X0 += 0.00000006297 * cos(4.40170593853 + 26088.1469590577*$t);
  $X0 += 0.00000005186 * cos(0.71187314766 + 77714.01528560399*$t);
  $X0 += 0.00000006196 * cos(2.58705857336 + 84672.23202702119*$t);
  $X0 += 0.00000006160 * cos(4.78250009298 + 239424.63407183639*$t);
  $X0 += 0.00000005414 * cos(2.99961957880 + 6180.2268932563*$t);
  $X0 += 0.00000005413 * cos(3.65415218952 + 6386.4124416935*$t);
  $X0 += 0.00000004863 * cos(3.76722359858 + 90280.16698558679*$t);
  $X0 += 0.00000005711 * cos(4.32712250291 + 6916.1034067881*$t);
  $X0 += 0.00000005150 * cos(4.10583483822 + 1577.5873599313*$t);
  $X0 += 0.00000004269 * cos(2.38358764863 + 7875.91568110771*$t);
  $X0 += 0.00000004017 * cos(3.78580903100 + 6254.8704800071*$t);
  $X0 += 0.00000004069 * cos(2.42056660765 + 3634.37720703489*$t);
  $X0 += 0.00000003993 * cos(2.86272128776 + 6311.7688549427*$t);
  $X0 += 0.00000004016 * cos(5.24041079205 + 4690.23601887509*$t);
  $X0 += 0.00000005290 * cos(3.34482936009 + 25158.3579022819*$t);
  $X0 += 0.00000004831 * cos(2.83916520281 + 5760.7422493811*$t);
  $X0 += 0.00000003487 * cos(3.51068129706 + 10447.6316570879*$t);
  $X0 += 0.00000004120 * cos(3.29656037233 + 6709.91785835091*$t);
  $X0 += 0.00000004410 * cos(3.80589939396 + 6805.89708556871*$t);
  $X0 += 0.00000004023 * cos(6.22474978871 + 4731.7868098599*$t);
  $X0 += 0.00000003980 * cos(3.31931976159 + 5856.7214765989*$t);
  $X0 += 0.00000003173 * cos(5.19128151293 + 1066.7392946735*$t);
  $X0 += 0.00000003293 * cos(4.01637480858 + 9917.45305702629*$t);
  $X0 += 0.00000002935 * cos(3.67590980046 + 12592.6938372661*$t);
  $X0 += 0.00000002979 * cos(6.20067573402 + 12566.4628277691*$t);
  $X0 += 0.00000003980 * cos(1.19681754169 + 13341.9181287903*$t);
  $X0 += 0.00000003892 * cos(5.52571426134 + 75.0254160508*$t);
  $X0 += 0.00000003042 * cos(3.19425693799 + 18053.1733606413*$t);
  $X0 += 0.00000003608 * cos(5.60952778146 + 6208.5380689076*$t);
  $X0 += 0.00000003721 * cos(5.22104546686 + 5966.9277978183*$t);
  $X0 += 0.00000003581 * cos(1.03995231220 + 6358.1012660422*$t);
  $X0 += 0.00000002880 * cos(1.61225556126 + 10575.6505004253*$t);
  $X0 += 0.00000002806 * cos(4.21551614220 + 5863.8350235997*$t);
  $X0 += 0.00000003626 * cos(1.42632163253 + 6599.7115371315*$t);
  $X0 += 0.00000002794 * cos(5.69269191706 + 8030.8484455749*$t);
  $X0 += 0.00000002729 * cos(4.17319557124 + 3.76693583251*$t);
  $X0 += 0.00000003625 * cos(3.00192313835 + 6020.2357441021*$t);
  $X0 += 0.00000003206 * cos(2.15397091751 + 11506.52595231009*$t);
  $X0 += 0.00000003556 * cos(4.28947576556 + 8428.9974489831*$t);
  $X0 += 0.00000002856 * cos(3.33625143564 + 12721.8159169005*$t);
  $X0 += 0.00000002611 * cos(2.43261867894 + 6702.8043113501*$t);
  $X0 += 0.00000002535 * cos(1.58310702384 + 31415.6230674405*$t);
  $X0 += 0.00000003520 * cos(5.37986371510 + 250570.91967470259*$t);
  $X0 += 0.00000003434 * cos(3.64656923781 + 6546.4035908477*$t);
  $X0 += 0.00000002572 * cos(4.79831420582 + 5884.68302909969*$t);
  $X0 += 0.00000002647 * cos(3.81972272861 + 2352.6223362883*$t);
  $X0 += 0.00000003026 * cos(5.24078074980 + 13916.2629271251*$t);
  $X0 += 0.00000002378 * cos(3.62833713669 + 2389.1378379327*$t);
  $X0 += 0.00000002979 * cos(0.36159339669 + 12566.32820716351*$t);
  $X0 += 0.00000003082 * cos(1.77514222265 + 14945.0723560709*$t);
  $X0 += 0.00000002716 * cos(3.06935389211 + 12029.5910053709*$t);
  $X0 += 0.00000002215 * cos(5.26643739208 + 13362.6935242827*$t);
  $X0 += 0.00000003032 * cos(4.76553829426 + 29088.5675985015*$t);
  $X0 += 0.00000002421 * cos(3.15326621321 + 11015.3502948183*$t);
  $X0 += 0.00000002275 * cos(5.95465292259 + 6077.1341190377*$t);
  $X0 += 0.00000002466 * cos(5.59166943387 + 16200.52890701769*$t);
  $X0 += 0.00000002529 * cos(5.94709131586 + 12043.8180993725*$t);
  $X0 += 0.00000002015 * cos(2.48432239832 + 6262.96434807611*$t);
  $X0 += 0.00000002218 * cos(0.69324011482 + 6489.5052159121*$t);
  $X0 += 0.00000002005 * cos(4.16423892775 + 6303.6749868737*$t);
  $X0 += 0.00000002010 * cos(4.11254992503 + 4700.87268422489*$t);
  $X0 += 0.00000002641 * cos(4.28275048815 + 4590.6663630055*$t);
  $X0 += 0.00000002438 * cos(6.12910205560 + 149.8070146181*$t);
  $X0 += 0.00000001893 * cos(0.98057464900 + 6279.4383321169*$t);
  $X0 += 0.00000001893 * cos(5.66795892365 + 6287.2010028329*$t);
  $X0 += 0.00000002156 * cos(2.00902236290 + 18139.5383188994*$t);
  $X0 += 0.00000002071 * cos(4.32179144410 + 11926.4982311523*$t);
  $X0 += 0.00000002395 * cos(0.13148357341 + 1162.7185218913*$t);
  $X0 += 0.00000001954 * cos(0.37275781655 + 13518.1139237169*$t);
  $X0 += 0.00000002006 * cos(0.31048315304 + 3154.9309023791*$t);
  $X0 += 0.00000001776 * cos(0.14855204887 + 13521.9952590749*$t);
  $X0 += 0.00000001964 * cos(0.25103153440 + 4686.6455902233*$t);
  $X0 += 0.00000002332 * cos(4.40649103371 + 10022.0810975829*$t);
  $X0 += 0.00000001863 * cos(5.26030609599 + 242.97242145751*$t);
  $X0 += 0.00000001928 * cos(4.59250450967 + 5746.5151553795*$t);
  $X0 += 0.00000002436 * cos(4.40770823480 + 95143.37673846159*$t);
  $X0 += 0.00000002163 * cos(1.41797907369 + 6037.4880212455*$t);
  $X0 += 0.00000002250 * cos(2.39728922664 + 12669.4882916849*$t);
  $X0 += 0.00000002052 * cos(5.23006608728 + 6529.1513137043*$t);
  $X0 += 0.00000001886 * cos(3.61213584641 + 7238.4317741165*$t);
  $X0 += 0.00000002170 * cos(5.49596575387 + 19651.2922985815*$t);
  $X0 += 0.00000002058 * cos(4.69821533065 + 23013.7833570707*$t);
  $X0 += 0.00000001774 * cos(2.08482289391 + 6820.1241795703*$t);
  $X0 += 0.00000001841 * cos(0.34653293659 + 65147.37595065419*$t);
  $X0 += 0.00000001578 * cos(5.64311385009 + 4292.5746504339*$t);
  $X0 += 0.00000001577 * cos(0.80779559190 + 7632.6994421667*$t);
  $X0 += 0.00000001541 * cos(1.80359816798 + 13119.9649203087*$t);
  $X0 += 0.00000002012 * cos(0.36995312887 + 4292.0870154669*$t);
  $X0 += 0.00000001543 * cos(0.68755069426 + 6293.95633282471*$t);
  $X0 += 0.00000001543 * cos(5.96098287839 + 6272.6830021251*$t);
  $X0 += 0.00000001513 * cos(0.65061890512 + 20.5315780089*$t);
  $X0 += 0.00000001489 * cos(2.95205535091 + 110.45013870291*$t);
  $X0 += 0.00000001639 * cos(4.44076102657 + 17655.0243572331*$t);
  $X0 += 0.00000001443 * cos(2.26329309493 + 1052.51220067191*$t);
  $X0 += 0.00000001337 * cos(3.06401553951 + 2544.5582373669*$t);
  $X0 += 0.00000001797 * cos(6.18654785499 + 33018.7772947211*$t);
  $X0 += 0.00000001488 * cos(5.67450527487 + 76.50988875911*$t);
  $X0 += 0.00000001453 * cos(5.46078654600 + 633.0275567967*$t);
  $X0 += 0.00000001349 * cos(5.75097749599 + 6016.7126257531*$t);
  $X0 += 0.00000001477 * cos(4.14004774348 + 12779.6946129043*$t);
  $X0 += 0.00000001688 * cos(3.20087734666 + 18875.2820522905*$t);
  $X0 += 0.00000001491 * cos(6.22974184712 + 9411.7084325707*$t);
  $X0 += 0.00000001471 * cos(5.75779240419 + 18636.1722720197*$t);
  $X0 += 0.00000001263 * cos(0.91728971350 + 12573.5090644671*$t);
  $X0 += 0.00000001685 * cos(5.70877589839 + 25934.3681485729*$t);
  $X0 += 0.00000001375 * cos(1.08927160683 + 2378.9206560881*$t);
  $X0 += 0.00000001641 * cos(6.27664360507 + 6.86972951729*$t);
  $X0 += 0.00000001200 * cos(1.47556274227 + 11499.9000402763*$t);
  $X0 += 0.00000001272 * cos(0.89738913067 + 6549.9267091967*$t);
  $X0 += 0.00000001214 * cos(1.22660393299 + 10973.3118688665*$t);
  $X0 += 0.00000001406 * cos(5.67596795657 + 11790.3852711753*$t);
  $X0 += 0.00000001524 * cos(4.27066787572 + 18209.5740811437*$t);
  $X0 += 0.00000001149 * cos(3.01961706159 + 10177.5014970171*$t);
  $X0 += 0.00000001547 * cos(4.02915828753 + 11926.01059618529*$t);
  $X0 += 0.00000001460 * cos(4.97235137781 + 246.0754637129*$t);
  $X0 += 0.00000001323 * cos(1.38571450422 + 8661.9965060795*$t);
  $X0 += 0.00000001252 * cos(1.41166880118 + 6993.2527160332*$t);
  $X0 += 0.00000001459 * cos(5.29807880334 + 38.3768531213*$t);
  $X0 += 0.00000001235 * cos(2.84096519816 + 24357.0246061251*$t);
  $X0 += 0.00000001028 * cos(2.51029997292 + 6112.6467968557*$t);
  $X0 += 0.00000001330 * cos(1.00065727327 + 2146.4092339587*$t);
  $X0 += 0.00000001312 * cos(1.10091584033 + 12491.613918899*$t);
  $X0 += 0.00000001246 * cos(4.66430542078 + 5429.63565075589*$t);
  $X0 += 0.00000000992 * cos(4.13817744468 + 6453.9925380941*$t);
  $X0 += 0.00000000988 * cos(0.97969587833 + 8274.0646845159*$t);
  $X0 += 0.00000001365 * cos(6.11146862666 + 11371.4608722747*$t);
  $X0 += 0.00000001020 * cos(2.82319817767 + 4732.2744448269*$t);
  $X0 += 0.00000001191 * cos(3.43008039922 + 6290.36590417291*$t);
  $X0 += 0.00000001191 * cos(3.21845317343 + 6276.2734307769*$t);
  $X0 += 0.00000000978 * cos(4.73852758176 + 6247.2918007975*$t);
  $X0 += 0.00000000971 * cos(1.91000724147 + 6319.34753415231*$t);
  $X0 += 0.00000000962 * cos(2.63568544853 + 12565.4151963981*$t);
  $X0 += 0.00000001025 * cos(2.21768401152 + 12545.6201219739*$t);
  $X0 += 0.00000000990 * cos(0.39039931315 + 4694.2467721911*$t);
  $X0 += 0.00000000964 * cos(1.79192739930 + 3893.93801205869*$t);
  $X0 += 0.00000000944 * cos(5.86379546667 + 6259.44122972711*$t);
  $X0 += 0.00000000944 * cos(0.78473810598 + 6307.1981052227*$t);
  $X0 += 0.00000001092 * cos(3.92065202481 + 17797.2029842693*$t);
  $X0 += 0.00000001132 * cos(1.00628522970 + 17782.9758902677*$t);
  $X0 += 0.00000000859 * cos(1.48109589441 + 1692.40948698591*$t);
  $X0 += 0.00000001213 * cos(4.04235990086 + 82576.73740351178*$t);
  $X0 += 0.00000000942 * cos(5.22790737110 + 6298.57213865991*$t);
  $X0 += 0.00000000942 * cos(1.42062620155 + 6268.0671962899*$t);
  $X0 += 0.00000001045 * cos(0.46195584294 + 15508.8589407579*$t);
  $X0 += 0.00000000851 * cos(5.19678367921 + 6173.1133462555*$t);
  $X0 += 0.00000000850 * cos(1.45204280805 + 6393.5259886943*$t);
  $X0 += 0.00000000895 * cos(2.40089211752 + 3904.1551939033*$t);
  $X0 += 0.00000001020 * cos(0.71539416375 + 220.6564599223*$t);
  $X0 += 0.00000000845 * cos(5.75499771232 + 17256.8753538249*$t);
  $X0 += 0.00000000863 * cos(4.43158774725 + 949.4194264533*$t);
  $X0 += 0.00000000853 * cos(2.75614337272 + 16201.0165419847*$t);
  $X0 += 0.00000000811 * cos(6.13459778682 + 4803.9654584435*$t);
  $X0 += 0.00000000966 * cos(4.14597367445 + 206.42936592071*$t);
  $X0 += 0.00000000917 * cos(2.47007329129 + 149854.64395229139*$t);
  $X0 += 0.00000001083 * cos(1.32514794865 + 36948.9869909407*$t);
  $X0 += 0.00000000779 * cos(3.58339682996 + 2648.6986429565*$t);
  $X0 += 0.00000000964 * cos(0.77431665261 + 796.0541893329*$t);
  $X0 += 0.00000000995 * cos(0.25423339373 + 11403.9208130585*$t);
  $X0 += 0.00000000962 * cos(3.92658368218 + 12567.37583853451*$t);
  $X0 += 0.00000000779 * cos(0.45683397157 + 10213.0417287275*$t);
  $X0 += 0.00000000980 * cos(4.62590378445 + 22805.4917485101*$t);
  $X0 += 0.00000000930 * cos(2.22316684933 + 2787.2868413409*$t);
  $X0 += 0.00000000829 * cos(5.09643797682 + 5120.35732810009*$t);
  $X0 += 0.00000000733 * cos(2.60949856930 + 10575.1628654583*$t);
  $X0 += 0.00000000743 * cos(3.79905998257 + 7834.3648901229*$t);
  $X0 += 0.00000000818 * cos(1.64368328490 + 5572.8989839496*$t);
  $X0 += 0.00000000905 * cos(3.81538816339 + 6284.8041401832*$t);
  $X0 += 0.00000000905 * cos(2.83314540925 + 6281.8351947666*$t);
  $X0 += 0.00000000798 * cos(2.62501051906 + 12410.9751180321*$t);
  $X0 += 0.00000000817 * cos(0.52083502825 + 12416.8323203317*$t);
  $X0 += 0.00000000884 * cos(0.84319899817 + 22483.60475700909*$t);
  $X0 += 0.00000000755 * cos(3.82941056281 + 4060.97539791089*$t);
  $X0 += 0.00000000651 * cos(3.93683821152 + 17259.91083720689*$t);
  $X0 += 0.00000000616 * cos(5.70474451820 + 1596.43025976811*$t);
  $X0 += 0.00000000651 * cos(2.41491885723 + 1748.2602305505*$t);
  $X0 += 0.00000000723 * cos(3.06743374106 + 161000.92955515759*$t);
  $X0 += 0.00000000784 * cos(0.87758060898 + 4907.05823266209*$t);
  $X0 += 0.00000000784 * cos(2.20169255256 + 7234.5504387585*$t);
  $X0 += 0.00000000785 * cos(3.43654258027 + 846.3266522347*$t);
  $X0 += 0.00000000611 * cos(1.53152362816 + 853.4401992355*$t);
  $X0 += 0.00000000576 * cos(1.22798260830 + 12323.6669134923*$t);
  $X0 += 0.00000000570 * cos(4.54665961586 + 12587.1709129587*$t);
  $X0 += 0.00000000576 * cos(3.06908128494 + 13915.77529215809*$t);
  $X0 += 0.00000000770 * cos(5.60311452827 + 6069.53293706989*$t);
  $X0 += 0.00000000773 * cos(0.21363273558 + 6133.2688353733*$t);
  $X0 += 0.00000000581 * cos(1.34025743471 + 11933.6117781531*$t);
  $X0 += 0.00000000719 * cos(0.90840576142 + 15720.5949673949*$t);
  $X0 += 0.00000000578 * cos(4.26997200274 + 8662.48414104651*$t);
  $X0 += 0.00000000536 * cos(6.06660590951 + 18852.9944858067*$t);
  $X0 += 0.00000000633 * cos(1.17258360285 + 52176.0501006319*$t);
  $X0 += 0.00000000581 * cos(2.92798889289 + 5334.1440585051*$t);
  $X0 += 0.00000000532 * cos(4.58762178742 + 18842.3578204569*$t);
  $X0 += 0.00000000657 * cos(3.25871870022 + 5849.1202946311*$t);
  $X0 += 0.00000000599 * cos(2.11793230261 + 6151.7777057885*$t);
  $X0 += 0.00000000540 * cos(3.24412649701 + 6286.6060248927*$t);
  $X0 += 0.00000000540 * cos(3.40440707563 + 6280.0333100571*$t);
  $X0 += 0.00000000628 * cos(0.31668062965 + 17298.4261448097*$t);
  $X0 += 0.00000000532 * cos(4.41105068397 + 11514.1271342779*$t);
  $X0 += 0.00000000513 * cos(3.70291605445 + 12456.1891962469*$t);
  $X0 += 0.00000000649 * cos(4.90568628758 + 11764.5745863425*$t);
  $X0 += 0.00000000582 * cos(4.53092429894 + 6414.8616291613*$t);
  $X0 += 0.00000000517 * cos(4.06133972007 + 3340.36860921629*$t);
  $X0 += 0.00000000609 * cos(3.94494306228 + 10420.23010099111*$t);
  $X0 += 0.00000000615 * cos(4.71270964329 + 10983.94853421629*$t);
  $X0 += 0.00000000622 * cos(5.53858241889 + 5326.5428765373*$t);
  $X0 += 0.00000000536 * cos(3.70224967645 + 7232.49527644471*$t);
  $X0 += 0.00000000516 * cos(2.92986975188 + 433.9555553603*$t);
  $X0 += 0.00000000613 * cos(1.79095811234 + 10969.72144021469*$t);
  $X0 += 0.00000000583 * cos(6.15311267171 + 5863.3473886327*$t);
  $X0 += 0.00000000636 * cos(6.06042539245 + 26735.7014447297*$t);
  $X0 += 0.00000000665 * cos(2.74682435671 + 40879.1966871603*$t);
  $X0 += 0.00000000583 * cos(2.82325235087 + 12592.2062022991*$t);
  $X0 += 0.00000000479 * cos(1.33548820034 + 5547.4431539431*$t);
  $X0 += 0.00000000571 * cos(2.58673571504 + 6062.9070250361*$t);
  $X0 += 0.00000000565 * cos(3.92092198777 + 4171.1817191303*$t);
  $X0 += 0.00000000462 * cos(1.96630641591 + 3104.6862419403*$t);
  $X0 += 0.00000000551 * cos(4.03874430699 + 6503.7323099137*$t);
  $X0 += 0.00000000504 * cos(5.14547341413 + 15670.83794192309*$t);
  $X0 += 0.00000000535 * cos(6.12277243019 + 173567.08125514039*$t);
  $X0 += 0.00000000460 * cos(3.18401450277 + 3495.78900865049*$t);
  $X0 += 0.00000000449 * cos(5.09833649130 + 4274.27449334889*$t);
  $X0 += 0.00000000453 * cos(3.57566005736 + 9387.76209193169*$t);
  $X0 += 0.00000000527 * cos(6.24827137997 + 24602.8562523545*$t);
  $X0 += 0.00000000502 * cos(0.97407216668 + 12490.1294461907*$t);
  $X0 += 0.00000000603 * cos(0.85487069842 + 322711.54834138996*$t);
  $X0 += 0.00000000532 * cos(1.83659178149 + 5120.8449630671*$t);
  $X0 += 0.00000000530 * cos(0.43491203890 + 18845.9482491087*$t);
  $X0 += 0.00000000431 * cos(5.31145947559 + 7019.19618100671*$t);
  $X0 += 0.00000000465 * cos(5.83298981980 + 8827.14645239129*$t);
  $X0 += 0.00000000559 * cos(1.71560880010 + 1582.2031657665*$t);
  $X0 += 0.00000000485 * cos(6.13610027053 + 29296.8592070621*$t);
  $X0 += 0.00000000584 * cos(0.07138791653 + 72850.80553272919*$t);
  $X0 += 0.00000000550 * cos(3.95560592819 + 213.0552779545*$t);
  $X0 += 0.00000000481 * cos(1.86946119801 + 14.47091148511*$t);
  $X0 += 0.00000000569 * cos(2.95240683895 + 97238.871361971*$t);
  $X0 += 0.00000000551 * cos(1.64539130884 + 14313.9242955663*$t);
  $X0 += 0.00000000389 * cos(3.43047350256 + 6245.1866318371*$t);
  $X0 += 0.00000000389 * cos(3.21806007009 + 6321.4527031127*$t);
  $X0 += 0.00000000388 * cos(1.13963224225 + 6297.5467614765*$t);
  $X0 += 0.00000000388 * cos(5.50890133040 + 6269.0925734733*$t);
  $X0 += 0.00000000515 * cos(1.67075264819 + 12320.56387123691*$t);
  $X0 += 0.00000000394 * cos(6.10437801091 + 4156.95462512869*$t);
  $X0 += 0.00000000491 * cos(5.96788884074 + 1479.11039154791*$t);
  $X0 += 0.00000000440 * cos(0.97316688838 + 5650.0482931947*$t);
  $X0 += 0.00000000382 * cos(3.07660544855 + 9917.9406919933*$t);
  $X0 += 0.00000000503 * cos(4.65767245093 + 17157.3056979553*$t);
  $X0 += 0.00000000439 * cos(4.82562869150 + 233141.55822184499*$t);
  $X0 += 0.00000000381 * cos(2.02484381212 + 14143.2514249471*$t);
  $X0 += 0.00000000371 * cos(4.59067170554 + 5643.4223811609*$t);
  $X0 += 0.00000000516 * cos(5.61424407240 + 135.30889751891*$t);
  $X0 += 0.00000000417 * cos(3.74461559548 + 13760.8425276909*$t);
  $X0 += 0.00000000483 * cos(4.41750912984 + 9779.3524936089*$t);
  $X0 += 0.00000000381 * cos(4.36951119319 + 14919.2616712381*$t);
  $X0 += 0.00000000378 * cos(4.51952349691 + 17267.5120191747*$t);
  $X0 += 0.00000000393 * cos(1.56678612595 + 7872.39256275871*$t);
  $X0 += 0.00000000376 * cos(4.45581102621 + 13517.62628874989*$t);
  $X0 += 0.00000000365 * cos(2.11020607854 + 6923.2169537889*$t);
  $X0 += 0.00000000371 * cos(5.76233679446 + 13625.7774476555*$t);
  $X0 += 0.00000000355 * cos(5.24317955258 + 10874.2298479639*$t);
  $X0 += 0.00000000499 * cos(2.72562606986 + 161710.8626037159*$t);
  $X0 += 0.00000000379 * cos(0.81621597880 + 3185.43584474911*$t);
  $X0 += 0.00000000471 * cos(4.78294711940 + 11712.71150074729*$t);
  $X0 += 0.00000000417 * cos(3.33073591690 + 22779.6810636773*$t);
  $X0 += 0.00000000485 * cos(1.35444198321 + 12528.26248182851*$t);
  $X0 += 0.00000000358 * cos(3.49115357527 + 6295.0490203109*$t);
  $X0 += 0.00000000358 * cos(3.15737999738 + 6271.5903146389*$t);
  $X0 += 0.00000000365 * cos(3.62050447597 + 6836.40143535029*$t);
  $X0 += 0.00000000351 * cos(2.21887831196 + 11617.21990849651*$t);
  $X0 += 0.00000000351 * cos(2.96356670458 + 205.9417309537*$t);
  $X0 += 0.00000000429 * cos(0.79790217165 + 3894.4256470257*$t);
  $X0 += 0.00000000388 * cos(0.49080052992 + 956.53297345411*$t);
  $X0 += 0.00000000464 * cos(0.69464877419 + 23581.5019948011*$t);
  $X0 += 0.00000000396 * cos(2.35908361907 + 5231.0512842865*$t);
  $X0 += 0.00000000421 * cos(4.82739444320 + 7445.7943718827*$t);
  $X0 += 0.00000000366 * cos(0.62612486089 + 17253.2849251731*$t);
  $X0 += 0.00000000360 * cos(0.81896878015 + 21393.7857873411*$t);
  $X0 += 0.00000000336 * cos(1.41330667750 + 6279.3875142118*$t);
  $X0 += 0.00000000336 * cos(5.23522689515 + 6287.251820738*$t);
  $X0 += 0.00000000326 * cos(4.93781139708 + 1059.1381127057*$t);
  $X0 += 0.00000000395 * cos(0.53943839302 + 5642.4420600927*$t);
  $X0 += 0.00000000450 * cos(0.23150267191 + 1385.3177574676*$t);
  $X0 += 0.00000000363 * cos(4.29615345291 + 22484.0923919761*$t);
  $X0 += 0.00000000399 * cos(0.80548840004 + 16858.7263504167*$t);
  $X0 += 0.00000000316 * cos(4.03075171777 + 20995.6367839329*$t);
  $X0 += 0.00000000430 * cos(2.39021484637 + 19650.8046636145*$t);
  $X0 += 0.00000000363 * cos(4.29069778349 + 7335.5880506633*$t);
  $X0 += 0.00000000317 * cos(1.52889301942 + 11769.6098756829*$t);
  $X0 += 0.00000000395 * cos(5.39427984473 + 5905.94605955911*$t);
  $X0 += 0.00000000324 * cos(3.70774573147 + 37.7838551523*$t);
  $X0 += 0.00000000299 * cos(3.86306301151 + 641.12142486571*$t);
  $X0 += 0.00000000304 * cos(0.15985948407 + 5750.1055840313*$t);
  $X0 += 0.00000000298 * cos(3.82763680613 + 1350.1112271423*$t);
  $X0 += 0.00000000414 * cos(4.17890604161 + 44809.4063833799*$t);
  $X0 += 0.00000000339 * cos(4.29176984719 + 3.6883357796*$t);
  $X0 += 0.00000000351 * cos(5.93395494462 + 12345.9828750275*$t);
  $X0 += 0.00000000362 * cos(0.42214982034 + 21953.91379191449*$t);
  $X0 += 0.00000000304 * cos(4.93815385347 + 29826.5501721567*$t);
  $X0 += 0.00000000395 * cos(0.07721971830 + 4176.2851599325*$t);
  $X0 += 0.00000000320 * cos(2.49901226571 + 10818.3791043993*$t);
  $X0 += 0.00000000384 * cos(4.01872268681 + 10177.01386205009*$t);
  $X0 += 0.00000000279 * cos(0.96409855547 + 10970.2090751817*$t);
  $X0 += 0.00000000365 * cos(1.25425361388 + 6660.6932753907*$t);
  $X0 += 0.00000000377 * cos(0.82514906124 + 29864.5778447925*$t);
  $X0 += 0.00000000275 * cos(5.73507538514 + 20597.4877805247*$t);
  $X0 += 0.00000000316 * cos(2.59688143484 + 316.6356871401*$t);
  $X0 += 0.00000000339 * cos(6.10829032638 + 6924.1972748571*$t);
  $X0 += 0.00000000386 * cos(2.29032835664 + 2636.9692901205*$t);
  $X0 += 0.00000000273 * cos(1.09519308783 + 26709.8907598969*$t);
  $X0 += 0.00000000314 * cos(1.47223989608 + 14945.5599910379*$t);
  $X0 += 0.00000000281 * cos(4.86653427016 + 16858.23871544969*$t);
  $X0 += 0.00000000287 * cos(3.30150277561 + 18073.46112116669*$t);
  $X0 += 0.00000000265 * cos(5.11010310272 + 19379.1623325523*$t);
  $X0 += 0.00000000325 * cos(2.49278036693 + 12360.2099690291*$t);
  $X0 += 0.00000000362 * cos(1.18157001338 + 30665.9111409493*$t);
  $X0 += 0.00000000269 * cos(0.20537228942 + 6816.53375091851*$t);
  $X0 += 0.00000000344 * cos(3.51559724211 + 6147.69434246491*$t);
  $X0 += 0.00000000255 * cos(4.94623609008 + 1376.0176173293*$t);
  $X0 += 0.00000000334 * cos(3.13303124260 + 6418.9449924849*$t);
  $X0 += 0.00000000316 * cos(5.54205330844 + 6055.8435346859*$t);
  $X0 += 0.00000000283 * cos(4.23095234926 + 28287.2343023447*$t);
  $X0 += 0.00000000305 * cos(4.26252488384 + 16522.4158985187*$t);
  $X0 += 0.00000000270 * cos(0.05215867170 + 283.6155013817*$t);
  $X0 += 0.00000000243 * cos(2.54680473739 + 6255.9181113781*$t);
  $X0 += 0.00000000243 * cos(4.10172883526 + 6310.7212235717*$t);
  $X0 += 0.00000000296 * cos(0.07899510796 + 6129.5408569901*$t);
  $X0 += 0.00000000301 * cos(1.10648037942 + 6510.7958002639*$t);
  $X0 += 0.00000000329 * cos(1.15683223901 + 377.6174253993*$t);
  $X0 += 0.00000000267 * cos(3.42011505320 + 24705.9490265731*$t);
  $X0 += 0.00000000285 * cos(2.50494570372 + 5469.7693835151*$t);
  $X0 += 0.00000000286 * cos(0.28647364691 + 6437.0984779597*$t);
  $X0 += 0.00000000311 * cos(3.21063889136 + 11720.3126827151*$t);
  $X0 += 0.00000000319 * cos(4.71059907821 + 169379.5000286584*$t);
  $X0 += 0.00000000241 * cos(2.99439330770 + 632.5399218297*$t);
  $X0 += 0.00000000229 * cos(1.01522459538 + 1265.81129610991*$t);
  $X0 += 0.00000000235 * cos(3.36978882786 + 4487.57358878689*$t);
  $X0 += 0.00000000253 * cos(0.51356087882 + 4377.3672675675*$t);
  $X0 += 0.00000000277 * cos(1.58719268637 + 419.2408263917*$t);
  $X0 += 0.00000000234 * cos(5.12574585310 + 11713.1991357143*$t);
  $X0 += 0.00000000216 * cos(5.01445941939 + 10454.25756912169*$t);
  $X0 += 0.00000000241 * cos(5.44670796756 + 103.3365917021*$t);
  $X0 += 0.00000000214 * cos(2.09481715597 + 2222.1004520805*$t);
  $X0 += 0.00000000213 * cos(3.79438383373 + 30356.2411372513*$t);
  $X0 += 0.00000000240 * cos(2.57405501441 + 6309.1303523077*$t);
  $X0 += 0.00000000212 * cos(2.36637350989 + 262.84010588929*$t);
  $X0 += 0.00000000259 * cos(3.21725974670 + 6283.56348495841*$t);
  $X0 += 0.00000000259 * cos(3.43127382595 + 6283.0758499914*$t);
  $X0 += 0.00000000222 * cos(1.42789121927 + 10440.03047512009*$t);
  $X0 += 0.00000000201 * cos(5.11101601554 + 5746.0275204125*$t);
  $X0 += 0.00000000274 * cos(3.85387261790 + 23581.0143598341*$t);
  $X0 += 0.00000000243 * cos(4.14346519403 + 7096.8699514347*$t);
  $X0 += 0.00000000234 * cos(5.23697266935 + 5573.3866189166*$t);
  $X0 += 0.00000000203 * cos(0.00533428175 + 16460.08971204149*$t);
  $X0 += 0.00000000246 * cos(5.83654379480 + 8672.21368792411*$t);
  $X0 += 0.00000000216 * cos(4.93054195434 + 5437.23683272371*$t);
  $X0 += 0.00000000210 * cos(5.82498971470 + 9381.2034902007*$t);
  $X0 += 0.00000000199 * cos(0.93528415346 + 11216.5281078075*$t);
  $X0 += 0.00000000270 * cos(0.40019527935 + 284.1031363487*$t);
  $X0 += 0.00000000207 * cos(3.06628694399 + 12562.80508881451*$t);
  $X0 += 0.00000000212 * cos(1.75471606720 + 7129.4025022261*$t);
  $X0 += 0.00000000269 * cos(1.52668960070 + 70755.31090921978*$t);
  $X0 += 0.00000000221 * cos(3.40184768346 + 77713.52765063698*$t);
  $X0 += 0.00000000225 * cos(4.01628844723 + 5635.8211991931*$t);
  $X0 += 0.00000000197 * cos(3.36122016267 + 14712.07329897449*$t);
  $X0 += 0.00000000192 * cos(2.04581063866 + 17272.1278250099*$t);
  $X0 += 0.00000000241 * cos(5.09422826000 + 15907.0079441661*$t);
  $X0 += 0.00000000261 * cos(5.60213035381 + 48739.6160795995*$t);
  $X0 += 0.00000000255 * cos(0.53150571182 + 6206.5659612323*$t);
  $X0 += 0.00000000256 * cos(2.30148639986 + 224.5886131854*$t);
  $X0 += 0.00000000182 * cos(4.41917983264 + 18848.98373249069*$t);
  $X0 += 0.00000000250 * cos(4.24183231344 + 5934.39524702691*$t);
  $X0 += 0.00000000196 * cos(2.21911266897 + 16460.5773470085*$t);
  $X0 += 0.00000000187 * cos(4.75761261391 + 22003.6708173863*$t);
  $X0 += 0.00000000229 * cos(0.16732487654 + 2942.21960580809*$t);
  $X0 += 0.00000000175 * cos(5.41173900219 + 11614.6771112157*$t);
  $X0 += 0.00000000187 * cos(5.47425531847 + 9778.8648586419*$t);
  $X0 += 0.00000000175 * cos(4.58223305763 + 3744.5835282543*$t);
  $X0 += 0.00000000241 * cos(0.28794939753 + 8390.3541750173*$t);
  $X0 += 0.00000000236 * cos(2.02485303450 + 1.7282901918*$t);
  $X0 += 0.00000000217 * cos(5.02460023035 + 17996.2749857057*$t);
  $X0 += 0.00000000173 * cos(1.08399000143 + 6275.71848550709*$t);
  $X0 += 0.00000000191 * cos(6.27756282518 + 394.86970254271*$t);
  $X0 += 0.00000000231 * cos(2.60472823534 + 34596.1208371689*$t);
  $X0 += 0.00000000169 * cos(5.11378923747 + 6438.2524319421*$t);
  $X0 += 0.00000000235 * cos(3.47396101480 + 17256.38771885789*$t);
  $X0 += 0.00000000188 * cos(5.59662915440 + 401.91593924071*$t);
  $X0 += 0.00000000217 * cos(4.97442863783 + 10984.4361691833*$t);
  $X0 += 0.00000000230 * cos(2.40692408305 + 6632.2440879229*$t);
  $X0 += 0.00000000208 * cos(0.72059454942 + 11087.5289434019*$t);
  $X0 += 0.00000000165 * cos(2.37182548424 + 743.23387801611*$t);
  $X0 += 0.00000000177 * cos(4.73067975820 + 4796.85191144269*$t);
  $X0 += 0.00000000208 * cos(4.59043597135 + 3097.64000524229*$t);
  $X0 += 0.00000000167 * cos(3.97387947664 + 5714.4977934475*$t);
  $X0 += 0.00000000198 * cos(3.26732644351 + 5539.8419719753*$t);
  $X0 += 0.00000000169 * cos(3.73983013574 + 12132.6837795895*$t);
  $X0 += 0.00000000214 * cos(4.34216809137 + 24492.6499311351*$t);
  $X0 += 0.00000000172 * cos(1.25880044898 + 6233.5626420031*$t);
  $X0 += 0.00000000172 * cos(5.38973312367 + 6333.0766929467*$t);
  $X0 += 0.00000000223 * cos(4.99990847060 + 266.85085920531*$t);
  $X0 += 0.00000000159 * cos(3.90246086071 + 13199.1792567795*$t);
  $X0 += 0.00000000219 * cos(5.40805183208 + 10344.05124790229*$t);
  $X0 += 0.00000000207 * cos(3.49598218672 + 12569.9859461181*$t);
  $X0 += 0.00000000176 * cos(4.05199209274 + 12012.8261146239*$t);
  $X0 += 0.00000000170 * cos(6.01039539440 + 6294.36536773881*$t);
  $X0 += 0.00000000170 * cos(0.63813817825 + 6272.273967211*$t);
  $X0 += 0.00000000205 * cos(5.87166506948 + 13119.47728534169*$t);
  $X0 += 0.00000000167 * cos(5.54385526640 + 17686.9966630499*$t);
  $X0 += 0.00000000210 * cos(0.88175440791 + 13521.50762410789*$t);
  $X0 += 0.00000000163 * cos(1.46796231870 + 802.0647486073*$t);
  $X0 += 0.00000000159 * cos(4.85018558111 + 5017.2645538815*$t);
  $X0 += 0.00000000148 * cos(0.75075299347 + 419.72846135871*$t);
  $X0 += 0.00000000165 * cos(0.87966880312 + 20199.3387771165*$t);
  $X0 += 0.00000000196 * cos(3.57999903444 + 33326.33491569069*$t);
  $X0 += 0.00000000146 * cos(0.39484750798 + 19800.7021387413*$t);
  $X0 += 0.00000000148 * cos(2.67465416652 + 6852.1415415023*$t);
  $X0 += 0.00000000146 * cos(0.23882077577 + 17370.6047933933*$t);
  $X0 += 0.00000000143 * cos(0.85202349514 + 5618.5636223449*$t);
  $X0 += 0.00000000142 * cos(5.37141800193 + 17654.5367222661*$t);
  $X0 += 0.00000000140 * cos(1.22241558577 + 2008.8013566425*$t);
  $X0 += 0.00000000153 * cos(1.79747194391 + 5436.7491977567*$t);
  $X0 += 0.00000000162 * cos(3.70215026876 + 775.2787938405*$t);
  $X0 += 0.00000000162 * cos(4.78754155685 + 12552.1684234647*$t);
  $X0 += 0.00000000143 * cos(2.32218951292 + 5010.1510068807*$t);
  $X0 += 0.00000000188 * cos(3.68702080121 + 28.6930049513*$t);
  $X0 += 0.00000000155 * cos(6.15650399253 + 11610.1063614957*$t);
  $X0 += 0.00000000174 * cos(5.71964679538 + 20452.6255947383*$t);
  $X0 += 0.00000000179 * cos(5.30407615411 + 27511.2240560537*$t);
  $X0 += 0.00000000135 * cos(0.07815962516 + 12431.3304374309*$t);
  $X0 += 0.00000000164 * cos(5.60920106543 + 28767.1682419675*$t);
  $X0 += 0.00000000134 * cos(5.44099179137 + 16840.9138282987*$t);
  $X0 += 0.00000000174 * cos(4.27755511799 + 19805.0711090663*$t);
  $X0 += 0.00000000146 * cos(1.55848605346 + 12701.4605975017*$t);
  $X0 += 0.00000000137 * cos(2.60101256262 + 11.2895177474*$t);
  $X0 += 0.00000000167 * cos(1.27059509188 + 17473.6975676119*$t);
  $X0 += 0.00000000152 * cos(4.19104806587 + 16627.6147328607*$t);
  $X0 += 0.00000000124 * cos(5.79651030598 + 6948.0757126049*$t);
  $X0 += 0.00000000135 * cos(3.38729000615 + 3531.2844328163*$t);
  $X0 += 0.00000000172 * cos(4.94261447200 + 167959.14629657479*$t);
  $X0 += 0.00000000123 * cos(5.21069118841 + 23013.29572210369*$t);
  $X0 += 0.00000000122 * cos(5.69263982892 + 3583.5848481573*$t);
  $X0 += 0.00000000170 * cos(1.45223428169 + 333857.83394425618*$t);
  $X0 += 0.00000000155 * cos(4.05745332726 + 6058.48723680599*$t);
  $X0 += 0.00000000120 * cos(1.19140907580 + 12809.12412144031*$t);
  $X0 += 0.00000000141 * cos(5.52535299558 + 162420.79565227419*$t);
  $X0 += 0.00000000120 * cos(5.84076902832 + 12528.3678448305*$t);
  $X0 += 0.00000000123 * cos(6.20892018031 + 25933.8805136059*$t);
  $X0 += 0.00000000144 * cos(2.13726910032 + 95.7354097343*$t);
  $X0 += 0.00000000165 * cos(0.74320909184 + 52669.8257758191*$t);
  $X0 += 0.00000000119 * cos(1.19695838858 + 19247.6203708659*$t);
  $X0 += 0.00000000117 * cos(0.73795876397 + 11610.7957758577*$t);
  $X0 += 0.00000000163 * cos(3.11536370558 + 661.4767442645*$t);
  $X0 += 0.00000000163 * cos(4.35849093916 + 9929.6700448293*$t);
  $X0 += 0.00000000119 * cos(4.28708216617 + 12250.0036478097*$t);
  $X0 += 0.00000000145 * cos(3.90603326867 + 6205.6458970469*$t);
  $X0 += 0.00000000145 * cos(2.74250030398 + 6360.99343790291*$t);
  $X0 += 0.00000000159 * cos(4.18513637906 + 228278.34846897019*$t);
  $X0 += 0.00000000114 * cos(1.84089435963 + 19402.55313533309*$t);
  $X0 += 0.00000000147 * cos(4.06094470975 + 38526.3305333885*$t);
  $X0 += 0.00000000156 * cos(2.57788751226 + 4307.8271216189*$t);
  $X0 += 0.00000000131 * cos(1.70667997590 + 21228.63584102931*$t);
  $X0 += 0.00000000118 * cos(5.40927777429 + 6263.64990657511*$t);
  $X0 += 0.00000000118 * cos(1.23925579836 + 6302.9894283747*$t);
  $X0 += 0.00000000137 * cos(2.54415078163 + 6315.8522182663*$t);
  $X0 += 0.00000000137 * cos(4.10438279102 + 6250.7871166835*$t);
  $X0 += 0.00000000109 * cos(2.76724250809 + 11925.5179100841*$t);
  $X0 += 0.00000000111 * cos(4.37410999057 + 6226.4212925393*$t);
  $X0 += 0.00000000111 * cos(2.27442358208 + 6340.2180424105*$t);
  $X0 += 0.00000000123 * cos(2.37617280556 + 24734.3982140409*$t);
  $X0 += 0.00000000107 * cos(2.16622176546 + 12463.30274324771*$t);
  $X0 += 0.00000000133 * cos(3.03066152119 + 18875.76968725751*$t);
  $X0 += 0.00000000123 * cos(5.64258939044 + 6260.5444660241*$t);
  $X0 += 0.00000000123 * cos(1.00594418221 + 6306.09486892571*$t);
  $X0 += 0.00000000113 * cos(1.95402250286 + 2111.8941308611*$t);
  $X0 += 0.00000000131 * cos(3.61193663544 + 18415.7596295809*$t);
  $X0 += 0.00000000110 * cos(1.76186229885 + 6289.94822637491*$t);
  $X0 += 0.00000000110 * cos(4.88667127380 + 6276.69110857489*$t);
  $X0 += 0.00000000103 * cos(3.89043805400 + 6241.7688764901*$t);
  $X0 += 0.00000000103 * cos(2.75809551865 + 6324.8704584597*$t);
  $X0 += 0.00000000113 * cos(2.20489389956 + 3496.2766436175*$t);
  $X0 += 0.00000000103 * cos(4.57936207476 + 10344.5388828693*$t);
  $X0 += 0.00000000115 * cos(2.66876079900 + 24336.2492106327*$t);
  $X0 += 0.00000000107 * cos(1.72027504380 + 83974.07917321339*$t);
  $X0 += 0.00000000107 * cos(2.75882626470 + 84020.10309797739*$t);
  $X0 += 0.00000000106 * cos(3.27680652019 + 12772.58106590351*$t);
  $X0 += 0.00000000143 * cos(1.51224865614 + 2069.2506523901*$t);
  $X0 += 0.00000000143 * cos(0.91984229557 + 18773.2052961821*$t);
  $X0 += 0.00000000115 * cos(3.78326005147 + 3641.4907540357*$t);
  $X0 += 0.00000000112 * cos(5.73842498855 + 11499.41240530929*$t);
  $X0 += 0.00000000099 * cos(1.79019915134 + 11190.6217176205*$t);
  $X0 += 0.00000000126 * cos(1.19294266238 + 18823.1730476579*$t);
  $X0 += 0.00000000115 * cos(4.66544469064 + 12570.3276707294*$t);
  $X0 += 0.00000000100 * cos(3.52903073097 + 16062.4283436003*$t);
  $X0 += 0.00000000107 * cos(4.02566335272 + 5216.8241902849*$t);
  $X0 += 0.00000000120 * cos(4.96595619835 + 9814.36028280769*$t);
  $X0 += 0.00000000138 * cos(4.55918305844 + 6210.0225416159*$t);
  $X0 += 0.00000000138 * cos(2.08935051421 + 6356.6167933339*$t);
  $X0 += 0.00000000105 * cos(1.03351724810 + 12721.32828193349*$t);
  $X0 += 0.00000000135 * cos(0.57056498904 + 18699.9081703231*$t);
  $X0 += 0.00000000104 * cos(2.15061044327 + 12560.8725931589*$t);
  $X0 += 0.00000000098 * cos(5.57514638218 + 5815.3546771205*$t);
  $X0 += 0.00000000111 * cos(3.97355954616 + 10239.3400485273*$t);
  $X0 += 0.00000000100 * cos(4.55824596261 + 263.3277408563*$t);
  $X0 += 0.00000000095 * cos(1.74741902247 + 155.6642169177*$t);
  $X0 += 0.00000000130 * cos(2.12273849218 + 27511.7116910207*$t);
  $X0 += 0.00000000120 * cos(0.27869701115 + 31441.4337522733*$t);
  $X0 += 0.00000000114 * cos(3.75372093481 + 6155.3008241375*$t);
  $X0 += 0.00000000114 * cos(2.89481263784 + 6411.3385108123*$t);
  $X0 += 0.00000000119 * cos(5.21922596573 + 951.9622237341*$t);
  $X0 += 0.00000000117 * cos(1.90078630587 + 28236.98964190589*$t);
  $X0 += 0.00000000107 * cos(1.90914871846 + 21.0192129759*$t);
  $X0 += 0.00000000095 * cos(5.63307991850 + 11300.8280388399*$t);
  $X0 += 0.00000000110 * cos(2.79120257993 + 6312.74917601091*$t);
  $X0 += 0.00000000110 * cos(3.85733099272 + 6253.8901589389*$t);
  $X0 += 0.00000000097 * cos(4.22068998833 + 78263.95324220609*$t);
  $X0 += 0.00000000095 * cos(5.98375623165 + 23938.1002072245*$t);
  $X0 += 0.00000000091 * cos(2.99457476326 + 12829.4794408391*$t);
  $X0 += 0.00000000112 * cos(4.31165167302 + 16737.8210540801*$t);
  $X0 += 0.00000000126 * cos(3.10862438843 + 3.2793008655*$t);
  $X0 += 0.00000000100 * cos(3.03286435761 + 6133.7564703403*$t);
  $X0 += 0.00000000127 * cos(5.41503454763 + 1293.24040609909*$t);
  $X0 += 0.00000000119 * cos(5.99165259734 + 17893.1822114871*$t);
  $X0 += 0.00000000089 * cos(1.33458093593 + 23539.9512038163*$t);
  $X0 += 0.00000000126 * cos(0.25750692887 + 311565.26273852374*$t);
  $X0 += 0.00000000093 * cos(5.67599033319 + 736.1203310153*$t);
  $X0 += 0.00000000120 * cos(2.08797711521 + 14158.9915310991*$t);
  $X0 += 0.00000000118 * cos(1.43212365415 + 16061.94070863329*$t);
  $X0 += 0.00000000099 * cos(3.61958161583 + 6432.8828646095*$t);
  $X0 += 0.00000000095 * cos(5.99715593195 + 2699.49100183409*$t);
  $X0 += 0.00000000089 * cos(2.30094279014 + 15671.3255768901*$t);
  $X0 += 0.00000000124 * cos(0.48008010598 + 178430.29100801519*$t);
  $X0 += 0.00000000089 * cos(1.07338684504 + 6751.28465782931*$t);
  $X0 += 0.00000000096 * cos(2.64494034094 + 7349.81514466491*$t);
  $X0 += 0.00000000096 * cos(0.74221743876 + 24066.0517402591*$t);
  $X0 += 0.00000000103 * cos(4.37747381017 + 18202.4605341429*$t);
  $X0 += 0.00000000099 * cos(6.06683620849 + 6252.40554183991*$t);
  $X0 += 0.00000000099 * cos(0.58169736416 + 6314.2337931099*$t);
  $X0 += 0.00000000090 * cos(0.38965345976 + 58864.30010066279*$t);
  $X0 += 0.00000000086 * cos(0.59831141560 + 9380.71585523369*$t);
  $X0 += 0.00000000086 * cos(0.93909542206 + 10557.35034334029*$t);
  $X0 += 0.00000000098 * cos(3.41472072058 + 6439.7203879773*$t);
  $X0 += 0.00000000098 * cos(3.23381285207 + 6126.91894697251*$t);
  $X0 += 0.00000000086 * cos(1.34148300572 + 23123.9896782901*$t);
  $X0 += 0.00000000118 * cos(3.73844359380 + 13951.9570924174*$t);
  $X0 += 0.00000000117 * cos(4.10902635534 + 89570.23393702849*$t);
  $X0 += 0.00000000083 * cos(3.14133645510 + 8858.0711268371*$t);
  $X0 += 0.00000000092 * cos(4.01226998426 + 12342.0507217644*$t);
  $X0 += 0.00000000085 * cos(2.29415888429 + 5017.7521888485*$t);
  $X0 += 0.00000000101 * cos(0.23020335948 + 18429.9867235825*$t);
  $X0 += 0.00000000088 * cos(3.76744436736 + 17054.2129237367*$t);
  $X0 += 0.00000000113 * cos(2.05049922518 + 12985.88016134151*$t);
  $X0 += 0.00000000083 * cos(0.90577628609 + 20597.0001455577*$t);
  $X0 += 0.00000000082 * cos(0.19375496576 + 5483.4985423095*$t);
  $X0 += 0.00000000087 * cos(0.10696172464 + 21424.2228268199*$t);
  $X0 += 0.00000000107 * cos(2.21757059467 + 522.3336006103*$t);
  $X0 += 0.00000000084 * cos(2.41107951633 + 6187.3404402571*$t);
  $X0 += 0.00000000084 * cos(4.23745405632 + 6379.2988946927*$t);
  $X0 += 0.00000000107 * cos(0.88149755532 + 24382.8352909579*$t);
  $X0 += 0.00000000082 * cos(0.94957627406 + 8983.0544867925*$t);
  $X0 += 0.00000000105 * cos(3.87374571694 + 6131.4223863897*$t);
  $X0 += 0.00000000105 * cos(2.77478785571 + 6435.2169485601*$t);
  $X0 += 0.00000000114 * cos(4.07080782247 + 8258.81221333091*$t);
  $X0 += 0.00000000082 * cos(3.82951941927 + 3957.8826236923*$t);
  $X0 += 0.00000000112 * cos(2.70888594040 + 3738.51761262449*$t);
  $X0 += 0.00000000102 * cos(2.89783593458 + 5767.8557963819*$t);
  $X0 += 0.00000000102 * cos(3.75069763806 + 6798.7835385679*$t);
  $X0 += 0.00000000092 * cos(1.35671084183 + 18216.6876281445*$t);
  $X0 += 0.00000000083 * cos(1.35246903804 + 29864.0902098255*$t);
  $X0 += 0.00000000112 * cos(5.48905138227 + 12189.0219095505*$t);
  $X0 += 0.00000000080 * cos(3.59069348639 + 24080.2788342607*$t);
  $X0 += 0.00000000080 * cos(4.80792276932 + 15141.14697682849*$t);
  $X0 += 0.00000000088 * cos(3.00407783628 + 1573.57660661529*$t);
  $X0 += 0.00000000081 * cos(3.72088724498 + 1550.8014051645*$t);
  $X0 += 0.00000000092 * cos(4.36458397294 + 101426.452588453*$t);
  $X0 += 0.00000000110 * cos(0.37007007331 + 78423.9483341623*$t);
  $X0 += 0.00000000087 * cos(2.32197271603 + 1580.6228433133*$t);
  $X0 += 0.00000000085 * cos(6.14240130116 + 27043.2590656993*$t);
  $X0 += 0.00000000078 * cos(1.45118645187 + 6812.5229976025*$t);
  $X0 += 0.00000000080 * cos(3.36946826019 + 6081.06627230081*$t);
  $X0 += 0.00000000080 * cos(3.27906531246 + 6485.573062649*$t);
  $X0 += 0.00000000079 * cos(4.53816488559 + 36109.6260221481*$t);
  $X0 += 0.00000000088 * cos(0.87069012239 + 16944.0066025173*$t);
  $X0 += 0.00000000081 * cos(1.41865192078 + 5.2791068239*$t);
  $X0 += 0.00000000093 * cos(5.85619230131 + 16737.33341911309*$t);
  $X0 += 0.00000000088 * cos(3.24901264480 + 12537.9463299985*$t);
  $X0 += 0.00000000096 * cos(5.19394745813 + 20198.85114214949*$t);
  $X0 += 0.00000000106 * cos(2.16665694222 + 56600.0354720387*$t);
  $X0 += 0.00000000097 * cos(0.14089796919 + 6040.10342853389*$t);
  $X0 += 0.00000000081 * cos(3.62140277149 + 3956.2641985359*$t);
  $X0 += 0.00000000077 * cos(1.39348893935 + 40796.5827401577*$t);
  $X0 += 0.00000000076 * cos(2.20964866296 + 22743.16556203289*$t);
  $X0 += 0.00000000098 * cos(5.48885750823 + 42456.5402296081*$t);
  $X0 += 0.00000000083 * cos(2.20640709608 + 19801.1897737083*$t);
  $X0 += 0.00000000079 * cos(4.50777033878 + 5622.08674069391*$t);
  $X0 += 0.00000000096 * cos(1.98497858569 + 5888.6937824157*$t);
  $X0 += 0.00000000096 * cos(4.66355498696 + 6677.9455525341*$t);
  $X0 += 0.00000000075 * cos(6.24025577336 + 41194.7317435659*$t);
  $X0 += 0.00000000074 * cos(0.66729085356 + 6261.9840270079*$t);
  $X0 += 0.00000000074 * cos(5.98124271908 + 6304.6553079419*$t);
  $X0 += 0.00000000073 * cos(4.02724017625 + 5870.9485706005*$t);
  $X0 += 0.00000000073 * cos(2.62129339640 + 6695.6907643493*$t);
  $X0 += 0.00000000085 * cos(3.65241534932 + 12850.2548363315*$t);
  $X0 += 0.00000000072 * cos(0.04178130909 + 6253.4982293261*$t);
  $X0 += 0.00000000072 * cos(0.32356695638 + 6313.14110562371*$t);
  $X0 += 0.00000000100 * cos(5.37794526764 + 5316.3487900393*$t);
  $X0 += 0.00000000085 * cos(2.90983978106 + 12282.5361986011*$t);
  $X0 += 0.00000000075 * cos(1.96590105616 + 24422.6141688908*$t);
  $X0 += 0.00000000076 * cos(1.98227687206 + 63659.1215683211*$t);
  $X0 += 0.00000000072 * cos(0.25938390676 + 16723.5939600785*$t);
  $X0 += 0.00000000097 * cos(4.92418361725 + 17995.78735073869*$t);
  $X0 += 0.00000000087 * cos(3.63417247018 + 18106.4813069251*$t);
  $X0 += 0.00000000080 * cos(5.17587638062 + 17363.4912463925*$t);
  $X0 += 0.00000000070 * cos(4.63132769081 + 6124.37614969171*$t);
  $X0 += 0.00000000070 * cos(2.01720588184 + 6442.2631852581*$t);
  $X0 += 0.00000000070 * cos(2.85493203288 + 4705.4884900601*$t);
  $X0 += 0.00000000078 * cos(4.94849285823 + 23550.5878691661*$t);
  $X0 += 0.00000000070 * cos(2.27501820444 + 12036.21691740469*$t);
  $X0 += 0.00000000077 * cos(3.43499900992 + 5237.67719632029*$t);
  $X0 += 0.00000000069 * cos(6.02127545231 + 16207.64245401849*$t);
  $X0 += 0.00000000082 * cos(5.48703292615 + 6774.98295993371*$t);
  $X0 += 0.00000000067 * cos(0.17045217443 + 7083.14079264031*$t);
  $X0 += 0.00000000067 * cos(1.83540783927 + 6394.50630976251*$t);
  $X0 += 0.00000000067 * cos(4.81312573338 + 6172.1330251873*$t);
  $X0 += 0.00000000077 * cos(4.99636632687 + 9924.5666040271*$t);
  $X0 += 0.00000000080 * cos(5.36758481138 + 22380.9996177575*$t);
  $X0 += 0.00000000070 * cos(4.60174692010 + 6390.9831914135*$t);
  $X0 += 0.00000000070 * cos(2.04678665255 + 6175.6561435363*$t);
  $X0 += 0.00000000074 * cos(2.55353968467 + 16193.41536001689*$t);
  $X0 += 0.00000000076 * cos(5.64799287134 + 32217.4439985643*$t);
  $X0 += 0.00000000091 * cos(2.47526506655 + 6653.0194834153*$t);
  $X0 += 0.00000000091 * cos(4.17326850610 + 5913.6198515345*$t);
  $X0 += 0.00000000067 * cos(0.23293815799 + 6265.50714535691*$t);
  $X0 += 0.00000000067 * cos(0.13241010748 + 6301.1321895929*$t);
  $X0 += 0.00000000067 * cos(1.44106493302 + 5959.3266158505*$t);
  $X0 += 0.00000000083 * cos(2.94569161083 + 16723.10632511149*$t);
  $X0 += 0.00000000080 * cos(0.77941152413 + 23646.5670963839*$t);
  $X0 += 0.00000000068 * cos(3.64312239532 + 4897.4243911387*$t);
  $X0 += 0.00000000069 * cos(2.14076318935 + 6944.5525942559*$t);
  $X0 += 0.00000000089 * cos(1.99980743200 + 10660.44311755889*$t);
  $X0 += 0.00000000079 * cos(1.67507258686 + 35371.6434484929*$t);
  $X0 += 0.00000000073 * cos(2.11438932219 + 6370.62787201471*$t);
  $X0 += 0.00000000073 * cos(4.53414425046 + 6196.0114629351*$t);
  $X0 += 0.00000000065 * cos(3.66592557921 + 22345.0165586247*$t);
  $X0 += 0.00000000064 * cos(4.23436375372 + 15265.64270181689*$t);
  $X0 += 0.00000000066 * cos(2.69579215047 + 6315.2919732917*$t);
  $X0 += 0.00000000066 * cos(3.95274142218 + 6251.34736165811*$t);
  $X0 += 0.00000000065 * cos(5.01328627787 + 323.74923414091*$t);
  $X0 += 0.00000000076 * cos(6.17321822941 + 10873.74221299689*$t);
  $X0 += 0.00000000084 * cos(5.21213167261 + 109.9625037359*$t);
  $X0 += 0.00000000063 * cos(4.27995662426 + 11823.4054569337*$t);
  $X0 += 0.00000000064 * cos(0.09093186873 + 28774.2817889683*$t);
  $X0 += 0.00000000072 * cos(0.54185576116 + 18099.7594409665*$t);
  $X0 += 0.00000000066 * cos(2.78134607936 + 17576.7903418305*$t);
  $X0 += 0.00000000072 * cos(1.59783352501 + 245707.70992182779*$t);
  $X0 += 0.00000000061 * cos(5.48721212671 + 10557.8379783073*$t);
  $X0 += 0.00000000064 * cos(0.75473231286 + 71430.9394356126*$t);
  $X0 += 0.00000000068 * cos(2.90814349886 + 28760.05469496669*$t);
  $X0 += 0.00000000062 * cos(0.67966569221 + 3854.7898494737*$t);
  $X0 += 0.00000000073 * cos(6.18332621846 + 23440.3815479467*$t);
  $X0 += 0.00000000060 * cos(3.22950754418 + 13088.9729355601*$t);
  $X0 += 0.00000000078 * cos(4.56094059497 + 12564.91104475801*$t);
  $X0 += 0.00000000060 * cos(4.47214922427 + 7548.8871461013*$t);
  $X0 += 0.00000000059 * cos(2.55184049976 + 6286.3551508569*$t);
  $X0 += 0.00000000075 * cos(4.42124944201 + 18625.1265717558*$t);
  $X0 += 0.00000000058 * cos(0.47683719349 + 35050.2440919589*$t);
  $X0 += 0.00000000060 * cos(0.20507190989 + 553.8132203259*$t);
  $X0 += 0.00000000069 * cos(5.82409350668 + 167993.93845370729*$t);
  $X0 += 0.00000000059 * cos(0.42390666617 + 41991.0297503823*$t);
  $X0 += 0.00000000062 * cos(2.87556762555 + 15663.79170522509*$t);
  $X0 += 0.00000000081 * cos(1.27058846781 + 7250.29054491051*$t);
  $X0 += 0.00000000059 * cos(2.68580345393 + 6277.2537518451*$t);
  $X0 += 0.00000000059 * cos(3.96273011871 + 6289.3855831047*$t);
  $X0 += 0.00000000063 * cos(2.13380171799 + 18003.38853270651*$t);
  $X0 += 0.00000000057 * cos(4.87646676285 + 793.0187059509*$t);
  $X0 += 0.00000000057 * cos(0.02714811761 + 10027.65937824569*$t);
  $X0 += 0.00000000060 * cos(2.20528431296 + 647.25465079831*$t);
  $X0 += 0.00000000072 * cos(4.16486482248 + 4597.77991000629*$t);
  $X0 += 0.00000000059 * cos(3.82312915284 + 6279.30891415889*$t);
  $X0 += 0.00000000068 * cos(2.71579349818 + 3166.66025521511*$t);
  $X0 += 0.00000000056 * cos(4.67855976016 + 6226.5164053051*$t);
  $X0 += 0.00000000056 * cos(1.96997381249 + 6340.12292964471*$t);
  $X0 += 0.00000000056 * cos(2.52728721608 + 12303.3115940935*$t);
  $X0 += 0.00000000057 * cos(3.09052199581 + 5864.3952685743*$t);
  $X0 += 0.00000000057 * cos(3.55801157684 + 6702.2440663755*$t);
  $X0 += 0.00000000069 * cos(1.90302432953 + 23536.3607751645*$t);
  $X0 += 0.00000000059 * cos(0.79584524101 + 5760.25461441409*$t);
  $X0 += 0.00000000065 * cos(0.39208551086 + 12139.30969162329*$t);
  $X0 += 0.00000000059 * cos(3.38503180730 + 67589.3312645407*$t);
  $X0 += 0.00000000073 * cos(0.51774809611 + 11079.92776143409*$t);
  $X0 += 0.00000000076 * cos(2.34882980338 + 23227.0824525087*$t);
  $X0 += 0.00000000067 * cos(2.11713130342 + 4804.4530934105*$t);
  $X0 += 0.00000000073 * cos(6.00949211634 + 30349.1275902505*$t);
  $X0 += 0.00000000074 * cos(4.74855693255 + 92747.9329843061*$t);
  $X0 += 0.00000000070 * cos(1.56579326622 + 12299.7884757445*$t);
  $X0 += 0.00000000060 * cos(0.37222072501 + 12171.7696324071*$t);
  $X0 += 0.00000000059 * cos(2.60537764043 + 15.49628866851*$t);
  $X0 += 0.00000000074 * cos(5.91207332800 + 3684.1342325067*$t);
  $X0 += 0.00000000058 * cos(3.15618940951 + 6717.0314053517*$t);
  $X0 += 0.00000000053 * cos(2.11594966811 + 26087.65932409069*$t);
  $X0 += 0.00000000059 * cos(1.05069506955 + 12164.7233957091*$t);
  $X0 += 0.00000000063 * cos(3.66132366701 + 5219.5179490556*$t);
  $X0 += 0.00000000056 * cos(4.02457482788 + 3178.38960805111*$t);
  $X0 += 0.00000000063 * cos(0.59069175384 + 5227.38225558179*$t);
  $X0 += 0.00000000070 * cos(3.26289105386 + 19004.4041319249*$t);
  $X0 += 0.00000000072 * cos(1.05516042130 + 4583.55281600469*$t);
  $X0 += 0.00000000052 * cos(5.67763480740 + 3627.2636600341*$t);
  $X0 += 0.00000000052 * cos(4.87358219235 + 6411.2712005095*$t);
  $X0 += 0.00000000052 * cos(1.77495138030 + 6155.3681344403*$t);
  $X0 += 0.00000000054 * cos(3.61747287023 + 5849.6079295981*$t);
  $X0 += 0.00000000066 * cos(4.36702417592 + 5791.16874004909*$t);
  $X0 += 0.00000000066 * cos(1.22543152233 + 5791.6563750161*$t);
  $X0 += 0.00000000051 * cos(0.84172627776 + 5113.2437810993*$t);
  $X0 += 0.00000000058 * cos(4.29307138428 + 30775.7257811265*$t);
  $X0 += 0.00000000061 * cos(5.44071514919 + 14169.5497447469*$t);
  $X0 += 0.00000000054 * cos(4.73181482869 + 10454.74520408871*$t);
  $X0 += 0.00000000056 * cos(2.77114790322 + 23141.8022004081*$t);
  $X0 += 0.00000000067 * cos(2.31997560907 + 28313.0449871775*$t);
  $X0 += 0.00000000056 * cos(1.94933767144 + 5244.2930566845*$t);
  $X0 += 0.00000000062 * cos(2.18007483018 + 5657.6494751625*$t);
  $X0 += 0.00000000062 * cos(4.46845874247 + 6908.9898597873*$t);
  $X0 += 0.00000000050 * cos(1.53914825533 + 2574.99527684569*$t);
  $X0 += 0.00000000050 * cos(1.32272515661 + 536.5606946119*$t);
  $X0 += 0.00000000050 * cos(1.95397557344 + 6684.9917892321*$t);
  $X0 += 0.00000000050 * cos(4.69455799921 + 5881.6475457177*$t);
  $X0 += 0.00000000049 * cos(5.07674655291 + 16310.73522823709*$t);
  $X0 += 0.00000000049 * cos(5.07674655291 + 16311.2228632041*$t);
  $X0 += 0.00000000065 * cos(0.63077087865 + 46386.7499258277*$t);
  $X0 += 0.00000000069 * cos(3.59016732594 + 60530.2451682583*$t);
  $X0 += 0.00000000068 * cos(6.19031950148 + 96678.14268052569*$t);
  $X0 += 0.00000000049 * cos(2.44170258748 + 12323.17927852529*$t);
  $X0 += 0.00000000050 * cos(3.95175048363 + 21954.4014268815*$t);
  $X0 += 0.00000000049 * cos(0.26987394090 + 4164.5558070965*$t);
  $X0 += 0.00000000059 * cos(2.11910349639 + 33794.7875410121*$t);
  $X0 += 0.00000000050 * cos(3.21674377716 + 43739.0461634493*$t);
  $X0 += 0.00000000059 * cos(4.28455887932 + 3981.73385156551*$t);
  $X0 += 0.00000000058 * cos(1.59500717257 + 27707.29867681129*$t);
  $X0 += 0.00000000051 * cos(3.00541030027 + 7669.21494381111*$t);
  $X0 += 0.00000000048 * cos(4.80655958998 + 3646.59419483791*$t);
  $X0 += 0.00000000065 * cos(3.20870046710 + 82534.6474380951*$t);
  $X0 += 0.00000000056 * cos(4.19440679704 + 800.06494264891*$t);
  $X0 += 0.00000000057 * cos(0.99121344005 + 11609.61872652869*$t);
  $X0 += 0.00000000048 * cos(5.23363777755 + 26.5421372833*$t);
  $X0 += 0.00000000047 * cos(1.10988199958 + 30640.1004561165*$t);
  $X0 += 0.00000000060 * cos(1.97427905695 + 8982.5668518255*$t);
  $X0 += 0.00000000049 * cos(3.72444308522 + 96563.24283557819*$t);
  $X0 += 0.00000000050 * cos(5.17708029533 + 17583.9038888313*$t);
  $X0 += 0.00000000046 * cos(2.75949485809 + 23539.46356884929*$t);
  $X0 += 0.00000000048 * cos(2.83397317642 + 170.4290531357*$t);
  $X0 += 0.00000000055 * cos(4.77764015710 + 735.6326960483*$t);
  $X0 += 0.00000000054 * cos(4.33153690679 + 6680.98103591609*$t);
  $X0 += 0.00000000060 * cos(1.72047044215 + 44033.8837720559*$t);
  $X0 += 0.00000000064 * cos(4.40652103235 + 80181.29364935629*$t);
  $X0 += 0.00000000059 * cos(5.18038765510 + 24279.3508356971*$t);
  $X0 += 0.00000000049 * cos(5.16566622453 + 5490.5447790075*$t);
  $X0 += 0.00000000058 * cos(1.24075349030 + 6490.0204047715*$t);
  $X0 += 0.00000000058 * cos(5.40778008235 + 6076.6189301783*$t);
  $X0 += 0.00000000046 * cos(6.06699951300 + 18208.1061251085*$t);
  $X0 += 0.00000000045 * cos(1.62616739636 + 4480.46004178609*$t);
  $X0 += 0.00000000055 * cos(3.56883579861 + 16097.9237677661*$t);
  $X0 += 0.00000000055 * cos(0.42724314502 + 16097.43613279909*$t);
  $X0 += 0.00000000061 * cos(5.10427594640 + 491.9071099423*$t);
  $X0 += 0.00000000054 * cos(2.79730041476 + 6006.5738956105*$t);
  $X0 += 0.00000000054 * cos(3.85123315789 + 6560.0654393393*$t);
  $X0 += 0.00000000044 * cos(3.20288072834 + 5333.65642353809*$t);
  $X0 += 0.00000000052 * cos(5.42298629738 + 244287.84382471119*$t);
  $X0 += 0.00000000044 * cos(1.12093494405 + 2301.34199842589*$t);
  $X0 += 0.00000000045 * cos(2.78871592108 + 33794.2999060451*$t);
  $X0 += 0.00000000046 * cos(2.27794751316 + 4384.48081456829*$t);
  $X0 += 0.00000000048 * cos(6.20709507263 + 35579.9350570535*$t);
  $X0 += 0.00000000051 * cos(0.20647678216 + 18326.8939493639*$t);
  $X0 += 0.00000000045 * cos(4.21002666289 + 533.45790092711*$t);
  $X0 += 0.00000000046 * cos(4.72419290173 + 16703.3059509825*$t);
  $X0 += 0.00000000047 * cos(0.82323755553 + 5209.2230083171*$t);
  $X0 += 0.00000000051 * cos(2.88192111957 + 38650.4173236825*$t);
  $X0 += 0.00000000046 * cos(4.04752097938 + 12555.3498172024*$t);
  $X0 += 0.00000000052 * cos(6.21526623133 + 5992.3468016089*$t);
  $X0 += 0.00000000052 * cos(0.43326734132 + 6574.2925333409*$t);
  $X0 += 0.00000000044 * cos(5.37917268925 + 69942.1974183125*$t);
  $X0 += 0.00000000049 * cos(5.19212576524 + 12146.9108735911*$t);
  $X0 += 0.00000000053 * cos(3.10372910020 + 39301.8531447125*$t);
  $X0 += 0.00000000045 * cos(6.22187415000 + 46360.9392409949*$t);
  $X0 += 0.00000000043 * cos(3.11607958976 + 8402.0835278533*$t);
  $X0 += 0.00000000043 * cos(1.76871622593 + 44137.1951668575*$t);
  $X0 += 0.00000000049 * cos(1.97645700808 + 22029.9691371861*$t);
  $X0 += 0.00000000044 * cos(3.04557845219 + 31441.92138724031*$t);
  $X0 += 0.00000000042 * cos(1.28858480303 + 9225.29545579949*$t);
  $X0 += 0.00000000045 * cos(4.79112566977 + 71519.54096076029*$t);
  $X0 += 0.00000000051 * cos(4.52703512787 + 7762.1862415393*$t);
  $X0 += 0.00000000041 * cos(0.43156198612 + 3735.48212924251*$t);
  $X0 += 0.00000000057 * cos(2.81178684757 + 40398.4337367495*$t);
  $X0 += 0.00000000047 * cos(4.46091937774 + 4707.9862312257*$t);
  $X0 += 0.00000000056 * cos(0.65497165024 + 28664.0754677489*$t);
  $X0 += 0.00000000050 * cos(4.15809563419 + 11919.3846841515*$t);
  $X0 += 0.00000000047 * cos(0.89798744348 + 316428.47249139856*$t);
  $X0 += 0.00000000041 * cos(4.27548568888 + 27278.7126339243*$t);
  $X0 += 0.00000000056 * cos(2.85120735939 + 83659.5206898825*$t);
  $X0 += 0.00000000048 * cos(2.50261741205 + 12662.3747446841*$t);
  $X0 += 0.00000000054 * cos(0.83831240155 + 16627.12709789369*$t);
  $X0 += 0.00000000052 * cos(4.41165168727 + 12571.9184417737*$t);
  $X0 += 0.00000000043 * cos(4.69793524808 + 7322.34627826531*$t);
  $X0 += 0.00000000041 * cos(3.56154893542 + 664.99986261351*$t);
  $X0 += 0.00000000042 * cos(1.54738888492 + 5641.9544251257*$t);
  $X0 += 0.00000000044 * cos(1.44765859641 + 6425.4982945111*$t);
  $X0 += 0.00000000044 * cos(5.20087497624 + 6141.1410404387*$t);
  $X0 += 0.00000000039 * cos(0.38205897719 + 22594.2987131955*$t);
  $X0 += 0.00000000040 * cos(5.88641926833 + 20894.53186172529*$t);
  $X0 += 0.00000000044 * cos(5.28307931868 + 5540.3296069423*$t);
  $X0 += 0.00000000050 * cos(5.69294803866 + 17782.48825530069*$t);
  $X0 += 0.00000000054 * cos(4.69164296803 + 6006.2846737335*$t);
  $X0 += 0.00000000054 * cos(1.95689060462 + 6560.3546612163*$t);
  $X0 += 0.00000000045 * cos(5.54499872381 + 142861.14741877468*$t);
  $X0 += 0.00000000047 * cos(1.12158335918 + 24499.7634781359*$t);
  $X0 += 0.00000000043 * cos(1.36615498859 + 7026.3097280075*$t);
  $X0 += 0.00000000047 * cos(1.95434456607 + 955.8435590921*$t);
  $X0 += 0.00000000047 * cos(4.50829221159 + 24485.5363841343*$t);
  $X0 += 0.00000000040 * cos(2.60727518415 + 9388.2497268987*$t);
  $X0 += 0.00000000043 * cos(5.81439105801 + 6359.5857387505*$t);
  $X0 += 0.00000000042 * cos(3.96208965107 + 8635.69818627969*$t);
  $X0 += 0.00000000051 * cos(2.46325624829 + 27831.79440179969*$t);
  $X0 += 0.00000000042 * cos(1.94770311943 + 6334.60000533731*$t);
  $X0 += 0.00000000042 * cos(4.70083045322 + 6232.03932961249*$t);
  $X0 += 0.00000000052 * cos(3.53311914292 + 11905.1625906853*$t);
  $X0 += 0.00000000040 * cos(1.50948151820 + 7076.0945559423*$t);
  $X0 += 0.00000000040 * cos(0.29378456988 + 5444.3503797245*$t);
  $X0 += 0.00000000040 * cos(0.07156369559 + 7122.2889552253*$t);
  $X0 += 0.00000000038 * cos(2.24525725009 + 44933.4931736739*$t);
  $X0 += 0.00000000037 * cos(0.27418012894 + 5715.6010297445*$t);
  $X0 += 0.00000000037 * cos(0.09116813653 + 6851.0383052053*$t);
  $X0 += 0.00000000042 * cos(0.79913949254 + 36147.6536947839*$t);
  $X0 += 0.00000000042 * cos(2.85822305358 + 6238.1784478383*$t);
  $X0 += 0.00000000042 * cos(3.79031051907 + 6328.4608871115*$t);
  $X0 += 0.00000000040 * cos(3.64347872660 + 3214.8925631597*$t);
  $X0 += 0.00000000043 * cos(0.65521409425 + 23141.3145654411*$t);
  $X0 += 0.00000000041 * cos(3.95515629208 + 19804.5834740993*$t);
  $X0 += 0.00000000038 * cos(2.90982798521 + 20.11150191529*$t);
  $X0 += 0.00000000050 * cos(1.62788860301 + 84334.66158130829*$t);
  $X0 += 0.00000000050 * cos(2.84763289309 + 60284.16619777939*$t);
  return $X0;
}



  function Earth_C_X1 ($t)
{
  $X1 =  0.0;
  $X1 += 0.00154550744 * cos(0.64605836878 + 0.2438174835*$t);
  $X1 += 0.00051503383 * cos(6.00263199393 + 12566.3955174663*$t);
  $X1 += 0.00001290763 * cos(5.95941652859 + 18849.4713674577*$t);
  $X1 += 0.00000702576 * cos(1.75347943445 + 6283.3196674749*$t);
  $X1 += 0.00000430422 * cos(2.45216492471 + 6282.83203250789*$t);
  $X1 += 0.00000212689 * cos(1.73380190045 + 6279.7965491259*$t);
  $X1 += 0.00000212524 * cos(4.91484799365 + 6286.84278582391*$t);
  $X1 += 0.00000062308 * cos(0.36193297710 + 4705.9761250271*$t);
  $X1 += 0.00000059808 * cos(3.81187956678 + 6257.0213476751*$t);
  $X1 += 0.00000059474 * cos(2.83659652893 + 6309.61798727471*$t);
  $X1 += 0.00000048914 * cos(5.21332670904 + 775.7664288075*$t);
  $X1 += 0.00000042814 * cos(0.43864033644 + 1059.6257476727*$t);
  $X1 += 0.00000046457 * cos(0.01089905463 + 7860.6632099227*$t);
  $X1 += 0.00000036653 * cos(2.19635713914 + 5753.6287023803*$t);
  $X1 += 0.00000035649 * cos(1.44752011203 + 5885.1706640667*$t);
  $X1 += 0.00000035362 * cos(4.47215447256 + 6813.0106325695*$t);
  $X1 += 0.00000032151 * cos(5.19677261546 + 6681.46867088311*$t);
  $X1 += 0.00000028763 * cos(5.91618988907 + 25132.5472174491*$t);
  $X1 += 0.00000028447 * cos(1.14976229491 + 6127.8992680407*$t);
  $X1 += 0.00000027537 * cos(5.49920443604 + 6438.7400669091*$t);
  $X1 += 0.00000024819 * cos(2.92230738957 + 5487.0216606585*$t);
  $X1 += 0.00000020615 * cos(3.71821460067 + 7079.61767429131*$t);
  $X1 += 0.00000019621 * cos(2.88650825392 + 5507.7970561509*$t);
  $X1 += 0.00000018378 * cos(1.46521342874 + 11790.8729061423*$t);
  $X1 += 0.00000016494 * cos(6.21543454587 + 11507.0135872771*$t);
  $X1 += 0.00000016756 * cos(3.81938434057 + 7058.8422787989*$t);
  $X1 += 0.00000014558 * cos(5.97530104893 + 6290.4332144757*$t);
  $X1 += 0.00000014404 * cos(0.68122522191 + 6276.2061204741*$t);
  $X1 += 0.00000014052 * cos(1.45747121073 + 796.5418242999*$t);
  $X1 += 0.00000012261 * cos(4.15789187748 + 4693.75913722409*$t);
  $X1 += 0.00000012758 * cos(0.34831751321 + 7.3573644843*$t);
  $X1 += 0.00000010086 * cos(3.29242550455 + 3739.0052475915*$t);
  $X1 += 0.00000009469 * cos(4.63920457850 + 6070.0205720369*$t);
  $X1 += 0.00000010425 * cos(2.38242547117 + 6284.2999885431*$t);
  $X1 += 0.00000010425 * cos(4.26610810148 + 6282.3393464067*$t);
  $X1 += 0.00000009570 * cos(1.89427100067 + 4137.1542509997*$t);
  $X1 += 0.00000009044 * cos(2.00972967096 + 6496.6187629129*$t);
  $X1 += 0.00000008544 * cos(0.05731253621 + 1194.6908277081*$t);
  $X1 += 0.00000008214 * cos(1.25401494002 + 1589.3167127673*$t);
  $X1 += 0.00000006157 * cos(3.35676469316 + 8827.6340873583*$t);
  $X1 += 0.00000006271 * cos(4.75475820102 + 8429.4850839501*$t);
  $X1 += 0.00000005524 * cos(5.36941014190 + 4933.4522578161*$t);
  $X1 += 0.00000007314 * cos(0.49102526454 + 4535.3032544079*$t);
  $X1 += 0.00000005157 * cos(5.14965163127 + 11770.0975106499*$t);
  $X1 += 0.00000006749 * cos(4.32513020462 + 5088.8726572503*$t);
  $X1 += 0.00000004853 * cos(0.62462823219 + 6040.5910635009*$t);
  $X1 += 0.00000005304 * cos(5.64244320178 + 3154.4432674121*$t);
  $X1 += 0.00000004985 * cos(4.62777616911 + 12569.91863581531*$t);
  $X1 += 0.00000004709 * cos(3.96386608147 + 5331.6012612243*$t);
  $X1 += 0.00000004601 * cos(6.02376124126 + 6526.04827144891*$t);
  $X1 += 0.00000004201 * cos(1.28125193997 + 7633.1870771337*$t);
  $X1 += 0.00000005607 * cos(2.55800509408 + 5729.7502646325*$t);
  $X1 += 0.00000004257 * cos(4.12450123624 + 3930.4535137031*$t);
  $X1 += 0.00000004394 * cos(0.04709285339 + 12559.2819704655*$t);
  $X1 += 0.00000003870 * cos(2.68681123019 + 7235.0380737255*$t);
  $X1 += 0.00000005154 * cos(6.15930214427 + 8031.3360805419*$t);
  $X1 += 0.00000005036 * cos(4.09009014859 + 6836.8890703173*$t);
  $X1 += 0.00000005076 * cos(2.30606090748 + 7477.7666776995*$t);
  $X1 += 0.00000003593 * cos(2.40570544354 + 12565.9078824993*$t);
  $X1 += 0.00000003384 * cos(5.40354177904 + 10977.32262218251*$t);
  $X1 += 0.00000003371 * cos(0.28961103245 + 11371.9485072417*$t);
  $X1 += 0.00000003536 * cos(3.73353119602 + 4164.0681721295*$t);
  $X1 += 0.00000004292 * cos(4.93786086114 + 1592.8398311163*$t);
  $X1 += 0.00000003407 * cos(2.40599273330 + 3128.6325825793*$t);
  $X1 += 0.00000003152 * cos(1.73356525688 + 5223.93773728571*$t);
  $X1 += 0.00000002883 * cos(4.92077247219 + 1747.7725955835*$t);
  $X1 += 0.00000002751 * cos(5.24449444697 + 7342.7015976641*$t);
  $X1 += 0.00000003323 * cos(1.91880015934 + 801.5771136403*$t);
  $X1 += 0.00000002999 * cos(2.25355241223 + 8636.18582124671*$t);
  $X1 += 0.00000002496 * cos(3.52078273708 + 2145.92159899169*$t);
  $X1 += 0.00000003358 * cos(4.25271343539 + 155.17658195069*$t);
  $X1 += 0.00000002297 * cos(4.53559364224 + 17260.3984721739*$t);
  $X1 += 0.00000002047 * cos(3.53660263792 + 1990.9888345245*$t);
  $X1 += 0.00000002778 * cos(1.46152428305 + 5481.4987363511*$t);
  $X1 += 0.00000002025 * cos(1.44003078455 + 951.4745887671*$t);
  $X1 += 0.00000002663 * cos(5.71398175957 + 26.0545023163*$t);
  $X1 += 0.00000002009 * cos(5.73390835065 + 4690.7236538421*$t);
  $X1 += 0.00000002148 * cos(1.89688144273 + 537.0483295789*$t);
  $X1 += 0.00000001853 * cos(2.84762029989 + 553.32558535889*$t);
  $X1 += 0.00000002478 * cos(0.03933370984 + 1349.62359217529*$t);
  $X1 += 0.00000002023 * cos(2.39095052485 + 522.8212355773*$t);
  $X1 += 0.00000001735 * cos(2.91944410412 + 529.44714761109*$t);
  $X1 += 0.00000002417 * cos(5.16772880951 + 7085.1405985987*$t);
  $X1 += 0.00000001809 * cos(0.78457177103 + 397.9051859247*$t);
  $X1 += 0.00000001893 * cos(4.22746619412 + 9438.0067523705*$t);
  $X1 += 0.00000001708 * cos(0.29122424525 + 10989.0519750185*$t);
  $X1 += 0.00000001898 * cos(2.34007370780 + 5216.33655531789*$t);
  $X1 += 0.00000001820 * cos(1.87728974480 + 5230.5636493195*$t);
  $X1 += 0.00000001541 * cos(1.10077450497 + 426.8420083595*$t);
  $X1 += 0.00000001555 * cos(3.67004127739 + 13096.0864825609*$t);
  $X1 += 0.00000001779 * cos(1.80817581905 + 12562.8723991173*$t);
  $X1 += 0.00000001448 * cos(0.18764842398 + 5753.14106741329*$t);
  $X1 += 0.00000001450 * cos(0.99962470222 + 6262.96434807611*$t);
  $X1 += 0.00000001450 * cos(5.64890887043 + 6303.6749868737*$t);
  $X1 += 0.00000001822 * cos(1.70526332053 + 10973.7995038335*$t);
  $X1 += 0.00000001372 * cos(0.89281758077 + 7875.91568110771*$t);
  $X1 += 0.00000001375 * cos(0.76961577554 + 7084.6529636317*$t);
  $X1 += 0.00000001400 * cos(4.85224030747 + 12721.8159169005*$t);
  $X1 += 0.00000001247 * cos(1.86305212941 + 2119.00767786191*$t);
  $X1 += 0.00000001231 * cos(4.10244270612 + 18319.7804023631*$t);
  $X1 += 0.00000001141 * cos(3.49241515175 + 1066.7392946735*$t);
  $X1 += 0.00000001138 * cos(2.80935582144 + 2942.7072407751*$t);
  $X1 += 0.00000001047 * cos(6.02902034733 + 5642.93474619389*$t);
  $X1 += 0.00000001058 * cos(3.76081315695 + 242.97242145751*$t);
  $X1 += 0.00000001025 * cos(5.32138364615 + 10447.14402212089*$t);
  $X1 += 0.00000000973 * cos(0.24159402695 + 640.1411037975*$t);
  $X1 += 0.00000001114 * cos(5.94057908115 + 15721.0826023619*$t);
  $X1 += 0.00000000963 * cos(2.13180404708 + 2389.1378379327*$t);
  $X1 += 0.00000000941 * cos(5.78706319005 + 20426.8149099055*$t);
  $X1 += 0.00000001068 * cos(0.37393702270 + 529.9347825781*$t);
  $X1 += 0.00000000929 * cos(3.11135132378 + 10575.6505004253*$t);
  $X1 += 0.00000000899 * cos(1.07875107899 + 16496.6052136859*$t);
  $X1 += 0.00000000889 * cos(0.29953586851 + 6277.7967431675*$t);
  $X1 += 0.00000000889 * cos(0.06581239696 + 6288.8425917823*$t);
  $X1 += 0.00000001018 * cos(4.23379398746 + 12540.0971976665*$t);
  $X1 += 0.00000001060 * cos(1.05626464973 + 5760.7422493811*$t);
  $X1 += 0.00000001017 * cos(5.59172649862 + 6805.89708556871*$t);
  $X1 += 0.00000000797 * cos(5.36416276600 + 14314.4119305333*$t);
  $X1 += 0.00000000795 * cos(1.67821896162 + 6286.6060248927*$t);
  $X1 += 0.00000000795 * cos(4.97031461103 + 6280.0333100571*$t);
  $X1 += 0.00000000800 * cos(4.75445763497 + 12029.5910053709*$t);
  $X1 += 0.00000000719 * cos(3.86746073982 + 9623.9320941747*$t);
  $X1 += 0.00000000698 * cos(0.23124353834 + 6148.2545874395*$t);
  $X1 += 0.00000000686 * cos(5.36448356218 + 5856.7214765989*$t);
  $X1 += 0.00000000673 * cos(5.56184807840 + 12964.5445208745*$t);
  $X1 += 0.00000000902 * cos(2.26778049127 + 13368.2164485901*$t);
  $X1 += 0.00000000678 * cos(0.13408295783 + 6418.38474751031*$t);
  $X1 += 0.00000000671 * cos(1.28940504615 + 6709.91785835091*$t);
  $X1 += 0.00000000744 * cos(4.25820705300 + 12043.8180993725*$t);
  $X1 += 0.00000000706 * cos(4.09030374624 + 16730.70750707931*$t);
  $X1 += 0.00000000661 * cos(3.99296008106 + 14712.5609339415*$t);
  $X1 += 0.00000000633 * cos(0.86914955896 + 4292.5746504339*$t);
  $X1 += 0.00000000621 * cos(3.31200729066 + 13119.9649203087*$t);
  $X1 += 0.00000000638 * cos(0.47109166303 + 4690.23601887509*$t);
  $X1 += 0.00000000625 * cos(1.88693051693 + 13518.1139237169*$t);
  $X1 += 0.00000000637 * cos(6.16733887432 + 5746.5151553795*$t);
  $X1 += 0.00000000628 * cos(1.85369027207 + 4686.6455902233*$t);
  $X1 += 0.00000000653 * cos(4.28657823528 + 3929.96587873609*$t);
  $X1 += 0.00000000578 * cos(5.33616352365 + 5088.3850222833*$t);
  $X1 += 0.00000000563 * cos(4.82044552939 + 10447.6316570879*$t);
  $X1 += 0.00000000610 * cos(0.48716946879 + 6820.1241795703*$t);
  $X1 += 0.00000000666 * cos(3.30009380787 + 3634.37720703489*$t);
  $X1 += 0.00000000720 * cos(0.47572131456 + 13916.2629271251*$t);
  $X1 += 0.00000000620 * cos(5.87390167695 + 31415.6230674405*$t);
  $X1 += 0.00000000553 * cos(4.28779208332 + 6259.44122972711*$t);
  $X1 += 0.00000000553 * cos(2.36074148933 + 6307.1981052227*$t);
  $X1 += 0.00000000523 * cos(0.75768878632 + 14143.7390599141*$t);
  $X1 += 0.00000000524 * cos(5.54806074141 + 12139.7973265903*$t);
  $X1 += 0.00000000569 * cos(0.12658241682 + 12036.7045523717*$t);
  $X1 += 0.00000000514 * cos(2.30528734098 + 4700.87268422489*$t);
  $X1 += 0.00000000563 * cos(2.21509710432 + 11014.8626598513*$t);
  $X1 += 0.00000000495 * cos(3.58067034949 + 13362.6935242827*$t);
  $X1 += 0.00000000481 * cos(2.50655660751 + 6279.4383321169*$t);
  $X1 += 0.00000000481 * cos(4.14197696514 + 6287.2010028329*$t);
  $X1 += 0.00000000466 * cos(4.51385713822 + 10177.5014970171*$t);
  $X1 += 0.00000000440 * cos(0.45716811540 + 1577.5873599313*$t);
  $X1 += 0.00000000437 * cos(3.18132586326 + 11499.9000402763*$t);
  $X1 += 0.00000000452 * cos(5.55409870988 + 12573.5090644671*$t);
  $X1 += 0.00000000499 * cos(1.08746970886 + 12410.9751180321*$t);
  $X1 += 0.00000000440 * cos(2.15051971988 + 24073.1652872599*$t);
  $X1 += 0.00000000587 * cos(4.71917094180 + 6.86972951729*$t);
  $X1 += 0.00000000388 * cos(2.04118602600 + 7860.17557495569*$t);
  $X1 += 0.00000000398 * cos(5.77147994683 + 8274.0646845159*$t);
  $X1 += 0.00000000423 * cos(1.16599451585 + 4694.2467721911*$t);
  $X1 += 0.00000000530 * cos(3.00672799320 + 12592.6938372661*$t);
  $X1 += 0.00000000379 * cos(2.02388854283 + 6180.2268932563*$t);
  $X1 += 0.00000000379 * cos(4.62464502982 + 6386.4124416935*$t);
  $X1 += 0.00000000377 * cos(5.90352173005 + 7872.39256275871*$t);
  $X1 += 0.00000000419 * cos(5.62219874401 + 5327.7199258663*$t);
  $X1 += 0.00000000383 * cos(6.24432820927 + 6247.2918007975*$t);
  $X1 += 0.00000000383 * cos(0.40420536338 + 6319.34753415231*$t);
  $X1 += 0.00000000375 * cos(5.62315844522 + 2352.6223362883*$t);
  $X1 += 0.00000000457 * cos(4.19200440747 + 6077.1341190377*$t);
  $X1 += 0.00000000457 * cos(2.45652916518 + 6489.5052159121*$t);
  $X1 += 0.00000000481 * cos(1.89483272077 + 4292.0870154669*$t);
  $X1 += 0.00000000344 * cos(0.28668049892 + 18451.3223640495*$t);
  $X1 += 0.00000000453 * cos(0.72577236980 + 2787.2868413409*$t);
  $X1 += 0.00000000364 * cos(4.39782645564 + 6245.2919948391*$t);
  $X1 += 0.00000000364 * cos(2.25070711701 + 6321.3473401107*$t);
  $X1 += 0.00000000327 * cos(2.71208539186 + 12323.6669134923*$t);
  $X1 += 0.00000000358 * cos(4.87210297876 + 9917.45305702629*$t);
  $X1 += 0.00000000342 * cos(0.54833716779 + 6262.5442719825*$t);
  $X1 += 0.00000000342 * cos(6.10019640486 + 6304.0950629673*$t);
  $X1 += 0.00000000318 * cos(0.13364568371 + 11926.4982311523*$t);
  $X1 += 0.00000000320 * cos(2.70295484544 + 77714.01528560399*$t);
  $X1 += 0.00000000354 * cos(1.02467818407 + 7238.9194090835*$t);
  $X1 += 0.00000000318 * cos(5.32503015719 + 6254.8704800071*$t);
  $X1 += 0.00000000318 * cos(1.32350341546 + 6311.7688549427*$t);
  $X1 += 0.00000000304 * cos(2.00970548291 + 12779.6946129043*$t);
  $X1 += 0.00000000343 * cos(3.71302827314 + 6298.57213865991*$t);
  $X1 += 0.00000000343 * cos(2.93550529951 + 6268.0671962899*$t);
  $X1 += 0.00000000359 * cos(4.09955266779 + 1052.51220067191*$t);
  $X1 += 0.00000000398 * cos(0.12298117861 + 1551.2890401315*$t);
  $X1 += 0.00000000306 * cos(2.58873546625 + 5863.8350235997*$t);
  $X1 += 0.00000000300 * cos(1.77608786075 + 90280.16698558679*$t);
  $X1 += 0.00000000307 * cos(3.29263568042 + 3893.93801205869*$t);
  $X1 += 0.00000000297 * cos(0.51221148619 + 5429.63565075589*$t);
  $X1 += 0.00000000365 * cos(2.74542548477 + 10022.0810975829*$t);
  $X1 += 0.00000000336 * cos(2.72364909606 + 17782.9758902677*$t);
  $X1 += 0.00000000295 * cos(4.05850212848 + 6702.8043113501*$t);
  $X1 += 0.00000000288 * cos(2.18795828306 + 18073.9487561337*$t);
  $X1 += 0.00000000287 * cos(3.33776996109 + 1577.0997249643*$t);
  $X1 += 0.00000000378 * cos(0.39946174567 + 2353.1099712553*$t);
  $X1 += 0.00000000289 * cos(3.04361347297 + 213.5429129215*$t);
  $X1 += 0.00000000347 * cos(0.72838501040 + 5223.4501023187*$t);
  $X1 += 0.00000000321 * cos(2.23787969105 + 17797.2029842693*$t);
  $X1 += 0.00000000289 * cos(5.30650717041 + 220.6564599223*$t);
  $X1 += 0.00000000260 * cos(1.04284839158 + 955.3559241251*$t);
  $X1 += 0.00000000268 * cos(3.62847841862 + 14945.0723560709*$t);
  $X1 += 0.00000000242 * cos(4.34386674771 + 2544.5582373669*$t);
  $X1 += 0.00000000245 * cos(2.31719119888 + 7632.6994421667*$t);
  $X1 += 0.00000000234 * cos(4.07393437960 + 1596.43025976811*$t);
  $X1 += 0.00000000267 * cos(5.83055956746 + 206.42936592071*$t);
  $X1 += 0.00000000282 * cos(4.50260656021 + 13341.9181287903*$t);
  $X1 += 0.00000000279 * cos(3.13773429847 + 4731.7868098599*$t);
  $X1 += 0.00000000290 * cos(2.03216763842 + 5642.4420600927*$t);
  $X1 += 0.00000000298 * cos(0.93822937797 + 17790.08943726851*$t);
  $X1 += 0.00000000270 * cos(2.16529088691 + 12168.2465140581*$t);
  $X1 += 0.00000000294 * cos(2.52895912407 + 2146.4092339587*$t);
  $X1 += 0.00000000214 * cos(0.93543623291 + 8030.8484455749*$t);
  $X1 += 0.00000000207 * cos(1.60966002008 + 213.0552779545*$t);
  $X1 += 0.00000000216 * cos(5.60316710178 + 3185.43584474911*$t);
  $X1 += 0.00000000195 * cos(2.87143133187 + 5884.68302909969*$t);
  $X1 += 0.00000000199 * cos(3.93236191602 + 1748.2602305505*$t);
  $X1 += 0.00000000250 * cos(4.61596023287 + 6924.1972748571*$t);
  $X1 += 0.00000000194 * cos(2.36749003244 + 641.12142486571*$t);
  $X1 += 0.00000000203 * cos(2.25356528795 + 6503.7323099137*$t);
  $X1 += 0.00000000203 * cos(4.39496828470 + 6062.9070250361*$t);
  $X1 += 0.00000000258 * cos(5.63025007570 + 796.0541893329*$t);
  $X1 += 0.00000000189 * cos(1.63377883836 + 11506.52595231009*$t);
  $X1 += 0.00000000186 * cos(0.12949416246 + 18209.5740811437*$t);
  $X1 += 0.00000000184 * cos(4.20955149479 + 12566.4628277691*$t);
  $X1 += 0.00000000180 * cos(5.76808682495 + 853.4401992355*$t);
  $X1 += 0.00000000185 * cos(4.68506649147 + 3495.78900865049*$t);
  $X1 += 0.00000000205 * cos(4.93663483706 + 5849.1202946311*$t);
  $X1 += 0.00000000187 * cos(5.91135912176 + 10213.5293636945*$t);
  $X1 += 0.00000000187 * cos(2.05685668523 + 6290.36590417291*$t);
  $X1 += 0.00000000187 * cos(4.59167688742 + 6276.2734307769*$t);
  $X1 += 0.00000000235 * cos(5.91611965384 + 9779.3524936089*$t);
  $X1 += 0.00000000173 * cos(1.38702654435 + 19651.2922985815*$t);
  $X1 += 0.00000000184 * cos(4.65365446464 + 12566.32820716351*$t);
  $X1 += 0.00000000230 * cos(2.23774195109 + 12567.37583853451*$t);
  $X1 += 0.00000000166 * cos(1.32597581910 + 110.45013870291*$t);
  $X1 += 0.00000000189 * cos(2.84387211432 + 3.76693583251*$t);
  $X1 += 0.00000000166 * cos(1.19482070134 + 433.9555553603*$t);
  $X1 += 0.00000000186 * cos(4.46969004938 + 5863.3473886327*$t);
  $X1 += 0.00000000184 * cos(3.01631602481 + 10983.94853421629*$t);
  $X1 += 0.00000000184 * cos(3.38049875173 + 6037.4880212455*$t);
  $X1 += 0.00000000156 * cos(2.34433370292 + 2648.6986429565*$t);
  $X1 += 0.00000000182 * cos(3.47271515850 + 10969.72144021469*$t);
  $X1 += 0.00000000175 * cos(3.26771548230 + 6529.1513137043*$t);
  $X1 += 0.00000000154 * cos(5.67725689556 + 6453.9925380941*$t);
  $X1 += 0.00000000154 * cos(0.97127667708 + 6112.6467968557*$t);
  $X1 += 0.00000000164 * cos(4.52273465985 + 12353.0964220283*$t);
  $X1 += 0.00000000146 * cos(4.05729660897 + 149.8070146181*$t);
  $X1 += 0.00000000184 * cos(0.20513580951 + 11015.3502948183*$t);
  $X1 += 0.00000000191 * cos(2.29402324776 + 3894.4256470257*$t);
  $X1 += 0.00000000144 * cos(3.76178854682 + 18636.1722720197*$t);
  $X1 += 0.00000000146 * cos(1.99164382254 + 13760.8425276909*$t);
  $X1 += 0.00000000142 * cos(1.34565609994 + 4156.95462512869*$t);
  $X1 += 0.00000000185 * cos(3.72101619927 + 7234.5504387585*$t);
  $X1 += 0.00000000133 * cos(0.01824676794 + 18139.5383188994*$t);
  $X1 += 0.00000000131 * cos(4.75893185547 + 5507.3094211839*$t);
  $X1 += 0.00000000146 * cos(5.03857686201 + 18875.2820522905*$t);
  $X1 += 0.00000000128 * cos(3.41348197806 + 6069.53293706989*$t);
  $X1 += 0.00000000128 * cos(0.18086618365 + 16200.52890701769*$t);
  $X1 += 0.00000000123 * cos(5.45134858107 + 20.5315780089*$t);
  $X1 += 0.00000000121 * cos(0.98195264587 + 17256.8753538249*$t);
  $X1 += 0.00000000123 * cos(0.10275700246 + 6393.5259886943*$t);
  $X1 += 0.00000000123 * cos(0.26259126301 + 6173.1133462555*$t);
  $X1 += 0.00000000117 * cos(4.47711713050 + 18852.9944858067*$t);
  $X1 += 0.00000000120 * cos(1.03913122140 + 9381.2034902007*$t);
  $X1 += 0.00000000113 * cos(2.33706395068 + 65147.37595065419*$t);
  $X1 += 0.00000000137 * cos(3.68199834086 + 16201.0165419847*$t);
  $X1 += 0.00000000113 * cos(5.07439785395 + 6836.40143535029*$t);
  $X1 += 0.00000000123 * cos(4.42839393502 + 12565.4151963981*$t);
  $X1 += 0.00000000132 * cos(6.08414353296 + 17655.0243572331*$t);
  $X1 += 0.00000000113 * cos(4.12294240934 + 10575.1628654583*$t);
  $X1 += 0.00000000113 * cos(2.09696400140 + 10213.0417287275*$t);
  $X1 += 0.00000000116 * cos(2.23828708218 + 17253.2849251731*$t);
  $X1 += 0.00000000120 * cos(2.28034205827 + 10420.23010099111*$t);
  $X1 += 0.00000000109 * cos(0.50597705280 + 633.0275567967*$t);
  $X1 += 0.00000000103 * cos(0.11832394316 + 6295.0490203109*$t);
  $X1 += 0.00000000103 * cos(0.24702432231 + 6271.5903146389*$t);
  $X1 += 0.00000000104 * cos(5.58102765204 + 23013.7833570707*$t);
  $X1 += 0.00000000105 * cos(3.75605193168 + 11790.3852711753*$t);
  $X1 += 0.00000000109 * cos(2.65465737803 + 3340.36860921629*$t);
  $X1 += 0.00000000102 * cos(2.59681923716 + 10970.2090751817*$t);
  $X1 += 0.00000000101 * cos(4.42190708814 + 4803.9654584435*$t);
  $X1 += 0.00000000114 * cos(2.21750546661 + 4171.1817191303*$t);
  $X1 += 0.00000000111 * cos(3.66232090402 + 1582.2031657665*$t);
  $X1 += 0.00000000107 * cos(2.47220154064 + 23543.4743221653*$t);
  $X1 += 0.00000000099 * cos(2.67705199399 + 10973.3118688665*$t);
  $X1 += 0.00000000102 * cos(5.67042027327 + 6549.9267091967*$t);
  $X1 += 0.00000000102 * cos(0.97811329938 + 6016.7126257531*$t);
  $X1 += 0.00000000120 * cos(2.49695982999 + 11514.1271342779*$t);
  $X1 += 0.00000000095 * cos(2.69903868611 + 17267.5120191747*$t);
  $X1 += 0.00000000121 * cos(0.05336928445 + 13625.7774476555*$t);
  $X1 += 0.00000000100 * cos(2.04355401267 + 10976.83498721549*$t);
  $X1 += 0.00000000090 * cos(3.68840859712 + 76.50988875911*$t);
  $X1 += 0.00000000100 * cos(4.37665365923 + 8661.9965060795*$t);
  $X1 += 0.00000000089 * cos(5.33255005639 + 1350.1112271423*$t);
  $X1 += 0.00000000087 * cos(4.33390332130 + 9917.9406919933*$t);
  $X1 += 0.00000000086 * cos(5.93949751968 + 12809.12412144031*$t);
  $X1 += 0.00000000095 * cos(1.34358559692 + 12345.9828750275*$t);
  $X1 += 0.00000000084 * cos(1.54530867800 + 775.2787938405*$t);
  $X1 += 0.00000000106 * cos(5.14280637669 + 11216.5281078075*$t);
  $X1 += 0.00000000095 * cos(2.50046187937 + 12012.8261146239*$t);
  $X1 += 0.00000000082 * cos(0.01600918310 + 5643.4223811609*$t);
  $X1 += 0.00000000081 * cos(3.84772162011 + 11614.6771112157*$t);
  $X1 += 0.00000000084 * cos(1.14755262027 + 6255.9181113781*$t);
  $X1 += 0.00000000084 * cos(5.50098095238 + 6310.7212235717*$t);
  $X1 += 0.00000000080 * cos(0.34711727404 + 6923.2169537889*$t);
  $X1 += 0.00000000085 * cos(5.79487336888 + 5635.8211991931*$t);
  $X1 += 0.00000000084 * cos(3.04423309467 + 10440.03047512009*$t);
  $X1 += 0.00000000080 * cos(4.19702378753 + 3583.5848481573*$t);
  $X1 += 0.00000000092 * cos(0.87932993874 + 10818.3791043993*$t);
  $X1 += 0.00000000077 * cos(5.70308186355 + 6993.2527160332*$t);
  $X1 += 0.00000000080 * cos(1.36958890049 + 13521.9952590749*$t);
  $X1 += 0.00000000104 * cos(5.42045444776 + 5650.0482931947*$t);
  $X1 += 0.00000000093 * cos(0.29330855376 + 4732.2744448269*$t);
  $X1 += 0.00000000085 * cos(0.17489631763 + 22805.4917485101*$t);
  $X1 += 0.00000000086 * cos(0.81273058913 + 12360.2099690291*$t);
  $X1 += 0.00000000075 * cos(4.00156639703 + 5120.35732810009*$t);
  $X1 += 0.00000000090 * cos(0.62558959530 + 6370.62787201471*$t);
  $X1 += 0.00000000090 * cos(6.02294397735 + 6196.0114629351*$t);
  $X1 += 0.00000000082 * cos(0.19767948100 + 18842.3578204569*$t);
  $X1 += 0.00000000101 * cos(6.08995730057 + 3097.64000524229*$t);
  $X1 += 0.00000000094 * cos(5.45896547971 + 10177.01386205009*$t);
  $X1 += 0.00000000083 * cos(5.31992956371 + 18415.7596295809*$t);
  $X1 += 0.00000000073 * cos(6.09826272325 + 949.4194264533*$t);
  $X1 += 0.00000000101 * cos(2.86248284119 + 3104.6862419403*$t);
  $X1 += 0.00000000074 * cos(5.96635290969 + 13517.62628874989*$t);
  $X1 += 0.00000000092 * cos(2.35039346805 + 16858.7263504167*$t);
  $X1 += 0.00000000075 * cos(0.00198703030 + 1059.1381127057*$t);
  $X1 += 0.00000000085 * cos(6.09242867296 + 398.3928208917*$t);
  $X1 += 0.00000000069 * cos(0.89145782253 + 11713.1991357143*$t);
  $X1 += 0.00000000084 * cos(4.35477901935 + 2378.9206560881*$t);
  $X1 += 0.00000000069 * cos(0.61262618132 + 11712.71150074729*$t);
  $X1 += 0.00000000075 * cos(1.62832949134 + 30356.2411372513*$t);
  $X1 += 0.00000000067 * cos(4.61214364579 + 3154.9309023791*$t);
  $X1 += 0.00000000076 * cos(4.83480996889 + 18429.9867235825*$t);
  $X1 += 0.00000000068 * cos(4.26265140929 + 11925.5179100841*$t);
  $X1 += 0.00000000067 * cos(3.24609638890 + 10454.25756912169*$t);
  $X1 += 0.00000000073 * cos(6.07047724510 + 15670.83794192309*$t);
  $X1 += 0.00000000065 * cos(0.20786131115 + 6438.2524319421*$t);
  $X1 += 0.00000000069 * cos(3.29499829591 + 17298.4261448097*$t);
  $X1 += 0.00000000087 * cos(5.09754892709 + 3904.1551939033*$t);
  $X1 += 0.00000000076 * cos(0.73384165663 + 5231.0512842865*$t);
  $X1 += 0.00000000064 * cos(3.69394501139 + 3496.2766436175*$t);
  $X1 += 0.00000000078 * cos(4.31639568529 + 8672.21368792411*$t);
  $X1 += 0.00000000066 * cos(3.41816290372 + 14143.2514249471*$t);
  $X1 += 0.00000000063 * cos(0.99537559299 + 24357.0246061251*$t);
  $X1 += 0.00000000063 * cos(5.29204726636 + 15720.5949673949*$t);
  $X1 += 0.00000000061 * cos(3.72699038600 + 16460.5773470085*$t);
  $X1 += 0.00000000073 * cos(4.50408758477 + 9387.76209193169*$t);
  $X1 += 0.00000000057 * cos(2.80099560279 + 17259.91083720689*$t);
  $X1 += 0.00000000059 * cos(0.69432195316 + 9778.8648586419*$t);
  $X1 += 0.00000000058 * cos(3.24953926506 + 155.6642169177*$t);
  $X1 += 0.00000000060 * cos(3.51548937348 + 34570.3101523361*$t);
  $X1 += 0.00000000057 * cos(4.46074610322 + 149854.64395229139*$t);
  $X1 += 0.00000000056 * cos(5.33393809517 + 12456.1891962469*$t);
  $X1 += 0.00000000056 * cos(0.91240244730 + 17996.2749857057*$t);
  $X1 += 0.00000000056 * cos(2.17966368743 + 11764.5745863425*$t);
  $X1 += 0.00000000054 * cos(2.96145051332 + 4705.4884900601*$t);
  $X1 += 0.00000000055 * cos(4.53949491324 + 13915.77529215809*$t);
  $X1 += 0.00000000061 * cos(0.15191781763 + 28237.4772768729*$t);
  $X1 += 0.00000000065 * cos(5.87045161229 + 7335.5880506633*$t);
  $X1 += 0.00000000072 * cos(0.77556931591 + 6055.8435346859*$t);
  $X1 += 0.00000000072 * cos(5.87296425674 + 6510.7958002639*$t);
  $X1 += 0.00000000071 * cos(0.23083621209 + 12545.6201219739*$t);
  $X1 += 0.00000000061 * cos(1.27148175728 + 6312.74917601091*$t);
  $X1 += 0.00000000061 * cos(5.37705181537 + 6253.8901589389*$t);
  $X1 += 0.00000000052 * cos(0.26640147565 + 5326.5428765373*$t);
  $X1 += 0.00000000054 * cos(1.21229891621 + 2699.49100183409*$t);
  $X1 += 0.00000000052 * cos(2.44818566509 + 8983.0544867925*$t);
  $X1 += 0.00000000066 * cos(2.35337977576 + 14919.2616712381*$t);
  $X1 += 0.00000000050 * cos(5.93502263343 + 5572.8989839496*$t);
  $X1 += 0.00000000051 * cos(0.76420455409 + 16522.4158985187*$t);
  $X1 += 0.00000000049 * cos(4.18738074622 + 35579.9350570535*$t);
  $X1 += 0.00000000053 * cos(1.36303997543 + 6208.5380689076*$t);
  $X1 += 0.00000000053 * cos(5.28549359722 + 6358.1012660422*$t);
  $X1 += 0.00000000049 * cos(4.92672897893 + 21393.7857873411*$t);
  $X1 += 0.00000000049 * cos(6.04327871377 + 5547.4431539431*$t);
  $X1 += 0.00000000049 * cos(0.60525485888 + 7019.19618100671*$t);
  $X1 += 0.00000000049 * cos(2.59123701567 + 12416.8323203317*$t);
  $X1 += 0.00000000050 * cos(5.65157500725 + 12592.2062022991*$t);
  $X1 += 0.00000000050 * cos(0.07520350695 + 26084.2656236997*$t);
  $X1 += 0.00000000051 * cos(3.40680645218 + 23006.6698100699*$t);
  $X1 += 0.00000000058 * cos(2.46543782438 + 15141.14697682849*$t);
  $X1 += 0.00000000047 * cos(0.97665096734 + 24279.3508356971*$t);
  $X1 += 0.00000000049 * cos(4.98006572526 + 6816.53375091851*$t);
  $X1 += 0.00000000049 * cos(1.66846784739 + 5750.1055840313*$t);
  $X1 += 0.00000000046 * cos(3.45134537804 + 19379.1623325523*$t);
  $X1 += 0.00000000052 * cos(4.17729143118 + 16737.33341911309*$t);
  $X1 += 0.00000000047 * cos(2.09298679166 + 24066.0517402591*$t);
  $X1 += 0.00000000046 * cos(5.73796654718 + 104351.85638378029*$t);
  $X1 += 0.00000000063 * cos(1.54245276158 + 8662.48414104651*$t);
  $X1 += 0.00000000048 * cos(1.71424177408 + 26735.7014447297*$t);
  $X1 += 0.00000000046 * cos(5.48854983581 + 12132.6837795895*$t);
  $X1 += 0.00000000050 * cos(4.49443808542 + 24602.8562523545*$t);
  $X1 += 0.00000000054 * cos(0.03975141461 + 7834.3648901229*$t);
  $X1 += 0.00000000045 * cos(5.05887207146 + 161000.92955515759*$t);
  $X1 += 0.00000000049 * cos(4.51484833854 + 29303.9727540629*$t);
  $X1 += 0.00000000049 * cos(3.00236481482 + 10984.4361691833*$t);
  $X1 += 0.00000000045 * cos(5.42122497288 + 45584.9289947039*$t);
  $X1 += 0.00000000046 * cos(3.44074843825 + 5244.2930566845*$t);
  $X1 += 0.00000000048 * cos(1.96431249949 + 23581.0143598341*$t);
  $X1 += 0.00000000049 * cos(0.60097746518 + 19650.8046636145*$t);
  $X1 += 0.00000000049 * cos(4.98977220505 + 29289.7456600613*$t);
  $X1 += 0.00000000044 * cos(3.01088620106 + 6390.9831914135*$t);
  $X1 += 0.00000000044 * cos(3.63764737159 + 6175.6561435363*$t);
  $X1 += 0.00000000051 * cos(1.08500510566 + 17789.60180230149*$t);
  $X1 += 0.00000000042 * cos(1.47304377234 + 24705.9490265731*$t);
  $X1 += 0.00000000042 * cos(4.33726197214 + 15663.79170522509*$t);
  $X1 += 0.00000000043 * cos(1.51170891404 + 16460.08971204149*$t);
  $X1 += 0.00000000043 * cos(1.85670214007 + 553.8132203259*$t);
  $X1 += 0.00000000041 * cos(4.78695133916 + 17370.6047933933*$t);
  $X1 += 0.00000000053 * cos(1.02071442021 + 13119.47728534169*$t);
  $X1 += 0.00000000042 * cos(0.40756986853 + 4164.5558070965*$t);
  $X1 += 0.00000000041 * cos(3.62600931231 + 23020.8969040715*$t);
  $X1 += 0.00000000045 * cos(2.13148338898 + 54247.1693182669*$t);
  $X1 += 0.00000000040 * cos(3.00393862246 + 32243.2546833971*$t);
  $X1 += 0.00000000040 * cos(0.45945430396 + 24336.2492106327*$t);
  $X1 += 0.00000000040 * cos(0.14772670564 + 11769.6098756829*$t);
  $X1 += 0.00000000045 * cos(4.68905632727 + 16723.10632511149*$t);
  $X1 += 0.00000000045 * cos(1.54746367368 + 16723.5939600785*$t);
  $X1 += 0.00000000042 * cos(4.32247442790 + 8827.14645239129*$t);
  $X1 += 0.00000000040 * cos(0.00254937606 + 8402.0835278533*$t);
  $X1 += 0.00000000039 * cos(5.06793905702 + 16062.4283436003*$t);
  $X1 += 0.00000000044 * cos(2.87431244066 + 5856.23384163189*$t);
  $X1 += 0.00000000038 * cos(2.71291798518 + 6297.5467614765*$t);
  $X1 += 0.00000000038 * cos(3.93561558747 + 6269.0925734733*$t);
  $X1 += 0.00000000041 * cos(4.95313128130 + 15508.8589407579*$t);
  $X1 += 0.00000000038 * cos(0.25558032671 + 6394.50630976251*$t);
  $X1 += 0.00000000038 * cos(0.10976793876 + 6172.1330251873*$t);
  $X1 += 0.00000000039 * cos(3.31895424299 + 29826.5501721567*$t);
  $X1 += 0.00000000046 * cos(5.02561530595 + 17297.9385098427*$t);
  $X1 += 0.00000000041 * cos(2.47236149910 + 6309.1303523077*$t);
  $X1 += 0.00000000038 * cos(1.11170997081 + 29089.0552334685*$t);
  $X1 += 0.00000000038 * cos(6.16488744565 + 11933.6117781531*$t);
  $X1 += 0.00000000037 * cos(4.91170884792 + 26482.4146271079*$t);
  $X1 += 0.00000000037 * cos(2.07642652738 + 20452.6255947383*$t);
  $X1 += 0.00000000037 * cos(5.02138933475 + 18073.46112116669*$t);
  $X1 += 0.00000000036 * cos(1.41330554556 + 11499.41240530929*$t);
  $X1 += 0.00000000045 * cos(0.04410300421 + 3340.8562441833*$t);
  $X1 += 0.00000000049 * cos(5.78167784671 + 18216.6876281445*$t);
  $X1 += 0.00000000038 * cos(6.16266694488 + 18202.4605341429*$t);
  $X1 += 0.00000000041 * cos(5.48085477947 + 5216.8241902849*$t);
  $X1 += 0.00000000036 * cos(4.64059514280 + 4060.97539791089*$t);
  $X1 += 0.00000000048 * cos(0.43106257187 + 951.9622237341*$t);
  $X1 += 0.00000000041 * cos(2.33852383906 + 18848.98373249069*$t);
  $X1 += 0.00000000038 * cos(6.17960213131 + 26709.8907598969*$t);
  $X1 += 0.00000000036 * cos(4.69601378640 + 28230.4310401749*$t);
  $X1 += 0.00000000036 * cos(0.39760453863 + 24491.18197509989*$t);
  $X1 += 0.00000000036 * cos(6.28050310342 + 9924.5666040271*$t);
  $X1 += 0.00000000048 * cos(0.32621587842 + 8982.5668518255*$t);
  $X1 += 0.00000000037 * cos(5.17748996647 + 22484.0923919761*$t);
  $X1 += 0.00000000047 * cos(1.64189885412 + 6040.10342853389*$t);
  $X1 += 0.00000000034 * cos(5.26052334707 + 6418.9449924849*$t);
  $X1 += 0.00000000034 * cos(1.38801022558 + 6147.69434246491*$t);
  $X1 += 0.00000000034 * cos(2.09927479760 + 9380.71585523369*$t);
  $X1 += 0.00000000036 * cos(5.01642644412 + 7238.4317741165*$t);
  $X1 += 0.00000000034 * cos(1.97967235505 + 17272.1278250099*$t);
  $X1 += 0.00000000037 * cos(2.80234472663 + 58953.3892607775*$t);
  $X1 += 0.00000000034 * cos(1.90506635542 + 29026.7290469913*$t);
  $X1 += 0.00000000033 * cos(2.30422309015 + 12721.32828193349*$t);
  $X1 += 0.00000000035 * cos(3.20661909223 + 7322.34627826531*$t);
  $X1 += 0.00000000044 * cos(2.79016934175 + 3981.73385156551*$t);
  $X1 += 0.00000000033 * cos(2.02741588975 + 19804.5834740993*$t);
  $X1 += 0.00000000033 * cos(4.13127522861 + 173567.08125514039*$t);
  $X1 += 0.00000000033 * cos(4.59578048276 + 205.9417309537*$t);
  $X1 += 0.00000000033 * cos(3.87810188817 + 23013.29572210369*$t);
  $X1 += 0.00000000034 * cos(0.56182222293 + 49515.1386909235*$t);
  $X1 += 0.00000000034 * cos(4.95130100456 + 38500.5198485557*$t);
  $X1 += 0.00000000032 * cos(4.38300866562 + 17686.9966630499*$t);
  $X1 += 0.00000000036 * cos(0.10343586811 + 5641.9544251257*$t);
  $X1 += 0.00000000032 * cos(4.48170445266 + 21228.63584102931*$t);
  $X1 += 0.00000000033 * cos(1.70919210465 + 34520.5531268643*$t);
  $X1 += 0.00000000033 * cos(4.08300924175 + 8635.69818627969*$t);
  $X1 += 0.00000000031 * cos(0.30962555206 + 5746.0275204125*$t);
  $X1 += 0.00000000041 * cos(4.09101330171 + 21202.3375212295*$t);
  $X1 += 0.00000000037 * cos(1.21597687953 + 7349.81514466491*$t);
  $X1 += 0.00000000034 * cos(0.61019544663 + 16496.11757871889*$t);
  $X1 += 0.00000000032 * cos(2.47223060088 + 33019.2649296881*$t);
  $X1 += 0.00000000032 * cos(6.25412877228 + 21150.56954840009*$t);
  $X1 += 0.00000000037 * cos(3.41910013684 + 29296.8592070621*$t);
  $X1 += 0.00000000036 * cos(3.45170661535 + 27511.2240560537*$t);
  $X1 += 0.00000000035 * cos(2.20855027459 + 11933.12414318609*$t);
  $X1 += 0.00000000035 * cos(2.69261850768 + 11918.89704918449*$t);
  $X1 += 0.00000000035 * cos(0.83074174405 + 29062.7569136687*$t);
  $X1 += 0.00000000030 * cos(2.96012497927 + 12490.1294461907*$t);
  $X1 += 0.00000000032 * cos(0.38688555099 + 6334.60000533731*$t);
  $X1 += 0.00000000032 * cos(6.26164802166 + 6232.03932961249*$t);
  $X1 += 0.00000000029 * cos(2.48914084100 + 419.2408263917*$t);
  $X1 += 0.00000000029 * cos(2.48914084100 + 419.72846135871*$t);
  $X1 += 0.00000000029 * cos(0.09098498823 + 16858.23871544969*$t);
  $X1 += 0.00000000030 * cos(4.30269873097 + 16208.13008898551*$t);
  $X1 += 0.00000000029 * cos(2.26254947152 + 27278.7126339243*$t);
  $X1 += 0.00000000032 * cos(3.16446260317 + 5017.2645538815*$t);
  $X1 += 0.00000000028 * cos(1.87847577782 + 24080.2788342607*$t);
  $X1 += 0.00000000030 * cos(2.57345584103 + 23539.9512038163*$t);
  $X1 += 0.00000000029 * cos(6.17121903514 + 18606.25512851669*$t);
  $X1 += 0.00000000030 * cos(3.16071544619 + 30665.9111409493*$t);
  $X1 += 0.00000000034 * cos(5.86279015300 + 6660.6932753907*$t);
  $X1 += 0.00000000034 * cos(0.78574341965 + 5905.94605955911*$t);
  $X1 += 0.00000000038 * cos(5.12222686816 + 31571.0434668747*$t);
  $X1 += 0.00000000038 * cos(2.95935499043 + 16061.94070863329*$t);
  $X1 += 0.00000000029 * cos(0.07805875622 + 23539.46356884929*$t);
  $X1 += 0.00000000033 * cos(1.31621330654 + 3738.51761262449*$t);
  $X1 += 0.00000000028 * cos(4.45185289388 + 2942.21960580809*$t);
  $X1 += 0.00000000032 * cos(4.32330584281 + 15110.7099373497*$t);
  $X1 += 0.00000000030 * cos(1.39195112722 + 55023.1795645579*$t);
  $X1 += 0.00000000027 * cos(0.53286078729 + 233141.55822184499*$t);
  $X1 += 0.00000000030 * cos(2.32405719366 + 12587.1709129587*$t);
  $X1 += 0.00000000028 * cos(5.54771281521 + 34911.6558935745*$t);
  $X1 += 0.00000000027 * cos(6.17188911074 + 1692.40948698591*$t);
  $X1 += 0.00000000027 * cos(4.56663555607 + 2544.07060239989*$t);
  $X1 += 0.00000000027 * cos(3.42500443489 + 24382.8352909579*$t);
  $X1 += 0.00000000027 * cos(5.99215939135 + 6205.6458970469*$t);
  $X1 += 0.00000000027 * cos(0.65637418130 + 6360.99343790291*$t);
  $X1 += 0.00000000027 * cos(0.24480889857 + 31172.8944634665*$t);
  $X1 += 0.00000000026 * cos(3.76734683925 + 36949.4746259077*$t);
  $X1 += 0.00000000034 * cos(6.02674277322 + 18053.1733606413*$t);
  $X1 += 0.00000000027 * cos(2.32047706036 + 32367.3414736911*$t);
  $X1 += 0.00000000027 * cos(1.77181133426 + 4487.57358878689*$t);
  $X1 += 0.00000000028 * cos(3.80331914659 + 10239.3400485273*$t);
  $X1 += 0.00000000026 * cos(6.01470923824 + 4796.85191144269*$t);
  $X1 += 0.00000000026 * cos(6.27941236443 + 6226.4212925393*$t);
  $X1 += 0.00000000026 * cos(0.36912120822 + 6340.2180424105*$t);
  $X1 += 0.00000000029 * cos(0.18788001431 + 5974.0413448191*$t);
  $X1 += 0.00000000029 * cos(0.17746825116 + 6592.5979901307*$t);
  $X1 += 0.00000000026 * cos(3.39870851542 + 19402.55313533309*$t);
  $X1 += 0.00000000028 * cos(2.42845493949 + 46386.7499258277*$t);
  $X1 += 0.00000000032 * cos(0.33223863826 + 9225.7830907665*$t);
  $X1 += 0.00000000026 * cos(2.54665382210 + 9910.33951002549*$t);
  $X1 += 0.00000000025 * cos(5.74078884001 + 15265.64270181689*$t);
  $X1 += 0.00000000029 * cos(5.90495655038 + 52176.0501006319*$t);
  $X1 += 0.00000000027 * cos(4.22338082584 + 62883.5989569971*$t);
  $X1 += 0.00000000024 * cos(0.55027097677 + 11617.21990849651*$t);
  $X1 += 0.00000000024 * cos(2.62016281496 + 5120.8449630671*$t);
  $X1 += 0.00000000028 * cos(3.25064295131 + 6680.98103591609*$t);
  $X1 += 0.00000000024 * cos(4.40689701323 + 522.3336006103*$t);
  $X1 += 0.00000000025 * cos(3.86362291910 + 6263.64990657511*$t);
  $X1 += 0.00000000025 * cos(2.78491065355 + 6302.9894283747*$t);
  $X1 += 0.00000000029 * cos(2.44405132476 + 23581.5019948011*$t);
  $X1 += 0.00000000024 * cos(0.50709291410 + 29424.8780503995*$t);
  $X1 += 0.00000000028 * cos(2.66240986547 + 16737.8210540801*$t);
  $X1 += 0.00000000024 * cos(1.98880441412 + 22743.16556203289*$t);
  $X1 += 0.00000000024 * cos(5.13039706771 + 22743.6531969999*$t);
  $X1 += 0.00000000024 * cos(5.85302121512 + 25158.8455372489*$t);
  $X1 += 0.00000000025 * cos(3.95115098429 + 21424.2228268199*$t);
  $X1 += 0.00000000025 * cos(0.80955833070 + 21424.7104617869*$t);
  $X1 += 0.00000000024 * cos(1.92863541994 + 14712.07329897449*$t);
  $X1 += 0.00000000028 * cos(4.50601984314 + 5760.25461441409*$t);
  $X1 += 0.00000000024 * cos(3.73455640738 + 31969.1924702829*$t);
  $X1 += 0.00000000023 * cos(0.62345777089 + 17893.1822114871*$t);
  $X1 += 0.00000000030 * cos(3.85563309519 + 8584.9054833843*$t);
  $X1 += 0.00000000024 * cos(3.21746306158 + 23550.5878691661*$t);
  $X1 += 0.00000000023 * cos(1.36063534536 + 6717.0314053517*$t);
  $X1 += 0.00000000022 * cos(3.99741791962 + 7445.7943718827*$t);
  $X1 += 0.00000000023 * cos(5.13650786055 + 5849.6079295981*$t);
  $X1 += 0.00000000025 * cos(0.81555419576 + 14155.4684127501*$t);
  $X1 += 0.00000000023 * cos(3.58569412080 + 6294.36536773881*$t);
  $X1 += 0.00000000023 * cos(3.06283945185 + 6272.273967211*$t);
  $X1 += 0.00000000024 * cos(4.24597953395 + 18208.1061251085*$t);
  $X1 += 0.00000000024 * cos(1.10438688036 + 18208.5937600755*$t);
  $X1 += 0.00000000021 * cos(5.78251945962 + 22779.6810636773*$t);
  $X1 += 0.00000000029 * cos(3.31448732534 + 28628.5800435831*$t);
  $X1 += 0.00000000021 * cos(5.13427576878 + 40879.6843221273*$t);
  $X1 += 0.00000000021 * cos(4.08575884387 + 30221.1760572159*$t);
  $X1 += 0.00000000022 * cos(1.38262024424 + 4379.8828549737*$t);
  $X1 += 0.00000000022 * cos(5.26591980546 + 8186.7564799761*$t);
  $X1 += 0.00000000022 * cos(4.52225402167 + 28760.05469496669*$t);
  $X1 += 0.00000000026 * cos(3.41053115091 + 18422.8731765817*$t);
  $X1 += 0.00000000020 * cos(0.80720267360 + 12036.21691740469*$t);
  $X1 += 0.00000000020 * cos(4.78724181293 + 28313.0449871775*$t);
  $X1 += 0.00000000027 * cos(0.67000770864 + 34513.5068901663*$t);
  $X1 += 0.00000000020 * cos(2.07630932980 + 34115.3578867581*$t);
  $X1 += 0.00000000020 * cos(1.72148703277 + 21548.7185518083*$t);
  $X1 += 0.00000000020 * cos(3.68576430300 + 17654.5367222661*$t);
  $X1 += 0.00000000025 * cos(3.53209868087 + 55798.7021758819*$t);
  $X1 += 0.00000000020 * cos(0.81961551511 + 20597.4877805247*$t);
  $X1 += 0.00000000020 * cos(2.60684350676 + 18875.76968725751*$t);
  $X1 += 0.00000000022 * cos(0.44774356245 + 1588.82907780029*$t);
  $X1 += 0.00000000024 * cos(1.20852424503 + 9411.7084325707*$t);
  $X1 += 0.00000000019 * cos(5.85945140949 + 536.5606946119*$t);
  $X1 += 0.00000000020 * cos(4.99560905506 + 6187.3404402571*$t);
  $X1 += 0.00000000020 * cos(1.65292451759 + 6379.2988946927*$t);
  $X1 += 0.00000000022 * cos(4.44471803531 + 18326.8939493639*$t);
  $X1 += 0.00000000022 * cos(2.18348213630 + 6233.5626420031*$t);
  $X1 += 0.00000000022 * cos(4.46505143635 + 6333.0766929467*$t);
  $X1 += 0.00000000018 * cos(2.03036294822 + 5972.4788686065*$t);
  $X1 += 0.00000000018 * cos(4.61817062443 + 6594.1604663433*$t);
  $X1 += 0.00000000019 * cos(4.28397604583 + 6948.0757126049*$t);
  $X1 += 0.00000000019 * cos(2.36455752682 + 5618.5636223449*$t);
  $X1 += 0.00000000019 * cos(0.18461366541 + 83974.07917321339*$t);
  $X1 += 0.00000000019 * cos(4.29574443999 + 84020.10309797739*$t);
  $X1 += 0.00000000020 * cos(3.84957027230 + 50316.9596220473*$t);
  $X1 += 0.00000000020 * cos(2.85391796921 + 9070.3626913323*$t);
  return $X1*$t;
}



  function Earth_C_X2 ($t)
{
  $X2 =  0.0;
  $X2 += 0.00052911498 * cos(3.32403354915 + 6283.3196674749*$t);
  $X2 += 0.00006074441 * cos(2.05485843872 + 0.2438174835*$t);
  $X2 += 0.00002406871 * cos(4.23086027149 + 12566.3955174663*$t);
  $X2 += 0.00000096033 * cos(4.14485769516 + 18849.4713674577*$t);
  $X2 += 0.00000029888 * cos(0.73436192593 + 6282.83203250789*$t);
  $X2 += 0.00000014021 * cos(3.21121684298 + 6279.7965491259*$t);
  $X2 += 0.00000013375 * cos(3.31400005464 + 6286.84278582391*$t);
  $X2 += 0.00000008148 * cos(2.19949162987 + 6309.61798727471*$t);
  $X2 += 0.00000008195 * cos(4.38954108022 + 6257.0213476751*$t);
  $X2 += 0.00000008001 * cos(5.91956929382 + 6127.8992680407*$t);
  $X2 += 0.00000007754 * cos(0.72231700953 + 6438.7400669091*$t);
  $X2 += 0.00000007223 * cos(5.38114271434 + 83997.09113559539*$t);
  $X2 += 0.00000004616 * cos(6.16703227370 + 710.1768660418*$t);
  $X2 += 0.00000003060 * cos(4.83964573312 + 4705.9761250271*$t);
  $X2 += 0.00000003717 * cos(2.45040909403 + 5507.7970561509*$t);
  $X2 += 0.00000002991 * cos(4.05993241608 + 25132.5472174491*$t);
  $X2 += 0.00000003235 * cos(4.10584554352 + 7058.8422787989*$t);
  $X2 += 0.00000002393 * cos(3.40776365917 + 775.7664288075*$t);
  $X2 += 0.00000002034 * cos(4.34141229883 + 6290.4332144757*$t);
  $X2 += 0.00000002028 * cos(2.28023581144 + 6276.2061204741*$t);
  $X2 += 0.00000002064 * cos(1.58527926677 + 7860.6632099227*$t);
  $X2 += 0.00000001914 * cos(4.42314112548 + 5487.0216606585*$t);
  $X2 += 0.00000001770 * cos(5.05862783743 + 1059.6257476727*$t);
  $X2 += 0.00000001761 * cos(3.37902852940 + 5753.6287023803*$t);
  $X2 += 0.00000001558 * cos(2.13660228192 + 7079.61767429131*$t);
  $X2 += 0.00000001551 * cos(2.12932375831 + 6040.5910635009*$t);
  $X2 += 0.00000001436 * cos(2.85243683562 + 5885.1706640667*$t);
  $X2 += 0.00000001469 * cos(4.51404554645 + 6526.04827144891*$t);
  $X2 += 0.00000001319 * cos(3.46234944603 + 6681.46867088311*$t);
  $X2 += 0.00000001180 * cos(2.99170595830 + 6813.0106325695*$t);
  $X2 += 0.00000001337 * cos(1.03982518814 + 5729.7502646325*$t);
  $X2 += 0.00000001039 * cos(5.82323058792 + 6282.3393464067*$t);
  $X2 += 0.00000001313 * cos(2.16977183919 + 529.9347825781*$t);
  $X2 += 0.00000001041 * cos(0.76562479642 + 6284.2999885431*$t);
  $X2 += 0.00000001202 * cos(5.59909179750 + 6836.8890703173*$t);
  $X2 += 0.00000000904 * cos(2.42848578586 + 5331.6012612243*$t);
  $X2 += 0.00000000870 * cos(3.83740101245 + 4933.4522578161*$t);
  $X2 += 0.00000001149 * cos(4.59530313333 + 167284.00540514899*$t);
  $X2 += 0.00000001069 * cos(5.80442130983 + 1577.0997249643*$t);
  $X2 += 0.00000000772 * cos(4.23369730112 + 7235.0380737255*$t);
  $X2 += 0.00000000846 * cos(2.93878609085 + 11790.8729061423*$t);
  $X2 += 0.00000000742 * cos(0.30768536261 + 4137.1542509997*$t);
  $X2 += 0.00000000966 * cos(3.62307276164 + 11856.462468908*$t);
  $X2 += 0.00000000664 * cos(2.78855764568 + 7633.1870771337*$t);
  $X2 += 0.00000000662 * cos(4.76048207091 + 1194.6908277081*$t);
  $X2 += 0.00000000659 * cos(1.23774551244 + 11507.0135872771*$t);
  $X2 += 0.00000000853 * cos(5.22418483353 + 4535.3032544079*$t);
  $X2 += 0.00000000823 * cos(5.77365627974 + 155.17658195069*$t);
  $X2 += 0.00000000783 * cos(5.87375907691 + 5088.8726572503*$t);
  $X2 += 0.00000000785 * cos(5.03738396313 + 2353.1099712553*$t);
  $X2 += 0.00000000694 * cos(1.93706172082 + 801.5771136403*$t);
  $X2 += 0.00000000566 * cos(6.00002295544 + 796.5418242999*$t);
  $X2 += 0.00000000684 * cos(2.68347359202 + 3128.6325825793*$t);
  $X2 += 0.00000000499 * cos(2.99674498554 + 12569.91863581531*$t);
  $X2 += 0.00000000596 * cos(1.38539217884 + 8031.3360805419*$t);
  $X2 += 0.00000000486 * cos(6.11316978391 + 1589.3167127673*$t);
  $X2 += 0.00000000483 * cos(6.25283705744 + 8429.4850839501*$t);
  $X2 += 0.00000000441 * cos(0.27873568624 + 6496.6187629129*$t);
  $X2 += 0.00000000412 * cos(5.58840963851 + 4693.75913722409*$t);
  $X2 += 0.00000000561 * cos(0.75091675093 + 7477.7666776995*$t);
  $X2 += 0.00000000390 * cos(6.20968064366 + 6070.0205720369*$t);
  $X2 += 0.00000000405 * cos(1.55299195368 + 3739.0052475915*$t);
  $X2 += 0.00000000501 * cos(3.39229516665 + 1592.8398311163*$t);
  $X2 += 0.00000000392 * cos(5.39455294636 + 26.0545023163*$t);
  $X2 += 0.00000000369 * cos(4.36331143713 + 553.32558535889*$t);
  $X2 += 0.00000000483 * cos(1.36538995021 + 12036.7045523717*$t);
  $X2 += 0.00000000489 * cos(2.13588971106 + 5223.4501023187*$t);
  $X2 += 0.00000000481 * cos(4.74275484789 + 10213.5293636945*$t);
  $X2 += 0.00000000448 * cos(0.85608336591 + 156137.71980228279*$t);
  $X2 += 0.00000000321 * cos(2.96911879180 + 951.4745887671*$t);
  $X2 += 0.00000000320 * cos(2.00218171333 + 1990.9888345245*$t);
  $X2 += 0.00000000361 * cos(0.59519501420 + 12565.9078824993*$t);
  $X2 += 0.00000000361 * cos(0.08584353459 + 12721.8159169005*$t);
  $X2 += 0.00000000412 * cos(5.91338851626 + 398.3928208917*$t);
  $X2 += 0.00000000304 * cos(0.96839213314 + 4690.7236538421*$t);
  $X2 += 0.00000000356 * cos(1.28855678128 + 5481.4987363511*$t);
  $X2 += 0.00000000283 * cos(2.23992178340 + 242.97242145751*$t);
  $X2 += 0.00000000362 * cos(3.88633843420 + 9438.0067523705*$t);
  $X2 += 0.00000000248 * cos(4.75322854174 + 8827.6340873583*$t);
  $X2 += 0.00000000252 * cos(1.16164987849 + 3154.4432674121*$t);
  $X2 += 0.00000000257 * cos(1.79452152688 + 11371.9485072417*$t);
  $X2 += 0.00000000327 * cos(3.02081233401 + 14143.7390599141*$t);
  $X2 += 0.00000000230 * cos(0.23367695814 + 1747.7725955835*$t);
  $X2 += 0.00000000289 * cos(5.24697142787 + 7085.1405985987*$t);
  $X2 += 0.00000000297 * cos(1.59965866765 + 1349.62359217529*$t);
  $X2 += 0.00000000209 * cos(0.27341674720 + 11770.0975106499*$t);
  $X2 += 0.00000000207 * cos(4.92862210539 + 4164.0681721295*$t);
  $X2 += 0.00000000188 * cos(5.64673454004 + 7875.91568110771*$t);
  $X2 += 0.00000000189 * cos(0.60545229996 + 2389.1378379327*$t);
  $X2 += 0.00000000194 * cos(0.41046959310 + 10977.32262218251*$t);
  $X2 += 0.00000000176 * cos(4.08570919572 + 7342.7015976641*$t);
  $X2 += 0.00000000164 * cos(2.79150408226 + 5223.93773728571*$t);
  $X2 += 0.00000000205 * cos(3.21370431881 + 10973.7995038335*$t);
  $X2 += 0.00000000205 * cos(2.25101785528 + 13368.2164485901*$t);
  $X2 += 0.00000000139 * cos(4.61869477858 + 10575.6505004253*$t);
  $X2 += 0.00000000155 * cos(5.81412821499 + 12410.9751180321*$t);
  $X2 += 0.00000000152 * cos(0.10500467147 + 3930.4535137031*$t);
  $X2 += 0.00000000129 * cos(5.52193535090 + 397.9051859247*$t);
  $X2 += 0.00000000127 * cos(0.96654930095 + 12592.6938372661*$t);
  $X2 += 0.00000000132 * cos(0.16052766322 + 8636.18582124671*$t);
  $X2 += 0.00000000122 * cos(4.78358483655 + 13119.9649203087*$t);
  $X2 += 0.00000000163 * cos(0.93280092706 + 5507.3094211839*$t);
  $X2 += 0.00000000114 * cos(5.70431693679 + 17260.3984721739*$t);
  $X2 += 0.00000000118 * cos(2.37854817453 + 4292.5746504339*$t);
  $X2 += 0.00000000148 * cos(5.63695738547 + 17790.08943726851*$t);
  $X2 += 0.00000000123 * cos(3.75785910050 + 12562.8723991173*$t);
  $X2 += 0.00000000103 * cos(3.36994741884 + 13518.1139237169*$t);
  $X2 += 0.00000000138 * cos(3.83865460083 + 12168.2465140581*$t);
  $X2 += 0.00000000107 * cos(4.33977826153 + 10989.0519750185*$t);
  $X2 += 0.00000000104 * cos(5.27997888785 + 2145.92159899169*$t);
  $X2 += 0.00000000096 * cos(1.97792917854 + 6283.25235717211*$t);
  $X2 += 0.00000000099 * cos(2.27831564394 + 13096.0864825609*$t);
  $X2 += 0.00000000096 * cos(1.53382620869 + 6283.3869777777*$t);
  $X2 += 0.00000000084 * cos(5.20596620689 + 16730.70750707931*$t);
  $X2 += 0.00000000111 * cos(3.96322491245 + 12540.0971976665*$t);
  $X2 += 0.00000000087 * cos(6.02515097465 + 10177.5014970171*$t);
  $X2 += 0.00000000078 * cos(4.18422621711 + 12323.6669134923*$t);
  $X2 += 0.00000000076 * cos(5.70862044549 + 6709.91785835091*$t);
  $X2 += 0.00000000105 * cos(3.53845405180 + 5642.4420600927*$t);
  $X2 += 0.00000000073 * cos(0.89693480363 + 5856.7214765989*$t);
  $X2 += 0.00000000102 * cos(0.66758153957 + 250570.91967470259*$t);
  $X2 += 0.00000000070 * cos(5.22505818809 + 5753.14106741329*$t);
  $X2 += 0.00000000071 * cos(0.56166089035 + 14314.4119305333*$t);
  $X2 += 0.00000000092 * cos(1.96485842296 + 13916.2629271251*$t);
  $X2 += 0.00000000070 * cos(2.53450052921 + 7084.6529636317*$t);
  $X2 += 0.00000000091 * cos(3.10960565577 + 6924.1972748571*$t);
  $X2 += 0.00000000083 * cos(3.98989749432 + 31415.6230674405*$t);
  $X2 += 0.00000000088 * cos(5.01539409795 + 71430.45180064559*$t);
  $X2 += 0.00000000074 * cos(1.96538390591 + 529.44714761109*$t);
  $X2 += 0.00000000085 * cos(5.97852929798 + 95143.37673846159*$t);
  $X2 += 0.00000000061 * cos(4.23114381660 + 8274.0646845159*$t);
  $X2 += 0.00000000060 * cos(5.52155170015 + 16496.6052136859*$t);
  $X2 += 0.00000000058 * cos(1.47891111226 + 5642.93474619389*$t);
  $X2 += 0.00000000078 * cos(2.41141378465 + 213.5429129215*$t);
  $X2 += 0.00000000059 * cos(4.67526538731 + 640.1411037975*$t);
  $X2 += 0.00000000057 * cos(2.06129454632 + 4690.23601887509*$t);
  $X2 += 0.00000000056 * cos(3.80170948025 + 13341.9181287903*$t);
  $X2 += 0.00000000065 * cos(3.38872777921 + 4731.7868098599*$t);
  $X2 += 0.00000000051 * cos(4.81168622601 + 3893.93801205869*$t);
  $X2 += 0.00000000050 * cos(4.17369676080 + 12573.5090644671*$t);
  $X2 += 0.00000000050 * cos(4.41669813786 + 3634.37720703489*$t);
  $X2 += 0.00000000049 * cos(2.27712508812 + 18319.7804023631*$t);
  $X2 += 0.00000000066 * cos(5.49585584500 + 2787.2868413409*$t);
  $X2 += 0.00000000049 * cos(1.99905022377 + 13362.6935242827*$t);
  $X2 += 0.00000000048 * cos(3.76233131596 + 12964.5445208745*$t);
  $X2 += 0.00000000053 * cos(4.12374270394 + 14919.2616712381*$t);
  $X2 += 0.00000000058 * cos(1.23083144160 + 1577.5873599313*$t);
  $X2 += 0.00000000052 * cos(1.27828874996 + 15721.0826023619*$t);
  $X2 += 0.00000000061 * cos(3.42876383277 + 4292.0870154669*$t);
  $X2 += 0.00000000044 * cos(0.31046230867 + 24073.1652872599*$t);
  $X2 += 0.00000000044 * cos(0.38954461131 + 10447.14402212089*$t);
  $X2 += 0.00000000042 * cos(4.09986255075 + 20426.8149099055*$t);
  $X2 += 0.00000000059 * cos(1.01599200374 + 84672.23202702119*$t);
  $X2 += 0.00000000051 * cos(5.38279738858 + 6370.62787201471*$t);
  $X2 += 0.00000000051 * cos(1.26573618407 + 6196.0114629351*$t);
  $X2 += 0.00000000046 * cos(0.52171400874 + 2119.00767786191*$t);
  $X2 += 0.00000000041 * cos(4.09327874029 + 3185.43584474911*$t);
  $X2 += 0.00000000056 * cos(3.27189314076 + 10976.83498721549*$t);
  $X2 += 0.00000000051 * cos(2.37524851068 + 9437.5191174035*$t);
  $X2 += 0.00000000049 * cos(3.21159567950 + 239424.63407183639*$t);
  $X2 += 0.00000000036 * cos(6.20393463674 + 3495.78900865049*$t);
  $X2 += 0.00000000044 * cos(3.69396549327 + 18139.5383188994*$t);
  $X2 += 0.00000000035 * cos(3.61386877088 + 3929.96587873609*$t);
  $X2 += 0.00000000044 * cos(1.66014811397 + 8661.9965060795*$t);
  $X2 += 0.00000000046 * cos(3.78615165617 + 3894.4256470257*$t);
  $X2 += 0.00000000034 * cos(3.81444510796 + 6262.5442719825*$t);
  $X2 += 0.00000000034 * cos(5.98049768477 + 6304.0950629673*$t);
  $X2 += 0.00000000035 * cos(3.58408872678 + 18875.2820522905*$t);
  $X2 += 0.00000000035 * cos(6.09075949155 + 10420.23010099111*$t);
  $X2 += 0.00000000032 * cos(0.62535692558 + 23013.7833570707*$t);
  $X2 += 0.00000000034 * cos(3.61147349841 + 7.3573644843*$t);
  $X2 += 0.00000000045 * cos(1.48783646485 + 3340.8562441833*$t);
  $X2 += 0.00000000035 * cos(0.38590076970 + 10213.0417287275*$t);
  $X2 += 0.00000000031 * cos(5.38472872675 + 14712.5609339415*$t);
  $X2 += 0.00000000030 * cos(4.39715700541 + 12809.12412144031*$t);
  $X2 += 0.00000000039 * cos(1.14782571257 + 9779.3524936089*$t);
  $X2 += 0.00000000041 * cos(5.61324415849 + 82576.73740351178*$t);
  $X2 += 0.00000000031 * cos(0.76672410297 + 22779.6810636773*$t);
  $X2 += 0.00000000028 * cos(4.07975589699 + 2942.7072407751*$t);
  $X2 += 0.00000000028 * cos(2.36060849192 + 5429.63565075589*$t);
  $X2 += 0.00000000027 * cos(4.04275590321 + 11014.8626598513*$t);
  $X2 += 0.00000000027 * cos(2.11023646997 + 9623.9320941747*$t);
  $X2 += 0.00000000025 * cos(1.72579553961 + 18209.5740811437*$t);
  $X2 += 0.00000000026 * cos(2.55064187749 + 9381.2034902007*$t);
  $X2 += 0.00000000025 * cos(2.68812943588 + 3583.5848481573*$t);
  $X2 += 0.00000000030 * cos(5.98905764002 + 10447.6316570879*$t);
  $X2 += 0.00000000032 * cos(4.08880306095 + 796.0541893329*$t);
  $X2 += 0.00000000023 * cos(6.09814489767 + 9917.45305702629*$t);
  $X2 += 0.00000000026 * cos(0.90493478768 + 12012.8261146239*$t);
  $X2 += 0.00000000024 * cos(1.88327707702 + 14143.2514249471*$t);
  $X2 += 0.00000000023 * cos(2.26727226510 + 26709.8907598969*$t);
  $X2 += 0.00000000021 * cos(3.86895197800 + 7632.6994421667*$t);
  $X2 += 0.00000000021 * cos(2.37138453193 + 17256.8753538249*$t);
  $X2 += 0.00000000028 * cos(1.07450535792 + 12353.0964220283*$t);
  $X2 += 0.00000000022 * cos(4.83463880427 + 77714.01528560399*$t);
  $X2 += 0.00000000021 * cos(5.98744320172 + 6993.2527160332*$t);
  $X2 += 0.00000000020 * cos(0.31265663265 + 6836.40143535029*$t);
  $X2 += 0.00000000020 * cos(5.44332565028 + 1748.2602305505*$t);
  $X2 += 0.00000000026 * cos(2.02675372626 + 9225.7830907665*$t);
  $X2 += 0.00000000023 * cos(0.80832702606 + 149854.64395229139*$t);
  $X2 += 0.00000000026 * cos(5.31358634432 + 2544.07060239989*$t);
  $X2 += 0.00000000018 * cos(2.28255799994 + 11614.6771112157*$t);
  $X2 += 0.00000000020 * cos(4.61413285151 + 426.8420083595*$t);
  $X2 += 0.00000000019 * cos(3.66100662326 + 30640.1004561165*$t);
  $X2 += 0.00000000018 * cos(4.77794649120 + 155.6642169177*$t);
  $X2 += 0.00000000018 * cos(1.89582517195 + 11926.4982311523*$t);
  $X2 += 0.00000000022 * cos(3.74943338657 + 17298.4261448097*$t);
  $X2 += 0.00000000019 * cos(3.25511318252 + 18073.46112116669*$t);
  $X2 += 0.00000000020 * cos(2.60030261119 + 19651.2922985815*$t);
  $X2 += 0.00000000024 * cos(1.57388276311 + 5856.23384163189*$t);
  $X2 += 0.00000000023 * cos(4.78368329384 + 72850.80553272919*$t);
  $X2 += 0.00000000017 * cos(3.95703430839 + 8983.0544867925*$t);
  $X2 += 0.00000000016 * cos(5.17069195690 + 16460.5773470085*$t);
  $X2 += 0.00000000016 * cos(1.20099644560 + 17259.91083720689*$t);
  $X2 += 0.00000000021 * cos(3.77366558760 + 16858.7263504167*$t);
  $X2 += 0.00000000020 * cos(0.39427566601 + 23543.4743221653*$t);
  $X2 += 0.00000000021 * cos(3.79445696120 + 13367.7288136231*$t);
  $X2 += 0.00000000020 * cos(4.04662298246 + 2146.4092339587*$t);
  $X2 += 0.00000000014 * cos(0.14269366851 + 22484.0923919761*$t);
  $X2 += 0.00000000014 * cos(4.66600220934 + 16200.52890701769*$t);
  $X2 += 0.00000000015 * cos(4.21847977142 + 20199.3387771165*$t);
  $X2 += 0.00000000019 * cos(2.81420484440 + 8672.21368792411*$t);
  $X2 += 0.00000000019 * cos(4.46915157584 + 18073.9487561337*$t);
  $X2 += 0.00000000013 * cos(4.71429939378 + 16201.0165419847*$t);
  $X2 += 0.00000000017 * cos(1.38925168648 + 7860.17557495569*$t);
  $X2 += 0.00000000013 * cos(4.69427401677 + 18451.3223640495*$t);
  $X2 += 0.00000000016 * cos(3.33196861521 + 5572.8989839496*$t);
  $X2 += 0.00000000012 * cos(2.70989366066 + 17996.2749857057*$t);
  $X2 += 0.00000000012 * cos(0.72221452149 + 19403.0407703001*$t);
  $X2 += 0.00000000012 * cos(5.53894834507 + 14945.0723560709*$t);
  $X2 += 0.00000000015 * cos(2.04879024946 + 12559.2819704655*$t);
  $X2 += 0.00000000012 * cos(4.37879205675 + 10818.3791043993*$t);
  $X2 += 0.00000000015 * cos(0.57625721169 + 12567.37583853451*$t);
  $X2 += 0.00000000011 * cos(1.78471307843 + 28767.1682419675*$t);
  $X2 += 0.00000000013 * cos(1.09547571668 + 90280.16698558679*$t);
  $X2 += 0.00000000011 * cos(5.02230424673 + 22805.4917485101*$t);
  $X2 += 0.00000000011 * cos(2.24605985689 + 35372.1310834599*$t);
  $X2 += 0.00000000010 * cos(6.26009139838 + 11506.52595231009*$t);
  $X2 += 0.00000000014 * cos(1.93802583909 + 21228.63584102931*$t);
  $X2 += 0.00000000010 * cos(0.13064402023 + 12779.6946129043*$t);
  $X2 += 0.00000000010 * cos(6.05309072952 + 23141.8022004081*$t);
  $X2 += 0.00000000010 * cos(1.18002886182 + 1350.1112271423*$t);
  $X2 += 0.00000000010 * cos(2.50762435685 + 10575.1628654583*$t);
  $X2 += 0.00000000010 * cos(2.55643759758 + 22345.5041935917*$t);
  $X2 += 0.00000000010 * cos(5.33273079625 + 9778.8648586419*$t);
  $X2 += 0.00000000009 * cos(1.49151911226 + 29826.5501721567*$t);
  $X2 += 0.00000000010 * cos(4.24000912367 + 23581.5019948011*$t);
  $X2 += 0.00000000011 * cos(0.39610887139 + 25158.8455372489*$t);
  return $X2*$t*$t;
}



  function Earth_C_X3 ($t)
{
  $X3 =  0.0;
  $X3 += 0.00000232790 * cos(3.40634928966 + 0.2438174835*$t);
  $X3 += 0.00000076843 * cos(2.52439403387 + 12566.3955174663*$t);
  $X3 += 0.00000035331 * cos(3.34616699853 + 6283.3196674749*$t);
  $X3 += 0.00000005282 * cos(2.40489818589 + 18849.4713674577*$t);
  $X3 += 0.00000001631 * cos(5.43859760597 + 6282.83203250789*$t);
  $X3 += 0.00000001483 * cos(2.22678849266 + 6438.7400669091*$t);
  $X3 += 0.00000001479 * cos(4.40151760084 + 6127.8992680407*$t);
  $X3 += 0.00000000652 * cos(4.70876083993 + 6279.7965491259*$t);
  $X3 += 0.00000000656 * cos(1.58695055624 + 6286.84278582391*$t);
  $X3 += 0.00000000317 * cos(3.00237328519 + 6526.04827144891*$t);
  $X3 += 0.00000000318 * cos(3.63024148359 + 6040.5910635009*$t);
  $X3 += 0.00000000227 * cos(2.27961613476 + 25132.5472174491*$t);
  $X3 += 0.00000000201 * cos(0.81376672334 + 6836.8890703173*$t);
  $X3 += 0.00000000201 * cos(5.80642900510 + 5729.7502646325*$t);
  $X3 += 0.00000000036 * cos(1.33765000112 + 12569.91863581531*$t);
  $X3 += 0.00000000034 * cos(1.93992455025 + 4705.9761250271*$t);
  $X3 += 0.00000000033 * cos(4.22745351005 + 12410.9751180321*$t);
  $X3 += 0.00000000032 * cos(5.38348719867 + 6257.0213476751*$t);
  $X3 += 0.00000000032 * cos(4.41212819179 + 6309.61798727471*$t);
  $X3 += 0.00000000026 * cos(0.50334838608 + 775.7664288075*$t);
  $X3 += 0.00000000023 * cos(2.01776542272 + 1059.6257476727*$t);
  $X3 += 0.00000000025 * cos(1.58405990040 + 7860.6632099227*$t);
  $X3 += 0.00000000027 * cos(5.17969059866 + 12565.9078824993*$t);
  $X3 += 0.00000000020 * cos(3.76292921295 + 5753.6287023803*$t);
  $X3 += 0.00000000019 * cos(3.01515389134 + 5885.1706640667*$t);
  $X3 += 0.00000000019 * cos(6.05056350877 + 6813.0106325695*$t);
  $X3 += 0.00000000018 * cos(2.29290644779 + 12721.8159169005*$t);
  $X3 += 0.00000000017 * cos(0.49235818139 + 6681.46867088311*$t);
  $X3 += 0.00000000013 * cos(4.49557806784 + 5487.0216606585*$t);
  $X3 += 0.00000000011 * cos(5.29141894629 + 7079.61767429131*$t);
  $X3 += 0.00000000010 * cos(4.46246654504 + 5507.7970561509*$t);
  $X3 += 0.00000000010 * cos(3.03842434664 + 11790.8729061423*$t);
  $X3 += 0.00000000009 * cos(1.50545167256 + 11507.0135872771*$t);
  $X3 += 0.00000000011 * cos(6.25880735981 + 12592.6938372661*$t);
  $X3 += 0.00000000009 * cos(5.39258795934 + 7058.8422787989*$t);
  $X3 += 0.00000000008 * cos(1.26531983919 + 6290.4332144757*$t);
  $X3 += 0.00000000008 * cos(2.25393064493 + 6276.2061204741*$t);
  $X3 += 0.00000000008 * cos(3.03070423945 + 796.5418242999*$t);
  $X3 += 0.00000000007 * cos(2.58386169059 + 4693.75913722409*$t);
  $X3 += 0.00000000007 * cos(1.92157668691 + 7.3573644843*$t);
  $X3 += 0.00000000005 * cos(4.86563371701 + 3739.0052475915*$t);
  $X3 += 0.00000000005 * cos(6.21240311845 + 6070.0205720369*$t);
  $X3 += 0.00000000006 * cos(3.95562930301 + 6284.2999885431*$t);
  $X3 += 0.00000000006 * cos(5.83931193332 + 6282.3393464067*$t);
  $X3 += 0.00000000005 * cos(3.46747665337 + 4137.1542509997*$t);
  $X3 += 0.00000000005 * cos(3.58293336989 + 6496.6187629129*$t);
  return $X3*$t*$t*$t;
}



  function Earth_C_X4 ($t)
{
  $X4 =  0.0;
  $X4 += 0.00000114918 * cos(0.06053023506 + 6283.3196674749*$t);
  $X4 += 0.00000006817 * cos(4.47624663983 + 0.2438174835*$t);
  $X4 += 0.00000003158 * cos(0.47910545815 + 12566.3955174663*$t);
  $X4 += 0.00000000211 * cos(3.72351646714 + 6438.7400669091*$t);
  $X4 += 0.00000000210 * cos(2.88489921647 + 6127.8992680407*$t);
  $X4 += 0.00000000253 * cos(0.64665875683 + 18849.4713674577*$t);
  $X4 += 0.00000000073 * cos(3.92376796583 + 6282.83203250789*$t);
  $X4 += 0.00000000042 * cos(4.60322795936 + 710.1768660418*$t);
  $X4 += 0.00000000023 * cos(6.04513529243 + 6279.7965491259*$t);
  $X4 += 0.00000000022 * cos(6.04140763882 + 6286.84278582391*$t);
  $X4 += 0.00000000012 * cos(0.51640078868 + 25132.5472174491*$t);
  $X4 += 0.00000000009 * cos(4.21008055560 + 83997.09113559539*$t);
  $X4 += 0.00000000009 * cos(5.19392488383 + 11856.462468908*$t);
  $X4 += 0.00000000008 * cos(6.16587249238 + 167284.00540514899*$t);
  $X4 += 0.00000000005 * cos(5.97913996910 + 6257.0213476751*$t);
  $X4 += 0.00000000005 * cos(3.78878463461 + 6309.61798727471*$t);
  $X4 += 0.00000000005 * cos(2.68915538708 + 12410.9751180321*$t);
  $X4 += 0.00000000005 * cos(5.56850457487 + 156137.71980228279*$t);
  $X4 += 0.00000000004 * cos(3.40118346072 + 12565.9078824993*$t);
  $X4 += 0.00000000003 * cos(5.17221494066 + 529.9347825781*$t);
  return $X4*$t*$t*$t*$t;
}



  function Earth_C_X5 ($t)
{
  $X5 =  0.0;
  $X5 += 0.00000000877 * cos(0.16136296068 + 6283.3196674749*$t);
  $X5 += 0.00000000305 * cos(5.62973274927 + 0.2438174835*$t);
  $X5 += 0.00000000101 * cos(4.88076699149 + 12566.3955174663*$t);
  $X5 += 0.00000000025 * cos(5.30593958386 + 6438.7400669091*$t);
  $X5 += 0.00000000025 * cos(1.27879113841 + 6127.8992680407*$t);
  $X5 += 0.00000000010 * cos(5.11399286577 + 18849.4713674577*$t);
  $X5 += 0.00000000003 * cos(2.56205735968 + 6282.83203250789*$t);
  return $X5*$t*$t*$t*$t*$t;
}



  function Earth_C_Y0 ($t)
{
  $Y0 =  0.0;
  $Y0 += 0.99986069925 * cos(0.18267413078 + 6283.3196674749*$t);
  $Y0 += 0.02506324281 * cos(3.36739796418 + 0.2438174835*$t);
  $Y0 += 0.00835274807 * cos(0.13953892859 + 12566.3955174663*$t);
  $Y0 += 0.00010466796 * cos(0.09642351540 + 18849.4713674577*$t);
  $Y0 += 0.00003490608 * cos(6.01453435910 + 6282.83203250789*$t);
  $Y0 += 0.00003110838 * cos(5.38114087369 + 83997.09113559539*$t);
  $Y0 += 0.00002561408 * cos(5.29827505528 + 529.9347825781*$t);
  $Y0 += 0.00002142365 * cos(2.66284107563 + 1577.0997249643*$t);
  $Y0 += 0.00001709161 * cos(5.20779761275 + 6279.7965491259*$t);
  $Y0 += 0.00001707934 * cos(4.58234386738 + 6286.84278582391*$t);
  $Y0 += 0.00001442753 * cos(1.90130765657 + 2353.1099712553*$t);
  $Y0 += 0.00001113027 * cos(5.26701283158 + 5223.4501023187*$t);
  $Y0 += 0.00000934484 * cos(4.50305745607 + 12036.7045523717*$t);
  $Y0 += 0.00000899854 * cos(1.60527831001 + 10213.5293636945*$t);
  $Y0 += 0.00000566820 * cos(0.58162314212 + 1059.6257476727*$t);
  $Y0 += 0.00000661858 * cos(6.02414120157 + 5753.6287023803*$t);
  $Y0 += 0.00000739644 * cos(2.79582891432 + 398.3928208917*$t);
  $Y0 += 0.00000681381 * cos(0.64735765260 + 4705.9761250271*$t);
  $Y0 += 0.00000611293 * cos(3.81390547656 + 6813.0106325695*$t);
  $Y0 += 0.00000451129 * cos(4.52236258525 + 5885.1706640667*$t);
  $Y0 += 0.00000451985 * cos(5.99169934357 + 6257.0213476751*$t);
  $Y0 += 0.00000449743 * cos(3.79862296384 + 6309.61798727471*$t);
  $Y0 += 0.00000406291 * cos(5.25608267423 + 6681.46867088311*$t);
  $Y0 += 0.00000541115 * cos(5.49909532338 + 775.7664288075*$t);
  $Y0 += 0.00000546682 * cos(6.17348361999 + 14143.7390599141*$t);
  $Y0 += 0.00000513780 * cos(2.86615405111 + 7860.6632099227*$t);
  $Y0 += 0.00000263916 * cos(3.82472119950 + 5507.7970561509*$t);
  $Y0 += 0.00000217220 * cos(2.94186064336 + 11507.0135872771*$t);
  $Y0 += 0.00000292146 * cos(4.08451989980 + 5507.3094211839*$t);
  $Y0 += 0.00000227915 * cos(5.95179814771 + 7058.8422787989*$t);
  $Y0 += 0.00000226835 * cos(4.84435977688 + 4693.75913722409*$t);
  $Y0 += 0.00000255833 * cos(0.69465437518 + 12168.2465140581*$t);
  $Y0 += 0.00000256157 * cos(6.16717762843 + 710.1768660418*$t);
  $Y0 += 0.00000178679 * cos(1.39565997429 + 796.5418242999*$t);
  $Y0 += 0.00000178303 * cos(5.11711459804 + 6283.25235717211*$t);
  $Y0 += 0.00000178303 * cos(4.67301162820 + 6283.3869777777*$t);
  $Y0 += 0.00000155471 * cos(0.05335100564 + 25132.5472174491*$t);
  $Y0 += 0.00000155246 * cos(6.13208007594 + 5487.0216606585*$t);
  $Y0 += 0.00000207640 * cos(4.28246516283 + 11790.8729061423*$t);
  $Y0 += 0.00000199988 * cos(2.50137197430 + 17790.08943726851*$t);
  $Y0 += 0.00000128970 * cos(3.64618696457 + 7079.61767429131*$t);
  $Y0 += 0.00000128155 * cos(3.23179068571 + 3739.0052475915*$t);
  $Y0 += 0.00000152241 * cos(5.58140597212 + 213.5429129215*$t);
  $Y0 += 0.00000078109 * cos(0.27810887092 + 8827.6340873583*$t);
  $Y0 += 0.00000073503 * cos(1.12438065243 + 1589.3167127673*$t);
  $Y0 += 0.00000093001 * cos(5.50857519732 + 9437.5191174035*$t);
  $Y0 += 0.00000065526 * cos(2.08488700481 + 11770.0975106499*$t);
  $Y0 += 0.00000063240 * cos(0.67044494917 + 6262.5442719825*$t);
  $Y0 += 0.00000062961 * cos(2.83649752628 + 6304.0950629673*$t);
  $Y0 += 0.00000085870 * cos(1.45351146305 + 167284.00540514899*$t);
  $Y0 += 0.00000083233 * cos(4.62701145755 + 3340.8562441833*$t);
  $Y0 += 0.00000062850 * cos(0.46743502764 + 7.3573644843*$t);
  $Y0 += 0.00000079971 * cos(0.92256149872 + 6070.0205720369*$t);
  $Y0 += 0.00000060043 * cos(1.82875530765 + 4137.1542509997*$t);
  $Y0 += 0.00000075613 * cos(2.58868557323 + 6496.6187629129*$t);
  $Y0 += 0.00000053731 * cos(6.27507790078 + 1194.6908277081*$t);
  $Y0 += 0.00000057574 * cos(2.39891957636 + 6284.2999885431*$t);
  $Y0 += 0.00000057574 * cos(1.10802134270 + 6282.3393464067*$t);
  $Y0 += 0.00000072385 * cos(0.13875968847 + 10976.83498721549*$t);
  $Y0 += 0.00000051135 * cos(6.02476231374 + 6290.4332144757*$t);
  $Y0 += 0.00000050604 * cos(3.77440441934 + 6276.2061204741*$t);
  $Y0 += 0.00000049613 * cos(1.07290414466 + 6127.8992680407*$t);
  $Y0 += 0.00000048009 * cos(2.43492252840 + 6438.7400669091*$t);
  $Y0 += 0.00000059233 * cos(5.35402385929 + 3154.4432674121*$t);
  $Y0 += 0.00000048264 * cos(0.05887245943 + 801.5771136403*$t);
  $Y0 += 0.00000047368 * cos(4.53616745806 + 3128.6325825793*$t);
  $Y0 += 0.00000039225 * cos(1.68202291816 + 8429.4850839501*$t);
  $Y0 += 0.00000051307 * cos(4.21369114598 + 12353.0964220283*$t);
  $Y0 += 0.00000050639 * cos(0.48135592944 + 11856.462468908*$t);
  $Y0 += 0.00000039555 * cos(3.35943021943 + 5481.4987363511*$t);
  $Y0 += 0.00000042757 * cos(2.06983819322 + 17260.3984721739*$t);
  $Y0 += 0.00000048941 * cos(5.16594049812 + 9225.7830907665*$t);
  $Y0 += 0.00000048302 * cos(2.17445966751 + 2544.07060239989*$t);
  $Y0 += 0.00000037971 * cos(1.47013374285 + 426.8420083595*$t);
  $Y0 += 0.00000043643 * cos(4.71767697827 + 5856.23384163189*$t);
  $Y0 += 0.00000031830 * cos(3.57964760085 + 2145.92159899169*$t);
  $Y0 += 0.00000033959 * cos(0.15150934422 + 7085.1405985987*$t);
  $Y0 += 0.00000030184 * cos(2.39802729198 + 10977.32262218251*$t);
  $Y0 += 0.00000032562 * cos(4.41726666203 + 4164.0681721295*$t);
  $Y0 += 0.00000038887 * cos(0.64783670316 + 13367.7288136231*$t);
  $Y0 += 0.00000028515 * cos(4.53853388778 + 12569.91863581531*$t);
  $Y0 += 0.00000028873 * cos(5.72467865653 + 3930.4535137031*$t);
  $Y0 += 0.00000036633 * cos(1.33719170745 + 18073.9487561337*$t);
  $Y0 += 0.00000024984 * cos(3.74998709416 + 26.0545023163*$t);
  $Y0 += 0.00000026364 * cos(5.25860499861 + 9438.0067523705*$t);
  $Y0 += 0.00000030326 * cos(0.42292659979 + 4535.3032544079*$t);
  $Y0 += 0.00000028166 * cos(5.19366223100 + 12562.8723991173*$t);
  $Y0 += 0.00000028001 * cos(1.25523598395 + 5088.8726572503*$t);
  $Y0 += 0.00000021157 * cos(3.50176956898 + 11371.9485072417*$t);
  $Y0 += 0.00000023113 * cos(5.57235828208 + 5223.93773728571*$t);
  $Y0 += 0.00000021642 * cos(3.06444525139 + 12559.2819704655*$t);
  $Y0 += 0.00000019448 * cos(5.97216607301 + 12565.9078824993*$t);
  $Y0 += 0.00000026055 * cos(1.87419996146 + 71430.45180064559*$t);
  $Y0 += 0.00000018232 * cos(4.98441727809 + 1747.7725955835*$t);
  $Y0 += 0.00000023248 * cos(4.61930360205 + 18319.7804023631*$t);
  $Y0 += 0.00000022785 * cos(2.73901481639 + 5753.14106741329*$t);
  $Y0 += 0.00000017091 * cos(5.29823070971 + 4933.4522578161*$t);
  $Y0 += 0.00000019399 * cos(6.00268090156 + 10447.14402212089*$t);
  $Y0 += 0.00000021067 * cos(2.22953967314 + 7477.7666776995*$t);
  $Y0 += 0.00000021310 * cos(3.08840298987 + 8031.3360805419*$t);
  $Y0 += 0.00000014189 * cos(6.02227444325 + 2942.7072407751*$t);
  $Y0 += 0.00000013864 * cos(3.02270988640 + 8636.18582124671*$t);
  $Y0 += 0.00000018884 * cos(0.85614785764 + 156137.71980228279*$t);
  $Y0 += 0.00000017875 * cos(4.86899529635 + 1592.8398311163*$t);
  $Y0 += 0.00000018602 * cos(2.07103958699 + 17297.9385098427*$t);
  $Y0 += 0.00000013605 * cos(3.62641283985 + 13096.0864825609*$t);
  $Y0 += 0.00000015064 * cos(1.55068405670 + 16496.6052136859*$t);
  $Y0 += 0.00000012969 * cos(4.49412072551 + 7633.1870771337*$t);
  $Y0 += 0.00000014403 * cos(6.14964820819 + 20426.8149099055*$t);
  $Y0 += 0.00000013311 * cos(2.03652540541 + 12139.7973265903*$t);
  $Y0 += 0.00000013645 * cos(3.57902352159 + 13368.2164485901*$t);
  $Y0 += 0.00000011583 * cos(3.88983863974 + 5331.6012612243*$t);
  $Y0 += 0.00000011405 * cos(5.97095658034 + 529.44714761109*$t);
  $Y0 += 0.00000015057 * cos(0.50195173390 + 7084.6529636317*$t);
  $Y0 += 0.00000014330 * cos(4.45695507640 + 7342.7015976641*$t);
  $Y0 += 0.00000012375 * cos(1.53862290035 + 6279.72923882311*$t);
  $Y0 += 0.00000012366 * cos(1.96831814313 + 6286.9100961267*$t);
  $Y0 += 0.00000010016 * cos(3.81622500644 + 397.9051859247*$t);
  $Y0 += 0.00000012435 * cos(5.77865382585 + 15110.7099373497*$t);
  $Y0 += 0.00000009513 * cos(5.90294963286 + 7235.0380737255*$t);
  $Y0 += 0.00000010997 * cos(0.62118771904 + 10989.0519750185*$t);
  $Y0 += 0.00000011583 * cos(2.48171191864 + 5729.7502646325*$t);
  $Y0 += 0.00000009034 * cos(3.85796197835 + 9623.9320941747*$t);
  $Y0 += 0.00000011842 * cos(2.59877813496 + 15721.0826023619*$t);
  $Y0 += 0.00000008869 * cos(3.47611287212 + 6148.2545874395*$t);
  $Y0 += 0.00000008614 * cos(0.03081566771 + 6418.38474751031*$t);
  $Y0 += 0.00000010312 * cos(1.02710009735 + 6836.8890703173*$t);
  $Y0 += 0.00000008411 * cos(0.87289239606 + 14712.5609339415*$t);
  $Y0 += 0.00000007911 * cos(1.58349090213 + 2119.00767786191*$t);
  $Y0 += 0.00000010379 * cos(0.10632075985 + 1349.62359217529*$t);
  $Y0 += 0.00000010374 * cos(3.97648848184 + 5486.53402569149*$t);
  $Y0 += 0.00000010480 * cos(1.38209289015 + 5999.4603486097*$t);
  $Y0 += 0.00000007404 * cos(3.84339417190 + 6040.5910635009*$t);
  $Y0 += 0.00000007357 * cos(5.40136984638 + 5088.3850222833*$t);
  $Y0 += 0.00000009820 * cos(2.12476608355 + 6567.1789863401*$t);
  $Y0 += 0.00000007018 * cos(5.94659139192 + 6526.04827144891*$t);
  $Y0 += 0.00000009668 * cos(3.49318502073 + 21228.1482060623*$t);
  $Y0 += 0.00000007545 * cos(5.94843445846 + 12540.0971976665*$t);
  $Y0 += 0.00000007202 * cos(4.31311905021 + 6245.2919948391*$t);
  $Y0 += 0.00000007144 * cos(5.47703554612 + 6321.3473401107*$t);
  $Y0 += 0.00000008883 * cos(5.46710407546 + 5642.93474619389*$t);
  $Y0 += 0.00000006626 * cos(5.41362465894 + 5327.7199258663*$t);
  $Y0 += 0.00000007015 * cos(5.70701993379 + 7860.17557495569*$t);
  $Y0 += 0.00000006159 * cos(5.65831198505 + 12964.5445208745*$t);
  $Y0 += 0.00000007413 * cos(3.46419092567 + 23543.4743221653*$t);
  $Y0 += 0.00000006355 * cos(3.46461466453 + 1990.9888345245*$t);
  $Y0 += 0.00000007286 * cos(2.01139981548 + 537.0483295789*$t);
  $Y0 += 0.00000006314 * cos(1.51246730786 + 951.4745887671*$t);
  $Y0 += 0.00000006257 * cos(2.66128485006 + 4690.7236538421*$t);
  $Y0 += 0.00000006484 * cos(1.63733658639 + 16730.70750707931*$t);
  $Y0 += 0.00000005803 * cos(1.38237252918 + 955.3559241251*$t);
  $Y0 += 0.00000006391 * cos(2.40521894071 + 24073.1652872599*$t);
  $Y0 += 0.00000007530 * cos(4.91537693059 + 10973.7995038335*$t);
  $Y0 += 0.00000006921 * cos(5.41208599854 + 522.8212355773*$t);
  $Y0 += 0.00000007626 * cos(2.72257180334 + 22004.1584523533*$t);
  $Y0 += 0.00000007531 * cos(1.94384811400 + 18422.8731765817*$t);
  $Y0 += 0.00000006902 * cos(4.32614260011 + 155.17658195069*$t);
  $Y0 += 0.00000005434 * cos(4.37546348368 + 7238.9194090835*$t);
  $Y0 += 0.00000006223 * cos(0.67316616422 + 18451.3223640495*$t);
  $Y0 += 0.00000007296 * cos(1.27743142232 + 16730.21987211229*$t);
  $Y0 += 0.00000005833 * cos(0.75851095819 + 640.1411037975*$t);
  $Y0 += 0.00000007171 * cos(1.43520696239 + 3929.96587873609*$t);
  $Y0 += 0.00000006251 * cos(0.62294633745 + 6277.7967431675*$t);
  $Y0 += 0.00000006251 * cos(2.88399458161 + 6288.8425917823*$t);
  $Y0 += 0.00000005683 * cos(1.92473239272 + 1551.2890401315*$t);
  $Y0 += 0.00000006383 * cos(2.21747129905 + 5216.33655531789*$t);
  $Y0 += 0.00000006194 * cos(5.13602240936 + 5230.5636493195*$t);
  $Y0 += 0.00000005036 * cos(2.26614918626 + 14314.4119305333*$t);
  $Y0 += 0.00000006774 * cos(3.56437941703 + 102.84895673509*$t);
  $Y0 += 0.00000006224 * cos(1.92311046214 + 11014.8626598513*$t);
  $Y0 += 0.00000004621 * cos(2.91747769543 + 553.32558535889*$t);
  $Y0 += 0.00000006293 * cos(0.74955598933 + 5650.5359281617*$t);
  $Y0 += 0.00000006297 * cos(2.83090961174 + 26088.1469590577*$t);
  $Y0 += 0.00000005186 * cos(5.42426212805 + 77714.01528560399*$t);
  $Y0 += 0.00000006196 * cos(4.15785490016 + 84672.23202702119*$t);
  $Y0 += 0.00000006160 * cos(3.21170376619 + 239424.63407183639*$t);
  $Y0 += 0.00000005414 * cos(1.42882325200 + 6180.2268932563*$t);
  $Y0 += 0.00000005413 * cos(2.08335586272 + 6386.4124416935*$t);
  $Y0 += 0.00000004863 * cos(2.19642727179 + 90280.16698558679*$t);
  $Y0 += 0.00000005711 * cos(2.75632617612 + 6916.1034067881*$t);
  $Y0 += 0.00000005150 * cos(2.53503851142 + 1577.5873599313*$t);
  $Y0 += 0.00000004269 * cos(0.81279132183 + 7875.91568110771*$t);
  $Y0 += 0.00000004017 * cos(2.21501270421 + 6254.8704800071*$t);
  $Y0 += 0.00000004069 * cos(3.99136293444 + 3634.37720703489*$t);
  $Y0 += 0.00000003993 * cos(1.29192496097 + 6311.7688549427*$t);
  $Y0 += 0.00000004016 * cos(0.52802181166 + 4690.23601887509*$t);
  $Y0 += 0.00000005290 * cos(4.91562568689 + 25158.3579022819*$t);
  $Y0 += 0.00000004831 * cos(1.26836887601 + 5760.7422493811*$t);
  $Y0 += 0.00000003487 * cos(1.93988497026 + 10447.6316570879*$t);
  $Y0 += 0.00000004120 * cos(1.72576404553 + 6709.91785835091*$t);
  $Y0 += 0.00000004410 * cos(2.23510306717 + 6805.89708556871*$t);
  $Y0 += 0.00000004023 * cos(1.51236080833 + 4731.7868098599*$t);
  $Y0 += 0.00000003980 * cos(1.74852343480 + 5856.7214765989*$t);
  $Y0 += 0.00000003173 * cos(3.62048518613 + 1066.7392946735*$t);
  $Y0 += 0.00000003293 * cos(5.58717113537 + 9917.45305702629*$t);
  $Y0 += 0.00000002935 * cos(2.10511347366 + 12592.6938372661*$t);
  $Y0 += 0.00000002979 * cos(4.62987940723 + 12566.4628277691*$t);
  $Y0 += 0.00000003980 * cos(5.90920652207 + 13341.9181287903*$t);
  $Y0 += 0.00000003892 * cos(3.95491793455 + 75.0254160508*$t);
  $Y0 += 0.00000003042 * cos(1.62346061120 + 18053.1733606413*$t);
  $Y0 += 0.00000003608 * cos(4.03873145467 + 6208.5380689076*$t);
  $Y0 += 0.00000003721 * cos(3.65024914006 + 5966.9277978183*$t);
  $Y0 += 0.00000003581 * cos(5.75234129258 + 6358.1012660422*$t);
  $Y0 += 0.00000002880 * cos(0.04145923446 + 10575.6505004253*$t);
  $Y0 += 0.00000002806 * cos(2.64471981541 + 5863.8350235997*$t);
  $Y0 += 0.00000003626 * cos(6.13871061291 + 6599.7115371315*$t);
  $Y0 += 0.00000002794 * cos(0.98030293667 + 8030.8484455749*$t);
  $Y0 += 0.00000002729 * cos(2.60239924444 + 3.76693583251*$t);
  $Y0 += 0.00000003625 * cos(1.43112681156 + 6020.2357441021*$t);
  $Y0 += 0.00000003206 * cos(3.72476724430 + 11506.52595231009*$t);
  $Y0 += 0.00000003556 * cos(5.86027209236 + 8428.9974489831*$t);
  $Y0 += 0.00000002856 * cos(1.76545510884 + 12721.8159169005*$t);
  $Y0 += 0.00000002611 * cos(0.86182235214 + 6702.8043113501*$t);
  $Y0 += 0.00000002535 * cos(0.01231069705 + 31415.6230674405*$t);
  $Y0 += 0.00000003520 * cos(3.80906738831 + 250570.91967470259*$t);
  $Y0 += 0.00000003434 * cos(2.07577291101 + 6546.4035908477*$t);
  $Y0 += 0.00000002572 * cos(0.08592522543 + 5884.68302909969*$t);
  $Y0 += 0.00000002647 * cos(5.39051905541 + 2352.6223362883*$t);
  $Y0 += 0.00000003026 * cos(3.66998442300 + 13916.2629271251*$t);
  $Y0 += 0.00000002378 * cos(2.05754080989 + 2389.1378379327*$t);
  $Y0 += 0.00000002979 * cos(5.07398237707 + 12566.32820716351*$t);
  $Y0 += 0.00000003082 * cos(3.34593854945 + 14945.0723560709*$t);
  $Y0 += 0.00000002716 * cos(1.49855756532 + 12029.5910053709*$t);
  $Y0 += 0.00000002215 * cos(3.69564106529 + 13362.6935242827*$t);
  $Y0 += 0.00000003032 * cos(0.05314931388 + 29088.5675985015*$t);
  $Y0 += 0.00000002421 * cos(1.58246988642 + 11015.3502948183*$t);
  $Y0 += 0.00000002275 * cos(4.38385659579 + 6077.1341190377*$t);
  $Y0 += 0.00000002466 * cos(0.87928045349 + 16200.52890701769*$t);
  $Y0 += 0.00000002529 * cos(4.37629498907 + 12043.8180993725*$t);
  $Y0 += 0.00000002015 * cos(0.91352607152 + 6262.96434807611*$t);
  $Y0 += 0.00000002218 * cos(5.40562909521 + 6489.5052159121*$t);
  $Y0 += 0.00000002005 * cos(2.59344260095 + 6303.6749868737*$t);
  $Y0 += 0.00000002010 * cos(5.68334625182 + 4700.87268422489*$t);
  $Y0 += 0.00000002641 * cos(5.85354681494 + 4590.6663630055*$t);
  $Y0 += 0.00000002438 * cos(4.55830572881 + 149.8070146181*$t);
  $Y0 += 0.00000001893 * cos(5.69296362938 + 6279.4383321169*$t);
  $Y0 += 0.00000001893 * cos(4.09716259686 + 6287.2010028329*$t);
  $Y0 += 0.00000002156 * cos(0.43822603611 + 18139.5383188994*$t);
  $Y0 += 0.00000002071 * cos(2.75099511730 + 11926.4982311523*$t);
  $Y0 += 0.00000002395 * cos(4.84387255380 + 1162.7185218913*$t);
  $Y0 += 0.00000001954 * cos(5.08514679694 + 13518.1139237169*$t);
  $Y0 += 0.00000002006 * cos(5.02287213343 + 3154.9309023791*$t);
  $Y0 += 0.00000001776 * cos(4.86094102925 + 13521.9952590749*$t);
  $Y0 += 0.00000001964 * cos(1.82182786120 + 4686.6455902233*$t);
  $Y0 += 0.00000002332 * cos(2.83569470692 + 10022.0810975829*$t);
  $Y0 += 0.00000001863 * cos(3.68950976920 + 242.97242145751*$t);
  $Y0 += 0.00000001928 * cos(3.02170818288 + 5746.5151553795*$t);
  $Y0 += 0.00000002436 * cos(2.83691190801 + 95143.37673846159*$t);
  $Y0 += 0.00000002163 * cos(6.13036805408 + 6037.4880212455*$t);
  $Y0 += 0.00000002250 * cos(0.82649289984 + 12669.4882916849*$t);
  $Y0 += 0.00000002052 * cos(3.65926976048 + 6529.1513137043*$t);
  $Y0 += 0.00000001886 * cos(5.18293217320 + 7238.4317741165*$t);
  $Y0 += 0.00000002170 * cos(3.92516942708 + 19651.2922985815*$t);
  $Y0 += 0.00000002058 * cos(3.12741900385 + 23013.7833570707*$t);
  $Y0 += 0.00000001774 * cos(0.51402656711 + 6820.1241795703*$t);
  $Y0 += 0.00000001841 * cos(1.91732926338 + 65147.37595065419*$t);
  $Y0 += 0.00000001578 * cos(4.07231752329 + 4292.5746504339*$t);
  $Y0 += 0.00000001577 * cos(2.37859191870 + 7632.6994421667*$t);
  $Y0 += 0.00000001541 * cos(0.23280184119 + 13119.9649203087*$t);
  $Y0 += 0.00000002012 * cos(1.94074945567 + 4292.0870154669*$t);
  $Y0 += 0.00000001543 * cos(5.39993967465 + 6293.95633282471*$t);
  $Y0 += 0.00000001543 * cos(4.39018655159 + 6272.6830021251*$t);
  $Y0 += 0.00000001513 * cos(2.22141523192 + 20.5315780089*$t);
  $Y0 += 0.00000001489 * cos(1.38125902411 + 110.45013870291*$t);
  $Y0 += 0.00000001639 * cos(2.86996469977 + 17655.0243572331*$t);
  $Y0 += 0.00000001443 * cos(0.69249676813 + 1052.51220067191*$t);
  $Y0 += 0.00000001337 * cos(1.49321921272 + 2544.5582373669*$t);
  $Y0 += 0.00000001797 * cos(1.47415887460 + 33018.7772947211*$t);
  $Y0 += 0.00000001488 * cos(4.10370894807 + 76.50988875911*$t);
  $Y0 += 0.00000001453 * cos(3.88999021921 + 633.0275567967*$t);
  $Y0 += 0.00000001349 * cos(4.18018116919 + 6016.7126257531*$t);
  $Y0 += 0.00000001477 * cos(2.56925141669 + 12779.6946129043*$t);
  $Y0 += 0.00000001688 * cos(4.77167367345 + 18875.2820522905*$t);
  $Y0 += 0.00000001491 * cos(4.65894552032 + 9411.7084325707*$t);
  $Y0 += 0.00000001471 * cos(4.18699607739 + 18636.1722720197*$t);
  $Y0 += 0.00000001263 * cos(5.62967869388 + 12573.5090644671*$t);
  $Y0 += 0.00000001685 * cos(4.13797957160 + 25934.3681485729*$t);
  $Y0 += 0.00000001375 * cos(2.66006793362 + 2378.9206560881*$t);
  $Y0 += 0.00000001641 * cos(1.56425462469 + 6.86972951729*$t);
  $Y0 += 0.00000001200 * cos(6.18795172265 + 11499.9000402763*$t);
  $Y0 += 0.00000001272 * cos(5.60977811105 + 6549.9267091967*$t);
  $Y0 += 0.00000001214 * cos(2.79740025979 + 10973.3118688665*$t);
  $Y0 += 0.00000001406 * cos(0.96357897619 + 11790.3852711753*$t);
  $Y0 += 0.00000001524 * cos(2.69987154893 + 18209.5740811437*$t);
  $Y0 += 0.00000001149 * cos(1.44882073480 + 10177.5014970171*$t);
  $Y0 += 0.00000001547 * cos(5.59995461433 + 11926.01059618529*$t);
  $Y0 += 0.00000001460 * cos(3.40155505101 + 246.0754637129*$t);
  $Y0 += 0.00000001323 * cos(2.95651083102 + 8661.9965060795*$t);
  $Y0 += 0.00000001252 * cos(6.12405778157 + 6993.2527160332*$t);
  $Y0 += 0.00000001459 * cos(3.72728247655 + 38.3768531213*$t);
  $Y0 += 0.00000001235 * cos(1.27016887136 + 24357.0246061251*$t);
  $Y0 += 0.00000001028 * cos(0.93950364612 + 6112.6467968557*$t);
  $Y0 += 0.00000001330 * cos(5.71304625366 + 2146.4092339587*$t);
  $Y0 += 0.00000001312 * cos(5.81330482072 + 12491.613918899*$t);
  $Y0 += 0.00000001246 * cos(6.23510174757 + 5429.63565075589*$t);
  $Y0 += 0.00000000992 * cos(2.56738111789 + 6453.9925380941*$t);
  $Y0 += 0.00000000988 * cos(5.69208485871 + 8274.0646845159*$t);
  $Y0 += 0.00000001365 * cos(1.39907964627 + 11371.4608722747*$t);
  $Y0 += 0.00000001020 * cos(1.25240185088 + 4732.2744448269*$t);
  $Y0 += 0.00000001191 * cos(1.85928407242 + 6290.36590417291*$t);
  $Y0 += 0.00000001191 * cos(1.64765684663 + 6276.2734307769*$t);
  $Y0 += 0.00000000978 * cos(3.16773125497 + 6247.2918007975*$t);
  $Y0 += 0.00000000971 * cos(0.33921091467 + 6319.34753415231*$t);
  $Y0 += 0.00000000962 * cos(1.06488912173 + 12565.4151963981*$t);
  $Y0 += 0.00000001025 * cos(0.64688768472 + 12545.6201219739*$t);
  $Y0 += 0.00000000990 * cos(5.10278829353 + 4694.2467721911*$t);
  $Y0 += 0.00000000964 * cos(3.36272372610 + 3893.93801205869*$t);
  $Y0 += 0.00000000944 * cos(4.29299913988 + 6259.44122972711*$t);
  $Y0 += 0.00000000944 * cos(5.49712708636 + 6307.1981052227*$t);
  $Y0 += 0.00000001092 * cos(2.34985569802 + 17797.2029842693*$t);
  $Y0 += 0.00000001132 * cos(5.71867421008 + 17782.9758902677*$t);
  $Y0 += 0.00000000859 * cos(6.19348487479 + 1692.40948698591*$t);
  $Y0 += 0.00000001213 * cos(5.61315622766 + 82576.73740351178*$t);
  $Y0 += 0.00000000942 * cos(3.65711104430 + 6298.57213865991*$t);
  $Y0 += 0.00000000942 * cos(6.13301518193 + 6268.0671962899*$t);
  $Y0 += 0.00000001045 * cos(5.17434482333 + 15508.8589407579*$t);
  $Y0 += 0.00000000851 * cos(3.62598735241 + 6173.1133462555*$t);
  $Y0 += 0.00000000850 * cos(6.16443178844 + 6393.5259886943*$t);
  $Y0 += 0.00000000895 * cos(0.83009579073 + 3904.1551939033*$t);
  $Y0 += 0.00000001020 * cos(5.42778314413 + 220.6564599223*$t);
  $Y0 += 0.00000000845 * cos(4.18420138552 + 17256.8753538249*$t);
  $Y0 += 0.00000000863 * cos(2.86079142045 + 949.4194264533*$t);
  $Y0 += 0.00000000853 * cos(1.18534704592 + 16201.0165419847*$t);
  $Y0 += 0.00000000811 * cos(1.42220880644 + 4803.9654584435*$t);
  $Y0 += 0.00000000966 * cos(2.57517734766 + 206.42936592071*$t);
  $Y0 += 0.00000000917 * cos(0.89927696450 + 149854.64395229139*$t);
  $Y0 += 0.00000001083 * cos(2.89594427545 + 36948.9869909407*$t);
  $Y0 += 0.00000000779 * cos(2.01260050316 + 2648.6986429565*$t);
  $Y0 += 0.00000000964 * cos(2.34511297941 + 796.0541893329*$t);
  $Y0 += 0.00000000995 * cos(4.96662237412 + 11403.9208130585*$t);
  $Y0 += 0.00000000962 * cos(2.35578735539 + 12567.37583853451*$t);
  $Y0 += 0.00000000779 * cos(2.02763029837 + 10213.0417287275*$t);
  $Y0 += 0.00000000980 * cos(6.19670011124 + 22805.4917485101*$t);
  $Y0 += 0.00000000930 * cos(0.65237052253 + 2787.2868413409*$t);
  $Y0 += 0.00000000829 * cos(0.38404899643 + 5120.35732810009*$t);
  $Y0 += 0.00000000733 * cos(4.18029489609 + 10575.1628654583*$t);
  $Y0 += 0.00000000743 * cos(2.22826365578 + 7834.3648901229*$t);
  $Y0 += 0.00000000818 * cos(3.21447961169 + 5572.8989839496*$t);
  $Y0 += 0.00000000905 * cos(2.24459183660 + 6284.8041401832*$t);
  $Y0 += 0.00000000905 * cos(1.26234908246 + 6281.8351947666*$t);
  $Y0 += 0.00000000798 * cos(1.05421419226 + 12410.9751180321*$t);
  $Y0 += 0.00000000817 * cos(5.23322400864 + 12416.8323203317*$t);
  $Y0 += 0.00000000884 * cos(2.41399532496 + 22483.60475700909*$t);
  $Y0 += 0.00000000755 * cos(5.40020688961 + 4060.97539791089*$t);
  $Y0 += 0.00000000651 * cos(5.50763453832 + 17259.91083720689*$t);
  $Y0 += 0.00000000616 * cos(4.13394819140 + 1596.43025976811*$t);
  $Y0 += 0.00000000651 * cos(0.84412253043 + 1748.2602305505*$t);
  $Y0 += 0.00000000723 * cos(1.49663741427 + 161000.92955515759*$t);
  $Y0 += 0.00000000784 * cos(2.44837693578 + 4907.05823266209*$t);
  $Y0 += 0.00000000784 * cos(3.77248887935 + 7234.5504387585*$t);
  $Y0 += 0.00000000785 * cos(1.86574625348 + 846.3266522347*$t);
  $Y0 += 0.00000000611 * cos(6.24391260854 + 853.4401992355*$t);
  $Y0 += 0.00000000576 * cos(5.94037158869 + 12323.6669134923*$t);
  $Y0 += 0.00000000570 * cos(2.97586328906 + 12587.1709129587*$t);
  $Y0 += 0.00000000576 * cos(4.63987761174 + 13915.77529215809*$t);
  $Y0 += 0.00000000770 * cos(0.89072554788 + 6069.53293706989*$t);
  $Y0 += 0.00000000773 * cos(1.78442906238 + 6133.2688353733*$t);
  $Y0 += 0.00000000581 * cos(6.05264641509 + 11933.6117781531*$t);
  $Y0 += 0.00000000719 * cos(2.47920208822 + 15720.5949673949*$t);
  $Y0 += 0.00000000578 * cos(2.69917567595 + 8662.48414104651*$t);
  $Y0 += 0.00000000536 * cos(4.49580958272 + 18852.9944858067*$t);
  $Y0 += 0.00000000633 * cos(5.88497258324 + 52176.0501006319*$t);
  $Y0 += 0.00000000581 * cos(1.35719256610 + 5334.1440585051*$t);
  $Y0 += 0.00000000532 * cos(3.01682546062 + 18842.3578204569*$t);
  $Y0 += 0.00000000657 * cos(4.82951502701 + 5849.1202946311*$t);
  $Y0 += 0.00000000599 * cos(0.54713597581 + 6151.7777057885*$t);
  $Y0 += 0.00000000540 * cos(1.67333017022 + 6286.6060248927*$t);
  $Y0 += 0.00000000540 * cos(1.83361074884 + 6280.0333100571*$t);
  $Y0 += 0.00000000628 * cos(5.02906961003 + 17298.4261448097*$t);
  $Y0 += 0.00000000532 * cos(2.84025435717 + 11514.1271342779*$t);
  $Y0 += 0.00000000513 * cos(2.13211972766 + 12456.1891962469*$t);
  $Y0 += 0.00000000649 * cos(3.33488996078 + 11764.5745863425*$t);
  $Y0 += 0.00000000582 * cos(2.96012797214 + 6414.8616291613*$t);
  $Y0 += 0.00000000517 * cos(5.63213604686 + 3340.36860921629*$t);
  $Y0 += 0.00000000609 * cos(2.37414673548 + 10420.23010099111*$t);
  $Y0 += 0.00000000615 * cos(0.00032066291 + 10983.94853421629*$t);
  $Y0 += 0.00000000622 * cos(0.82619343851 + 5326.5428765373*$t);
  $Y0 += 0.00000000536 * cos(2.13145334966 + 7232.49527644471*$t);
  $Y0 += 0.00000000516 * cos(1.35907342509 + 433.9555553603*$t);
  $Y0 += 0.00000000613 * cos(3.36175443914 + 10969.72144021469*$t);
  $Y0 += 0.00000000583 * cos(1.44072369133 + 5863.3473886327*$t);
  $Y0 += 0.00000000636 * cos(1.34803641207 + 26735.7014447297*$t);
  $Y0 += 0.00000000665 * cos(4.31762068350 + 40879.1966871603*$t);
  $Y0 += 0.00000000583 * cos(4.39404867767 + 12592.2062022991*$t);
  $Y0 += 0.00000000479 * cos(6.04787718072 + 5547.4431539431*$t);
  $Y0 += 0.00000000571 * cos(1.01593938825 + 6062.9070250361*$t);
  $Y0 += 0.00000000565 * cos(5.49171831457 + 4171.1817191303*$t);
  $Y0 += 0.00000000462 * cos(3.53710274271 + 3104.6862419403*$t);
  $Y0 += 0.00000000551 * cos(2.46794798020 + 6503.7323099137*$t);
  $Y0 += 0.00000000504 * cos(0.43308443375 + 15670.83794192309*$t);
  $Y0 += 0.00000000535 * cos(4.55197610339 + 173567.08125514039*$t);
  $Y0 += 0.00000000460 * cos(4.75481082956 + 3495.78900865049*$t);
  $Y0 += 0.00000000449 * cos(0.38594751092 + 4274.27449334889*$t);
  $Y0 += 0.00000000453 * cos(5.14645638415 + 9387.76209193169*$t);
  $Y0 += 0.00000000527 * cos(4.67747505318 + 24602.8562523545*$t);
  $Y0 += 0.00000000502 * cos(5.68646114706 + 12490.1294461907*$t);
  $Y0 += 0.00000000603 * cos(5.56725967880 + 322711.54834138996*$t);
  $Y0 += 0.00000000532 * cos(0.26579545469 + 5120.8449630671*$t);
  $Y0 += 0.00000000530 * cos(5.14730101928 + 18845.9482491087*$t);
  $Y0 += 0.00000000431 * cos(3.74066314880 + 7019.19618100671*$t);
  $Y0 += 0.00000000465 * cos(1.12060083942 + 8827.14645239129*$t);
  $Y0 += 0.00000000559 * cos(0.14481247330 + 1582.2031657665*$t);
  $Y0 += 0.00000000485 * cos(4.56530394374 + 29296.8592070621*$t);
  $Y0 += 0.00000000584 * cos(4.78377689692 + 72850.80553272919*$t);
  $Y0 += 0.00000000550 * cos(5.52640225498 + 213.0552779545*$t);
  $Y0 += 0.00000000481 * cos(0.29866487122 + 14.47091148511*$t);
  $Y0 += 0.00000000569 * cos(1.38161051216 + 97238.871361971*$t);
  $Y0 += 0.00000000551 * cos(3.21618763564 + 14313.9242955663*$t);
  $Y0 += 0.00000000389 * cos(1.85967717576 + 6245.1866318371*$t);
  $Y0 += 0.00000000389 * cos(1.64726374330 + 6321.4527031127*$t);
  $Y0 += 0.00000000388 * cos(5.85202122263 + 6297.5467614765*$t);
  $Y0 += 0.00000000388 * cos(3.93810500361 + 6269.0925734733*$t);
  $Y0 += 0.00000000515 * cos(0.09995632139 + 12320.56387123691*$t);
  $Y0 += 0.00000000394 * cos(1.39198903052 + 4156.95462512869*$t);
  $Y0 += 0.00000000491 * cos(4.39709251394 + 1479.11039154791*$t);
  $Y0 += 0.00000000440 * cos(2.54396321518 + 5650.0482931947*$t);
  $Y0 += 0.00000000382 * cos(1.50580912176 + 9917.9406919933*$t);
  $Y0 += 0.00000000503 * cos(3.08687612414 + 17157.3056979553*$t);
  $Y0 += 0.00000000439 * cos(3.25483236471 + 233141.55822184499*$t);
  $Y0 += 0.00000000381 * cos(3.59564013891 + 14143.2514249471*$t);
  $Y0 += 0.00000000371 * cos(3.01987537874 + 5643.4223811609*$t);
  $Y0 += 0.00000000516 * cos(4.04344774561 + 135.30889751891*$t);
  $Y0 += 0.00000000417 * cos(2.17381926869 + 13760.8425276909*$t);
  $Y0 += 0.00000000483 * cos(2.84671280305 + 9779.3524936089*$t);
  $Y0 += 0.00000000381 * cos(2.79871486639 + 14919.2616712381*$t);
  $Y0 += 0.00000000378 * cos(2.94872717012 + 17267.5120191747*$t);
  $Y0 += 0.00000000393 * cos(6.27917510634 + 7872.39256275871*$t);
  $Y0 += 0.00000000376 * cos(6.02660735301 + 13517.62628874989*$t);
  $Y0 += 0.00000000365 * cos(0.53940975175 + 6923.2169537889*$t);
  $Y0 += 0.00000000371 * cos(4.19154046767 + 13625.7774476555*$t);
  $Y0 += 0.00000000355 * cos(3.67238322579 + 10874.2298479639*$t);
  $Y0 += 0.00000000499 * cos(1.15482974306 + 161710.8626037159*$t);
  $Y0 += 0.00000000379 * cos(5.52860495919 + 3185.43584474911*$t);
  $Y0 += 0.00000000471 * cos(0.07055813902 + 11712.71150074729*$t);
  $Y0 += 0.00000000417 * cos(1.75993959010 + 22779.6810636773*$t);
  $Y0 += 0.00000000485 * cos(6.06683096360 + 12528.26248182851*$t);
  $Y0 += 0.00000000358 * cos(1.92035724848 + 6295.0490203109*$t);
  $Y0 += 0.00000000358 * cos(1.58658367058 + 6271.5903146389*$t);
  $Y0 += 0.00000000365 * cos(5.19130080276 + 6836.40143535029*$t);
  $Y0 += 0.00000000351 * cos(0.64808198517 + 11617.21990849651*$t);
  $Y0 += 0.00000000351 * cos(4.53436303138 + 205.9417309537*$t);
  $Y0 += 0.00000000429 * cos(5.51029115203 + 3894.4256470257*$t);
  $Y0 += 0.00000000388 * cos(5.20318951030 + 956.53297345411*$t);
  $Y0 += 0.00000000464 * cos(5.40703775457 + 23581.5019948011*$t);
  $Y0 += 0.00000000396 * cos(0.78828729228 + 5231.0512842865*$t);
  $Y0 += 0.00000000421 * cos(3.25659811640 + 7445.7943718827*$t);
  $Y0 += 0.00000000366 * cos(5.33851384127 + 17253.2849251731*$t);
  $Y0 += 0.00000000360 * cos(5.53135776054 + 21393.7857873411*$t);
  $Y0 += 0.00000000336 * cos(6.12569565789 + 6279.3875142118*$t);
  $Y0 += 0.00000000336 * cos(3.66443056835 + 6287.251820738*$t);
  $Y0 += 0.00000000326 * cos(0.22542241669 + 1059.1381127057*$t);
  $Y0 += 0.00000000395 * cos(5.25182737341 + 5642.4420600927*$t);
  $Y0 += 0.00000000450 * cos(1.80229899871 + 1385.3177574676*$t);
  $Y0 += 0.00000000363 * cos(2.72535712612 + 22484.0923919761*$t);
  $Y0 += 0.00000000399 * cos(5.51787738042 + 16858.7263504167*$t);
  $Y0 += 0.00000000316 * cos(2.45995539098 + 20995.6367839329*$t);
  $Y0 += 0.00000000430 * cos(3.96101117316 + 19650.8046636145*$t);
  $Y0 += 0.00000000363 * cos(2.71990145670 + 7335.5880506633*$t);
  $Y0 += 0.00000000317 * cos(3.09968934621 + 11769.6098756829*$t);
  $Y0 += 0.00000000395 * cos(3.82348351794 + 5905.94605955911*$t);
  $Y0 += 0.00000000324 * cos(5.27854205827 + 37.7838551523*$t);
  $Y0 += 0.00000000299 * cos(2.29226668471 + 641.12142486571*$t);
  $Y0 += 0.00000000304 * cos(4.87224846445 + 5750.1055840313*$t);
  $Y0 += 0.00000000298 * cos(2.25684047934 + 1350.1112271423*$t);
  $Y0 += 0.00000000414 * cos(5.74970236841 + 44809.4063833799*$t);
  $Y0 += 0.00000000339 * cos(5.86256617398 + 3.6883357796*$t);
  $Y0 += 0.00000000351 * cos(4.36315861783 + 12345.9828750275*$t);
  $Y0 += 0.00000000362 * cos(1.99294614713 + 21953.91379191449*$t);
  $Y0 += 0.00000000304 * cos(3.36735752668 + 29826.5501721567*$t);
  $Y0 += 0.00000000395 * cos(4.78960869869 + 4176.2851599325*$t);
  $Y0 += 0.00000000320 * cos(0.92821593891 + 10818.3791043993*$t);
  $Y0 += 0.00000000384 * cos(5.58951901360 + 10177.01386205009*$t);
  $Y0 += 0.00000000279 * cos(5.67648753585 + 10970.2090751817*$t);
  $Y0 += 0.00000000365 * cos(5.96664259426 + 6660.6932753907*$t);
  $Y0 += 0.00000000377 * cos(5.53753804163 + 29864.5778447925*$t);
  $Y0 += 0.00000000275 * cos(4.16427905835 + 20597.4877805247*$t);
  $Y0 += 0.00000000316 * cos(1.02608510804 + 316.6356871401*$t);
  $Y0 += 0.00000000339 * cos(4.53749399958 + 6924.1972748571*$t);
  $Y0 += 0.00000000386 * cos(0.71953202985 + 2636.9692901205*$t);
  $Y0 += 0.00000000273 * cos(5.80758206821 + 26709.8907598969*$t);
  $Y0 += 0.00000000314 * cos(6.18462887647 + 14945.5599910379*$t);
  $Y0 += 0.00000000281 * cos(0.15414528977 + 16858.23871544969*$t);
  $Y0 += 0.00000000287 * cos(4.87229910240 + 18073.46112116669*$t);
  $Y0 += 0.00000000265 * cos(3.53930677592 + 19379.1623325523*$t);
  $Y0 += 0.00000000325 * cos(0.92198404013 + 12360.2099690291*$t);
  $Y0 += 0.00000000362 * cos(2.75236634018 + 30665.9111409493*$t);
  $Y0 += 0.00000000269 * cos(4.91776126981 + 6816.53375091851*$t);
  $Y0 += 0.00000000344 * cos(1.94480091531 + 6147.69434246491*$t);
  $Y0 += 0.00000000255 * cos(3.37543976329 + 1376.0176173293*$t);
  $Y0 += 0.00000000334 * cos(1.56223491581 + 6418.9449924849*$t);
  $Y0 += 0.00000000316 * cos(3.97125698165 + 6055.8435346859*$t);
  $Y0 += 0.00000000283 * cos(2.66015602247 + 28287.2343023447*$t);
  $Y0 += 0.00000000305 * cos(5.83332121064 + 16522.4158985187*$t);
  $Y0 += 0.00000000270 * cos(1.62295499850 + 283.6155013817*$t);
  $Y0 += 0.00000000243 * cos(0.97600841060 + 6255.9181113781*$t);
  $Y0 += 0.00000000243 * cos(2.53093250846 + 6310.7212235717*$t);
  $Y0 += 0.00000000296 * cos(4.79138408835 + 6129.5408569901*$t);
  $Y0 += 0.00000000301 * cos(5.81886935980 + 6510.7958002639*$t);
  $Y0 += 0.00000000329 * cos(5.86922121940 + 377.6174253993*$t);
  $Y0 += 0.00000000267 * cos(1.84931872641 + 24705.9490265731*$t);
  $Y0 += 0.00000000285 * cos(0.93414937692 + 5469.7693835151*$t);
  $Y0 += 0.00000000286 * cos(4.99886262730 + 6437.0984779597*$t);
  $Y0 += 0.00000000311 * cos(1.63984256457 + 11720.3126827151*$t);
  $Y0 += 0.00000000319 * cos(3.13980275142 + 169379.5000286584*$t);
  $Y0 += 0.00000000241 * cos(4.56518963450 + 632.5399218297*$t);
  $Y0 += 0.00000000229 * cos(5.72761357577 + 1265.81129610991*$t);
  $Y0 += 0.00000000235 * cos(4.94058515466 + 4487.57358878689*$t);
  $Y0 += 0.00000000253 * cos(2.08435720561 + 4377.3672675675*$t);
  $Y0 += 0.00000000277 * cos(3.15798901317 + 419.2408263917*$t);
  $Y0 += 0.00000000234 * cos(3.55494952630 + 11713.1991357143*$t);
  $Y0 += 0.00000000216 * cos(0.30207043900 + 10454.25756912169*$t);
  $Y0 += 0.00000000241 * cos(3.87591164077 + 103.3365917021*$t);
  $Y0 += 0.00000000214 * cos(0.52402082918 + 2222.1004520805*$t);
  $Y0 += 0.00000000213 * cos(2.22358750694 + 30356.2411372513*$t);
  $Y0 += 0.00000000240 * cos(4.14485134121 + 6309.1303523077*$t);
  $Y0 += 0.00000000212 * cos(3.93716983669 + 262.84010588929*$t);
  $Y0 += 0.00000000259 * cos(1.64646341991 + 6283.56348495841*$t);
  $Y0 += 0.00000000259 * cos(1.86047749915 + 6283.0758499914*$t);
  $Y0 += 0.00000000222 * cos(2.99868754607 + 10440.03047512009*$t);
  $Y0 += 0.00000000201 * cos(0.39862703515 + 5746.0275204125*$t);
  $Y0 += 0.00000000274 * cos(5.42466894469 + 23581.0143598341*$t);
  $Y0 += 0.00000000243 * cos(2.57266886723 + 7096.8699514347*$t);
  $Y0 += 0.00000000234 * cos(3.66617634256 + 5573.3866189166*$t);
  $Y0 += 0.00000000203 * cos(1.57613060854 + 16460.08971204149*$t);
  $Y0 += 0.00000000246 * cos(4.26574746801 + 8672.21368792411*$t);
  $Y0 += 0.00000000216 * cos(3.35974562754 + 5437.23683272371*$t);
  $Y0 += 0.00000000210 * cos(4.25419338790 + 9381.2034902007*$t);
  $Y0 += 0.00000000199 * cos(5.64767313384 + 11216.5281078075*$t);
  $Y0 += 0.00000000270 * cos(5.11258425974 + 284.1031363487*$t);
  $Y0 += 0.00000000207 * cos(1.49549061720 + 12562.80508881451*$t);
  $Y0 += 0.00000000212 * cos(0.18391974040 + 7129.4025022261*$t);
  $Y0 += 0.00000000269 * cos(6.23907858108 + 70755.31090921978*$t);
  $Y0 += 0.00000000221 * cos(4.97264401025 + 77713.52765063698*$t);
  $Y0 += 0.00000000225 * cos(5.58708477402 + 5635.8211991931*$t);
  $Y0 += 0.00000000197 * cos(4.93201648946 + 14712.07329897449*$t);
  $Y0 += 0.00000000192 * cos(0.47501431186 + 17272.1278250099*$t);
  $Y0 += 0.00000000241 * cos(3.52343193321 + 15907.0079441661*$t);
  $Y0 += 0.00000000261 * cos(0.88974137342 + 48739.6160795995*$t);
  $Y0 += 0.00000000255 * cos(2.10230203862 + 6206.5659612323*$t);
  $Y0 += 0.00000000256 * cos(0.73069007306 + 224.5886131854*$t);
  $Y0 += 0.00000000182 * cos(5.98997615944 + 18848.98373249069*$t);
  $Y0 += 0.00000000250 * cos(2.67103598665 + 5934.39524702691*$t);
  $Y0 += 0.00000000196 * cos(0.64831634218 + 16460.5773470085*$t);
  $Y0 += 0.00000000187 * cos(0.04522363352 + 22003.6708173863*$t);
  $Y0 += 0.00000000229 * cos(1.73812120333 + 2942.21960580809*$t);
  $Y0 += 0.00000000175 * cos(3.84094267540 + 11614.6771112157*$t);
  $Y0 += 0.00000000187 * cos(0.76186633809 + 9778.8648586419*$t);
  $Y0 += 0.00000000175 * cos(6.15302938442 + 3744.5835282543*$t);
  $Y0 += 0.00000000241 * cos(5.00033837792 + 8390.3541750173*$t);
  $Y0 += 0.00000000236 * cos(0.45405670770 + 1.7282901918*$t);
  $Y0 += 0.00000000217 * cos(3.45380390356 + 17996.2749857057*$t);
  $Y0 += 0.00000000173 * cos(2.65478632822 + 6275.71848550709*$t);
  $Y0 += 0.00000000191 * cos(4.70676649838 + 394.86970254271*$t);
  $Y0 += 0.00000000231 * cos(4.17552456214 + 34596.1208371689*$t);
  $Y0 += 0.00000000169 * cos(0.40140025709 + 6438.2524319421*$t);
  $Y0 += 0.00000000235 * cos(5.04475734159 + 17256.38771885789*$t);
  $Y0 += 0.00000000188 * cos(4.02583282760 + 401.91593924071*$t);
  $Y0 += 0.00000000217 * cos(3.40363231104 + 10984.4361691833*$t);
  $Y0 += 0.00000000230 * cos(0.83612775625 + 6632.2440879229*$t);
  $Y0 += 0.00000000208 * cos(5.43298352980 + 11087.5289434019*$t);
  $Y0 += 0.00000000165 * cos(0.80102915744 + 743.23387801611*$t);
  $Y0 += 0.00000000177 * cos(0.01829077781 + 4796.85191144269*$t);
  $Y0 += 0.00000000208 * cos(6.16123229814 + 3097.64000524229*$t);
  $Y0 += 0.00000000167 * cos(2.40308314985 + 5714.4977934475*$t);
  $Y0 += 0.00000000198 * cos(4.83812277030 + 5539.8419719753*$t);
  $Y0 += 0.00000000169 * cos(2.16903380895 + 12132.6837795895*$t);
  $Y0 += 0.00000000214 * cos(2.77137176457 + 24492.6499311351*$t);
  $Y0 += 0.00000000172 * cos(5.97118942936 + 6233.5626420031*$t);
  $Y0 += 0.00000000172 * cos(3.81893679688 + 6333.0766929467*$t);
  $Y0 += 0.00000000223 * cos(3.42911214381 + 266.85085920531*$t);
  $Y0 += 0.00000000159 * cos(2.33166453392 + 13199.1792567795*$t);
  $Y0 += 0.00000000219 * cos(0.69566285170 + 10344.05124790229*$t);
  $Y0 += 0.00000000207 * cos(1.92518585993 + 12569.9859461181*$t);
  $Y0 += 0.00000000176 * cos(2.48119576594 + 12012.8261146239*$t);
  $Y0 += 0.00000000170 * cos(4.43959906760 + 6294.36536773881*$t);
  $Y0 += 0.00000000170 * cos(5.35052715864 + 6272.273967211*$t);
  $Y0 += 0.00000000205 * cos(1.15927608909 + 13119.47728534169*$t);
  $Y0 += 0.00000000167 * cos(3.97305893961 + 17686.9966630499*$t);
  $Y0 += 0.00000000210 * cos(2.45255073470 + 13521.50762410789*$t);
  $Y0 += 0.00000000163 * cos(6.18035129909 + 802.0647486073*$t);
  $Y0 += 0.00000000159 * cos(0.13779660073 + 5017.2645538815*$t);
  $Y0 += 0.00000000148 * cos(5.46314197385 + 419.72846135871*$t);
  $Y0 += 0.00000000165 * cos(5.59205778351 + 20199.3387771165*$t);
  $Y0 += 0.00000000196 * cos(5.15079536124 + 33326.33491569069*$t);
  $Y0 += 0.00000000146 * cos(1.96564383477 + 19800.7021387413*$t);
  $Y0 += 0.00000000148 * cos(1.10385783973 + 6852.1415415023*$t);
  $Y0 += 0.00000000146 * cos(4.95120975616 + 17370.6047933933*$t);
  $Y0 += 0.00000000143 * cos(5.56441247552 + 5618.5636223449*$t);
  $Y0 += 0.00000000142 * cos(0.65902902155 + 17654.5367222661*$t);
  $Y0 += 0.00000000140 * cos(5.93480456615 + 2008.8013566425*$t);
  $Y0 += 0.00000000153 * cos(3.36826827070 + 5436.7491977567*$t);
  $Y0 += 0.00000000162 * cos(5.27294659555 + 775.2787938405*$t);
  $Y0 += 0.00000000162 * cos(3.21674523006 + 12552.1684234647*$t);
  $Y0 += 0.00000000143 * cos(3.89298583971 + 5010.1510068807*$t);
  $Y0 += 0.00000000188 * cos(2.11622447442 + 28.6930049513*$t);
  $Y0 += 0.00000000155 * cos(4.58570766573 + 11610.1063614957*$t);
  $Y0 += 0.00000000174 * cos(1.00725781500 + 20452.6255947383*$t);
  $Y0 += 0.00000000179 * cos(0.59168717373 + 27511.2240560537*$t);
  $Y0 += 0.00000000135 * cos(4.79054860554 + 12431.3304374309*$t);
  $Y0 += 0.00000000164 * cos(4.03840473864 + 28767.1682419675*$t);
  $Y0 += 0.00000000134 * cos(3.87019546457 + 16840.9138282987*$t);
  $Y0 += 0.00000000174 * cos(2.70675879120 + 19805.0711090663*$t);
  $Y0 += 0.00000000146 * cos(6.27087503385 + 12701.4605975017*$t);
  $Y0 += 0.00000000137 * cos(1.03021623583 + 11.2895177474*$t);
  $Y0 += 0.00000000167 * cos(5.98298407227 + 17473.6975676119*$t);
  $Y0 += 0.00000000152 * cos(2.62025173907 + 16627.6147328607*$t);
  $Y0 += 0.00000000124 * cos(4.22571397919 + 6948.0757126049*$t);
  $Y0 += 0.00000000135 * cos(4.95808633295 + 3531.2844328163*$t);
  $Y0 += 0.00000000172 * cos(0.23022549161 + 167959.14629657479*$t);
  $Y0 += 0.00000000123 * cos(0.49830220802 + 23013.29572210369*$t);
  $Y0 += 0.00000000122 * cos(4.12184350213 + 3583.5848481573*$t);
  $Y0 += 0.00000000170 * cos(6.16462326207 + 333857.83394425618*$t);
  $Y0 += 0.00000000155 * cos(5.62824965405 + 6058.48723680599*$t);
  $Y0 += 0.00000000120 * cos(5.90379805618 + 12809.12412144031*$t);
  $Y0 += 0.00000000141 * cos(3.95455666878 + 162420.79565227419*$t);
  $Y0 += 0.00000000120 * cos(4.26997270152 + 12528.3678448305*$t);
  $Y0 += 0.00000000123 * cos(1.49653119992 + 25933.8805136059*$t);
  $Y0 += 0.00000000144 * cos(3.70806542711 + 95.7354097343*$t);
  $Y0 += 0.00000000165 * cos(2.31400541864 + 52669.8257758191*$t);
  $Y0 += 0.00000000119 * cos(5.90934736896 + 19247.6203708659*$t);
  $Y0 += 0.00000000117 * cos(5.45034774436 + 11610.7957758577*$t);
  $Y0 += 0.00000000163 * cos(1.54456737879 + 661.4767442645*$t);
  $Y0 += 0.00000000163 * cos(2.78769461236 + 9929.6700448293*$t);
  $Y0 += 0.00000000119 * cos(2.71628583938 + 12250.0036478097*$t);
  $Y0 += 0.00000000145 * cos(2.33523694188 + 6205.6458970469*$t);
  $Y0 += 0.00000000145 * cos(1.17170397718 + 6360.99343790291*$t);
  $Y0 += 0.00000000159 * cos(2.61434005227 + 228278.34846897019*$t);
  $Y0 += 0.00000000114 * cos(3.41169068642 + 19402.55313533309*$t);
  $Y0 += 0.00000000147 * cos(5.63174103655 + 38526.3305333885*$t);
  $Y0 += 0.00000000156 * cos(1.00709118546 + 4307.8271216189*$t);
  $Y0 += 0.00000000131 * cos(0.13588364911 + 21228.63584102931*$t);
  $Y0 += 0.00000000118 * cos(3.83848144749 + 6263.64990657511*$t);
  $Y0 += 0.00000000118 * cos(5.95164477875 + 6302.9894283747*$t);
  $Y0 += 0.00000000137 * cos(0.97335445483 + 6315.8522182663*$t);
  $Y0 += 0.00000000137 * cos(2.53358646423 + 6250.7871166835*$t);
  $Y0 += 0.00000000109 * cos(1.19644618130 + 11925.5179100841*$t);
  $Y0 += 0.00000000111 * cos(2.80331366377 + 6226.4212925393*$t);
  $Y0 += 0.00000000111 * cos(0.70362725529 + 6340.2180424105*$t);
  $Y0 += 0.00000000123 * cos(0.80537647876 + 24734.3982140409*$t);
  $Y0 += 0.00000000107 * cos(0.59542543867 + 12463.30274324771*$t);
  $Y0 += 0.00000000133 * cos(1.45986519440 + 18875.76968725751*$t);
  $Y0 += 0.00000000123 * cos(4.07179306364 + 6260.5444660241*$t);
  $Y0 += 0.00000000123 * cos(5.71833316259 + 6306.09486892571*$t);
  $Y0 += 0.00000000113 * cos(0.38322617607 + 2111.8941308611*$t);
  $Y0 += 0.00000000131 * cos(2.04114030865 + 18415.7596295809*$t);
  $Y0 += 0.00000000110 * cos(0.19106597205 + 6289.94822637491*$t);
  $Y0 += 0.00000000110 * cos(3.31587494701 + 6276.69110857489*$t);
  $Y0 += 0.00000000103 * cos(2.31964172720 + 6241.7688764901*$t);
  $Y0 += 0.00000000103 * cos(1.18729919186 + 6324.8704584597*$t);
  $Y0 += 0.00000000113 * cos(0.63409757277 + 3496.2766436175*$t);
  $Y0 += 0.00000000103 * cos(3.00856574797 + 10344.5388828693*$t);
  $Y0 += 0.00000000115 * cos(1.09796447220 + 24336.2492106327*$t);
  $Y0 += 0.00000000107 * cos(0.14947871700 + 83974.07917321339*$t);
  $Y0 += 0.00000000107 * cos(1.18802993790 + 84020.10309797739*$t);
  $Y0 += 0.00000000106 * cos(1.70601019340 + 12772.58106590351*$t);
  $Y0 += 0.00000000143 * cos(6.22463763653 + 2069.2506523901*$t);
  $Y0 += 0.00000000143 * cos(5.63223127595 + 18773.2052961821*$t);
  $Y0 += 0.00000000115 * cos(5.35405637827 + 3641.4907540357*$t);
  $Y0 += 0.00000000112 * cos(1.02603600816 + 11499.41240530929*$t);
  $Y0 += 0.00000000099 * cos(0.21940282455 + 11190.6217176205*$t);
  $Y0 += 0.00000000126 * cos(5.90533164276 + 18823.1730476579*$t);
  $Y0 += 0.00000000115 * cos(3.09464836385 + 12570.3276707294*$t);
  $Y0 += 0.00000000100 * cos(1.95823440417 + 16062.4283436003*$t);
  $Y0 += 0.00000000107 * cos(2.45486702592 + 5216.8241902849*$t);
  $Y0 += 0.00000000120 * cos(0.25356721797 + 9814.36028280769*$t);
  $Y0 += 0.00000000138 * cos(2.98838673165 + 6210.0225416159*$t);
  $Y0 += 0.00000000138 * cos(0.51855418741 + 6356.6167933339*$t);
  $Y0 += 0.00000000105 * cos(2.60431357489 + 12721.32828193349*$t);
  $Y0 += 0.00000000135 * cos(5.28295396943 + 18699.9081703231*$t);
  $Y0 += 0.00000000104 * cos(0.57981411648 + 12560.8725931589*$t);
  $Y0 += 0.00000000098 * cos(4.00435005538 + 5815.3546771205*$t);
  $Y0 += 0.00000000111 * cos(5.54435587296 + 10239.3400485273*$t);
  $Y0 += 0.00000000100 * cos(2.98744963581 + 263.3277408563*$t);
  $Y0 += 0.00000000095 * cos(0.17662269567 + 155.6642169177*$t);
  $Y0 += 0.00000000130 * cos(0.55194216539 + 27511.7116910207*$t);
  $Y0 += 0.00000000120 * cos(1.84949333794 + 31441.4337522733*$t);
  $Y0 += 0.00000000114 * cos(2.18292460802 + 6155.3008241375*$t);
  $Y0 += 0.00000000114 * cos(1.32401631104 + 6411.3385108123*$t);
  $Y0 += 0.00000000119 * cos(3.64842963894 + 951.9622237341*$t);
  $Y0 += 0.00000000117 * cos(3.47158263266 + 28236.98964190589*$t);
  $Y0 += 0.00000000107 * cos(0.33835239167 + 21.0192129759*$t);
  $Y0 += 0.00000000095 * cos(4.06228359170 + 11300.8280388399*$t);
  $Y0 += 0.00000000110 * cos(1.22040625314 + 6312.74917601091*$t);
  $Y0 += 0.00000000110 * cos(2.28653466592 + 6253.8901589389*$t);
  $Y0 += 0.00000000097 * cos(2.64989366154 + 78263.95324220609*$t);
  $Y0 += 0.00000000095 * cos(4.41295990485 + 23938.1002072245*$t);
  $Y0 += 0.00000000091 * cos(1.42377843647 + 12829.4794408391*$t);
  $Y0 += 0.00000000112 * cos(2.74085534623 + 16737.8210540801*$t);
  $Y0 += 0.00000000126 * cos(4.67942071523 + 3.2793008655*$t);
  $Y0 += 0.00000000100 * cos(1.46206803081 + 6133.7564703403*$t);
  $Y0 += 0.00000000127 * cos(0.70264556724 + 1293.24040609909*$t);
  $Y0 += 0.00000000119 * cos(4.42085627054 + 17893.1822114871*$t);
  $Y0 += 0.00000000089 * cos(6.04696991631 + 23539.9512038163*$t);
  $Y0 += 0.00000000126 * cos(4.96989590925 + 311565.26273852374*$t);
  $Y0 += 0.00000000093 * cos(4.10519400640 + 736.1203310153*$t);
  $Y0 += 0.00000000120 * cos(0.51718078841 + 14158.9915310991*$t);
  $Y0 += 0.00000000118 * cos(3.00291998094 + 16061.94070863329*$t);
  $Y0 += 0.00000000099 * cos(2.04878528903 + 6432.8828646095*$t);
  $Y0 += 0.00000000095 * cos(1.28476695157 + 2699.49100183409*$t);
  $Y0 += 0.00000000089 * cos(0.73014646335 + 15671.3255768901*$t);
  $Y0 += 0.00000000124 * cos(5.19246908636 + 178430.29100801519*$t);
  $Y0 += 0.00000000089 * cos(5.78577582542 + 6751.28465782931*$t);
  $Y0 += 0.00000000096 * cos(1.07414401415 + 7349.81514466491*$t);
  $Y0 += 0.00000000096 * cos(5.45460641914 + 24066.0517402591*$t);
  $Y0 += 0.00000000103 * cos(2.80667748337 + 18202.4605341429*$t);
  $Y0 += 0.00000000099 * cos(4.49603988169 + 6252.40554183991*$t);
  $Y0 += 0.00000000099 * cos(5.29408634455 + 6314.2337931099*$t);
  $Y0 += 0.00000000090 * cos(1.96044978655 + 58864.30010066279*$t);
  $Y0 += 0.00000000086 * cos(2.16910774240 + 9380.71585523369*$t);
  $Y0 += 0.00000000086 * cos(2.50989174885 + 10557.35034334029*$t);
  $Y0 += 0.00000000098 * cos(1.84392439378 + 6439.7203879773*$t);
  $Y0 += 0.00000000098 * cos(1.66301652528 + 6126.91894697251*$t);
  $Y0 += 0.00000000086 * cos(6.05387198611 + 23123.9896782901*$t);
  $Y0 += 0.00000000118 * cos(2.16764726700 + 13951.9570924174*$t);
  $Y0 += 0.00000000117 * cos(2.53823002855 + 89570.23393702849*$t);
  $Y0 += 0.00000000083 * cos(4.71213278190 + 8858.0711268371*$t);
  $Y0 += 0.00000000092 * cos(2.44147365747 + 12342.0507217644*$t);
  $Y0 += 0.00000000085 * cos(0.72336255749 + 5017.7521888485*$t);
  $Y0 += 0.00000000101 * cos(4.94259233986 + 18429.9867235825*$t);
  $Y0 += 0.00000000088 * cos(2.19664804056 + 17054.2129237367*$t);
  $Y0 += 0.00000000113 * cos(0.47970289838 + 12985.88016134151*$t);
  $Y0 += 0.00000000083 * cos(2.47657261289 + 20597.0001455577*$t);
  $Y0 += 0.00000000082 * cos(4.90614394615 + 5483.4985423095*$t);
  $Y0 += 0.00000000087 * cos(1.67775805144 + 21424.2228268199*$t);
  $Y0 += 0.00000000107 * cos(3.78836692146 + 522.3336006103*$t);
  $Y0 += 0.00000000084 * cos(0.84028318953 + 6187.3404402571*$t);
  $Y0 += 0.00000000084 * cos(2.66665772953 + 6379.2988946927*$t);
  $Y0 += 0.00000000107 * cos(2.45229388212 + 24382.8352909579*$t);
  $Y0 += 0.00000000082 * cos(5.66196525445 + 8983.0544867925*$t);
  $Y0 += 0.00000000105 * cos(2.30294939014 + 6131.4223863897*$t);
  $Y0 += 0.00000000105 * cos(1.20399152892 + 6435.2169485601*$t);
  $Y0 += 0.00000000114 * cos(2.50001149568 + 8258.81221333091*$t);
  $Y0 += 0.00000000082 * cos(5.40031574607 + 3957.8826236923*$t);
  $Y0 += 0.00000000112 * cos(4.27968226719 + 3738.51761262449*$t);
  $Y0 += 0.00000000102 * cos(1.32703960779 + 5767.8557963819*$t);
  $Y0 += 0.00000000102 * cos(2.17990131127 + 6798.7835385679*$t);
  $Y0 += 0.00000000092 * cos(6.06909982221 + 18216.6876281445*$t);
  $Y0 += 0.00000000083 * cos(2.92326536483 + 29864.0902098255*$t);
  $Y0 += 0.00000000112 * cos(3.91825505548 + 12189.0219095505*$t);
  $Y0 += 0.00000000080 * cos(2.01989715959 + 24080.2788342607*$t);
  $Y0 += 0.00000000080 * cos(0.09553378894 + 15141.14697682849*$t);
  $Y0 += 0.00000000088 * cos(4.57487416308 + 1573.57660661529*$t);
  $Y0 += 0.00000000081 * cos(5.29168357177 + 1550.8014051645*$t);
  $Y0 += 0.00000000092 * cos(2.79378764615 + 101426.452588453*$t);
  $Y0 += 0.00000000110 * cos(5.08245905369 + 78423.9483341623*$t);
  $Y0 += 0.00000000087 * cos(3.89276904283 + 1580.6228433133*$t);
  $Y0 += 0.00000000085 * cos(1.43001232077 + 27043.2590656993*$t);
  $Y0 += 0.00000000078 * cos(3.02198277867 + 6812.5229976025*$t);
  $Y0 += 0.00000000080 * cos(1.79867193339 + 6081.06627230081*$t);
  $Y0 += 0.00000000080 * cos(1.70826898567 + 6485.573062649*$t);
  $Y0 += 0.00000000079 * cos(2.96736855880 + 36109.6260221481*$t);
  $Y0 += 0.00000000088 * cos(5.58307910278 + 16944.0066025173*$t);
  $Y0 += 0.00000000081 * cos(2.98944824758 + 5.2791068239*$t);
  $Y0 += 0.00000000093 * cos(1.14380332092 + 16737.33341911309*$t);
  $Y0 += 0.00000000088 * cos(1.67821631800 + 12537.9463299985*$t);
  $Y0 += 0.00000000096 * cos(0.48155847774 + 20198.85114214949*$t);
  $Y0 += 0.00000000106 * cos(3.73745326901 + 56600.0354720387*$t);
  $Y0 += 0.00000000097 * cos(1.71169429599 + 6040.10342853389*$t);
  $Y0 += 0.00000000081 * cos(5.19219909829 + 3956.2641985359*$t);
  $Y0 += 0.00000000077 * cos(6.10587791973 + 40796.5827401577*$t);
  $Y0 += 0.00000000076 * cos(3.78044498975 + 22743.16556203289*$t);
  $Y0 += 0.00000000098 * cos(0.77646852784 + 42456.5402296081*$t);
  $Y0 += 0.00000000083 * cos(0.63561076928 + 19801.1897737083*$t);
  $Y0 += 0.00000000079 * cos(2.93697401198 + 5622.08674069391*$t);
  $Y0 += 0.00000000096 * cos(0.41418225890 + 5888.6937824157*$t);
  $Y0 += 0.00000000096 * cos(3.09275866016 + 6677.9455525341*$t);
  $Y0 += 0.00000000075 * cos(4.66945944657 + 41194.7317435659*$t);
  $Y0 += 0.00000000074 * cos(5.37967983395 + 6261.9840270079*$t);
  $Y0 += 0.00000000074 * cos(4.41044639229 + 6304.6553079419*$t);
  $Y0 += 0.00000000073 * cos(2.45644384945 + 5870.9485706005*$t);
  $Y0 += 0.00000000073 * cos(1.05049706961 + 6695.6907643493*$t);
  $Y0 += 0.00000000085 * cos(2.08161902252 + 12850.2548363315*$t);
  $Y0 += 0.00000000072 * cos(4.75417028947 + 6253.4982293261*$t);
  $Y0 += 0.00000000072 * cos(5.03595593677 + 6313.14110562371*$t);
  $Y0 += 0.00000000100 * cos(3.80714894085 + 5316.3487900393*$t);
  $Y0 += 0.00000000085 * cos(1.33904345426 + 12282.5361986011*$t);
  $Y0 += 0.00000000075 * cos(0.39510472937 + 24422.6141688908*$t);
  $Y0 += 0.00000000076 * cos(0.41148054527 + 63659.1215683211*$t);
  $Y0 += 0.00000000072 * cos(4.97177288715 + 16723.5939600785*$t);
  $Y0 += 0.00000000097 * cos(0.21179463686 + 17995.78735073869*$t);
  $Y0 += 0.00000000087 * cos(2.06337614338 + 18106.4813069251*$t);
  $Y0 += 0.00000000080 * cos(3.60508005382 + 17363.4912463925*$t);
  $Y0 += 0.00000000070 * cos(3.06053136401 + 6124.37614969171*$t);
  $Y0 += 0.00000000070 * cos(0.44640955505 + 6442.2631852581*$t);
  $Y0 += 0.00000000070 * cos(4.42572835968 + 4705.4884900601*$t);
  $Y0 += 0.00000000078 * cos(3.37769653143 + 23550.5878691661*$t);
  $Y0 += 0.00000000070 * cos(3.84581453123 + 12036.21691740469*$t);
  $Y0 += 0.00000000077 * cos(5.00579533671 + 5237.67719632029*$t);
  $Y0 += 0.00000000069 * cos(1.30888647192 + 16207.64245401849*$t);
  $Y0 += 0.00000000082 * cos(3.91623659935 + 6774.98295993371*$t);
  $Y0 += 0.00000000067 * cos(4.88284115481 + 7083.14079264031*$t);
  $Y0 += 0.00000000067 * cos(0.26461151247 + 6394.50630976251*$t);
  $Y0 += 0.00000000067 * cos(3.24232940659 + 6172.1330251873*$t);
  $Y0 += 0.00000000077 * cos(0.28397734649 + 9924.5666040271*$t);
  $Y0 += 0.00000000080 * cos(3.79678848458 + 22380.9996177575*$t);
  $Y0 += 0.00000000070 * cos(3.03095059330 + 6390.9831914135*$t);
  $Y0 += 0.00000000070 * cos(0.47599032576 + 6175.6561435363*$t);
  $Y0 += 0.00000000074 * cos(4.12433601146 + 16193.41536001689*$t);
  $Y0 += 0.00000000076 * cos(4.07719654455 + 32217.4439985643*$t);
  $Y0 += 0.00000000091 * cos(0.90446873976 + 6653.0194834153*$t);
  $Y0 += 0.00000000091 * cos(2.60247217930 + 5913.6198515345*$t);
  $Y0 += 0.00000000067 * cos(4.94532713838 + 6265.50714535691*$t);
  $Y0 += 0.00000000067 * cos(4.84479908786 + 6301.1321895929*$t);
  $Y0 += 0.00000000067 * cos(3.01186125982 + 5959.3266158505*$t);
  $Y0 += 0.00000000083 * cos(4.51648793763 + 16723.10632511149*$t);
  $Y0 += 0.00000000080 * cos(5.49180050451 + 23646.5670963839*$t);
  $Y0 += 0.00000000068 * cos(2.07232606852 + 4897.4243911387*$t);
  $Y0 += 0.00000000069 * cos(0.56996686256 + 6944.5525942559*$t);
  $Y0 += 0.00000000089 * cos(3.57060375879 + 10660.44311755889*$t);
  $Y0 += 0.00000000079 * cos(3.24586891365 + 35371.6434484929*$t);
  $Y0 += 0.00000000073 * cos(0.54359299539 + 6370.62787201471*$t);
  $Y0 += 0.00000000073 * cos(2.96334792367 + 6196.0114629351*$t);
  $Y0 += 0.00000000065 * cos(5.23672190600 + 22345.0165586247*$t);
  $Y0 += 0.00000000064 * cos(5.80516008052 + 15265.64270181689*$t);
  $Y0 += 0.00000000066 * cos(1.12499582368 + 6315.2919732917*$t);
  $Y0 += 0.00000000066 * cos(2.38194509538 + 6251.34736165811*$t);
  $Y0 += 0.00000000065 * cos(3.44248995108 + 323.74923414091*$t);
  $Y0 += 0.00000000076 * cos(1.46082924902 + 10873.74221299689*$t);
  $Y0 += 0.00000000084 * cos(0.49974269222 + 109.9625037359*$t);
  $Y0 += 0.00000000063 * cos(2.70916029747 + 11823.4054569337*$t);
  $Y0 += 0.00000000064 * cos(4.80332084911 + 28774.2817889683*$t);
  $Y0 += 0.00000000072 * cos(2.11265208796 + 18099.7594409665*$t);
  $Y0 += 0.00000000066 * cos(1.21054975257 + 17576.7903418305*$t);
  $Y0 += 0.00000000072 * cos(0.02703719822 + 245707.70992182779*$t);
  $Y0 += 0.00000000061 * cos(3.91641579991 + 10557.8379783073*$t);
  $Y0 += 0.00000000064 * cos(5.46712129325 + 71430.9394356126*$t);
  $Y0 += 0.00000000068 * cos(1.33734717206 + 28760.05469496669*$t);
  $Y0 += 0.00000000062 * cos(2.25046201901 + 3854.7898494737*$t);
  $Y0 += 0.00000000073 * cos(4.61252989167 + 23440.3815479467*$t);
  $Y0 += 0.00000000060 * cos(1.65871121739 + 13088.9729355601*$t);
  $Y0 += 0.00000000078 * cos(2.99014426818 + 12564.91104475801*$t);
  $Y0 += 0.00000000060 * cos(2.90135289748 + 7548.8871461013*$t);
  $Y0 += 0.00000000059 * cos(4.12263682656 + 6286.3551508569*$t);
  $Y0 += 0.00000000075 * cos(2.85045311521 + 18625.1265717558*$t);
  $Y0 += 0.00000000058 * cos(5.18922617388 + 35050.2440919589*$t);
  $Y0 += 0.00000000060 * cos(4.91746089028 + 553.8132203259*$t);
  $Y0 += 0.00000000069 * cos(4.25329717989 + 167993.93845370729*$t);
  $Y0 += 0.00000000059 * cos(5.13629564655 + 41991.0297503823*$t);
  $Y0 += 0.00000000062 * cos(4.44636395235 + 15663.79170522509*$t);
  $Y0 += 0.00000000081 * cos(5.98297744820 + 7250.29054491051*$t);
  $Y0 += 0.00000000059 * cos(1.11500712714 + 6277.2537518451*$t);
  $Y0 += 0.00000000059 * cos(2.39193379192 + 6289.3855831047*$t);
  $Y0 += 0.00000000063 * cos(0.56300539120 + 18003.38853270651*$t);
  $Y0 += 0.00000000057 * cos(3.30567043605 + 793.0187059509*$t);
  $Y0 += 0.00000000057 * cos(1.59794444440 + 10027.65937824569*$t);
  $Y0 += 0.00000000060 * cos(0.63448798616 + 647.25465079831*$t);
  $Y0 += 0.00000000072 * cos(5.73566114928 + 4597.77991000629*$t);
  $Y0 += 0.00000000059 * cos(5.39392547964 + 6279.30891415889*$t);
  $Y0 += 0.00000000068 * cos(1.14499717138 + 3166.66025521511*$t);
  $Y0 += 0.00000000056 * cos(3.10776343336 + 6226.5164053051*$t);
  $Y0 += 0.00000000056 * cos(0.39917748570 + 6340.12292964471*$t);
  $Y0 += 0.00000000056 * cos(0.95649088929 + 12303.3115940935*$t);
  $Y0 += 0.00000000057 * cos(1.51972566902 + 5864.3952685743*$t);
  $Y0 += 0.00000000057 * cos(1.98721525004 + 6702.2440663755*$t);
  $Y0 += 0.00000000069 * cos(0.33222800273 + 23536.3607751645*$t);
  $Y0 += 0.00000000059 * cos(2.36664156781 + 5760.25461441409*$t);
  $Y0 += 0.00000000065 * cos(1.96288183765 + 12139.30969162329*$t);
  $Y0 += 0.00000000059 * cos(1.81423548051 + 67589.3312645407*$t);
  $Y0 += 0.00000000073 * cos(2.08854442290 + 11079.92776143409*$t);
  $Y0 += 0.00000000076 * cos(0.77803347659 + 23227.0824525087*$t);
  $Y0 += 0.00000000067 * cos(0.54633497662 + 4804.4530934105*$t);
  $Y0 += 0.00000000073 * cos(4.43869578954 + 30349.1275902505*$t);
  $Y0 += 0.00000000074 * cos(3.17776060575 + 92747.9329843061*$t);
  $Y0 += 0.00000000070 * cos(6.27818224660 + 12299.7884757445*$t);
  $Y0 += 0.00000000060 * cos(5.08460970539 + 12171.7696324071*$t);
  $Y0 += 0.00000000059 * cos(1.03458131364 + 15.49628866851*$t);
  $Y0 += 0.00000000074 * cos(1.19968434762 + 3684.1342325067*$t);
  $Y0 += 0.00000000058 * cos(1.58539308271 + 6717.0314053517*$t);
  $Y0 += 0.00000000053 * cos(3.68674599490 + 26087.65932409069*$t);
  $Y0 += 0.00000000059 * cos(5.76308404993 + 12164.7233957091*$t);
  $Y0 += 0.00000000063 * cos(5.23211999381 + 5219.5179490556*$t);
  $Y0 += 0.00000000056 * cos(2.45377850108 + 3178.38960805111*$t);
  $Y0 += 0.00000000063 * cos(2.16148808063 + 5227.38225558179*$t);
  $Y0 += 0.00000000070 * cos(4.83368738065 + 19004.4041319249*$t);
  $Y0 += 0.00000000072 * cos(2.62595674809 + 4583.55281600469*$t);
  $Y0 += 0.00000000052 * cos(0.96524582701 + 3627.2636600341*$t);
  $Y0 += 0.00000000052 * cos(3.30278586555 + 6411.2712005095*$t);
  $Y0 += 0.00000000052 * cos(0.20415505351 + 6155.3681344403*$t);
  $Y0 += 0.00000000054 * cos(2.04667654344 + 5849.6079295981*$t);
  $Y0 += 0.00000000066 * cos(5.93782050272 + 5791.16874004909*$t);
  $Y0 += 0.00000000066 * cos(5.93782050272 + 5791.6563750161*$t);
  $Y0 += 0.00000000051 * cos(2.41252260456 + 5113.2437810993*$t);
  $Y0 += 0.00000000058 * cos(2.72227505748 + 30775.7257811265*$t);
  $Y0 += 0.00000000061 * cos(0.72832616881 + 14169.5497447469*$t);
  $Y0 += 0.00000000054 * cos(3.16101850189 + 10454.74520408871*$t);
  $Y0 += 0.00000000056 * cos(1.20035157643 + 23141.8022004081*$t);
  $Y0 += 0.00000000067 * cos(3.89077193587 + 28313.0449871775*$t);
  $Y0 += 0.00000000056 * cos(0.37854134464 + 5244.2930566845*$t);
  $Y0 += 0.00000000062 * cos(0.60927850338 + 5657.6494751625*$t);
  $Y0 += 0.00000000062 * cos(2.89766241568 + 6908.9898597873*$t);
  $Y0 += 0.00000000050 * cos(3.10994458213 + 2574.99527684569*$t);
  $Y0 += 0.00000000050 * cos(2.89352148340 + 536.5606946119*$t);
  $Y0 += 0.00000000050 * cos(0.38317924664 + 6684.9917892321*$t);
  $Y0 += 0.00000000050 * cos(3.12376167242 + 5881.6475457177*$t);
  $Y0 += 0.00000000049 * cos(0.36435757253 + 16310.73522823709*$t);
  $Y0 += 0.00000000049 * cos(3.50595022612 + 16311.2228632041*$t);
  $Y0 += 0.00000000065 * cos(2.20156720545 + 46386.7499258277*$t);
  $Y0 += 0.00000000069 * cos(5.16096365273 + 60530.2451682583*$t);
  $Y0 += 0.00000000068 * cos(4.61952317468 + 96678.14268052569*$t);
  $Y0 += 0.00000000049 * cos(4.01249891427 + 12323.17927852529*$t);
  $Y0 += 0.00000000050 * cos(2.38095415684 + 21954.4014268815*$t);
  $Y0 += 0.00000000049 * cos(4.98226292129 + 4164.5558070965*$t);
  $Y0 += 0.00000000059 * cos(0.54830716960 + 33794.7875410121*$t);
  $Y0 += 0.00000000050 * cos(1.64594745036 + 43739.0461634493*$t);
  $Y0 += 0.00000000059 * cos(2.71376255252 + 3981.73385156551*$t);
  $Y0 += 0.00000000058 * cos(3.16580349936 + 27707.29867681129*$t);
  $Y0 += 0.00000000051 * cos(1.43461397348 + 7669.21494381111*$t);
  $Y0 += 0.00000000048 * cos(3.23576326319 + 3646.59419483791*$t);
  $Y0 += 0.00000000065 * cos(1.63790414031 + 82534.6474380951*$t);
  $Y0 += 0.00000000056 * cos(2.62361047024 + 800.06494264891*$t);
  $Y0 += 0.00000000057 * cos(2.56200976684 + 11609.61872652869*$t);
  $Y0 += 0.00000000048 * cos(3.66284145075 + 26.5421372833*$t);
  $Y0 += 0.00000000047 * cos(5.82227097996 + 30640.1004561165*$t);
  $Y0 += 0.00000000060 * cos(3.54507538375 + 8982.5668518255*$t);
  $Y0 += 0.00000000049 * cos(2.15364675842 + 96563.24283557819*$t);
  $Y0 += 0.00000000050 * cos(3.60628396854 + 17583.9038888313*$t);
  $Y0 += 0.00000000046 * cos(4.33029118489 + 23539.46356884929*$t);
  $Y0 += 0.00000000048 * cos(4.40476950322 + 170.4290531357*$t);
  $Y0 += 0.00000000055 * cos(0.06525117672 + 735.6326960483*$t);
  $Y0 += 0.00000000054 * cos(5.90233323358 + 6680.98103591609*$t);
  $Y0 += 0.00000000060 * cos(3.29126676894 + 44033.8837720559*$t);
  $Y0 += 0.00000000064 * cos(5.97731735914 + 80181.29364935629*$t);
  $Y0 += 0.00000000059 * cos(3.60959132830 + 24279.3508356971*$t);
  $Y0 += 0.00000000049 * cos(3.59486989773 + 5490.5447790075*$t);
  $Y0 += 0.00000000058 * cos(5.95314247069 + 6490.0204047715*$t);
  $Y0 += 0.00000000058 * cos(3.83698375555 + 6076.6189301783*$t);
  $Y0 += 0.00000000046 * cos(1.35461053261 + 18208.1061251085*$t);
  $Y0 += 0.00000000045 * cos(3.19696372316 + 4480.46004178609*$t);
  $Y0 += 0.00000000055 * cos(1.99803947181 + 16097.9237677661*$t);
  $Y0 += 0.00000000055 * cos(1.99803947181 + 16097.43613279909*$t);
  $Y0 += 0.00000000061 * cos(3.53347961961 + 491.9071099423*$t);
  $Y0 += 0.00000000054 * cos(1.22650408797 + 6006.5738956105*$t);
  $Y0 += 0.00000000054 * cos(2.28043683109 + 6560.0654393393*$t);
  $Y0 += 0.00000000044 * cos(4.77367705513 + 5333.65642353809*$t);
  $Y0 += 0.00000000052 * cos(3.85218997059 + 244287.84382471119*$t);
  $Y0 += 0.00000000044 * cos(2.69173127084 + 2301.34199842589*$t);
  $Y0 += 0.00000000045 * cos(4.35951224787 + 33794.2999060451*$t);
  $Y0 += 0.00000000046 * cos(3.84874383995 + 4384.48081456829*$t);
  $Y0 += 0.00000000048 * cos(4.63629874583 + 35579.9350570535*$t);
  $Y0 += 0.00000000051 * cos(4.91886576255 + 18326.8939493639*$t);
  $Y0 += 0.00000000045 * cos(2.63923033609 + 533.45790092711*$t);
  $Y0 += 0.00000000046 * cos(3.15339657493 + 16703.3059509825*$t);
  $Y0 += 0.00000000047 * cos(2.39403388232 + 5209.2230083171*$t);
  $Y0 += 0.00000000051 * cos(1.31112479278 + 38650.4173236825*$t);
  $Y0 += 0.00000000046 * cos(2.47672465258 + 12555.3498172024*$t);
  $Y0 += 0.00000000052 * cos(4.64446990453 + 5992.3468016089*$t);
  $Y0 += 0.00000000052 * cos(5.14565632171 + 6574.2925333409*$t);
  $Y0 += 0.00000000044 * cos(3.80837636245 + 69942.1974183125*$t);
  $Y0 += 0.00000000049 * cos(3.62132943845 + 12146.9108735911*$t);
  $Y0 += 0.00000000053 * cos(4.67452542700 + 39301.8531447125*$t);
  $Y0 += 0.00000000045 * cos(4.65107782321 + 46360.9392409949*$t);
  $Y0 += 0.00000000043 * cos(1.54528326296 + 8402.0835278533*$t);
  $Y0 += 0.00000000043 * cos(0.19791989913 + 44137.1951668575*$t);
  $Y0 += 0.00000000049 * cos(3.54725333487 + 22029.9691371861*$t);
  $Y0 += 0.00000000044 * cos(1.47478212539 + 31441.92138724031*$t);
  $Y0 += 0.00000000042 * cos(2.85938112982 + 9225.29545579949*$t);
  $Y0 += 0.00000000045 * cos(3.22032934298 + 71519.54096076029*$t);
  $Y0 += 0.00000000051 * cos(2.95623880108 + 7762.1862415393*$t);
  $Y0 += 0.00000000041 * cos(5.14395096650 + 3735.48212924251*$t);
  $Y0 += 0.00000000057 * cos(1.24099052077 + 40398.4337367495*$t);
  $Y0 += 0.00000000047 * cos(6.03171570454 + 4707.9862312257*$t);
  $Y0 += 0.00000000056 * cos(5.36736063063 + 28664.0754677489*$t);
  $Y0 += 0.00000000050 * cos(2.58729930740 + 11919.3846841515*$t);
  $Y0 += 0.00000000047 * cos(5.61037642387 + 316428.47249139856*$t);
  $Y0 += 0.00000000041 * cos(2.70468936208 + 27278.7126339243*$t);
  $Y0 += 0.00000000056 * cos(1.28041103259 + 83659.5206898825*$t);
  $Y0 += 0.00000000048 * cos(0.93182108526 + 12662.3747446841*$t);
  $Y0 += 0.00000000054 * cos(2.40910872834 + 16627.12709789369*$t);
  $Y0 += 0.00000000052 * cos(2.84085536047 + 12571.9184417737*$t);
  $Y0 += 0.00000000043 * cos(3.12713892129 + 7322.34627826531*$t);
  $Y0 += 0.00000000041 * cos(1.99075260862 + 664.99986261351*$t);
  $Y0 += 0.00000000042 * cos(3.11818521171 + 5641.9544251257*$t);
  $Y0 += 0.00000000044 * cos(6.16004757680 + 6425.4982945111*$t);
  $Y0 += 0.00000000044 * cos(3.63007864944 + 6141.1410404387*$t);
  $Y0 += 0.00000000039 * cos(5.09444795757 + 22594.2987131955*$t);
  $Y0 += 0.00000000040 * cos(1.17403028794 + 20894.53186172529*$t);
  $Y0 += 0.00000000044 * cos(3.71228299188 + 5540.3296069423*$t);
  $Y0 += 0.00000000050 * cos(0.98055905828 + 17782.48825530069*$t);
  $Y0 += 0.00000000054 * cos(3.12084664124 + 6006.2846737335*$t);
  $Y0 += 0.00000000054 * cos(0.38609427782 + 6560.3546612163*$t);
  $Y0 += 0.00000000045 * cos(0.83260974343 + 142861.14741877468*$t);
  $Y0 += 0.00000000047 * cos(5.83397233956 + 24499.7634781359*$t);
  $Y0 += 0.00000000043 * cos(6.07854396898 + 7026.3097280075*$t);
  $Y0 += 0.00000000047 * cos(0.38354823927 + 955.8435590921*$t);
  $Y0 += 0.00000000047 * cos(2.93749588479 + 24485.5363841343*$t);
  $Y0 += 0.00000000040 * cos(1.03647885736 + 9388.2497268987*$t);
  $Y0 += 0.00000000043 * cos(4.24359473122 + 6359.5857387505*$t);
  $Y0 += 0.00000000042 * cos(5.53288597787 + 8635.69818627969*$t);
  $Y0 += 0.00000000051 * cos(4.03405257508 + 27831.79440179969*$t);
  $Y0 += 0.00000000042 * cos(0.37690679264 + 6334.60000533731*$t);
  $Y0 += 0.00000000042 * cos(3.13003412642 + 6232.03932961249*$t);
  $Y0 += 0.00000000052 * cos(1.96232281613 + 11905.1625906853*$t);
  $Y0 += 0.00000000040 * cos(6.22187049858 + 7076.0945559423*$t);
  $Y0 += 0.00000000040 * cos(5.00617355027 + 5444.3503797245*$t);
  $Y0 += 0.00000000040 * cos(4.78395267597 + 7122.2889552253*$t);
  $Y0 += 0.00000000038 * cos(0.67446092329 + 44933.4931736739*$t);
  $Y0 += 0.00000000037 * cos(4.98656910933 + 5715.6010297445*$t);
  $Y0 += 0.00000000037 * cos(4.80355711691 + 6851.0383052053*$t);
  $Y0 += 0.00000000042 * cos(5.51152847292 + 36147.6536947839*$t);
  $Y0 += 0.00000000042 * cos(1.28742672679 + 6238.1784478383*$t);
  $Y0 += 0.00000000042 * cos(2.21951419227 + 6328.4608871115*$t);
  $Y0 += 0.00000000040 * cos(5.21427505339 + 3214.8925631597*$t);
  $Y0 += 0.00000000043 * cos(2.22601042104 + 23141.3145654411*$t);
  $Y0 += 0.00000000041 * cos(5.52595261887 + 19804.5834740993*$t);
  $Y0 += 0.00000000038 * cos(4.48062431201 + 20.11150191529*$t);
  $Y0 += 0.00000000050 * cos(0.05709227621 + 84334.66158130829*$t);
  $Y0 += 0.00000000050 * cos(4.41842921988 + 60284.16619777939*$t);
  return $Y0;
}



  function Earth_C_Y1 ($t)
{
  $Y1 =  0.0;
  $Y1 += 0.00154550744 * cos(5.35844734917 + 0.2438174835*$t);
  $Y1 += 0.00051503383 * cos(4.43183566713 + 12566.3955174663*$t);
  $Y1 += 0.00001290763 * cos(4.38862020180 + 18849.4713674577*$t);
  $Y1 += 0.00000702576 * cos(0.18268310766 + 6283.3196674749*$t);
  $Y1 += 0.00000430422 * cos(4.02296125150 + 6282.83203250789*$t);
  $Y1 += 0.00000212689 * cos(0.16300557365 + 6279.7965491259*$t);
  $Y1 += 0.00000212524 * cos(3.34405166686 + 6286.84278582391*$t);
  $Y1 += 0.00000062308 * cos(5.07432195748 + 4705.9761250271*$t);
  $Y1 += 0.00000059808 * cos(2.24108323998 + 6257.0213476751*$t);
  $Y1 += 0.00000059474 * cos(1.26580020213 + 6309.61798727471*$t);
  $Y1 += 0.00000048914 * cos(3.64253038225 + 775.7664288075*$t);
  $Y1 += 0.00000042814 * cos(5.15102931682 + 1059.6257476727*$t);
  $Y1 += 0.00000046457 * cos(4.72328803502 + 7860.6632099227*$t);
  $Y1 += 0.00000036653 * cos(0.62556081234 + 5753.6287023803*$t);
  $Y1 += 0.00000035649 * cos(6.15990909241 + 5885.1706640667*$t);
  $Y1 += 0.00000035362 * cos(2.90135814576 + 6813.0106325695*$t);
  $Y1 += 0.00000032151 * cos(3.62597628866 + 6681.46867088311*$t);
  $Y1 += 0.00000028763 * cos(4.34539356227 + 25132.5472174491*$t);
  $Y1 += 0.00000028447 * cos(5.86215127530 + 6127.8992680407*$t);
  $Y1 += 0.00000027537 * cos(3.92840810925 + 6438.7400669091*$t);
  $Y1 += 0.00000024819 * cos(1.35151106278 + 5487.0216606585*$t);
  $Y1 += 0.00000020615 * cos(2.14741827387 + 7079.61767429131*$t);
  $Y1 += 0.00000019621 * cos(1.31571192713 + 5507.7970561509*$t);
  $Y1 += 0.00000018378 * cos(6.17760240913 + 11790.8729061423*$t);
  $Y1 += 0.00000016494 * cos(4.64463821908 + 11507.0135872771*$t);
  $Y1 += 0.00000016756 * cos(2.24858801378 + 7058.8422787989*$t);
  $Y1 += 0.00000014558 * cos(4.40450472214 + 6290.4332144757*$t);
  $Y1 += 0.00000014404 * cos(5.39361420229 + 6276.2061204741*$t);
  $Y1 += 0.00000014052 * cos(6.16986019111 + 796.5418242999*$t);
  $Y1 += 0.00000012261 * cos(5.72868820428 + 4693.75913722409*$t);
  $Y1 += 0.00000012758 * cos(5.06070649359 + 7.3573644843*$t);
  $Y1 += 0.00000010086 * cos(1.72162917776 + 3739.0052475915*$t);
  $Y1 += 0.00000009469 * cos(3.06840825171 + 6070.0205720369*$t);
  $Y1 += 0.00000010425 * cos(0.81162914438 + 6284.2999885431*$t);
  $Y1 += 0.00000010425 * cos(2.69531177468 + 6282.3393464067*$t);
  $Y1 += 0.00000009570 * cos(0.32347467387 + 4137.1542509997*$t);
  $Y1 += 0.00000009044 * cos(0.43893334417 + 6496.6187629129*$t);
  $Y1 += 0.00000008544 * cos(4.76970151659 + 1194.6908277081*$t);
  $Y1 += 0.00000008214 * cos(5.96640392040 + 1589.3167127673*$t);
  $Y1 += 0.00000006157 * cos(1.78596836636 + 8827.6340873583*$t);
  $Y1 += 0.00000006271 * cos(3.18396187423 + 8429.4850839501*$t);
  $Y1 += 0.00000005524 * cos(3.79861381511 + 4933.4522578161*$t);
  $Y1 += 0.00000007314 * cos(5.20341424492 + 4535.3032544079*$t);
  $Y1 += 0.00000005157 * cos(3.57885530448 + 11770.0975106499*$t);
  $Y1 += 0.00000006749 * cos(2.75433387783 + 5088.8726572503*$t);
  $Y1 += 0.00000004853 * cos(5.33701721257 + 6040.5910635009*$t);
  $Y1 += 0.00000005304 * cos(0.93005422139 + 3154.4432674121*$t);
  $Y1 += 0.00000004985 * cos(3.05697984231 + 12569.91863581531*$t);
  $Y1 += 0.00000004709 * cos(2.39306975468 + 5331.6012612243*$t);
  $Y1 += 0.00000004601 * cos(4.45296491447 + 6526.04827144891*$t);
  $Y1 += 0.00000004201 * cos(5.99364092036 + 7633.1870771337*$t);
  $Y1 += 0.00000005607 * cos(0.98720876729 + 5729.7502646325*$t);
  $Y1 += 0.00000004257 * cos(2.55370490945 + 3930.4535137031*$t);
  $Y1 += 0.00000004394 * cos(4.75948183378 + 12559.2819704655*$t);
  $Y1 += 0.00000003870 * cos(1.11601490340 + 7235.0380737255*$t);
  $Y1 += 0.00000005154 * cos(4.58850581748 + 8031.3360805419*$t);
  $Y1 += 0.00000005036 * cos(2.51929382179 + 6836.8890703173*$t);
  $Y1 += 0.00000005076 * cos(0.73526458069 + 7477.7666776995*$t);
  $Y1 += 0.00000003593 * cos(3.97650177033 + 12565.9078824993*$t);
  $Y1 += 0.00000003384 * cos(3.83274545225 + 10977.32262218251*$t);
  $Y1 += 0.00000003371 * cos(5.00200001284 + 11371.9485072417*$t);
  $Y1 += 0.00000003536 * cos(5.30432752281 + 4164.0681721295*$t);
  $Y1 += 0.00000004292 * cos(3.36706453434 + 1592.8398311163*$t);
  $Y1 += 0.00000003407 * cos(0.83519640650 + 3128.6325825793*$t);
  $Y1 += 0.00000003152 * cos(0.16276893009 + 5223.93773728571*$t);
  $Y1 += 0.00000002883 * cos(0.20838349180 + 1747.7725955835*$t);
  $Y1 += 0.00000002751 * cos(3.67369812017 + 7342.7015976641*$t);
  $Y1 += 0.00000003323 * cos(3.48959648614 + 801.5771136403*$t);
  $Y1 += 0.00000002999 * cos(0.68275608544 + 8636.18582124671*$t);
  $Y1 += 0.00000002496 * cos(5.09157906387 + 2145.92159899169*$t);
  $Y1 += 0.00000003358 * cos(5.82350976219 + 155.17658195069*$t);
  $Y1 += 0.00000002297 * cos(2.96479731544 + 17260.3984721739*$t);
  $Y1 += 0.00000002047 * cos(1.96580631113 + 1990.9888345245*$t);
  $Y1 += 0.00000002778 * cos(6.17391326343 + 5481.4987363511*$t);
  $Y1 += 0.00000002025 * cos(3.01082711135 + 951.4745887671*$t);
  $Y1 += 0.00000002663 * cos(1.00159277919 + 26.0545023163*$t);
  $Y1 += 0.00000002009 * cos(4.16311202386 + 4690.7236538421*$t);
  $Y1 += 0.00000002148 * cos(0.32608511593 + 537.0483295789*$t);
  $Y1 += 0.00000001853 * cos(4.41841662668 + 553.32558535889*$t);
  $Y1 += 0.00000002478 * cos(1.61013003664 + 1349.62359217529*$t);
  $Y1 += 0.00000002023 * cos(0.82015419806 + 522.8212355773*$t);
  $Y1 += 0.00000001735 * cos(4.49024043092 + 529.44714761109*$t);
  $Y1 += 0.00000002417 * cos(3.59693248271 + 7085.1405985987*$t);
  $Y1 += 0.00000001809 * cos(2.35536809783 + 397.9051859247*$t);
  $Y1 += 0.00000001893 * cos(2.65666986732 + 9438.0067523705*$t);
  $Y1 += 0.00000001708 * cos(5.00361322564 + 10989.0519750185*$t);
  $Y1 += 0.00000001898 * cos(3.91087003459 + 5216.33655531789*$t);
  $Y1 += 0.00000001820 * cos(3.44808607160 + 5230.5636493195*$t);
  $Y1 += 0.00000001541 * cos(5.81316348536 + 426.8420083595*$t);
  $Y1 += 0.00000001555 * cos(2.09924495059 + 13096.0864825609*$t);
  $Y1 += 0.00000001779 * cos(0.23737949225 + 12562.8723991173*$t);
  $Y1 += 0.00000001448 * cos(1.75844475078 + 5753.14106741329*$t);
  $Y1 += 0.00000001450 * cos(5.71201368260 + 6262.96434807611*$t);
  $Y1 += 0.00000001450 * cos(4.07811254364 + 6303.6749868737*$t);
  $Y1 += 0.00000001822 * cos(0.13446699374 + 10973.7995038335*$t);
  $Y1 += 0.00000001372 * cos(5.60520656116 + 7875.91568110771*$t);
  $Y1 += 0.00000001375 * cos(2.34041210234 + 7084.6529636317*$t);
  $Y1 += 0.00000001400 * cos(3.28144398068 + 12721.8159169005*$t);
  $Y1 += 0.00000001247 * cos(0.29225580262 + 2119.00767786191*$t);
  $Y1 += 0.00000001231 * cos(2.53164637932 + 18319.7804023631*$t);
  $Y1 += 0.00000001141 * cos(1.92161882496 + 1066.7392946735*$t);
  $Y1 += 0.00000001138 * cos(1.23855949465 + 2942.7072407751*$t);
  $Y1 += 0.00000001047 * cos(1.31663136695 + 5642.93474619389*$t);
  $Y1 += 0.00000001058 * cos(2.19001683016 + 242.97242145751*$t);
  $Y1 += 0.00000001025 * cos(0.60899466577 + 10447.14402212089*$t);
  $Y1 += 0.00000000973 * cos(4.95398300734 + 640.1411037975*$t);
  $Y1 += 0.00000001114 * cos(4.36978275435 + 15721.0826023619*$t);
  $Y1 += 0.00000000963 * cos(0.56100772029 + 2389.1378379327*$t);
  $Y1 += 0.00000000941 * cos(4.21626686326 + 20426.8149099055*$t);
  $Y1 += 0.00000001068 * cos(5.08632600308 + 529.9347825781*$t);
  $Y1 += 0.00000000929 * cos(1.54055499699 + 10575.6505004253*$t);
  $Y1 += 0.00000000899 * cos(5.79114005938 + 16496.6052136859*$t);
  $Y1 += 0.00000000889 * cos(5.01192484889 + 6277.7967431675*$t);
  $Y1 += 0.00000000889 * cos(4.77820137734 + 6288.8425917823*$t);
  $Y1 += 0.00000001018 * cos(2.66299766067 + 12540.0971976665*$t);
  $Y1 += 0.00000001060 * cos(5.76865363011 + 5760.7422493811*$t);
  $Y1 += 0.00000001017 * cos(4.02093017183 + 6805.89708556871*$t);
  $Y1 += 0.00000000797 * cos(3.79336643920 + 14314.4119305333*$t);
  $Y1 += 0.00000000795 * cos(0.10742263482 + 6286.6060248927*$t);
  $Y1 += 0.00000000795 * cos(3.39951828424 + 6280.0333100571*$t);
  $Y1 += 0.00000000800 * cos(3.18366130818 + 12029.5910053709*$t);
  $Y1 += 0.00000000719 * cos(2.29666441302 + 9623.9320941747*$t);
  $Y1 += 0.00000000698 * cos(4.94363251872 + 6148.2545874395*$t);
  $Y1 += 0.00000000686 * cos(3.79368723538 + 5856.7214765989*$t);
  $Y1 += 0.00000000673 * cos(3.99105175160 + 12964.5445208745*$t);
  $Y1 += 0.00000000902 * cos(0.69698416448 + 13368.2164485901*$t);
  $Y1 += 0.00000000678 * cos(4.84647193821 + 6418.38474751031*$t);
  $Y1 += 0.00000000671 * cos(6.00179402654 + 6709.91785835091*$t);
  $Y1 += 0.00000000744 * cos(2.68741072621 + 12043.8180993725*$t);
  $Y1 += 0.00000000706 * cos(2.51950741945 + 16730.70750707931*$t);
  $Y1 += 0.00000000661 * cos(2.42216375426 + 14712.5609339415*$t);
  $Y1 += 0.00000000633 * cos(5.58153853935 + 4292.5746504339*$t);
  $Y1 += 0.00000000621 * cos(1.74121096386 + 13119.9649203087*$t);
  $Y1 += 0.00000000638 * cos(2.04188798982 + 4690.23601887509*$t);
  $Y1 += 0.00000000625 * cos(0.31613419014 + 13518.1139237169*$t);
  $Y1 += 0.00000000637 * cos(4.59654254753 + 5746.5151553795*$t);
  $Y1 += 0.00000000628 * cos(3.42448659886 + 4686.6455902233*$t);
  $Y1 += 0.00000000653 * cos(5.85737456207 + 3929.96587873609*$t);
  $Y1 += 0.00000000578 * cos(0.62377454326 + 5088.3850222833*$t);
  $Y1 += 0.00000000563 * cos(3.24964920260 + 10447.6316570879*$t);
  $Y1 += 0.00000000610 * cos(5.19955844918 + 6820.1241795703*$t);
  $Y1 += 0.00000000666 * cos(4.87089013467 + 3634.37720703489*$t);
  $Y1 += 0.00000000720 * cos(5.18811029494 + 13916.2629271251*$t);
  $Y1 += 0.00000000620 * cos(4.30310535016 + 31415.6230674405*$t);
  $Y1 += 0.00000000553 * cos(2.71699575652 + 6259.44122972711*$t);
  $Y1 += 0.00000000553 * cos(0.78994516254 + 6307.1981052227*$t);
  $Y1 += 0.00000000523 * cos(5.47007776670 + 14143.7390599141*$t);
  $Y1 += 0.00000000524 * cos(3.97726441461 + 12139.7973265903*$t);
  $Y1 += 0.00000000569 * cos(4.83897139720 + 12036.7045523717*$t);
  $Y1 += 0.00000000514 * cos(3.87608366777 + 4700.87268422489*$t);
  $Y1 += 0.00000000563 * cos(3.78589343112 + 11014.8626598513*$t);
  $Y1 += 0.00000000495 * cos(2.00987402269 + 13362.6935242827*$t);
  $Y1 += 0.00000000481 * cos(0.93576028071 + 6279.4383321169*$t);
  $Y1 += 0.00000000481 * cos(2.57118063835 + 6287.2010028329*$t);
  $Y1 += 0.00000000466 * cos(2.94306081142 + 10177.5014970171*$t);
  $Y1 += 0.00000000440 * cos(5.16955709579 + 1577.5873599313*$t);
  $Y1 += 0.00000000437 * cos(1.61052953646 + 11499.9000402763*$t);
  $Y1 += 0.00000000452 * cos(3.98330238308 + 12573.5090644671*$t);
  $Y1 += 0.00000000499 * cos(5.79985868924 + 12410.9751180321*$t);
  $Y1 += 0.00000000440 * cos(0.57972339309 + 24073.1652872599*$t);
  $Y1 += 0.00000000587 * cos(0.00678196141 + 6.86972951729*$t);
  $Y1 += 0.00000000388 * cos(3.61198235279 + 7860.17557495569*$t);
  $Y1 += 0.00000000398 * cos(4.20068362004 + 8274.0646845159*$t);
  $Y1 += 0.00000000423 * cos(5.87838349624 + 4694.2467721911*$t);
  $Y1 += 0.00000000530 * cos(1.43593166640 + 12592.6938372661*$t);
  $Y1 += 0.00000000379 * cos(0.45309221604 + 6180.2268932563*$t);
  $Y1 += 0.00000000379 * cos(3.05384870302 + 6386.4124416935*$t);
  $Y1 += 0.00000000377 * cos(4.33272540326 + 7872.39256275871*$t);
  $Y1 += 0.00000000419 * cos(4.05140241721 + 5327.7199258663*$t);
  $Y1 += 0.00000000383 * cos(4.67353188247 + 6247.2918007975*$t);
  $Y1 += 0.00000000383 * cos(5.11659434377 + 6319.34753415231*$t);
  $Y1 += 0.00000000375 * cos(0.91076946484 + 2352.6223362883*$t);
  $Y1 += 0.00000000457 * cos(2.62120808067 + 6077.1341190377*$t);
  $Y1 += 0.00000000457 * cos(0.88573283839 + 6489.5052159121*$t);
  $Y1 += 0.00000000481 * cos(3.46562904756 + 4292.0870154669*$t);
  $Y1 += 0.00000000344 * cos(4.99906947930 + 18451.3223640495*$t);
  $Y1 += 0.00000000453 * cos(5.43816135018 + 2787.2868413409*$t);
  $Y1 += 0.00000000364 * cos(2.82703012884 + 6245.2919948391*$t);
  $Y1 += 0.00000000364 * cos(0.67991079022 + 6321.3473401107*$t);
  $Y1 += 0.00000000327 * cos(1.14128906507 + 12323.6669134923*$t);
  $Y1 += 0.00000000358 * cos(0.15971399837 + 9917.45305702629*$t);
  $Y1 += 0.00000000342 * cos(5.26072614817 + 6262.5442719825*$t);
  $Y1 += 0.00000000342 * cos(4.52940007806 + 6304.0950629673*$t);
  $Y1 += 0.00000000318 * cos(4.84603466410 + 11926.4982311523*$t);
  $Y1 += 0.00000000320 * cos(1.13215851865 + 77714.01528560399*$t);
  $Y1 += 0.00000000354 * cos(5.73706716445 + 7238.9194090835*$t);
  $Y1 += 0.00000000318 * cos(3.75423383039 + 6254.8704800071*$t);
  $Y1 += 0.00000000318 * cos(6.03589239585 + 6311.7688549427*$t);
  $Y1 += 0.00000000304 * cos(0.43890915611 + 12779.6946129043*$t);
  $Y1 += 0.00000000343 * cos(2.14223194635 + 6298.57213865991*$t);
  $Y1 += 0.00000000343 * cos(1.36470897271 + 6268.0671962899*$t);
  $Y1 += 0.00000000359 * cos(2.52875634099 + 1052.51220067191*$t);
  $Y1 += 0.00000000398 * cos(4.83537015899 + 1551.2890401315*$t);
  $Y1 += 0.00000000306 * cos(1.01793913946 + 5863.8350235997*$t);
  $Y1 += 0.00000000300 * cos(0.20529153395 + 90280.16698558679*$t);
  $Y1 += 0.00000000307 * cos(4.86343200722 + 3893.93801205869*$t);
  $Y1 += 0.00000000297 * cos(2.08300781298 + 5429.63565075589*$t);
  $Y1 += 0.00000000365 * cos(1.17462915798 + 10022.0810975829*$t);
  $Y1 += 0.00000000336 * cos(1.15285276926 + 17782.9758902677*$t);
  $Y1 += 0.00000000295 * cos(2.48770580169 + 6702.8043113501*$t);
  $Y1 += 0.00000000288 * cos(0.61716195626 + 18073.9487561337*$t);
  $Y1 += 0.00000000287 * cos(4.90856628789 + 1577.0997249643*$t);
  $Y1 += 0.00000000378 * cos(5.11185072605 + 2353.1099712553*$t);
  $Y1 += 0.00000000289 * cos(1.47281714617 + 213.5429129215*$t);
  $Y1 += 0.00000000347 * cos(2.29918133719 + 5223.4501023187*$t);
  $Y1 += 0.00000000321 * cos(0.66708336426 + 17797.2029842693*$t);
  $Y1 += 0.00000000289 * cos(3.73571084362 + 220.6564599223*$t);
  $Y1 += 0.00000000260 * cos(2.61364471837 + 955.3559241251*$t);
  $Y1 += 0.00000000268 * cos(5.19927474541 + 14945.0723560709*$t);
  $Y1 += 0.00000000242 * cos(2.77307042091 + 2544.5582373669*$t);
  $Y1 += 0.00000000245 * cos(3.88798752568 + 7632.6994421667*$t);
  $Y1 += 0.00000000234 * cos(2.50313805280 + 1596.43025976811*$t);
  $Y1 += 0.00000000267 * cos(4.25976324066 + 206.42936592071*$t);
  $Y1 += 0.00000000282 * cos(2.93181023342 + 13341.9181287903*$t);
  $Y1 += 0.00000000279 * cos(4.70853062526 + 4731.7868098599*$t);
  $Y1 += 0.00000000290 * cos(0.46137131163 + 5642.4420600927*$t);
  $Y1 += 0.00000000298 * cos(5.65061835836 + 17790.08943726851*$t);
  $Y1 += 0.00000000270 * cos(0.59449456012 + 12168.2465140581*$t);
  $Y1 += 0.00000000294 * cos(0.95816279728 + 2146.4092339587*$t);
  $Y1 += 0.00000000214 * cos(2.50623255971 + 8030.8484455749*$t);
  $Y1 += 0.00000000207 * cos(3.18045634687 + 213.0552779545*$t);
  $Y1 += 0.00000000216 * cos(4.03237077499 + 3185.43584474911*$t);
  $Y1 += 0.00000000195 * cos(4.44222765867 + 5884.68302909969*$t);
  $Y1 += 0.00000000199 * cos(2.36156558922 + 1748.2602305505*$t);
  $Y1 += 0.00000000250 * cos(3.04516390608 + 6924.1972748571*$t);
  $Y1 += 0.00000000194 * cos(0.79669370564 + 641.12142486571*$t);
  $Y1 += 0.00000000203 * cos(0.68276896116 + 6503.7323099137*$t);
  $Y1 += 0.00000000203 * cos(2.82417195790 + 6062.9070250361*$t);
  $Y1 += 0.00000000258 * cos(0.91786109532 + 796.0541893329*$t);
  $Y1 += 0.00000000189 * cos(3.20457516516 + 11506.52595231009*$t);
  $Y1 += 0.00000000186 * cos(4.84188314285 + 18209.5740811437*$t);
  $Y1 += 0.00000000184 * cos(2.63875516800 + 12566.4628277691*$t);
  $Y1 += 0.00000000180 * cos(4.19729049815 + 853.4401992355*$t);
  $Y1 += 0.00000000185 * cos(6.25586281827 + 3495.78900865049*$t);
  $Y1 += 0.00000000205 * cos(0.22424585668 + 5849.1202946311*$t);
  $Y1 += 0.00000000187 * cos(4.34056279496 + 10213.5293636945*$t);
  $Y1 += 0.00000000187 * cos(0.48606035843 + 6290.36590417291*$t);
  $Y1 += 0.00000000187 * cos(3.02088056063 + 6276.2734307769*$t);
  $Y1 += 0.00000000235 * cos(4.34532332705 + 9779.3524936089*$t);
  $Y1 += 0.00000000173 * cos(6.09941552473 + 19651.2922985815*$t);
  $Y1 += 0.00000000184 * cos(3.08285813784 + 12566.32820716351*$t);
  $Y1 += 0.00000000230 * cos(0.66694562429 + 12567.37583853451*$t);
  $Y1 += 0.00000000166 * cos(6.03836479949 + 110.45013870291*$t);
  $Y1 += 0.00000000189 * cos(1.27307578752 + 3.76693583251*$t);
  $Y1 += 0.00000000166 * cos(5.90720968173 + 433.9555553603*$t);
  $Y1 += 0.00000000186 * cos(6.04048637618 + 5863.3473886327*$t);
  $Y1 += 0.00000000184 * cos(4.58711235161 + 10983.94853421629*$t);
  $Y1 += 0.00000000184 * cos(1.80970242494 + 6037.4880212455*$t);
  $Y1 += 0.00000000156 * cos(0.77353737613 + 2648.6986429565*$t);
  $Y1 += 0.00000000182 * cos(5.04351148530 + 10969.72144021469*$t);
  $Y1 += 0.00000000175 * cos(1.69691915551 + 6529.1513137043*$t);
  $Y1 += 0.00000000154 * cos(4.10646056877 + 6453.9925380941*$t);
  $Y1 += 0.00000000154 * cos(5.68366565747 + 6112.6467968557*$t);
  $Y1 += 0.00000000164 * cos(2.95193833305 + 12353.0964220283*$t);
  $Y1 += 0.00000000146 * cos(2.48650028218 + 149.8070146181*$t);
  $Y1 += 0.00000000184 * cos(4.91752478989 + 11015.3502948183*$t);
  $Y1 += 0.00000000191 * cos(0.72322692096 + 3894.4256470257*$t);
  $Y1 += 0.00000000144 * cos(2.19099222002 + 18636.1722720197*$t);
  $Y1 += 0.00000000146 * cos(0.42084749575 + 13760.8425276909*$t);
  $Y1 += 0.00000000142 * cos(2.91645242674 + 4156.95462512869*$t);
  $Y1 += 0.00000000185 * cos(5.29181252606 + 7234.5504387585*$t);
  $Y1 += 0.00000000133 * cos(4.73063574833 + 18139.5383188994*$t);
  $Y1 += 0.00000000131 * cos(0.04654287508 + 5507.3094211839*$t);
  $Y1 += 0.00000000146 * cos(0.32618788162 + 18875.2820522905*$t);
  $Y1 += 0.00000000128 * cos(4.98427830485 + 6069.53293706989*$t);
  $Y1 += 0.00000000128 * cos(1.75166251045 + 16200.52890701769*$t);
  $Y1 += 0.00000000123 * cos(0.73895960068 + 20.5315780089*$t);
  $Y1 += 0.00000000121 * cos(5.69434162626 + 17256.8753538249*$t);
  $Y1 += 0.00000000123 * cos(4.81514598285 + 6393.5259886943*$t);
  $Y1 += 0.00000000123 * cos(4.97498024339 + 6173.1133462555*$t);
  $Y1 += 0.00000000117 * cos(2.90632080371 + 18852.9944858067*$t);
  $Y1 += 0.00000000120 * cos(5.75152020178 + 9381.2034902007*$t);
  $Y1 += 0.00000000113 * cos(3.90786027747 + 65147.37595065419*$t);
  $Y1 += 0.00000000137 * cos(2.11120201406 + 16201.0165419847*$t);
  $Y1 += 0.00000000113 * cos(0.36200887356 + 6836.40143535029*$t);
  $Y1 += 0.00000000123 * cos(2.85759760823 + 12565.4151963981*$t);
  $Y1 += 0.00000000132 * cos(4.51334720616 + 17655.0243572331*$t);
  $Y1 += 0.00000000113 * cos(5.69373873614 + 10575.1628654583*$t);
  $Y1 += 0.00000000113 * cos(3.66776032820 + 10213.0417287275*$t);
  $Y1 += 0.00000000116 * cos(0.66749075538 + 17253.2849251731*$t);
  $Y1 += 0.00000000120 * cos(0.70954573147 + 10420.23010099111*$t);
  $Y1 += 0.00000000109 * cos(5.21836603318 + 633.0275567967*$t);
  $Y1 += 0.00000000103 * cos(4.83071292354 + 6295.0490203109*$t);
  $Y1 += 0.00000000103 * cos(4.95941330270 + 6271.5903146389*$t);
  $Y1 += 0.00000000104 * cos(4.01023132524 + 23013.7833570707*$t);
  $Y1 += 0.00000000105 * cos(5.32684825848 + 11790.3852711753*$t);
  $Y1 += 0.00000000109 * cos(4.22545370482 + 3340.36860921629*$t);
  $Y1 += 0.00000000102 * cos(1.02602291037 + 10970.2090751817*$t);
  $Y1 += 0.00000000101 * cos(5.99270341494 + 4803.9654584435*$t);
  $Y1 += 0.00000000114 * cos(3.78830179341 + 4171.1817191303*$t);
  $Y1 += 0.00000000111 * cos(2.09152457722 + 1582.2031657665*$t);
  $Y1 += 0.00000000107 * cos(0.90140521385 + 23543.4743221653*$t);
  $Y1 += 0.00000000099 * cos(4.24784832079 + 10973.3118688665*$t);
  $Y1 += 0.00000000102 * cos(4.09962394648 + 6549.9267091967*$t);
  $Y1 += 0.00000000102 * cos(5.69050227976 + 6016.7126257531*$t);
  $Y1 += 0.00000000120 * cos(0.92616350319 + 11514.1271342779*$t);
  $Y1 += 0.00000000095 * cos(1.12824235931 + 17267.5120191747*$t);
  $Y1 += 0.00000000121 * cos(4.76575826483 + 13625.7774476555*$t);
  $Y1 += 0.00000000100 * cos(3.61435033946 + 10976.83498721549*$t);
  $Y1 += 0.00000000090 * cos(2.11761227033 + 76.50988875911*$t);
  $Y1 += 0.00000000100 * cos(5.94744998603 + 8661.9965060795*$t);
  $Y1 += 0.00000000089 * cos(3.76175372959 + 1350.1112271423*$t);
  $Y1 += 0.00000000087 * cos(2.76310699450 + 9917.9406919933*$t);
  $Y1 += 0.00000000086 * cos(4.36870119289 + 12809.12412144031*$t);
  $Y1 += 0.00000000095 * cos(6.05597457730 + 12345.9828750275*$t);
  $Y1 += 0.00000000084 * cos(3.11610500480 + 775.2787938405*$t);
  $Y1 += 0.00000000106 * cos(3.57201004990 + 11216.5281078075*$t);
  $Y1 += 0.00000000095 * cos(0.92966555257 + 12012.8261146239*$t);
  $Y1 += 0.00000000082 * cos(4.72839816349 + 5643.4223811609*$t);
  $Y1 += 0.00000000081 * cos(2.27692529332 + 11614.6771112157*$t);
  $Y1 += 0.00000000084 * cos(5.85994160066 + 6255.9181113781*$t);
  $Y1 += 0.00000000084 * cos(3.93018462558 + 6310.7212235717*$t);
  $Y1 += 0.00000000080 * cos(5.05950625443 + 6923.2169537889*$t);
  $Y1 += 0.00000000085 * cos(1.08248438849 + 5635.8211991931*$t);
  $Y1 += 0.00000000084 * cos(4.61502942146 + 10440.03047512009*$t);
  $Y1 += 0.00000000080 * cos(2.62622746074 + 3583.5848481573*$t);
  $Y1 += 0.00000000092 * cos(5.59171891913 + 10818.3791043993*$t);
  $Y1 += 0.00000000077 * cos(4.13228553675 + 6993.2527160332*$t);
  $Y1 += 0.00000000080 * cos(6.08197788088 + 13521.9952590749*$t);
  $Y1 += 0.00000000104 * cos(0.70806546737 + 5650.0482931947*$t);
  $Y1 += 0.00000000093 * cos(5.00569753414 + 4732.2744448269*$t);
  $Y1 += 0.00000000085 * cos(1.74569264442 + 22805.4917485101*$t);
  $Y1 += 0.00000000086 * cos(5.52511956951 + 12360.2099690291*$t);
  $Y1 += 0.00000000075 * cos(5.57236272383 + 5120.35732810009*$t);
  $Y1 += 0.00000000090 * cos(5.33797857569 + 6370.62787201471*$t);
  $Y1 += 0.00000000090 * cos(4.45214765055 + 6196.0114629351*$t);
  $Y1 += 0.00000000082 * cos(4.91006846138 + 18842.3578204569*$t);
  $Y1 += 0.00000000101 * cos(1.37756832018 + 3097.64000524229*$t);
  $Y1 += 0.00000000094 * cos(0.74657649932 + 10177.01386205009*$t);
  $Y1 += 0.00000000083 * cos(3.74913323692 + 18415.7596295809*$t);
  $Y1 += 0.00000000073 * cos(4.52746639645 + 949.4194264533*$t);
  $Y1 += 0.00000000101 * cos(4.43327916798 + 3104.6862419403*$t);
  $Y1 += 0.00000000074 * cos(1.25396392931 + 13517.62628874989*$t);
  $Y1 += 0.00000000092 * cos(0.77959714125 + 16858.7263504167*$t);
  $Y1 += 0.00000000075 * cos(1.57278335709 + 1059.1381127057*$t);
  $Y1 += 0.00000000085 * cos(4.52163234616 + 398.3928208917*$t);
  $Y1 += 0.00000000069 * cos(5.60384680292 + 11713.1991357143*$t);
  $Y1 += 0.00000000084 * cos(5.92557534615 + 2378.9206560881*$t);
  $Y1 += 0.00000000069 * cos(2.18342250812 + 11712.71150074729*$t);
  $Y1 += 0.00000000075 * cos(0.05753316454 + 30356.2411372513*$t);
  $Y1 += 0.00000000067 * cos(3.04134731899 + 3154.9309023791*$t);
  $Y1 += 0.00000000076 * cos(3.26401364210 + 18429.9867235825*$t);
  $Y1 += 0.00000000068 * cos(2.69185508250 + 11925.5179100841*$t);
  $Y1 += 0.00000000067 * cos(4.81689271569 + 10454.25756912169*$t);
  $Y1 += 0.00000000073 * cos(1.35808826471 + 15670.83794192309*$t);
  $Y1 += 0.00000000065 * cos(1.77865763794 + 6438.2524319421*$t);
  $Y1 += 0.00000000069 * cos(1.72420196911 + 17298.4261448097*$t);
  $Y1 += 0.00000000087 * cos(3.52675260029 + 3904.1551939033*$t);
  $Y1 += 0.00000000076 * cos(5.44623063701 + 5231.0512842865*$t);
  $Y1 += 0.00000000064 * cos(2.12314868459 + 3496.2766436175*$t);
  $Y1 += 0.00000000078 * cos(2.74559935849 + 8672.21368792411*$t);
  $Y1 += 0.00000000066 * cos(4.98895923052 + 14143.2514249471*$t);
  $Y1 += 0.00000000063 * cos(5.70776457338 + 24357.0246061251*$t);
  $Y1 += 0.00000000063 * cos(0.57965828598 + 15720.5949673949*$t);
  $Y1 += 0.00000000061 * cos(2.15619405920 + 16460.5773470085*$t);
  $Y1 += 0.00000000073 * cos(6.07488391156 + 9387.76209193169*$t);
  $Y1 += 0.00000000057 * cos(4.37179192959 + 17259.91083720689*$t);
  $Y1 += 0.00000000059 * cos(2.26511827996 + 9778.8648586419*$t);
  $Y1 += 0.00000000058 * cos(1.67874293827 + 155.6642169177*$t);
  $Y1 += 0.00000000060 * cos(1.94469304669 + 34570.3101523361*$t);
  $Y1 += 0.00000000057 * cos(2.88994977642 + 149854.64395229139*$t);
  $Y1 += 0.00000000056 * cos(3.76314176838 + 12456.1891962469*$t);
  $Y1 += 0.00000000056 * cos(5.62479142768 + 17996.2749857057*$t);
  $Y1 += 0.00000000056 * cos(0.60886736064 + 11764.5745863425*$t);
  $Y1 += 0.00000000054 * cos(4.53224684011 + 4705.4884900601*$t);
  $Y1 += 0.00000000055 * cos(6.11029124003 + 13915.77529215809*$t);
  $Y1 += 0.00000000061 * cos(4.86430679802 + 28237.4772768729*$t);
  $Y1 += 0.00000000065 * cos(4.29965528550 + 7335.5880506633*$t);
  $Y1 += 0.00000000072 * cos(5.48795829629 + 6055.8435346859*$t);
  $Y1 += 0.00000000072 * cos(4.30216792995 + 6510.7958002639*$t);
  $Y1 += 0.00000000071 * cos(4.94322519248 + 12545.6201219739*$t);
  $Y1 += 0.00000000061 * cos(5.98387073766 + 6312.74917601091*$t);
  $Y1 += 0.00000000061 * cos(3.80625548858 + 6253.8901589389*$t);
  $Y1 += 0.00000000052 * cos(1.83719780245 + 5326.5428765373*$t);
  $Y1 += 0.00000000054 * cos(2.78309524301 + 2699.49100183409*$t);
  $Y1 += 0.00000000052 * cos(0.87738933830 + 8983.0544867925*$t);
  $Y1 += 0.00000000066 * cos(0.78258344897 + 14919.2616712381*$t);
  $Y1 += 0.00000000050 * cos(1.22263365304 + 5572.8989839496*$t);
  $Y1 += 0.00000000051 * cos(2.33500088089 + 16522.4158985187*$t);
  $Y1 += 0.00000000049 * cos(2.61658441943 + 35579.9350570535*$t);
  $Y1 += 0.00000000053 * cos(6.07542895582 + 6208.5380689076*$t);
  $Y1 += 0.00000000053 * cos(3.71469727042 + 6358.1012660422*$t);
  $Y1 += 0.00000000049 * cos(3.35593265214 + 21393.7857873411*$t);
  $Y1 += 0.00000000049 * cos(4.47248238697 + 5547.4431539431*$t);
  $Y1 += 0.00000000049 * cos(5.31764383927 + 7019.19618100671*$t);
  $Y1 += 0.00000000049 * cos(1.02044068888 + 12416.8323203317*$t);
  $Y1 += 0.00000000050 * cos(0.93918602686 + 12592.2062022991*$t);
  $Y1 += 0.00000000050 * cos(4.78759248733 + 26084.2656236997*$t);
  $Y1 += 0.00000000051 * cos(1.83601012538 + 23006.6698100699*$t);
  $Y1 += 0.00000000058 * cos(4.03623415117 + 15141.14697682849*$t);
  $Y1 += 0.00000000047 * cos(5.68903994773 + 24279.3508356971*$t);
  $Y1 += 0.00000000049 * cos(3.40926939847 + 6816.53375091851*$t);
  $Y1 += 0.00000000049 * cos(0.09767152059 + 5750.1055840313*$t);
  $Y1 += 0.00000000046 * cos(1.88054905125 + 19379.1623325523*$t);
  $Y1 += 0.00000000052 * cos(5.74808775798 + 16737.33341911309*$t);
  $Y1 += 0.00000000047 * cos(0.52219046486 + 24066.0517402591*$t);
  $Y1 += 0.00000000046 * cos(4.16717022039 + 104351.85638378029*$t);
  $Y1 += 0.00000000063 * cos(6.25484174196 + 8662.48414104651*$t);
  $Y1 += 0.00000000048 * cos(3.28503810088 + 26735.7014447297*$t);
  $Y1 += 0.00000000046 * cos(3.91775350902 + 12132.6837795895*$t);
  $Y1 += 0.00000000050 * cos(2.92364175862 + 24602.8562523545*$t);
  $Y1 += 0.00000000054 * cos(4.75214039499 + 7834.3648901229*$t);
  $Y1 += 0.00000000045 * cos(3.48807574467 + 161000.92955515759*$t);
  $Y1 += 0.00000000049 * cos(2.94405201174 + 29303.9727540629*$t);
  $Y1 += 0.00000000049 * cos(1.43156848803 + 10984.4361691833*$t);
  $Y1 += 0.00000000045 * cos(0.70883599249 + 45584.9289947039*$t);
  $Y1 += 0.00000000046 * cos(1.86995211145 + 5244.2930566845*$t);
  $Y1 += 0.00000000048 * cos(3.53510882628 + 23581.0143598341*$t);
  $Y1 += 0.00000000049 * cos(2.17177379198 + 19650.8046636145*$t);
  $Y1 += 0.00000000049 * cos(3.41897587826 + 29289.7456600613*$t);
  $Y1 += 0.00000000044 * cos(1.44008987426 + 6390.9831914135*$t);
  $Y1 += 0.00000000044 * cos(2.06685104480 + 6175.6561435363*$t);
  $Y1 += 0.00000000051 * cos(2.65580143245 + 17789.60180230149*$t);
  $Y1 += 0.00000000042 * cos(6.18543275273 + 24705.9490265731*$t);
  $Y1 += 0.00000000042 * cos(5.90805829894 + 15663.79170522509*$t);
  $Y1 += 0.00000000043 * cos(3.08250524084 + 16460.08971204149*$t);
  $Y1 += 0.00000000043 * cos(0.28590581328 + 553.8132203259*$t);
  $Y1 += 0.00000000041 * cos(3.21615501236 + 17370.6047933933*$t);
  $Y1 += 0.00000000053 * cos(2.59151074700 + 13119.47728534169*$t);
  $Y1 += 0.00000000042 * cos(5.11995884892 + 4164.5558070965*$t);
  $Y1 += 0.00000000041 * cos(2.05521298551 + 23020.8969040715*$t);
  $Y1 += 0.00000000045 * cos(3.70227971577 + 54247.1693182669*$t);
  $Y1 += 0.00000000040 * cos(4.57473494926 + 32243.2546833971*$t);
  $Y1 += 0.00000000040 * cos(5.17184328434 + 24336.2492106327*$t);
  $Y1 += 0.00000000040 * cos(1.71852303243 + 11769.6098756829*$t);
  $Y1 += 0.00000000045 * cos(6.25985265406 + 16723.10632511149*$t);
  $Y1 += 0.00000000045 * cos(6.25985265406 + 16723.5939600785*$t);
  $Y1 += 0.00000000042 * cos(5.89327075469 + 8827.14645239129*$t);
  $Y1 += 0.00000000040 * cos(4.71493835645 + 8402.0835278533*$t);
  $Y1 += 0.00000000039 * cos(3.49714273023 + 16062.4283436003*$t);
  $Y1 += 0.00000000044 * cos(4.44510876745 + 5856.23384163189*$t);
  $Y1 += 0.00000000038 * cos(1.14212165839 + 6297.5467614765*$t);
  $Y1 += 0.00000000038 * cos(2.36481926067 + 6269.0925734733*$t);
  $Y1 += 0.00000000041 * cos(3.38233495451 + 15508.8589407579*$t);
  $Y1 += 0.00000000038 * cos(4.96796930709 + 6394.50630976251*$t);
  $Y1 += 0.00000000038 * cos(4.82215691915 + 6172.1330251873*$t);
  $Y1 += 0.00000000039 * cos(1.74815791619 + 29826.5501721567*$t);
  $Y1 += 0.00000000046 * cos(0.31322632556 + 17297.9385098427*$t);
  $Y1 += 0.00000000041 * cos(4.04315782590 + 6309.1303523077*$t);
  $Y1 += 0.00000000038 * cos(5.82409895120 + 29089.0552334685*$t);
  $Y1 += 0.00000000038 * cos(4.59409111885 + 11933.6117781531*$t);
  $Y1 += 0.00000000037 * cos(3.34091252113 + 26482.4146271079*$t);
  $Y1 += 0.00000000037 * cos(3.64722285417 + 20452.6255947383*$t);
  $Y1 += 0.00000000037 * cos(0.30900035436 + 18073.46112116669*$t);
  $Y1 += 0.00000000036 * cos(2.98410187235 + 11499.41240530929*$t);
  $Y1 += 0.00000000045 * cos(4.75649198460 + 3340.8562441833*$t);
  $Y1 += 0.00000000049 * cos(4.21088151991 + 18216.6876281445*$t);
  $Y1 += 0.00000000038 * cos(4.59187061808 + 18202.4605341429*$t);
  $Y1 += 0.00000000041 * cos(3.91005845267 + 5216.8241902849*$t);
  $Y1 += 0.00000000036 * cos(6.21139146959 + 4060.97539791089*$t);
  $Y1 += 0.00000000048 * cos(5.14345155225 + 951.9622237341*$t);
  $Y1 += 0.00000000041 * cos(3.90932016585 + 18848.98373249069*$t);
  $Y1 += 0.00000000038 * cos(4.60880580452 + 26709.8907598969*$t);
  $Y1 += 0.00000000036 * cos(3.12521745961 + 28230.4310401749*$t);
  $Y1 += 0.00000000036 * cos(1.96840086543 + 24491.18197509989*$t);
  $Y1 += 0.00000000036 * cos(1.56811412304 + 9924.5666040271*$t);
  $Y1 += 0.00000000048 * cos(1.89701220521 + 8982.5668518255*$t);
  $Y1 += 0.00000000037 * cos(3.60669363968 + 22484.0923919761*$t);
  $Y1 += 0.00000000047 * cos(3.21269518092 + 6040.10342853389*$t);
  $Y1 += 0.00000000034 * cos(3.68972702028 + 6418.9449924849*$t);
  $Y1 += 0.00000000034 * cos(6.10039920596 + 6147.69434246491*$t);
  $Y1 += 0.00000000034 * cos(3.67007112439 + 9380.71585523369*$t);
  $Y1 += 0.00000000036 * cos(0.30403746373 + 7238.4317741165*$t);
  $Y1 += 0.00000000034 * cos(0.40887602826 + 17272.1278250099*$t);
  $Y1 += 0.00000000037 * cos(1.23154839984 + 58953.3892607775*$t);
  $Y1 += 0.00000000034 * cos(0.33427002863 + 29026.7290469913*$t);
  $Y1 += 0.00000000033 * cos(3.87501941695 + 12721.32828193349*$t);
  $Y1 += 0.00000000035 * cos(1.63582276543 + 7322.34627826531*$t);
  $Y1 += 0.00000000044 * cos(1.21937301495 + 3981.73385156551*$t);
  $Y1 += 0.00000000033 * cos(3.59821221655 + 19804.5834740993*$t);
  $Y1 += 0.00000000033 * cos(2.56047890182 + 173567.08125514039*$t);
  $Y1 += 0.00000000033 * cos(6.16657680956 + 205.9417309537*$t);
  $Y1 += 0.00000000033 * cos(5.44889821497 + 23013.29572210369*$t);
  $Y1 += 0.00000000034 * cos(2.13261854972 + 49515.1386909235*$t);
  $Y1 += 0.00000000034 * cos(3.38050467777 + 38500.5198485557*$t);
  $Y1 += 0.00000000032 * cos(2.81221233882 + 17686.9966630499*$t);
  $Y1 += 0.00000000036 * cos(1.67423219491 + 5641.9544251257*$t);
  $Y1 += 0.00000000032 * cos(2.91090812586 + 21228.63584102931*$t);
  $Y1 += 0.00000000033 * cos(0.13839577785 + 34520.5531268643*$t);
  $Y1 += 0.00000000033 * cos(5.65380556855 + 8635.69818627969*$t);
  $Y1 += 0.00000000031 * cos(1.88042187886 + 5746.0275204125*$t);
  $Y1 += 0.00000000041 * cos(2.52021697492 + 21202.3375212295*$t);
  $Y1 += 0.00000000037 * cos(5.92836585991 + 7349.81514466491*$t);
  $Y1 += 0.00000000034 * cos(2.18099177342 + 16496.11757871889*$t);
  $Y1 += 0.00000000032 * cos(0.90143427409 + 33019.2649296881*$t);
  $Y1 += 0.00000000032 * cos(1.54173979189 + 21150.56954840009*$t);
  $Y1 += 0.00000000037 * cos(1.84830381005 + 29296.8592070621*$t);
  $Y1 += 0.00000000036 * cos(5.02250294215 + 27511.2240560537*$t);
  $Y1 += 0.00000000035 * cos(3.77934660139 + 11933.12414318609*$t);
  $Y1 += 0.00000000035 * cos(4.26341483447 + 11918.89704918449*$t);
  $Y1 += 0.00000000035 * cos(5.54313072444 + 29062.7569136687*$t);
  $Y1 += 0.00000000030 * cos(1.38932865248 + 12490.1294461907*$t);
  $Y1 += 0.00000000032 * cos(5.09927453137 + 6334.60000533731*$t);
  $Y1 += 0.00000000032 * cos(4.69085169487 + 6232.03932961249*$t);
  $Y1 += 0.00000000029 * cos(4.05993716780 + 419.2408263917*$t);
  $Y1 += 0.00000000029 * cos(0.91834451421 + 419.72846135871*$t);
  $Y1 += 0.00000000029 * cos(1.66178131503 + 16858.23871544969*$t);
  $Y1 += 0.00000000030 * cos(2.73190240418 + 16208.13008898551*$t);
  $Y1 += 0.00000000029 * cos(0.69175314473 + 27278.7126339243*$t);
  $Y1 += 0.00000000032 * cos(4.73525892997 + 5017.2645538815*$t);
  $Y1 += 0.00000000028 * cos(0.30767945102 + 24080.2788342607*$t);
  $Y1 += 0.00000000030 * cos(1.00265951424 + 23539.9512038163*$t);
  $Y1 += 0.00000000029 * cos(1.45883005475 + 18606.25512851669*$t);
  $Y1 += 0.00000000030 * cos(4.73151177298 + 30665.9111409493*$t);
  $Y1 += 0.00000000034 * cos(4.29199382621 + 6660.6932753907*$t);
  $Y1 += 0.00000000034 * cos(5.49813240003 + 5905.94605955911*$t);
  $Y1 += 0.00000000038 * cos(3.55143054136 + 31571.0434668747*$t);
  $Y1 += 0.00000000038 * cos(4.53015131722 + 16061.94070863329*$t);
  $Y1 += 0.00000000029 * cos(1.64885508302 + 23539.46356884929*$t);
  $Y1 += 0.00000000033 * cos(2.88700963334 + 3738.51761262449*$t);
  $Y1 += 0.00000000028 * cos(6.02264922068 + 2942.21960580809*$t);
  $Y1 += 0.00000000032 * cos(2.75250951602 + 15110.7099373497*$t);
  $Y1 += 0.00000000030 * cos(6.10434010761 + 55023.1795645579*$t);
  $Y1 += 0.00000000027 * cos(5.24524976767 + 233141.55822184499*$t);
  $Y1 += 0.00000000030 * cos(0.75326086687 + 12587.1709129587*$t);
  $Y1 += 0.00000000028 * cos(3.97691648841 + 34911.6558935745*$t);
  $Y1 += 0.00000000027 * cos(4.60109278395 + 1692.40948698591*$t);
  $Y1 += 0.00000000027 * cos(6.13743188286 + 2544.07060239989*$t);
  $Y1 += 0.00000000027 * cos(4.99580076168 + 24382.8352909579*$t);
  $Y1 += 0.00000000027 * cos(4.42136306455 + 6205.6458970469*$t);
  $Y1 += 0.00000000027 * cos(5.36876316169 + 6360.99343790291*$t);
  $Y1 += 0.00000000027 * cos(4.95719787895 + 31172.8944634665*$t);
  $Y1 += 0.00000000026 * cos(2.19655051246 + 36949.4746259077*$t);
  $Y1 += 0.00000000034 * cos(4.45594644643 + 18053.1733606413*$t);
  $Y1 += 0.00000000027 * cos(0.74968073356 + 32367.3414736911*$t);
  $Y1 += 0.00000000027 * cos(3.34260766105 + 4487.57358878689*$t);
  $Y1 += 0.00000000028 * cos(5.37411547339 + 10239.3400485273*$t);
  $Y1 += 0.00000000026 * cos(1.30232025786 + 4796.85191144269*$t);
  $Y1 += 0.00000000026 * cos(4.70861603764 + 6226.4212925393*$t);
  $Y1 += 0.00000000026 * cos(5.08151018860 + 6340.2180424105*$t);
  $Y1 += 0.00000000029 * cos(4.90026899469 + 5974.0413448191*$t);
  $Y1 += 0.00000000029 * cos(4.88985723155 + 6592.5979901307*$t);
  $Y1 += 0.00000000026 * cos(4.96950484222 + 19402.55313533309*$t);
  $Y1 += 0.00000000028 * cos(3.99925126629 + 46386.7499258277*$t);
  $Y1 += 0.00000000032 * cos(5.04462761864 + 9225.7830907665*$t);
  $Y1 += 0.00000000026 * cos(4.11745014890 + 9910.33951002549*$t);
  $Y1 += 0.00000000025 * cos(1.02839985963 + 15265.64270181689*$t);
  $Y1 += 0.00000000029 * cos(4.33416022359 + 52176.0501006319*$t);
  $Y1 += 0.00000000027 * cos(2.65258449905 + 62883.5989569971*$t);
  $Y1 += 0.00000000024 * cos(5.26265995716 + 11617.21990849651*$t);
  $Y1 += 0.00000000024 * cos(1.04936648816 + 5120.8449630671*$t);
  $Y1 += 0.00000000028 * cos(4.82143927810 + 6680.98103591609*$t);
  $Y1 += 0.00000000024 * cos(5.97769334002 + 522.3336006103*$t);
  $Y1 += 0.00000000025 * cos(2.29282659231 + 6263.64990657511*$t);
  $Y1 += 0.00000000025 * cos(1.21411432675 + 6302.9894283747*$t);
  $Y1 += 0.00000000029 * cos(0.87325499796 + 23581.5019948011*$t);
  $Y1 += 0.00000000024 * cos(5.21948189448 + 29424.8780503995*$t);
  $Y1 += 0.00000000028 * cos(1.09161353868 + 16737.8210540801*$t);
  $Y1 += 0.00000000024 * cos(3.55960074091 + 22743.16556203289*$t);
  $Y1 += 0.00000000024 * cos(3.55960074091 + 22743.6531969999*$t);
  $Y1 += 0.00000000024 * cos(4.28222488832 + 25158.8455372489*$t);
  $Y1 += 0.00000000025 * cos(5.52194731109 + 21424.2228268199*$t);
  $Y1 += 0.00000000025 * cos(5.52194731109 + 21424.7104617869*$t);
  $Y1 += 0.00000000024 * cos(3.49943174674 + 14712.07329897449*$t);
  $Y1 += 0.00000000028 * cos(6.07681616993 + 5760.25461441409*$t);
  $Y1 += 0.00000000024 * cos(2.16376008059 + 31969.1924702829*$t);
  $Y1 += 0.00000000023 * cos(5.33584675127 + 17893.1822114871*$t);
  $Y1 += 0.00000000030 * cos(2.28483676839 + 8584.9054833843*$t);
  $Y1 += 0.00000000024 * cos(1.64666673478 + 23550.5878691661*$t);
  $Y1 += 0.00000000023 * cos(6.07302432574 + 6717.0314053517*$t);
  $Y1 += 0.00000000022 * cos(2.42662159283 + 7445.7943718827*$t);
  $Y1 += 0.00000000023 * cos(3.56571153376 + 5849.6079295981*$t);
  $Y1 += 0.00000000025 * cos(5.52794317615 + 14155.4684127501*$t);
  $Y1 += 0.00000000023 * cos(2.01489779401 + 6294.36536773881*$t);
  $Y1 += 0.00000000023 * cos(1.49204312505 + 6272.273967211*$t);
  $Y1 += 0.00000000024 * cos(5.81677586075 + 18208.1061251085*$t);
  $Y1 += 0.00000000024 * cos(5.81677586075 + 18208.5937600755*$t);
  $Y1 += 0.00000000021 * cos(4.21172313283 + 22779.6810636773*$t);
  $Y1 += 0.00000000029 * cos(1.74369099855 + 28628.5800435831*$t);
  $Y1 += 0.00000000021 * cos(3.56347944199 + 40879.6843221273*$t);
  $Y1 += 0.00000000021 * cos(2.51496251708 + 30221.1760572159*$t);
  $Y1 += 0.00000000022 * cos(6.09500922463 + 4379.8828549737*$t);
  $Y1 += 0.00000000022 * cos(3.69512347867 + 8186.7564799761*$t);
  $Y1 += 0.00000000022 * cos(2.95145769488 + 28760.05469496669*$t);
  $Y1 += 0.00000000026 * cos(1.83973482412 + 18422.8731765817*$t);
  $Y1 += 0.00000000020 * cos(2.37799900039 + 12036.21691740469*$t);
  $Y1 += 0.00000000020 * cos(0.07485283254 + 28313.0449871775*$t);
  $Y1 += 0.00000000027 * cos(5.38239668902 + 34513.5068901663*$t);
  $Y1 += 0.00000000020 * cos(0.50551300300 + 34115.3578867581*$t);
  $Y1 += 0.00000000020 * cos(3.29228335956 + 21548.7185518083*$t);
  $Y1 += 0.00000000020 * cos(5.25656062979 + 17654.5367222661*$t);
  $Y1 += 0.00000000025 * cos(1.96130235408 + 55798.7021758819*$t);
  $Y1 += 0.00000000020 * cos(5.53200449549 + 20597.4877805247*$t);
  $Y1 += 0.00000000020 * cos(1.03604717996 + 18875.76968725751*$t);
  $Y1 += 0.00000000022 * cos(2.01853988925 + 1588.82907780029*$t);
  $Y1 += 0.00000000024 * cos(5.92091322542 + 9411.7084325707*$t);
  $Y1 += 0.00000000019 * cos(1.14706242910 + 536.5606946119*$t);
  $Y1 += 0.00000000020 * cos(3.42481272827 + 6187.3404402571*$t);
  $Y1 += 0.00000000020 * cos(0.08212819079 + 6379.2988946927*$t);
  $Y1 += 0.00000000022 * cos(2.87392170851 + 18326.8939493639*$t);
  $Y1 += 0.00000000022 * cos(0.61268580951 + 6233.5626420031*$t);
  $Y1 += 0.00000000022 * cos(2.89425510955 + 6333.0766929467*$t);
  $Y1 += 0.00000000018 * cos(0.45956662142 + 5972.4788686065*$t);
  $Y1 += 0.00000000018 * cos(3.04737429764 + 6594.1604663433*$t);
  $Y1 += 0.00000000019 * cos(2.71317971903 + 6948.0757126049*$t);
  $Y1 += 0.00000000019 * cos(0.79376120003 + 5618.5636223449*$t);
  $Y1 += 0.00000000019 * cos(4.89700264579 + 83974.07917321339*$t);
  $Y1 += 0.00000000019 * cos(2.72494811319 + 84020.10309797739*$t);
  $Y1 += 0.00000000020 * cos(5.42036659910 + 50316.9596220473*$t);
  $Y1 += 0.00000000020 * cos(1.28312164242 + 9070.3626913323*$t);
  return $Y1*$t;
}



  function Earth_C_Y2 ($t)
{
  $Y2 =  0.0;
  $Y2 += 0.00052911498 * cos(1.75323722235 + 6283.3196674749*$t);
  $Y2 += 0.00006074441 * cos(0.48406211192 + 0.2438174835*$t);
  $Y2 += 0.00002406871 * cos(2.66006394470 + 12566.3955174663*$t);
  $Y2 += 0.00000096033 * cos(2.57406136836 + 18849.4713674577*$t);
  $Y2 += 0.00000029888 * cos(2.30515825272 + 6282.83203250789*$t);
  $Y2 += 0.00000014021 * cos(1.64042051619 + 6279.7965491259*$t);
  $Y2 += 0.00000013375 * cos(1.74320372785 + 6286.84278582391*$t);
  $Y2 += 0.00000008148 * cos(0.62869530307 + 6309.61798727471*$t);
  $Y2 += 0.00000008195 * cos(2.81874475342 + 6257.0213476751*$t);
  $Y2 += 0.00000008001 * cos(4.34877296703 + 6127.8992680407*$t);
  $Y2 += 0.00000007754 * cos(5.43470598991 + 6438.7400669091*$t);
  $Y2 += 0.00000007223 * cos(3.81034638754 + 83997.09113559539*$t);
  $Y2 += 0.00000004616 * cos(4.59623594691 + 710.1768660418*$t);
  $Y2 += 0.00000003060 * cos(3.26884940633 + 4705.9761250271*$t);
  $Y2 += 0.00000003717 * cos(0.87961276723 + 5507.7970561509*$t);
  $Y2 += 0.00000002991 * cos(2.48913608928 + 25132.5472174491*$t);
  $Y2 += 0.00000003235 * cos(2.53504921673 + 7058.8422787989*$t);
  $Y2 += 0.00000002393 * cos(1.83696733237 + 775.7664288075*$t);
  $Y2 += 0.00000002034 * cos(2.77061597204 + 6290.4332144757*$t);
  $Y2 += 0.00000002028 * cos(0.70943948464 + 6276.2061204741*$t);
  $Y2 += 0.00000002064 * cos(0.01448293997 + 7860.6632099227*$t);
  $Y2 += 0.00000001914 * cos(2.85234479868 + 5487.0216606585*$t);
  $Y2 += 0.00000001770 * cos(3.48783151064 + 1059.6257476727*$t);
  $Y2 += 0.00000001761 * cos(1.80823220260 + 5753.6287023803*$t);
  $Y2 += 0.00000001558 * cos(0.56580595512 + 7079.61767429131*$t);
  $Y2 += 0.00000001551 * cos(0.55852743151 + 6040.5910635009*$t);
  $Y2 += 0.00000001436 * cos(1.28164050883 + 5885.1706640667*$t);
  $Y2 += 0.00000001469 * cos(2.94324921966 + 6526.04827144891*$t);
  $Y2 += 0.00000001319 * cos(1.89155311923 + 6681.46867088311*$t);
  $Y2 += 0.00000001180 * cos(1.42090963151 + 6813.0106325695*$t);
  $Y2 += 0.00000001337 * cos(5.75221416852 + 5729.7502646325*$t);
  $Y2 += 0.00000001039 * cos(4.25243426113 + 6282.3393464067*$t);
  $Y2 += 0.00000001313 * cos(0.59897551240 + 529.9347825781*$t);
  $Y2 += 0.00000001041 * cos(5.47801377680 + 6284.2999885431*$t);
  $Y2 += 0.00000001202 * cos(4.02829547071 + 6836.8890703173*$t);
  $Y2 += 0.00000000904 * cos(0.85768945907 + 5331.6012612243*$t);
  $Y2 += 0.00000000870 * cos(2.26660468565 + 4933.4522578161*$t);
  $Y2 += 0.00000001149 * cos(3.02450680654 + 167284.00540514899*$t);
  $Y2 += 0.00000001069 * cos(1.09203232944 + 1577.0997249643*$t);
  $Y2 += 0.00000000772 * cos(2.66290097432 + 7235.0380737255*$t);
  $Y2 += 0.00000000846 * cos(1.36798976406 + 11790.8729061423*$t);
  $Y2 += 0.00000000742 * cos(5.02007434299 + 4137.1542509997*$t);
  $Y2 += 0.00000000966 * cos(2.05227643484 + 11856.462468908*$t);
  $Y2 += 0.00000000664 * cos(1.21776131888 + 7633.1870771337*$t);
  $Y2 += 0.00000000662 * cos(3.18968574411 + 1194.6908277081*$t);
  $Y2 += 0.00000000659 * cos(5.95013449282 + 11507.0135872771*$t);
  $Y2 += 0.00000000853 * cos(3.65338850674 + 4535.3032544079*$t);
  $Y2 += 0.00000000823 * cos(1.06126729936 + 155.17658195069*$t);
  $Y2 += 0.00000000783 * cos(4.30296275012 + 5088.8726572503*$t);
  $Y2 += 0.00000000785 * cos(3.46658763633 + 2353.1099712553*$t);
  $Y2 += 0.00000000694 * cos(3.50785804761 + 801.5771136403*$t);
  $Y2 += 0.00000000566 * cos(4.42922662864 + 796.5418242999*$t);
  $Y2 += 0.00000000684 * cos(1.11267726523 + 3128.6325825793*$t);
  $Y2 += 0.00000000499 * cos(1.42594865875 + 12569.91863581531*$t);
  $Y2 += 0.00000000596 * cos(6.09778115923 + 8031.3360805419*$t);
  $Y2 += 0.00000000486 * cos(4.54237345712 + 1589.3167127673*$t);
  $Y2 += 0.00000000483 * cos(4.68204073064 + 8429.4850839501*$t);
  $Y2 += 0.00000000441 * cos(4.99112466662 + 6496.6187629129*$t);
  $Y2 += 0.00000000412 * cos(0.87602065813 + 4693.75913722409*$t);
  $Y2 += 0.00000000561 * cos(5.46330573132 + 7477.7666776995*$t);
  $Y2 += 0.00000000390 * cos(4.63888431687 + 6070.0205720369*$t);
  $Y2 += 0.00000000405 * cos(6.26538093406 + 3739.0052475915*$t);
  $Y2 += 0.00000000501 * cos(1.82149883986 + 1592.8398311163*$t);
  $Y2 += 0.00000000392 * cos(0.68216396598 + 26.0545023163*$t);
  $Y2 += 0.00000000369 * cos(5.93410776393 + 553.32558535889*$t);
  $Y2 += 0.00000000483 * cos(6.07777893059 + 12036.7045523717*$t);
  $Y2 += 0.00000000489 * cos(3.70668603785 + 5223.4501023187*$t);
  $Y2 += 0.00000000481 * cos(3.17195852109 + 10213.5293636945*$t);
  $Y2 += 0.00000000448 * cos(5.56847234629 + 156137.71980228279*$t);
  $Y2 += 0.00000000321 * cos(4.53991511859 + 951.4745887671*$t);
  $Y2 += 0.00000000320 * cos(0.43138538654 + 1990.9888345245*$t);
  $Y2 += 0.00000000361 * cos(2.16599134100 + 12565.9078824993*$t);
  $Y2 += 0.00000000361 * cos(4.79823251497 + 12721.8159169005*$t);
  $Y2 += 0.00000000412 * cos(4.34259218946 + 398.3928208917*$t);
  $Y2 += 0.00000000304 * cos(5.68078111352 + 4690.7236538421*$t);
  $Y2 += 0.00000000356 * cos(6.00094576166 + 5481.4987363511*$t);
  $Y2 += 0.00000000283 * cos(0.66912545661 + 242.97242145751*$t);
  $Y2 += 0.00000000362 * cos(2.31554210740 + 9438.0067523705*$t);
  $Y2 += 0.00000000248 * cos(3.18243221495 + 8827.6340873583*$t);
  $Y2 += 0.00000000252 * cos(2.73244620528 + 3154.4432674121*$t);
  $Y2 += 0.00000000257 * cos(0.22372520009 + 11371.9485072417*$t);
  $Y2 += 0.00000000327 * cos(1.45001600721 + 14143.7390599141*$t);
  $Y2 += 0.00000000230 * cos(1.80447328493 + 1747.7725955835*$t);
  $Y2 += 0.00000000289 * cos(3.67617510107 + 7085.1405985987*$t);
  $Y2 += 0.00000000297 * cos(3.17045499445 + 1349.62359217529*$t);
  $Y2 += 0.00000000209 * cos(4.98580572759 + 11770.0975106499*$t);
  $Y2 += 0.00000000207 * cos(0.21623312501 + 4164.0681721295*$t);
  $Y2 += 0.00000000188 * cos(4.07593821324 + 7875.91568110771*$t);
  $Y2 += 0.00000000189 * cos(5.31784128034 + 2389.1378379327*$t);
  $Y2 += 0.00000000194 * cos(5.12285857348 + 10977.32262218251*$t);
  $Y2 += 0.00000000176 * cos(2.51491286893 + 7342.7015976641*$t);
  $Y2 += 0.00000000164 * cos(1.22070775546 + 5223.93773728571*$t);
  $Y2 += 0.00000000205 * cos(1.64290799201 + 10973.7995038335*$t);
  $Y2 += 0.00000000205 * cos(0.68022152849 + 13368.2164485901*$t);
  $Y2 += 0.00000000139 * cos(3.04789845179 + 10575.6505004253*$t);
  $Y2 += 0.00000000155 * cos(4.24333188820 + 12410.9751180321*$t);
  $Y2 += 0.00000000152 * cos(4.81739365185 + 3930.4535137031*$t);
  $Y2 += 0.00000000129 * cos(0.80954637051 + 397.9051859247*$t);
  $Y2 += 0.00000000127 * cos(5.67893828134 + 12592.6938372661*$t);
  $Y2 += 0.00000000132 * cos(4.87291664360 + 8636.18582124671*$t);
  $Y2 += 0.00000000122 * cos(3.21278850975 + 13119.9649203087*$t);
  $Y2 += 0.00000000163 * cos(2.50359725386 + 5507.3094211839*$t);
  $Y2 += 0.00000000114 * cos(4.13352060999 + 17260.3984721739*$t);
  $Y2 += 0.00000000118 * cos(0.80775184774 + 4292.5746504339*$t);
  $Y2 += 0.00000000148 * cos(4.06616105867 + 17790.08943726851*$t);
  $Y2 += 0.00000000123 * cos(2.18706277371 + 12562.8723991173*$t);
  $Y2 += 0.00000000103 * cos(1.79915109205 + 13518.1139237169*$t);
  $Y2 += 0.00000000138 * cos(2.26785827403 + 12168.2465140581*$t);
  $Y2 += 0.00000000107 * cos(2.76898193474 + 10989.0519750185*$t);
  $Y2 += 0.00000000104 * cos(0.56758990747 + 2145.92159899169*$t);
  $Y2 += 0.00000000096 * cos(0.40713285174 + 6283.25235717211*$t);
  $Y2 += 0.00000000099 * cos(0.70751931715 + 13096.0864825609*$t);
  $Y2 += 0.00000000096 * cos(6.24621518908 + 6283.3869777777*$t);
  $Y2 += 0.00000000084 * cos(3.63516988010 + 16730.70750707931*$t);
  $Y2 += 0.00000000111 * cos(2.39242858566 + 12540.0971976665*$t);
  $Y2 += 0.00000000087 * cos(4.45435464785 + 10177.5014970171*$t);
  $Y2 += 0.00000000078 * cos(2.61342989032 + 12323.6669134923*$t);
  $Y2 += 0.00000000076 * cos(4.13782411870 + 6709.91785835091*$t);
  $Y2 += 0.00000000105 * cos(1.96765772501 + 5642.4420600927*$t);
  $Y2 += 0.00000000073 * cos(5.60932378402 + 5856.7214765989*$t);
  $Y2 += 0.00000000102 * cos(5.37997051996 + 250570.91967470259*$t);
  $Y2 += 0.00000000070 * cos(0.51266920771 + 5753.14106741329*$t);
  $Y2 += 0.00000000071 * cos(5.27404987073 + 14314.4119305333*$t);
  $Y2 += 0.00000000092 * cos(0.39406209616 + 13916.2629271251*$t);
  $Y2 += 0.00000000070 * cos(4.10529685600 + 7084.6529636317*$t);
  $Y2 += 0.00000000091 * cos(1.53880932897 + 6924.1972748571*$t);
  $Y2 += 0.00000000083 * cos(2.41910116753 + 31415.6230674405*$t);
  $Y2 += 0.00000000088 * cos(0.30300511757 + 71430.45180064559*$t);
  $Y2 += 0.00000000074 * cos(3.53618023271 + 529.44714761109*$t);
  $Y2 += 0.00000000085 * cos(4.40773297118 + 95143.37673846159*$t);
  $Y2 += 0.00000000061 * cos(2.66034748981 + 8274.0646845159*$t);
  $Y2 += 0.00000000060 * cos(3.95075537336 + 16496.6052136859*$t);
  $Y2 += 0.00000000058 * cos(3.04970743906 + 5642.93474619389*$t);
  $Y2 += 0.00000000078 * cos(0.84061745785 + 213.5429129215*$t);
  $Y2 += 0.00000000059 * cos(3.10446906052 + 640.1411037975*$t);
  $Y2 += 0.00000000057 * cos(3.63209087311 + 4690.23601887509*$t);
  $Y2 += 0.00000000056 * cos(2.23091315346 + 13341.9181287903*$t);
  $Y2 += 0.00000000065 * cos(4.95952410600 + 4731.7868098599*$t);
  $Y2 += 0.00000000051 * cos(0.09929724563 + 3893.93801205869*$t);
  $Y2 += 0.00000000050 * cos(2.60290043400 + 12573.5090644671*$t);
  $Y2 += 0.00000000050 * cos(5.98749446465 + 3634.37720703489*$t);
  $Y2 += 0.00000000049 * cos(0.70632876133 + 18319.7804023631*$t);
  $Y2 += 0.00000000066 * cos(3.92505951821 + 2787.2868413409*$t);
  $Y2 += 0.00000000049 * cos(0.42825389697 + 13362.6935242827*$t);
  $Y2 += 0.00000000048 * cos(2.19153498916 + 12964.5445208745*$t);
  $Y2 += 0.00000000053 * cos(2.55294637714 + 14919.2616712381*$t);
  $Y2 += 0.00000000058 * cos(5.94322042199 + 1577.5873599313*$t);
  $Y2 += 0.00000000052 * cos(5.99067773035 + 15721.0826023619*$t);
  $Y2 += 0.00000000061 * cos(4.99956015956 + 4292.0870154669*$t);
  $Y2 += 0.00000000044 * cos(5.02285128905 + 24073.1652872599*$t);
  $Y2 += 0.00000000044 * cos(1.96034093811 + 10447.14402212089*$t);
  $Y2 += 0.00000000042 * cos(2.52906622396 + 20426.8149099055*$t);
  $Y2 += 0.00000000059 * cos(2.58678833053 + 84672.23202702119*$t);
  $Y2 += 0.00000000051 * cos(3.81200106179 + 6370.62787201471*$t);
  $Y2 += 0.00000000051 * cos(5.97812516445 + 6196.0114629351*$t);
  $Y2 += 0.00000000046 * cos(5.23410298912 + 2119.00767786191*$t);
  $Y2 += 0.00000000041 * cos(2.52248241350 + 3185.43584474911*$t);
  $Y2 += 0.00000000056 * cos(4.84268946755 + 10976.83498721549*$t);
  $Y2 += 0.00000000051 * cos(3.94604483748 + 9437.5191174035*$t);
  $Y2 += 0.00000000049 * cos(1.64079935270 + 239424.63407183639*$t);
  $Y2 += 0.00000000036 * cos(1.49154565635 + 3495.78900865049*$t);
  $Y2 += 0.00000000044 * cos(2.12316916648 + 18139.5383188994*$t);
  $Y2 += 0.00000000035 * cos(5.18466509768 + 3929.96587873609*$t);
  $Y2 += 0.00000000044 * cos(3.23094444076 + 8661.9965060795*$t);
  $Y2 += 0.00000000046 * cos(2.21535532938 + 3894.4256470257*$t);
  $Y2 += 0.00000000034 * cos(2.24364878116 + 6262.5442719825*$t);
  $Y2 += 0.00000000034 * cos(4.40970135798 + 6304.0950629673*$t);
  $Y2 += 0.00000000035 * cos(5.15488505358 + 18875.2820522905*$t);
  $Y2 += 0.00000000035 * cos(4.51996316476 + 10420.23010099111*$t);
  $Y2 += 0.00000000032 * cos(5.33774590597 + 23013.7833570707*$t);
  $Y2 += 0.00000000034 * cos(2.04067717162 + 7.3573644843*$t);
  $Y2 += 0.00000000045 * cos(6.20022544523 + 3340.8562441833*$t);
  $Y2 += 0.00000000035 * cos(1.95669709650 + 10213.0417287275*$t);
  $Y2 += 0.00000000031 * cos(3.81393239996 + 14712.5609339415*$t);
  $Y2 += 0.00000000030 * cos(2.82636067861 + 12809.12412144031*$t);
  $Y2 += 0.00000000039 * cos(5.86021469295 + 9779.3524936089*$t);
  $Y2 += 0.00000000041 * cos(0.90085517811 + 82576.73740351178*$t);
  $Y2 += 0.00000000031 * cos(5.47911308336 + 22779.6810636773*$t);
  $Y2 += 0.00000000028 * cos(2.50895957020 + 2942.7072407751*$t);
  $Y2 += 0.00000000028 * cos(3.93140481871 + 5429.63565075589*$t);
  $Y2 += 0.00000000027 * cos(5.61355223000 + 11014.8626598513*$t);
  $Y2 += 0.00000000027 * cos(0.53944014317 + 9623.9320941747*$t);
  $Y2 += 0.00000000025 * cos(0.15499921281 + 18209.5740811437*$t);
  $Y2 += 0.00000000026 * cos(0.97984555070 + 9381.2034902007*$t);
  $Y2 += 0.00000000025 * cos(1.11733310909 + 3583.5848481573*$t);
  $Y2 += 0.00000000030 * cos(4.41826131323 + 10447.6316570879*$t);
  $Y2 += 0.00000000032 * cos(5.65959938774 + 796.0541893329*$t);
  $Y2 += 0.00000000023 * cos(1.38575591729 + 9917.45305702629*$t);
  $Y2 += 0.00000000026 * cos(5.61732376806 + 12012.8261146239*$t);
  $Y2 += 0.00000000024 * cos(3.45407340381 + 14143.2514249471*$t);
  $Y2 += 0.00000000023 * cos(0.69647593831 + 26709.8907598969*$t);
  $Y2 += 0.00000000021 * cos(5.43974830479 + 7632.6994421667*$t);
  $Y2 += 0.00000000021 * cos(0.80058820514 + 17256.8753538249*$t);
  $Y2 += 0.00000000028 * cos(5.78689433830 + 12353.0964220283*$t);
  $Y2 += 0.00000000022 * cos(3.26384247748 + 77714.01528560399*$t);
  $Y2 += 0.00000000021 * cos(4.41664687493 + 6993.2527160332*$t);
  $Y2 += 0.00000000020 * cos(1.88345295944 + 6836.40143535029*$t);
  $Y2 += 0.00000000020 * cos(3.87252932348 + 1748.2602305505*$t);
  $Y2 += 0.00000000026 * cos(0.45595739946 + 9225.7830907665*$t);
  $Y2 += 0.00000000023 * cos(5.52071600644 + 149854.64395229139*$t);
  $Y2 += 0.00000000026 * cos(0.60119736394 + 2544.07060239989*$t);
  $Y2 += 0.00000000018 * cos(0.71176167314 + 11614.6771112157*$t);
  $Y2 += 0.00000000020 * cos(3.04333652471 + 426.8420083595*$t);
  $Y2 += 0.00000000019 * cos(2.09021029647 + 30640.1004561165*$t);
  $Y2 += 0.00000000018 * cos(3.20715016441 + 155.6642169177*$t);
  $Y2 += 0.00000000018 * cos(0.32502884515 + 11926.4982311523*$t);
  $Y2 += 0.00000000022 * cos(2.17863705978 + 17298.4261448097*$t);
  $Y2 += 0.00000000019 * cos(4.82590950931 + 18073.46112116669*$t);
  $Y2 += 0.00000000020 * cos(1.02950628439 + 19651.2922985815*$t);
  $Y2 += 0.00000000024 * cos(3.14467908991 + 5856.23384163189*$t);
  $Y2 += 0.00000000023 * cos(3.21288696705 + 72850.80553272919*$t);
  $Y2 += 0.00000000017 * cos(2.38623798159 + 8983.0544867925*$t);
  $Y2 += 0.00000000016 * cos(3.59989563011 + 16460.5773470085*$t);
  $Y2 += 0.00000000016 * cos(2.77179277240 + 17259.91083720689*$t);
  $Y2 += 0.00000000021 * cos(2.20286926080 + 16858.7263504167*$t);
  $Y2 += 0.00000000020 * cos(5.10666464640 + 23543.4743221653*$t);
  $Y2 += 0.00000000021 * cos(5.36525328799 + 13367.7288136231*$t);
  $Y2 += 0.00000000020 * cos(2.47582665567 + 2146.4092339587*$t);
  $Y2 += 0.00000000014 * cos(4.85508264889 + 22484.0923919761*$t);
  $Y2 += 0.00000000014 * cos(6.23679853613 + 16200.52890701769*$t);
  $Y2 += 0.00000000015 * cos(2.64768344463 + 20199.3387771165*$t);
  $Y2 += 0.00000000019 * cos(1.24340851761 + 8672.21368792411*$t);
  $Y2 += 0.00000000019 * cos(2.89835524904 + 18073.9487561337*$t);
  $Y2 += 0.00000000013 * cos(3.14350306699 + 16201.0165419847*$t);
  $Y2 += 0.00000000017 * cos(2.96004801328 + 7860.17557495569*$t);
  $Y2 += 0.00000000013 * cos(3.12347768998 + 18451.3223640495*$t);
  $Y2 += 0.00000000016 * cos(4.90276494200 + 5572.8989839496*$t);
  $Y2 += 0.00000000012 * cos(1.13909733386 + 17996.2749857057*$t);
  $Y2 += 0.00000000012 * cos(5.43460350187 + 19403.0407703001*$t);
  $Y2 += 0.00000000012 * cos(0.82655936469 + 14945.0723560709*$t);
  $Y2 += 0.00000000015 * cos(0.47799392266 + 12559.2819704655*$t);
  $Y2 += 0.00000000012 * cos(2.80799572996 + 10818.3791043993*$t);
  $Y2 += 0.00000000015 * cos(5.28864619208 + 12567.37583853451*$t);
  $Y2 += 0.00000000011 * cos(0.21391675163 + 28767.1682419675*$t);
  $Y2 += 0.00000000013 * cos(5.80786469706 + 90280.16698558679*$t);
  $Y2 += 0.00000000011 * cos(0.30991526634 + 22805.4917485101*$t);
  $Y2 += 0.00000000011 * cos(0.67526353010 + 35372.1310834599*$t);
  $Y2 += 0.00000000010 * cos(1.54770241799 + 11506.52595231009*$t);
  $Y2 += 0.00000000014 * cos(0.36722951229 + 21228.63584102931*$t);
  $Y2 += 0.00000000010 * cos(4.84303300061 + 12779.6946129043*$t);
  $Y2 += 0.00000000010 * cos(4.48229440272 + 23141.8022004081*$t);
  $Y2 += 0.00000000010 * cos(5.89241784221 + 1350.1112271423*$t);
  $Y2 += 0.00000000010 * cos(4.07842068364 + 10575.1628654583*$t);
  $Y2 += 0.00000000010 * cos(0.98564127078 + 22345.5041935917*$t);
  $Y2 += 0.00000000010 * cos(0.62034181586 + 9778.8648586419*$t);
  $Y2 += 0.00000000009 * cos(6.20390809264 + 29826.5501721567*$t);
  $Y2 += 0.00000000010 * cos(2.66921279687 + 23581.5019948011*$t);
  $Y2 += 0.00000000011 * cos(5.10849785178 + 25158.8455372489*$t);
  return $Y2*$t*$t;
}



  function Earth_C_Y3 ($t)
{
  $Y3 =  0.0;
  $Y3 += 0.00000232790 * cos(1.83555296287 + 0.2438174835*$t);
  $Y3 += 0.00000076843 * cos(0.95359770708 + 12566.3955174663*$t);
  $Y3 += 0.00000035331 * cos(1.77537067174 + 6283.3196674749*$t);
  $Y3 += 0.00000005282 * cos(0.83410185910 + 18849.4713674577*$t);
  $Y3 += 0.00000001631 * cos(0.72620862558 + 6282.83203250789*$t);
  $Y3 += 0.00000001483 * cos(0.65599216587 + 6438.7400669091*$t);
  $Y3 += 0.00000001479 * cos(2.83072127404 + 6127.8992680407*$t);
  $Y3 += 0.00000000652 * cos(3.13796451313 + 6279.7965491259*$t);
  $Y3 += 0.00000000656 * cos(0.01615422945 + 6286.84278582391*$t);
  $Y3 += 0.00000000317 * cos(1.43157695840 + 6526.04827144891*$t);
  $Y3 += 0.00000000318 * cos(2.05944515679 + 6040.5910635009*$t);
  $Y3 += 0.00000000227 * cos(0.70881980797 + 25132.5472174491*$t);
  $Y3 += 0.00000000201 * cos(5.52615570373 + 6836.8890703173*$t);
  $Y3 += 0.00000000201 * cos(4.23563267830 + 5729.7502646325*$t);
  $Y3 += 0.00000000036 * cos(6.05003898151 + 12569.91863581531*$t);
  $Y3 += 0.00000000034 * cos(0.36912822345 + 4705.9761250271*$t);
  $Y3 += 0.00000000033 * cos(2.65665718326 + 12410.9751180321*$t);
  $Y3 += 0.00000000032 * cos(3.81269087187 + 6257.0213476751*$t);
  $Y3 += 0.00000000032 * cos(2.84133186500 + 6309.61798727471*$t);
  $Y3 += 0.00000000026 * cos(5.21573736647 + 775.7664288075*$t);
  $Y3 += 0.00000000023 * cos(0.44696909593 + 1059.6257476727*$t);
  $Y3 += 0.00000000025 * cos(0.01326357360 + 7860.6632099227*$t);
  $Y3 += 0.00000000027 * cos(0.46730161827 + 12565.9078824993*$t);
  $Y3 += 0.00000000020 * cos(2.19213288615 + 5753.6287023803*$t);
  $Y3 += 0.00000000019 * cos(1.44435756454 + 5885.1706640667*$t);
  $Y3 += 0.00000000019 * cos(4.47976718197 + 6813.0106325695*$t);
  $Y3 += 0.00000000018 * cos(0.72211012099 + 12721.8159169005*$t);
  $Y3 += 0.00000000017 * cos(5.20474716177 + 6681.46867088311*$t);
  $Y3 += 0.00000000013 * cos(2.92478174105 + 5487.0216606585*$t);
  $Y3 += 0.00000000011 * cos(3.72062261949 + 7079.61767429131*$t);
  $Y3 += 0.00000000010 * cos(2.89167021825 + 5507.7970561509*$t);
  $Y3 += 0.00000000010 * cos(1.46762801985 + 11790.8729061423*$t);
  $Y3 += 0.00000000009 * cos(6.21784065295 + 11507.0135872771*$t);
  $Y3 += 0.00000000011 * cos(4.68801103302 + 12592.6938372661*$t);
  $Y3 += 0.00000000009 * cos(3.82179163254 + 7058.8422787989*$t);
  $Y3 += 0.00000000008 * cos(5.97770881958 + 6290.4332144757*$t);
  $Y3 += 0.00000000008 * cos(0.68313431813 + 6276.2061204741*$t);
  $Y3 += 0.00000000008 * cos(1.45990791265 + 796.5418242999*$t);
  $Y3 += 0.00000000007 * cos(4.15465801739 + 4693.75913722409*$t);
  $Y3 += 0.00000000007 * cos(0.35078036011 + 7.3573644843*$t);
  $Y3 += 0.00000000005 * cos(3.29483739022 + 3739.0052475915*$t);
  $Y3 += 0.00000000005 * cos(4.64160679165 + 6070.0205720369*$t);
  $Y3 += 0.00000000006 * cos(2.38483297622 + 6284.2999885431*$t);
  $Y3 += 0.00000000006 * cos(4.26851560652 + 6282.3393464067*$t);
  $Y3 += 0.00000000005 * cos(1.89668032657 + 4137.1542509997*$t);
  $Y3 += 0.00000000005 * cos(2.01213704309 + 6496.6187629129*$t);
  return $Y3*$t*$t*$t;
}



  function Earth_C_Y4 ($t)
{
  $Y4 =  0.0;
  $Y4 += 0.00000114918 * cos(4.77291921544 + 6283.3196674749*$t);
  $Y4 += 0.00000006817 * cos(2.90545031303 + 0.2438174835*$t);
  $Y4 += 0.00000003158 * cos(5.19149443854 + 12566.3955174663*$t);
  $Y4 += 0.00000000211 * cos(2.15272014034 + 6438.7400669091*$t);
  $Y4 += 0.00000000210 * cos(1.31410288968 + 6127.8992680407*$t);
  $Y4 += 0.00000000253 * cos(5.35904773722 + 18849.4713674577*$t);
  $Y4 += 0.00000000073 * cos(5.49456429263 + 6282.83203250789*$t);
  $Y4 += 0.00000000042 * cos(3.03243163257 + 710.1768660418*$t);
  $Y4 += 0.00000000023 * cos(4.47433896564 + 6279.7965491259*$t);
  $Y4 += 0.00000000022 * cos(4.47061131203 + 6286.84278582391*$t);
  $Y4 += 0.00000000012 * cos(5.22878976906 + 25132.5472174491*$t);
  $Y4 += 0.00000000009 * cos(2.63928422881 + 83997.09113559539*$t);
  $Y4 += 0.00000000009 * cos(3.62312855703 + 11856.462468908*$t);
  $Y4 += 0.00000000008 * cos(4.59507616558 + 167284.00540514899*$t);
  $Y4 += 0.00000000005 * cos(4.40834364231 + 6257.0213476751*$t);
  $Y4 += 0.00000000005 * cos(2.21798830782 + 6309.61798727471*$t);
  $Y4 += 0.00000000005 * cos(1.11835906029 + 12410.9751180321*$t);
  $Y4 += 0.00000000005 * cos(3.99770824807 + 156137.71980228279*$t);
  $Y4 += 0.00000000004 * cos(4.97197978751 + 12565.9078824993*$t);
  $Y4 += 0.00000000003 * cos(3.60141861387 + 529.9347825781*$t);
  return $Y4*$t*$t*$t*$t;
}



  function Earth_C_Y5 ($t)
{
  $Y5 =  0.0;
  $Y5 += 0.00000000877 * cos(4.87375194107 + 6283.3196674749*$t);
  $Y5 += 0.00000000305 * cos(4.05893642248 + 0.2438174835*$t);
  $Y5 += 0.00000000101 * cos(3.30997066470 + 12566.3955174663*$t);
  $Y5 += 0.00000000025 * cos(3.73514325706 + 6438.7400669091*$t);
  $Y5 += 0.00000000025 * cos(5.99118011879 + 6127.8992680407*$t);
  $Y5 += 0.00000000010 * cos(3.54319653898 + 18849.4713674577*$t);
  $Y5 += 0.00000000003 * cos(4.13285368647 + 6282.83203250789*$t);
  return $Y5*$t*$t*$t*$t*$t;
}



  function Earth_C_Z0 ($t)
{
  $Z0 =  0.0;
  $Z0 += 0.00000279620 * cos(3.19870156017 + 84334.66158130829*$t);
  $Z0 += 0.00000101625 * cos(5.42248110597 + 5507.5532386674*$t);
  $Z0 += 0.00000080461 * cos(3.88027157914 + 5223.6939198022*$t);
  $Z0 += 0.00000043855 * cos(3.70430347723 + 2352.8661537718*$t);
  $Z0 += 0.00000031853 * cos(3.99997840986 + 1577.3435424478*$t);
  $Z0 += 0.00000022724 * cos(3.98473831560 + 1047.7473117547*$t);
  $Z0 += 0.00000016395 * cos(3.56456162523 + 5856.4776591154*$t);
  $Z0 += 0.00000018150 * cos(4.98479613321 + 6283.0758499914*$t);
  $Z0 += 0.00000014477 * cos(3.70258423465 + 9437.762934887*$t);
  $Z0 += 0.00000014325 * cos(3.41020246931 + 10213.285546211*$t);
  $Z0 += 0.00000011204 * cos(4.83021499098 + 14143.4952424306*$t);
  $Z0 += 0.00000010896 * cos(2.08023708321 + 6812.766815086*$t);
  $Z0 += 0.00000009716 * cos(3.47560205064 + 4694.0029547076*$t);
  $Z0 += 0.00000010363 * cos(4.05663928093 + 71092.88135493269*$t);
  $Z0 += 0.00000008792 * cos(4.44890729280 + 5753.3848848968*$t);
  $Z0 += 0.00000008337 * cos(4.99167706048 + 7084.8967811152*$t);
  $Z0 += 0.00000006921 * cos(4.32559054073 + 6275.9623029906*$t);
  $Z0 += 0.00000009145 * cos(1.14182646613 + 6620.8901131878*$t);
  $Z0 += 0.00000007205 * cos(3.62441599378 + 529.6909650946*$t);
  $Z0 += 0.00000007698 * cos(5.55425745881 + 167621.57585086189*$t);
  $Z0 += 0.00000005186 * cos(6.25384533126 + 18073.7049386502*$t);
  $Z0 += 0.00000005027 * cos(2.49727910749 + 4705.7323075436*$t);
  $Z0 += 0.00000004529 * cos(2.33827747356 + 6309.3741697912*$t);
  $Z0 += 0.00000004754 * cos(0.71100829534 + 5884.9268465832*$t);
  $Z0 += 0.00000004292 * cos(1.10034019036 + 6681.2248533996*$t);
  $Z0 += 0.00000003855 * cos(1.82331477760 + 5486.777843175*$t);
  $Z0 += 0.00000005256 * cos(4.42445744523 + 7860.4193924392*$t);
  $Z0 += 0.00000004025 * cos(5.11990285618 + 13367.9726311066*$t);
  $Z0 += 0.00000004061 * cos(6.02923989849 + 3930.2096962196*$t);
  $Z0 += 0.00000003798 * cos(0.44370219832 + 3154.6870848956*$t);
  $Z0 += 0.00000002933 * cos(5.12428135363 + 1059.3819301892*$t);
  $Z0 += 0.00000003424 * cos(5.42065191700 + 6069.7767545534*$t);
  $Z0 += 0.00000003670 * cos(4.58210192227 + 12194.0329146209*$t);
  $Z0 += 0.00000002912 * cos(1.92688087702 + 10977.078804699*$t);
  $Z0 += 0.00000002506 * cos(0.60484952637 + 6496.3749454294*$t);
  $Z0 += 0.00000002680 * cos(1.39497359287 + 22003.9146348698*$t);
  $Z0 += 0.00000002120 * cos(4.30691000285 + 5643.1785636774*$t);
  $Z0 += 0.00000002235 * cos(0.81363184041 + 8635.9420037632*$t);
  $Z0 += 0.00000001819 * cos(3.75748003107 + 3340.6124266998*$t);
  $Z0 += 0.00000002230 * cos(2.76407822446 + 12036.4607348882*$t);
  $Z0 += 0.00000001945 * cos(5.69949789177 + 11790.6290886588*$t);
  $Z0 += 0.00000001529 * cos(1.98639348122 + 398.1490034082*$t);
  $Z0 += 0.00000001581 * cos(3.19976230948 + 5088.6288397668*$t);
  $Z0 += 0.00000001424 * cos(6.26116472313 + 2544.3144198834*$t);
  $Z0 += 0.00000001405 * cos(4.69394873481 + 7058.5984613154*$t);
  $Z0 += 0.00000001588 * cos(0.25704624784 + 17298.1823273262*$t);
  $Z0 += 0.00000001478 * cos(2.81808207569 + 25934.1243310894*$t);
  $Z0 += 0.00000001693 * cos(4.95689385293 + 156475.2902479957*$t);
  $Z0 += 0.00000001123 * cos(2.38605285936 + 3738.761430108*$t);
  $Z0 += 0.00000000990 * cos(4.29600699156 + 9225.539273283*$t);
  $Z0 += 0.00000000923 * cos(3.07195736431 + 4164.311989613*$t);
  $Z0 += 0.00000000863 * cos(0.55119493097 + 8429.2412664666*$t);
  $Z0 += 0.00000000984 * cos(5.96784225392 + 7079.3738568078*$t);
  $Z0 += 0.00000001086 * cos(3.14159265359);
  $Z0 += 0.00000000824 * cos(1.50050055147 + 10447.3878396044*$t);
  $Z0 += 0.00000000829 * cos(3.51336978167 + 11506.7697697936*$t);
  $Z0 += 0.00000000908 * cos(0.12102885474 + 11015.1064773348*$t);
  $Z0 += 0.00000000742 * cos(1.99159139281 + 26087.9031415742*$t);
  $Z0 += 0.00000000850 * cos(4.24120016095 + 29864.334027309*$t);
  $Z0 += 0.00000000762 * cos(2.90028034892 + 4732.0306273434*$t);
  $Z0 += 0.00000000711 * cos(1.38596151724 + 2146.1654164752*$t);
  $Z0 += 0.00000000766 * cos(0.61397570576 + 796.2980068164*$t);
  $Z0 += 0.00000000708 * cos(1.91406542362 + 8031.0922630584*$t);
  $Z0 += 0.00000000810 * cos(5.13961498599 + 2942.4634232916*$t);
  $Z0 += 0.00000000751 * cos(1.67479850166 + 21228.3920235458*$t);
  $Z0 += 0.00000000589 * cos(2.02193316047 + 775.522611324*$t);
  $Z0 += 0.00000000513 * cos(2.60734651128 + 12566.1516999828*$t);
  $Z0 += 0.00000000550 * cos(1.61119298963 + 801.8209311238*$t);
  $Z0 += 0.00000000592 * cos(4.59481504319 + 4690.4798363586*$t);
  $Z0 += 0.00000000519 * cos(5.72925039114 + 8827.3902698748*$t);
  $Z0 += 0.00000000515 * cos(4.09976487552 + 64809.80550494129*$t);
  $Z0 += 0.00000000503 * cos(5.66433137112 + 33794.5437235286*$t);
  $Z0 += 0.00000000476 * cos(3.69640472448 + 213.299095438*$t);
  $Z0 += 0.00000000463 * cos(1.24987240483 + 15720.8387848784*$t);
  $Z0 += 0.00000000411 * cos(0.10769444525 + 3128.3887650958*$t);
  $Z0 += 0.00000000504 * cos(3.26207669160 + 7632.9432596502*$t);
  $Z0 += 0.00000000552 * cos(1.02926440457 + 239762.20451754928*$t);
  $Z0 += 0.00000000394 * cos(5.81496021156 + 426.598190876*$t);
  $Z0 += 0.00000000476 * cos(3.52810472421 + 16496.3613962024*$t);
  $Z0 += 0.00000000503 * cos(4.85802444134 + 6290.1893969922*$t);
  $Z0 += 0.00000000417 * cos(0.81920713533 + 5216.5803728014*$t);
  $Z0 += 0.00000000363 * cos(5.70015720452 + 1589.0728952838*$t);
  $Z0 += 0.00000000363 * cos(1.28376436579 + 6206.8097787158*$t);
  $Z0 += 0.00000000353 * cos(4.70059133110 + 7234.794256242*$t);
  $Z0 += 0.00000000381 * cos(2.61890749829 + 7342.4577801806*$t);
  $Z0 += 0.00000000420 * cos(0.97821135132 + 4136.9104335162*$t);
  $Z0 += 0.00000000335 * cos(6.22057967320 + 12168.0026965746*$t);
  $Z0 += 0.00000000387 * cos(3.09145061418 + 25158.6017197654*$t);
  $Z0 += 0.00000000349 * cos(2.94840720073 + 9623.6882766912*$t);
  $Z0 += 0.00000000418 * cos(3.75759994446 + 5230.807466803*$t);
  $Z0 += 0.00000000396 * cos(1.22507712354 + 6438.4962494256*$t);
  $Z0 += 0.00000000322 * cos(1.21162178805 + 8662.240323563*$t);
  $Z0 += 0.00000000323 * cos(5.50254808471 + 1194.4470102246*$t);
  $Z0 += 0.00000000372 * cos(1.72256107938 + 14945.3161735544*$t);
  $Z0 += 0.00000000305 * cos(0.80429352049 + 37724.7534197482*$t);
  $Z0 += 0.00000000265 * cos(6.10358507671 + 6836.6452528338*$t);
  $Z0 += 0.00000000250 * cos(4.56452895547 + 7477.522860216*$t);
  $Z0 += 0.00000000266 * cos(2.62926282354 + 7238.6755916*$t);
  $Z0 += 0.00000000262 * cos(1.34297269105 + 11769.8536931664*$t);
  $Z0 += 0.00000000263 * cos(6.22089501237 + 6133.5126528568*$t);
  $Z0 += 0.00000000302 * cos(2.81139045072 + 1748.016413067*$t);
  $Z0 += 0.00000000316 * cos(1.62662805006 + 250908.49012041549*$t);
  $Z0 += 0.00000000226 * cos(2.42346415873 + 11371.7046897582*$t);
  $Z0 += 0.00000000216 * cos(3.68721275185 + 5849.3641121146*$t);
  $Z0 += 0.00000000276 * cos(2.33399767923 + 19651.048481098*$t);
  $Z0 += 0.00000000230 * cos(0.36165162947 + 5863.5912061162*$t);
  $Z0 += 0.00000000200 * cos(5.86073159059 + 4535.0594369244*$t);
  $Z0 += 0.00000000277 * cos(4.65400292395 + 82239.16695779889*$t);
  $Z0 += 0.00000000199 * cos(5.05186622555 + 5429.8794682394*$t);
  $Z0 += 0.00000000206 * cos(3.70556027982 + 10973.55568635*$t);
  $Z0 += 0.00000000210 * cos(4.50691909144 + 29088.811415985*$t);
  $Z0 += 0.00000000181 * cos(6.00294783127 + 4292.3308329504*$t);
  $Z0 += 0.00000000249 * cos(0.12900984422 + 154379.79562448629*$t);
  $Z0 += 0.00000000167 * cos(6.27348370813 + 10988.808157535*$t);
  $Z0 += 0.00000000183 * cos(3.19836584401 + 16730.4636895958*$t);
  $Z0 += 0.00000000225 * cos(3.18339652605 + 18875.525869774*$t);
  $Z0 += 0.00000000192 * cos(0.87192032514 + 77375.95720492408*$t);
  $Z0 += 0.00000000188 * cos(2.22746128596 + 41654.9631159678*$t);
  $Z0 += 0.00000000160 * cos(5.20207795189 + 5481.2549188676*$t);
  $Z0 += 0.00000000192 * cos(3.89678943865 + 17789.845619785*$t);
  $Z0 += 0.00000000159 * cos(5.32590846475 + 7.1135470008*$t);
  $Z0 += 0.00000000214 * cos(4.08171403539 + 337.8142631964*$t);
  $Z0 += 0.00000000184 * cos(3.75465072369 + 23581.2581773176*$t);
  $Z0 += 0.00000000160 * cos(4.53897529970 + 18477.1087646123*$t);
  $Z0 += 0.00000000144 * cos(5.19486374726 + 20426.571092422*$t);
  $Z0 += 0.00000000126 * cos(1.69446958184 + 15110.4661198662*$t);
  $Z0 += 0.00000000149 * cos(1.55306832217 + 10021.8372800994*$t);
  $Z0 += 0.00000000127 * cos(5.31068233515 + 639.897286314*$t);
  $Z0 += 0.00000000118 * cos(2.73268114062 + 18849.2275499742*$t);
  $Z0 += 0.00000000123 * cos(2.55361087146 + 12592.4500197826*$t);
  $Z0 += 0.00000000113 * cos(6.07178776726 + 6709.6740408674*$t);
  $Z0 += 0.00000000130 * cos(3.94161517411 + 7330.8231617461*$t);
  $Z0 += 0.00000000110 * cos(3.51203379263 + 18052.9295431578*$t);
  $Z0 += 0.00000000147 * cos(4.63371971408 + 22805.7355659936*$t);
  $Z0 += 0.00000000113 * cos(1.20711498905 + 14919.0178537546*$t);
  $Z0 += 0.00000000108 * cos(3.76359880753 + 14314.1681130498*$t);
  $Z0 += 0.00000000148 * cos(0.65447253687 + 95480.9471841745*$t);
  $Z0 += 0.00000000121 * cos(3.13748782783 + 14712.317116458*$t);
  $Z0 += 0.00000000119 * cos(5.92110458985 + 33019.0211122046*$t);
  $Z0 += 0.00000000124 * cos(2.93638421840 + 32217.2001810808*$t);
  $Z0 += 0.00000000117 * cos(3.65065271640 + 45585.1728121874*$t);
  $Z0 += 0.00000000127 * cos(4.74596574209 + 49515.382508407*$t);
  $Z0 += 0.00000000120 * cos(1.04211499785 + 6915.8595893046*$t);
  $Z0 += 0.00000000120 * cos(5.60638811846 + 5650.2921106782*$t);
  $Z0 += 0.00000000127 * cos(2.70766997307 + 12352.8526045448*$t);
  $Z0 += 0.00000000113 * cos(5.39691616452 + 5235.3285382367*$t);
  $Z0 += 0.00000000097 * cos(1.07908724794 + 9917.6968745098*$t);
  $Z0 += 0.00000000123 * cos(5.15992792934 + 27511.4678735372*$t);
  $Z0 += 0.00000000099 * cos(4.45774681732 + 4933.2084403326*$t);
  $Z0 += 0.00000000087 * cos(3.93637812950 + 17654.7805397496*$t);
  $Z0 += 0.00000000122 * cos(2.23956068680 + 83997.09113559539*$t);
  $Z0 += 0.00000000102 * cos(3.97386522171 + 10818.1352869158*$t);
  $Z0 += 0.00000000084 * cos(4.21241958885 + 22779.4372461938*$t);
  $Z0 += 0.00000000103 * cos(4.63519841733 + 1349.8674096588*$t);
  $Z0 += 0.00000000081 * cos(4.01655240430 + 1592.5960136328*$t);
  $Z0 += 0.00000000092 * cos(3.24182657569 + 78051.5857313169*$t);
  $Z0 += 0.00000000094 * cos(4.33873972800 + 36147.4098773004*$t);
  $Z0 += 0.00000000076 * cos(2.83897554420 + 17260.1546546904*$t);
  $Z0 += 0.00000000100 * cos(6.07733097102 + 26735.9452622132*$t);
  $Z0 += 0.00000000078 * cos(0.72462427283 + 12779.4507954208*$t);
  $Z0 += 0.00000000086 * cos(5.26029638250 + 28313.288804661*$t);
  $Z0 += 0.00000000093 * cos(4.31900620254 + 44809.6502008634*$t);
  $Z0 += 0.00000000076 * cos(6.22743405935 + 13521.7514415914*$t);
  $Z0 += 0.00000000081 * cos(2.16420552322 + 13095.8426650774*$t);
  $Z0 += 0.00000000100 * cos(1.38002787119 + 28286.9904848612*$t);
  $Z0 += 0.00000000072 * cos(1.55820597747 + 6256.7775301916*$t);
  $Z0 += 0.00000000082 * cos(4.95202664555 + 10575.4066829418*$t);
  $Z0 += 0.00000000082 * cos(1.69647647075 + 1990.745017041*$t);
  $Z0 += 0.00000000096 * cos(6.16038106485 + 24356.7807886416*$t);
  $Z0 += 0.00000000075 * cos(2.29836095644 + 3634.6210245184*$t);
  $Z0 += 0.00000000075 * cos(2.66367876557 + 16200.7727245012*$t);
  $Z0 += 0.00000000087 * cos(0.26630214764 + 31441.6775697568*$t);
  $Z0 += 0.00000000080 * cos(5.00001604436 + 150192.21439800429*$t);
  $Z0 += 0.00000000079 * cos(0.01398391548 + 90617.7374312997*$t);
  $Z0 += 0.00000000054 * cos(5.59738773448 + 161338.5000008705*$t);
  $Z0 += 0.00000000056 * cos(2.60133794851 + 73188.3759784421*$t);
  $Z0 += 0.00000000055 * cos(5.81483150022 + 143233.51002162008*$t);
  $Z0 += 0.00000000054 * cos(3.38482031504 + 323049.11878710288*$t);
  return $Z0;
}



  function Earth_C_Z1 ($t)
{
  $Z1 =  0.0;
  $Z1 += 0.00000009031 * cos(3.89751156799 + 5507.5532386674*$t);
  $Z1 += 0.00000006179 * cos(1.73051337995 + 5223.6939198022*$t);
  $Z1 += 0.00000003793 * cos(5.24575814515 + 2352.8661537718*$t);
  $Z1 += 0.00000002840 * cos(2.47694599818 + 1577.3435424478*$t);
  $Z1 += 0.00000001817 * cos(0.41874743765 + 6283.0758499914*$t);
  $Z1 += 0.00000001499 * cos(1.83320979291 + 5856.4776591154*$t);
  $Z1 += 0.00000001463 * cos(5.68891324948 + 5753.3848848968*$t);
  $Z1 += 0.00000001302 * cos(2.18800611215 + 9437.762934887*$t);
  $Z1 += 0.00000001239 * cos(4.95327097854 + 10213.285546211*$t);
  $Z1 += 0.00000001029 * cos(0.09367831611 + 7860.4193924392*$t);
  $Z1 += 0.00000000975 * cos(0.08833256880 + 14143.4952424306*$t);
  $Z1 += 0.00000000851 * cos(1.79547916132 + 3930.2096962196*$t);
  $Z1 += 0.00000000581 * cos(2.26949174067 + 5884.9268465832*$t);
  $Z1 += 0.00000000515 * cos(5.64196681593 + 529.6909650946*$t);
  $Z1 += 0.00000000473 * cos(6.22750969242 + 6309.3741697912*$t);
  $Z1 += 0.00000000449 * cos(1.52767374606 + 18073.7049386502*$t);
  $Z1 += 0.00000000360 * cos(3.62344325932 + 13367.9726311066*$t);
  $Z1 += 0.00000000372 * cos(3.22470721320 + 6275.9623029906*$t);
  $Z1 += 0.00000000260 * cos(1.87645933242 + 11790.6290886588*$t);
  $Z1 += 0.00000000322 * cos(0.94084045832 + 6069.7767545534*$t);
  $Z1 += 0.00000000232 * cos(0.27531852596 + 7058.5984613154*$t);
  $Z1 += 0.00000000217 * cos(6.03652873142 + 10977.078804699*$t);
  $Z1 += 0.00000000232 * cos(2.93325646109 + 22003.9146348698*$t);
  $Z1 += 0.00000000204 * cos(3.86264841382 + 6496.3749454294*$t);
  $Z1 += 0.00000000189 * cos(2.88937704419 + 15720.8387848784*$t);
  $Z1 += 0.00000000179 * cos(4.90537280911 + 12036.4607348882*$t);
  $Z1 += 0.00000000222 * cos(3.98495366315 + 6812.766815086*$t);
  $Z1 += 0.00000000213 * cos(1.57516933652 + 4694.0029547076*$t);
  $Z1 += 0.00000000157 * cos(1.08259734788 + 5643.1785636774*$t);
  $Z1 += 0.00000000154 * cos(5.99434678412 + 5486.777843175*$t);
  $Z1 += 0.00000000137 * cos(2.67760436027 + 6290.1893969922*$t);
  $Z1 += 0.00000000179 * cos(2.05905949693 + 7084.8967811152*$t);
  $Z1 += 0.00000000121 * cos(5.90212574947 + 9225.539273283*$t);
  $Z1 += 0.00000000125 * cos(2.24111392416 + 1059.3819301892*$t);
  $Z1 += 0.00000000150 * cos(2.00175038718 + 5230.807466803*$t);
  $Z1 += 0.00000000149 * cos(5.06157254516 + 17298.1823273262*$t);
  $Z1 += 0.00000000118 * cos(5.39979058038 + 3340.6124266998*$t);
  $Z1 += 0.00000000161 * cos(3.32421999691 + 6283.3196674749*$t);
  $Z1 += 0.00000000115 * cos(5.92406672373 + 4705.7323075436*$t);
  $Z1 += 0.00000000118 * cos(4.40207874911 + 19651.048481098*$t);
  $Z1 += 0.00000000128 * cos(4.35489873365 + 25934.1243310894*$t);
  $Z1 += 0.00000000109 * cos(2.52157834166 + 6438.4962494256*$t);
  $Z1 += 0.00000000099 * cos(2.70727488041 + 5216.5803728014*$t);
  $Z1 += 0.00000000122;
  $Z1 += 0.00000000103 * cos(0.93782340879 + 8827.3902698748*$t);
  $Z1 += 0.00000000083 * cos(4.12473540351 + 8635.9420037632*$t);
  $Z1 += 0.00000000097 * cos(5.50959692365 + 29864.334027309*$t);
  $Z1 += 0.00000000073 * cos(1.73905345744 + 11506.7697697936*$t);
  $Z1 += 0.00000000083 * cos(5.69169692653 + 775.522611324*$t);
  $Z1 += 0.00000000072 * cos(0.21891639822 + 21228.3920235458*$t);
  $Z1 += 0.00000000071 * cos(2.86755026812 + 6681.2248533996*$t);
  $Z1 += 0.00000000074 * cos(2.20184828895 + 37724.7534197482*$t);
  $Z1 += 0.00000000063 * cos(4.45586625948 + 7079.3738568078*$t);
  $Z1 += 0.00000000047 * cos(2.04946724464 + 3128.3887650958*$t);
  $Z1 += 0.00000000061 * cos(0.63918772258 + 33794.5437235286*$t);
  $Z1 += 0.00000000047 * cos(3.32543843300 + 26087.9031415742*$t);
  $Z1 += 0.00000000049 * cos(1.60680905005 + 6702.5604938666*$t);
  $Z1 += 0.00000000057 * cos(0.11215813438 + 29088.811415985*$t);
  $Z1 += 0.00000000049 * cos(3.02832204050 + 20426.571092422*$t);
  $Z1 += 0.00000000041 * cos(5.55329394890 + 11015.1064773348*$t);
  $Z1 += 0.00000000041 * cos(5.91861144924 + 23581.2581773176*$t);
  $Z1 += 0.00000000045 * cos(2.00068583743 + 426.598190876*$t);
  $Z1 += 0.00000000045 * cos(4.95273290181 + 5863.5912061162*$t);
  $Z1 += 0.00000000050 * cos(3.62740835096 + 41654.9631159678*$t);
  $Z1 += 0.00000000046 * cos(1.65798680284 + 25158.6017197654*$t);
  $Z1 += 0.00000000036 * cos(5.61836577943 + 12566.1516999828*$t);
  $Z1 += 0.00000000036 * cos(6.24373396652 + 6283.14316029419*$t);
  $Z1 += 0.00000000036 * cos(0.40465162918 + 6283.0085396886*$t);
  $Z1 += 0.00000000032 * cos(6.09025731476 + 64809.80550494129*$t);
  $Z1 += 0.00000000032 * cos(6.03707103538 + 2942.4634232916*$t);
  $Z1 += 0.00000000041 * cos(4.86809570283 + 1592.5960136328*$t);
  $Z1 += 0.00000000037 * cos(1.04055368426 + 213.299095438*$t);
  $Z1 += 0.00000000031 * cos(3.62641145030 + 13095.8426650774*$t);
  $Z1 += 0.00000000028 * cos(4.38359423735 + 7632.9432596502*$t);
  $Z1 += 0.00000000030 * cos(2.03616887071 + 12139.5535091068*$t);
  $Z1 += 0.00000000028 * cos(6.03334294232 + 17789.845619785*$t);
  $Z1 += 0.00000000026 * cos(3.88971333608 + 5331.3574437408*$t);
  $Z1 += 0.00000000031 * cos(1.44666331503 + 16730.4636895958*$t);
  $Z1 += 0.00000000026 * cos(6.26376705837 + 23543.23050468179*$t);
  $Z1 += 0.00000000023 * cos(4.44388985550 + 18849.2275499742*$t);
  $Z1 += 0.00000000025 * cos(4.13395006026 + 3154.6870848956*$t);
  $Z1 += 0.00000000028 * cos(1.53862289477 + 6279.4854213396*$t);
  $Z1 += 0.00000000028 * cos(1.96831814872 + 6286.6662786432*$t);
  $Z1 += 0.00000000028 * cos(5.78094918529 + 15110.4661198662*$t);
  $Z1 += 0.00000000025 * cos(0.62040343662 + 10988.808157535*$t);
  $Z1 += 0.00000000022 * cos(6.02390113954 + 16496.3613962024*$t);
  $Z1 += 0.00000000026 * cos(2.48165809843 + 5729.506447149*$t);
  $Z1 += 0.00000000020 * cos(3.85655029499 + 9623.6882766912*$t);
  $Z1 += 0.00000000021 * cos(5.83006047147 + 7234.794256242*$t);
  $Z1 += 0.00000000021 * cos(0.69628570421 + 398.1490034082*$t);
  $Z1 += 0.00000000022 * cos(5.02222806555 + 6127.6554505572*$t);
  $Z1 += 0.00000000020 * cos(3.47611265290 + 6148.010769956*$t);
  $Z1 += 0.00000000020 * cos(0.90769829044 + 5481.2549188676*$t);
  $Z1 += 0.00000000020 * cos(0.03081589303 + 6418.1409300268*$t);
  $Z1 += 0.00000000020 * cos(3.74220084927 + 1589.0728952838*$t);
  $Z1 += 0.00000000018 * cos(1.58348238359 + 2118.7638603784*$t);
  $Z1 += 0.00000000019 * cos(0.85407021371 + 14712.317116458*$t);
  return $Z1*$t;
}



  function Earth_C_Z2 ($t)
{
  $Z2 =  0.0;
  $Z2 += 0.00000001662 * cos(1.62703209173 + 84334.66158130829*$t);
  $Z2 += 0.00000000492 * cos(2.41382223971 + 1047.7473117547*$t);
  $Z2 += 0.00000000344 * cos(2.24353004539 + 5507.5532386674*$t);
  $Z2 += 0.00000000258 * cos(6.00906896311 + 5223.6939198022*$t);
  $Z2 += 0.00000000131 * cos(0.95447345240 + 6283.0758499914*$t);
  $Z2 += 0.00000000086 * cos(1.69139956945 + 7860.4193924392*$t);
  $Z2 += 0.00000000090 * cos(0.97606804452 + 1577.3435424478*$t);
  $Z2 += 0.00000000090 * cos(0.37899871725 + 2352.8661537718*$t);
  $Z2 += 0.00000000089 * cos(6.25807507963 + 10213.285546211*$t);
  $Z2 += 0.00000000075 * cos(0.84213523741 + 167621.57585086189*$t);
  $Z2 += 0.00000000052 * cos(1.70501566089 + 14143.4952424306*$t);
  $Z2 += 0.00000000057 * cos(6.15295833679 + 12194.0329146209*$t);
  $Z2 += 0.00000000051 * cos(1.27616016740 + 5753.3848848968*$t);
  $Z2 += 0.00000000051 * cos(5.37229738682 + 6812.766815086*$t);
  $Z2 += 0.00000000034 * cos(1.73672994279 + 7058.5984613154*$t);
  $Z2 += 0.00000000038 * cos(2.77761031485 + 10988.808157535*$t);
  $Z2 += 0.00000000046 * cos(3.38617099014 + 156475.2902479957*$t);
  $Z2 += 0.00000000021 * cos(1.95248349228 + 8827.3902698748*$t);
  $Z2 += 0.00000000018 * cos(3.33419222028 + 8429.2412664666*$t);
  $Z2 += 0.00000000019 * cos(4.32945160287 + 17789.845619785*$t);
  $Z2 += 0.00000000017 * cos(0.66191210656 + 6283.0085396886*$t);
  $Z2 += 0.00000000018 * cos(3.74885333072 + 11769.8536931664*$t);
  $Z2 += 0.00000000017 * cos(4.23058370776 + 10977.078804699*$t);
  $Z2 += 0.00000000017 * cos(1.78116162721 + 5486.777843175*$t);
  $Z2 += 0.00000000018 * cos(6.14348240716 + 11790.6290886588*$t);
  $Z2 += 0.00000000022 * cos(1.34376831204 + 12036.4607348882*$t);
  $Z2 += 0.00000000017 * cos(2.79601092529 + 796.2980068164*$t);
  $Z2 += 0.00000000015 * cos(1.17032155085 + 213.299095438*$t);
  $Z2 += 0.00000000018 * cos(2.85221514199 + 5088.6288397668*$t);
  $Z2 += 0.00000000017 * cos(0.21780913672 + 6283.14316029419*$t);
  $Z2 += 0.00000000013 * cos(1.21201504386 + 25132.3033999656*$t);
  $Z2 += 0.00000000012 * cos(5.13714452592 + 7079.3738568078*$t);
  $Z2 += 0.00000000013 * cos(3.79842135217 + 4933.2084403326*$t);
  $Z2 += 0.00000000012 * cos(4.89407978213 + 3738.761430108*$t);
  $Z2 += 0.00000000015 * cos(6.05682328852 + 398.1490034082*$t);
  $Z2 += 0.00000000014 * cos(4.81029291856 + 4694.0029547076*$t);
  $Z2 += 0.00000000011 * cos(0.61684523405 + 3128.3887650958*$t);
  $Z2 += 0.00000000011 * cos(5.32876538500 + 6040.3472460174*$t);
  $Z2 += 0.00000000014 * cos(5.27227350286 + 4535.0594369244*$t);
  $Z2 += 0.00000000011 * cos(2.39292099451 + 5331.3574437408*$t);
  $Z2 += 0.00000000010 * cos(4.45296532710 + 6525.8044539654*$t);
  $Z2 += 0.00000000014 * cos(4.66400985037 + 8031.0922630584*$t);
  $Z2 += 0.00000000010 * cos(3.22472385926 + 9437.762934887*$t);
  $Z2 += 0.00000000011 * cos(3.80913404437 + 801.8209311238*$t);
  $Z2 += 0.00000000010 * cos(5.15032130575 + 11371.7046897582*$t);
  $Z2 += 0.00000000013 * cos(0.98720797401 + 5729.506447149*$t);
  $Z2 += 0.00000000009 * cos(5.94191743597 + 7632.9432596502*$t);
  return $Z2*$t*$t;
}



  function Earth_C_Z3 ($t)
{
  $Z3 =  0.0;
  $Z3 += 0.00000000011 * cos(0.23877262399 + 7860.4193924392*$t);
  $Z3 += 0.00000000009 * cos(1.16069982609 + 5507.5532386674*$t);
  $Z3 += 0.00000000008 * cos(1.65357552925 + 5884.9268465832*$t);
  $Z3 += 0.00000000008 * cos(2.86720038197 + 7058.5984613154*$t);
  $Z3 += 0.00000000007 * cos(3.04818741666 + 5486.777843175*$t);
  $Z3 += 0.00000000007 * cos(2.59437103785 + 529.6909650946*$t);
  $Z3 += 0.00000000008 * cos(4.02863090524 + 6256.7775301916*$t);
  $Z3 += 0.00000000008 * cos(2.42003508927 + 5753.3848848968*$t);
  $Z3 += 0.00000000006 * cos(0.84181087594 + 6275.9623029906*$t);
  $Z3 += 0.00000000006 * cos(5.40160929468 + 1577.3435424478*$t);
  $Z3 += 0.00000000007 * cos(2.73399865247 + 6309.3741697912*$t);
  return $Z3*$t*$t*$t;
}



  function Earth_C_Z4 ($t)
{
  $Z4 =  0.0;
  $Z4 += 0.00000000004 * cos(0.79662198849 + 6438.4962494256*$t);
  $Z4 += 0.00000000005 * cos(0.84308705203 + 1047.7473117547*$t);
  $Z4 += 0.00000000005 * cos(0.05711572303 + 84334.66158130829*$t);
  $Z4 += 0.00000000003 * cos(3.46779895686 + 6279.5527316424*$t);
  $Z4 += 0.00000000003 * cos(2.89822201212 + 6127.6554505572*$t);
  return $Z4*$t*$t*$t*$t;
}



  function Earth_C_Z5 ($t)
{
  $Z5 =  0.0;
  return $Z5*$t*$t*$t*$t*$t;
}






/*
 ----------------------------------------------------------------------------
 Hard-Coded PHP Implementation of the VSOP87 Theory - Series Version C

 Body Name              : Venus
 VSOP87 Series Version  : C
 Coordinates Type/Epoch : Rectangular XYZ-Coordinates
                          HELIOCENTRIC DYNAMICAL ECLIPTIC/EQUINOX OF DATE

 Ephemeris Date Span    : 2000 BC < Date < 6000 AD

 These functions collectively compute the rectangular space-time coordinates
 of the planet Venus according to the VSOP87 theory, series version C.

 JDTT = Standard Julian Date (JD) for any given moment on the TT scale.

    t = Julian millennia reckoned from J2000 (2000-Jan-01-Sat 12:00:00 TT)
      = (JDTT - 2451545.0) / 365250

 Source Code Generator Author:
 Jay Tanner - 2023

 License:
 This PHP program source code is released to the public domain.
 ----------------------------------------------------------------------------
*/


   function Venus_C_X0 ($t)
{
  $X0 =  0.0;
  $X0 += 0.72268045621 * cos(3.17614669179 + 10213.5293636945*$t);
  $X0 += 0.00733886107 * cos(5.43699242686 + 0.2438174835*$t);
  $X0 += 0.00244692613 * cos(4.05605630888 + 20426.8149099055*$t);
  $X0 += 0.00063317702 * cos(0.49335411201 + 10213.0417287275*$t);
  $X0 += 0.00002795043 * cos(0.33061720033 + 2353.1099712553*$t);
  $X0 += 0.00001941766 * cos(4.23356531450 + 1577.0997249643*$t);
  $X0 += 0.00001242687 * cos(4.93613589610 + 30640.1004561165*$t);
  $X0 += 0.00001163369 * cos(2.88004293502 + 18073.9487561337*$t);
  $X0 += 0.00001044280 * cos(1.75322105845 + 6283.3196674749*$t);
  $X0 += 0.00000767420 * cos(0.59253172189 + 529.9347825781*$t);
  $X0 += 0.00000669994 * cos(1.45757409332 + 14143.7390599141*$t);
  $X0 += 0.00000657435 * cos(0.50103996032 + 8636.18582124671*$t);
  $X0 += 0.00000476814 * cos(5.84349432310 + 10187.2310438947*$t);
  $X0 += 0.00000475078 * cos(3.65048802648 + 10239.8276834943*$t);
  $X0 += 0.00000559353 * cos(1.16579177696 + 22004.1584523533*$t);
  $X0 += 0.00000544577 * cos(2.71804028246 + 11790.8729061423*$t);
  $X0 += 0.00000408020 * cos(3.92608771235 + 775.7664288075*$t);
  $X0 += 0.00000281345 * cos(2.80298571306 + 9683.8383985999*$t);
  $X0 += 0.00000270035 * cos(3.67770752796 + 9438.0067523705*$t);
  $X0 += 0.00000268860 * cos(0.41990030277 + 10743.2203287891*$t);
  $X0 += 0.00000299980 * cos(5.65601998711 + 5507.3094211839*$t);
  $X0 += 0.00000214307 * cos(0.74923674788 + 10022.0810975829*$t);
  $X0 += 0.00000241347 * cos(5.80682329886 + 10989.0519750185*$t);
  $X0 += 0.00000208372 * cos(2.46285909236 + 10404.9776298061*$t);
  $X0 += 0.00000271224 * cos(2.62417096158 + 19897.1239448109*$t);
  $X0 += 0.00000264276 * cos(5.12064283406 + 9153.6597985383*$t);
  $X0 += 0.00000214535 * cos(1.37526779747 + 20426.32727493849*$t);
  $X0 += 0.00000175488 * cos(6.12331394777 + 191.2044486281*$t);
  $X0 += 0.00000123055 * cos(1.58857792634 + 1059.6257476727*$t);
  $X0 += 0.00000154230 * cos(5.35560161427 + 4705.9761250271*$t);
  $X0 += 0.00000147037 * cos(5.55854050911 + 19651.2922985815*$t);
  $X0 += 0.00000100153 * cos(0.79332045392 + 9437.5191174035*$t);
  $X0 += 0.00000069555 * cos(0.09311754829 + 9104.1508116011*$t);
  $X0 += 0.00000060317 * cos(3.11675324526 + 11322.9079157879*$t);
  $X0 += 0.00000081789 * cos(4.14338512686 + 15721.0826023619*$t);
  $X0 += 0.00000058874 * cos(3.05764615349 + 20618.2631760171*$t);
  $X0 += 0.00000060776 * cos(3.78470873239 + 4552.1973145423*$t);
  $X0 += 0.00000046411 * cos(0.52070218977 + 10192.7539682021*$t);
  $X0 += 0.00000046285 * cos(2.68960619882 + 10234.3047591869*$t);
  $X0 += 0.00000062288 * cos(2.59109725374 + 25934.3681485729*$t);
  $X0 += 0.00000050365 * cos(4.75194275844 + 8623.96883344369*$t);
  $X0 += 0.00000057275 * cos(0.64239189151 + 3154.4432674121*$t);
  $X0 += 0.00000044993 * cos(1.63208209330 + 19367.4329797163*$t);
  $X0 += 0.00000040167 * cos(3.21167128301 + 9411.7084325707*$t);
  $X0 += 0.00000047716 * cos(0.86304453306 + 213.5429129215*$t);
  $X0 += 0.00000039763 * cos(1.64025153322 + 801.5771136403*$t);
  $X0 += 0.00000036106 * cos(0.00294457034 + 11015.3502948183*$t);
  $X0 += 0.00000045150 * cos(2.05121968981 + 29580.7185259273*$t);
  $X0 += 0.00000036973 * cos(4.39488677348 + 7058.8422787989*$t);
  $X0 += 0.00000044928 * cos(2.21932487684 + 13367.7288136231*$t);
  $X0 += 0.00000027822 * cos(1.80340755563 + 1109.1347346099*$t);
  $X0 += 0.00000031714 * cos(5.71016699928 + 15874.8614128467*$t);
  $X0 += 0.00000036279 * cos(3.91641576039 + 10000.23026825651*$t);
  $X0 += 0.00000035360 * cos(5.58217966591 + 10426.8284591325*$t);
  $X0 += 0.00000025530 * cos(5.55124903584 + 7860.6632099227*$t);
  $X0 += 0.00000024951 * cos(5.10701160912 + 13368.2164485901*$t);
  $X0 += 0.00000020285 * cos(2.70230185537 + 10220.6429106953*$t);
  $X0 += 0.00000020275 * cos(0.50470014586 + 10206.4158166937*$t);
  $X0 += 0.00000021291 * cos(2.94920881997 + 3128.6325825793*$t);
  $X0 += 0.00000019173 * cos(2.04473251084 + 7.3573644843*$t);
  $X0 += 0.00000018901 * cos(5.32807743689 + 26.0545023163*$t);
  $X0 += 0.00000021874 * cos(3.64157746468 + 17297.9385098427*$t);
  $X0 += 0.00000019888 * cos(2.97802303514 + 3930.4535137031*$t);
  $X0 += 0.00000015237 * cos(4.38451579542 + 9830.6328314713*$t);
  $X0 += 0.00000017432 * cos(0.19412655939 + 3531.81687532789*$t);
  $X0 += 0.00000014522 * cos(5.10931707627 + 10596.4258959177*$t);
  $X0 += 0.00000016153 * cos(2.06702370588 + 7084.6529636317*$t);
  $X0 += 0.00000016091 * cos(2.35723470212 + 20213.5158144675*$t);
  $X0 += 0.00000014842 * cos(4.06993785667 + 29864.5778447925*$t);
  $X0 += 0.00000011112 * cos(3.77156689319 + 28287.2343023447*$t);
  $X0 += 0.00000012828 * cos(2.04993681745 + 1589.3167127673*$t);
  $X0 += 0.00000011212 * cos(2.47660347576 + 9154.1474335053*$t);
  $X0 += 0.00000014376 * cos(3.86295510498 + 23581.5019948011*$t);
  $X0 += 0.00000012175 * cos(4.86624913254 + 21228.63584102931*$t);
  $X0 += 0.00000009393 * cos(0.62322150367 + 11272.91129388371*$t);
  $X0 += 0.00000012824 * cos(1.41267695017 + 18837.25437965469*$t);
  $X0 += 0.00000009207 * cos(0.63567894131 + 5661.5758666357*$t);
  $X0 += 0.00000008622 * cos(4.96988848671 + 21536.1934619989*$t);
  $X0 += 0.00000011653 * cos(6.20176223180 + 3340.8562441833*$t);
  $X0 += 0.00000011496 * cos(5.06383150221 + 21228.1482060623*$t);
  $X0 += 0.00000009511 * cos(0.26562072904 + 17298.4261448097*$t);
  $X0 += 0.00000011281 * cos(4.58316811302 + 9786.44353785149*$t);
  $X0 += 0.00000008498 * cos(3.85640563749 + 1577.5873599313*$t);
  $X0 += 0.00000010763 * cos(1.23302415918 + 9929.6700448293*$t);
  $X0 += 0.00000008847 * cos(1.67978485166 + 29051.0275608327*$t);
  $X0 += 0.00000010378 * cos(1.97768679369 + 10497.38868255971*$t);
  $X0 += 0.00000007498 * cos(5.81617198925 + 40853.3860023275*$t);
  $X0 += 0.00000007375 * cos(0.80020428978 + 16496.6052136859*$t);
  $X0 += 0.00000008792 * cos(0.46879154707 + 10208.0064393871*$t);
  $X0 += 0.00000008786 * cos(2.74189610123 + 10219.0522880019*$t);
  $X0 += 0.00000007423 * cos(4.16147581059 + 10175.5016910587*$t);
  $X0 += 0.00000007386 * cos(5.33241732891 + 10251.55703633031*$t);
  $X0 += 0.00000006692 * cos(4.38326911706 + 8094.2778683491*$t);
  $X0 += 0.00000006531 * cos(1.17040611406 + 20419.7013629047*$t);
  $X0 += 0.00000005876 * cos(2.02888635328 + 32217.4439985643*$t);
  $X0 += 0.00000007945 * cos(3.46479056876 + 12566.3955174663*$t);
  $X0 += 0.00000005723 * cos(2.30960586444 + 24357.0246061251*$t);
  $X0 += 0.00000005960 * cos(0.33603622534 + 6681.46867088311*$t);
  $X0 += 0.00000005974 * cos(2.16510174683 + 426.8420083595*$t);
  $X0 += 0.00000005761 * cos(0.76064746748 + 2352.6223362883*$t);
  $X0 += 0.00000007279 * cos(3.49868729640 + 11014.8626598513*$t);
  $X0 += 0.00000004942 * cos(3.65960075191 + 3149.4079780717*$t);
  $X0 += 0.00000005638 * cos(2.37982075471 + 382.6527147397*$t);
  $X0 += 0.00000006069 * cos(2.45567436191 + 9683.35076363289*$t);
  $X0 += 0.00000004581 * cos(2.63348121114 + 14765.48286075331*$t);
  $X0 += 0.00000006372 * cos(0.20312515446 + 25158.3579022819*$t);
  $X0 += 0.00000004902 * cos(1.17139302409 + 18837.7420146217*$t);
  $X0 += 0.00000004698 * cos(0.27470947352 + 18849.4713674577*$t);
  $X0 += 0.00000005371 * cos(4.44585316652 + 26088.1469590577*$t);
  $X0 += 0.00000005495 * cos(3.29251136036 + 17086.2024832057*$t);
  $X0 += 0.00000005381 * cos(5.41096356380 + 33794.7875410121*$t);
  $X0 += 0.00000004870 * cos(2.78487952662 + 20453.1132297053*$t);
  $X0 += 0.00000003922 * cos(2.87932422455 + 13745.5900565059*$t);
  $X0 += 0.00000004608 * cos(4.34320749688 + 5661.0882316687*$t);
  $X0 += 0.00000003970 * cos(3.08739367796 + 4731.7868098599*$t);
  $X0 += 0.00000003556 * cos(0.34805582338 + 1551.2890401315*$t);
  $X0 += 0.00000004329 * cos(3.40536513934 + 23958.8756027169*$t);
  $X0 += 0.00000003274 * cos(3.43453378712 + 529.44714761109*$t);
  $X0 += 0.00000003328 * cos(1.04776147690 + 18307.56341456009*$t);
  $X0 += 0.00000002787 * cos(2.05633948048 + 11790.3852711753*$t);
  $X0 += 0.00000003603 * cos(4.92117852022 + 14945.0723560709*$t);
  $X0 += 0.00000002949 * cos(2.82363129219 + 10198.2768925095*$t);
  $X0 += 0.00000002944 * cos(0.38707318449 + 10228.78183487951*$t);
  $X0 += 0.00000003221 * cos(0.43638422425 + 20400.5165901057*$t);
  $X0 += 0.00000003653 * cos(1.62294150568 + 29088.5675985015*$t);
  $X0 += 0.00000002683 * cos(2.20899209567 + 6282.83203250789*$t);
  $X0 += 0.00000002848 * cos(0.52334662875 + 11322.42028082089*$t);
  $X0 += 0.00000002745 * cos(1.78121493204 + 5481.4987363511*$t);
  $X0 += 0.00000002426 * cos(2.81466312460 + 6872.91693699471*$t);
  $X0 += 0.00000002262 * cos(3.48344118262 + 7860.17557495569*$t);
  $X0 += 0.00000002431 * cos(3.85595069475 + 30110.4094910219*$t);
  $X0 += 0.00000002218 * cos(5.83392361752 + 17277.6507493173*$t);
  $X0 += 0.00000002955 * cos(5.30083680831 + 27511.7116910207*$t);
  $X0 += 0.00000002300 * cos(3.89687853440 + 3442.81876244891*$t);
  $X0 += 0.00000002424 * cos(0.96902068311 + 20956.5058750001*$t);
  $X0 += 0.00000002622 * cos(3.74514898210 + 9580.7456243813*$t);
  $X0 += 0.00000002032 * cos(1.05319678961 + 20000.2167190295*$t);
  $X0 += 0.00000002206 * cos(3.60536125643 + 537.0483295789*$t);
  $X0 += 0.00000002010 * cos(0.56779046000 + 21202.3375212295*$t);
  $X0 += 0.00000002471 * cos(5.74733670645 + 10846.3131030077*$t);
  $X0 += 0.00000002315 * cos(5.33473916529 + 9573.14444241349*$t);
  $X0 += 0.00000002188 * cos(5.98208918864 + 9967.69771746511*$t);
  $X0 += 0.00000002278 * cos(4.39189942690 + 10110.4365894759*$t);
  $X0 += 0.00000002278 * cos(5.10198662047 + 10316.6221379131*$t);
  $X0 += 0.00000001808 * cos(4.00370769986 + 22779.6810636773*$t);
  $X0 += 0.00000002244 * cos(2.44298085439 + 5507.7970561509*$t);
  $X0 += 0.00000001796 * cos(3.09913214862 + 7063.87756813929*$t);
  $X0 += 0.00000002118 * cos(3.51159951397 + 10459.3610099239*$t);
  $X0 += 0.00000001908 * cos(5.61152019917 + 20809.7114421287*$t);
  $X0 += 0.00000002093 * cos(0.69713061337 + 522.8212355773*$t);
  $X0 += 0.00000001753 * cos(0.39797312506 + 13554.1417903943*$t);
  $X0 += 0.00000002072 * cos(4.26049243578 + 9690.9519456007*$t);
  $X0 += 0.00000001993 * cos(3.55209979851 + 10404.48999483909*$t);
  $X0 += 0.00000002160 * cos(3.04497475534 + 33018.7772947211*$t);
  $X0 += 0.00000001962 * cos(5.23488234630 + 10736.1067817883*$t);
  $X0 += 0.00000001484 * cos(2.74179945598 + 3723.26514143949*$t);
  $X0 += 0.00000001997 * cos(0.06145988645 + 18875.2820522905*$t);
  $X0 += 0.00000002057 * cos(1.98619862343 + 102.84895673509*$t);
  $X0 += 0.00000002016 * cos(0.55406656183 + 37724.9972372317*$t);
  $X0 += 0.00000001618 * cos(4.87669871338 + 7085.1405985987*$t);
  $X0 += 0.00000001659 * cos(1.57309690432 + 20235.36664379391*$t);
  $X0 += 0.00000001553 * cos(1.42749385034 + 14945.5599910379*$t);
  $X0 += 0.00000001873 * cos(1.50254912801 + 30213.5022652405*$t);
  $X0 += 0.00000001542 * cos(4.02240332746 + 6490.0204047715*$t);
  $X0 += 0.00000001360 * cos(5.79998899684 + 10233.1991245943*$t);
  $X0 += 0.00000001360 * cos(3.69389705053 + 10193.85960279471*$t);
  $X0 += 0.00000001592 * cos(0.72118861666 + 10138.7477651272*$t);
  $X0 += 0.00000001592 * cos(2.48951212353 + 10288.3109622618*$t);
  $X0 += 0.00000001368 * cos(2.85917999065 + 18875.76968725751*$t);
  $X0 += 0.00000001235 * cos(3.79205714927 + 20.5315780089*$t);
  $X0 += 0.00000001485 * cos(4.99009504257 + 9160.77334553909*$t);
  $X0 += 0.00000001516 * cos(2.06896537087 + 9146.54625153749*$t);
  $X0 += 0.00000001233 * cos(0.18739466393 + 18073.46112116669*$t);
  $X0 += 0.00000001560 * cos(0.36404331783 + 9897.1374940379*$t);
  $X0 += 0.00000001560 * cos(2.84665742236 + 10529.9212333511*$t);
  $X0 += 0.00000001179 * cos(6.01432548499 + 14919.2616712381*$t);
  $X0 += 0.00000001213 * cos(1.30457787805 + 28521.3365957381*$t);
  $X0 += 0.00000001182 * cos(5.63437933479 + 9794.0447198193*$t);
  $X0 += 0.00000001402 * cos(4.53367387536 + 8661.9965060795*$t);
  $X0 += 0.00000001158 * cos(3.85902457723 + 10633.0140075697*$t);
  $X0 += 0.00000001257 * cos(4.23637984727 + 2378.9206560881*$t);
  $X0 += 0.00000001089 * cos(2.26544798668 + 30639.61282114949*$t);
  $X0 += 0.00000001402 * cos(5.00395460415 + 10640.1275545705*$t);
  $X0 += 0.00000001483 * cos(5.56946826365 + 21535.70582703189*$t);
  $X0 += 0.00000001079 * cos(4.38415798738 + 775.2787938405*$t);
  $X0 += 0.00000001370 * cos(4.61207624622 + 9786.9311728185*$t);
  $X0 += 0.00000001064 * cos(5.60167497040 + 16984.2399649401*$t);
  $X0 += 0.00000001158 * cos(4.33523311867 + 3929.96587873609*$t);
  $X0 += 0.00000000967 * cos(1.59661459457 + 640.1411037975*$t);
  $X0 += 0.00000000995 * cos(1.12539751877 + 8662.48414104651*$t);
  $X0 += 0.00000001305 * cos(4.46692235351 + 36948.9869909407*$t);
  $X0 += 0.00000001191 * cos(4.52742138803 + 39264.3131070437*$t);
  $X0 += 0.00000001010 * cos(1.09565332862 + 10007.3438152573*$t);
  $X0 += 0.00000001010 * cos(2.11504740292 + 10419.7149121317*$t);
  $X0 += 0.00000000950 * cos(4.36909872600 + 1109.6223695769*$t);
  $X0 += 0.00000001221 * cos(5.50189153252 + 75.0254160508*$t);
  $X0 += 0.00000000987 * cos(5.46991186463 + 13937.0383226175*$t);
  $X0 += 0.00000001164 * cos(1.47388964891 + 22805.4917485101*$t);
  $X0 += 0.00000000845 * cos(4.27255310755 + 6770.46678376209*$t);
  $X0 += 0.00000000996 * cos(4.53838005508 + 13341.9181287903*$t);
  $X0 += 0.00000001123 * cos(1.83377276818 + 246.0754637129*$t);
  $X0 += 0.00000001139 * cos(2.43198497783 + 2119.00767786191*$t);
  $X0 += 0.00000001046 * cos(0.31602811545 + 31441.92138724031*$t);
  $X0 += 0.00000000879 * cos(3.85735462170 + 15720.5949673949*$t);
  $X0 += 0.00000000761 * cos(4.01867784780 + 7564.58690325449*$t);
  $X0 += 0.00000000814 * cos(6.07006670549 + 9676.7248515991*$t);
  $X0 += 0.00000000786 * cos(2.08315748724 + 11764.5745863425*$t);
  $X0 += 0.00000000883 * cos(0.01404050923 + 25158.8455372489*$t);
  $X0 += 0.00000000795 * cos(3.42432291896 + 10750.33387578991*$t);
  $X0 += 0.00000000770 * cos(0.68478801852 + 7834.3648901229*$t);
  $X0 += 0.00000000825 * cos(2.06778751923 + 191.6920835951*$t);
  $X0 += 0.00000000696 * cos(3.39721023806 + 36147.6536947839*$t);
  $X0 += 0.00000000941 * cos(3.99222118800 + 28520.84896077109*$t);
  $X0 += 0.00000000787 * cos(5.89002484288 + 19890.0103978101*$t);
  $X0 += 0.00000000788 * cos(0.18085455233 + 7994.77225950771*$t);
  $X0 += 0.00000000624 * cos(2.84762425105 + 39794.0040721383*$t);
  $X0 += 0.00000000609 * cos(2.15716574588 + 8624.45646841071*$t);
  $X0 += 0.00000000836 * cos(1.97255748877 + 41655.2069334513*$t);
  $X0 += 0.00000000744 * cos(2.51526655235 + 19904.2374918117*$t);
  $X0 += 0.00000000689 * cos(4.60442929527 + 1066.7392946735*$t);
  $X0 += 0.00000000803 * cos(5.88878266978 + 40879.1966871603*$t);
  $X0 += 0.00000000692 * cos(0.54636447385 + 6770.9544187291*$t);
  $X0 += 0.00000000585 * cos(5.02593807559 + 14143.2514249471*$t);
  $X0 += 0.00000000678 * cos(5.96525738921 + 12592.2062022991*$t);
  $X0 += 0.00000000573 * cos(2.52291476260 + 12592.6938372661*$t);
  $X0 += 0.00000000670 * cos(0.92908106036 + 10239.3400485273*$t);
  $X0 += 0.00000000655 * cos(4.98008645111 + 19366.94534474929*$t);
  $X0 += 0.00000000626 * cos(1.17708461387 + 52176.0501006319*$t);
  $X0 += 0.00000000548 * cos(0.67624288629 + 17777.87244946549*$t);
  $X0 += 0.00000000709 * cos(2.90326183951 + 26735.7014447297*$t);
  $X0 += 0.00000000531 * cos(3.09187361677 + 110.45013870291*$t);
  $X0 += 0.00000000605 * cos(4.63445748441 + 10059.7505532097*$t);
  $X0 += 0.00000000676 * cos(5.20222552429 + 20529.9076841241*$t);
  $X0 += 0.00000000598 * cos(3.03085156721 + 12432.2864678813*$t);
  $X0 += 0.00000000593 * cos(4.85950569906 + 10367.3081741793*$t);
  $X0 += 0.00000000663 * cos(0.05389382712 + 1162.7185218913*$t);
  $X0 += 0.00000000466 * cos(5.52080701144 + 8631.0823804445*$t);
  $X0 += 0.00000000468 * cos(3.02762841033 + 16983.75232997309*$t);
  $X0 += 0.00000000454 * cos(0.79241866785 + 10042.8564930753*$t);
  $X0 += 0.00000000462 * cos(5.82955181248 + 6.86972951729*$t);
  $X0 += 0.00000000444 * cos(2.41828213333 + 10384.2022343137*$t);
  $X0 += 0.00000000460 * cos(0.69082886296 + 11802.6022589783*$t);
  $X0 += 0.00000000436 * cos(1.85693465963 + 9639.18456535971*$t);
  $X0 += 0.00000000565 * cos(5.70677906646 + 8520.87605922509*$t);
  $X0 += 0.00000000416 * cos(1.72605691131 + 10225.2587165305*$t);
  $X0 += 0.00000000416 * cos(1.48464382888 + 10201.80001085851*$t);
  $X0 += 0.00000000414 * cos(3.17556892991 + 10186.7434089277*$t);
  $X0 += 0.00000000431 * cos(1.73079752624 + 8616.85528644289*$t);
  $X0 += 0.00000000393 * cos(2.42848511919 + 3532.3045102949*$t);
  $X0 += 0.00000000406 * cos(1.35364773044 + 10787.8741620293*$t);
  $X0 += 0.00000000380 * cos(0.22739133734 + 19317.43635781211*$t);
  $X0 += 0.00000000458 * cos(1.71416676029 + 2218.51328670329*$t);
  $X0 += 0.00000000433 * cos(5.30346380915 + 19650.8046636145*$t);
  $X0 += 0.00000000377 * cos(5.67314793766 + 149.8070146181*$t);
  $X0 += 0.00000000390 * cos(0.06912441711 + 13936.5506876505*$t);
  $X0 += 0.00000000360 * cos(5.95509031178 + 24150.3238688285*$t);
  $X0 += 0.00000000359 * cos(4.26088296989 + 30831.5487222281*$t);
  $X0 += 0.00000000501 * cos(1.02737770483 + 44809.4063833799*$t);
  $X0 += 0.00000000409 * cos(1.77188267484 + 27197.03787618409*$t);
  $X0 += 0.00000000354 * cos(2.84306437211 + 10323.7356849139*$t);
  $X0 += 0.00000000354 * cos(0.36763636808 + 10103.3230424751*$t);
  $X0 += 0.00000000428 * cos(2.67107743725 + 13656.10430865991*$t);
  $X0 += 0.00000000467 * cos(5.30307476925 + 38.3768531213*$t);
  $X0 += 0.00000000343 * cos(1.61330776142 + 19786.9176235915*$t);
  $X0 += 0.00000000457 * cos(0.79025821347 + 18308.0510495271*$t);
  $X0 += 0.00000000399 * cos(0.98531427210 + 1052.51220067191*$t);
  $X0 += 0.00000000445 * cos(4.32811724206 + 30665.9111409493*$t);
  $X0 += 0.00000000344 * cos(0.03854207192 + 27490.9362955283*$t);
  $X0 += 0.00000000315 * cos(0.01870495544 + 20640.1140053435*$t);
  $X0 += 0.00000000399 * cos(4.24912842655 + 10212.0448909862*$t);
  $X0 += 0.00000000399 * cos(5.24475762082 + 10215.0138364028*$t);
  $X0 += 0.00000000390 * cos(2.28211006759 + 30000.2031698025*$t);
  $X0 += 0.00000000340 * cos(1.17434519565 + 22805.9793834771*$t);
  $X0 += 0.00000000398 * cos(3.64836715501 + 9836.1557557787*$t);
  $X0 += 0.00000000311 * cos(4.76207516886 + 22003.6708173863*$t);
  $X0 += 0.00000000404 * cos(3.98593080978 + 20352.0333113382*$t);
  $X0 += 0.00000000366 * cos(1.12867710261 + 16522.4158985187*$t);
  $X0 += 0.00000000350 * cos(2.99077020749 + 15874.37377787969*$t);
  $X0 += 0.00000000385 * cos(1.36867906917 + 20180.9832636761*$t);
  $X0 += 0.00000000379 * cos(5.84551902141 + 10590.9029716103*$t);
  $X0 += 0.00000000395 * cos(0.41318733253 + 17277.16311435029*$t);
  $X0 += 0.00000000383 * cos(1.78033504479 + 35372.1310834599*$t);
  $X0 += 0.00000000277 * cos(3.16062357954 + 10988.5643400515*$t);
  $X0 += 0.00000000365 * cos(1.42467845102 + 10349.1546887045*$t);
  $X0 += 0.00000000365 * cos(1.78602228917 + 10077.90403868451*$t);
  $X0 += 0.00000000336 * cos(0.74013259732 + 220.6564599223*$t);
  $X0 += 0.00000000313 * cos(5.66612603850 + 6309.1303523077*$t);
  $X0 += 0.00000000276 * cos(5.59087067643 + 26709.8907598969*$t);
  $X0 += 0.00000000283 * cos(5.53432657905 + 3904.1551939033*$t);
  $X0 += 0.00000000271 * cos(3.85648651665 + 9745.5643733401*$t);
  $X0 += 0.00000000321 * cos(4.20436094748 + 38734.6221419491*$t);
  $X0 += 0.00000000327 * cos(6.11821528186 + 9359.84534697549*$t);
  $X0 += 0.00000000264 * cos(5.16095616548 + 76.50988875911*$t);
  $X0 += 0.00000000310 * cos(3.61551590451 + 27991.15799567649*$t);
  $X0 += 0.00000000359 * cos(3.38306212619 + 45585.4166296709*$t);
  $X0 += 0.00000000326 * cos(5.59092073268 + 633.0275567967*$t);
  $X0 += 0.00000000314 * cos(1.40080599663 + 20406.0395144131*$t);
  $X0 += 0.00000000306 * cos(1.12609450630 + 2957.9597119601*$t);
  $X0 += 0.00000000266 * cos(4.09083877114 + 8635.69818627969*$t);
  $X0 += 0.00000000254 * cos(5.63745242067 + 10681.49435404891*$t);
  $X0 += 0.00000000343 * cos(4.64295996667 + 8106.4948561521*$t);
  $X0 += 0.00000000300 * cos(4.12771906867 + 206.42936592071*$t);
  $X0 += 0.00000000250 * cos(3.04073965857 + 283.6155013817*$t);
  $X0 += 0.00000000336 * cos(0.68541596989 + 23581.0143598341*$t);
  $X0 += 0.00000000236 * cos(5.97871163742 + 10595.9382609507*$t);
  $X0 += 0.00000000234 * cos(3.82015244691 + 19624.9939787817*$t);
  $X0 += 0.00000000255 * cos(2.78388035745 + 213.0552779545*$t);
  $X0 += 0.00000000281 * cos(0.78332195796 + 9399.9790797347*$t);
  $X0 += 0.00000000314 * cos(0.56852266937 + 19786.42998862449*$t);
  $X0 += 0.00000000229 * cos(4.91536328985 + 574.10098085129*$t);
  $X0 += 0.00000000295 * cos(3.93680452053 + 31749.4790082099*$t);
  $X0 += 0.00000000316 * cos(2.45044363511 + 48739.6160795995*$t);
  $X0 += 0.00000000229 * cos(4.45667675327 + 949.4194264533*$t);
  $X0 += 0.00000000229 * cos(6.25019131093 + 19896.63630984389*$t);
  $X0 += 0.00000000257 * cos(4.89479846572 + 19360.3194327155*$t);
  $X0 += 0.00000000231 * cos(4.38656769900 + 9264.35375472471*$t);
  $X0 += 0.00000000255 * cos(4.03464641753 + 9993.1167212557*$t);
  $X0 += 0.00000000255 * cos(5.45923962984 + 10433.9420061333*$t);
  $X0 += 0.00000000291 * cos(0.75030918802 + 9999.7426332895*$t);
  $X0 += 0.00000000285 * cos(5.75179047399 + 34596.1208371689*$t);
  $X0 += 0.00000000211 * cos(0.18276464350 + 10249.55723037191*$t);
  $X0 += 0.00000000211 * cos(3.02793609669 + 10177.5014970171*$t);
  $X0 += 0.00000000255 * cos(2.42745847719 + 11027.07964765431*$t);
  $X0 += 0.00000000220 * cos(0.56223178729 + 37.7838551523*$t);
  $X0 += 0.00000000280 * cos(0.52583614761 + 37410.32342239509*$t);
  $X0 += 0.00000000258 * cos(5.27008173054 + 29573.6049789265*$t);
  $X0 += 0.00000000247 * cos(1.90810058449 + 29587.8320729281*$t);
  $X0 += 0.00000000206 * cos(3.37472645930 + 30426.8013606785*$t);
  $X0 += 0.00000000263 * cos(3.16130275876 + 20433.9284569063*$t);
  $X0 += 0.00000000212 * cos(3.16045353079 + 10206.9008047945*$t);
  $X0 += 0.00000000212 * cos(0.05024720940 + 10220.15792259451*$t);
  $X0 += 0.00000000202 * cos(0.82632204894 + 16894.7542170941*$t);
  $X0 += 0.00000000272 * cos(4.85092349120 + 12320.56387123691*$t);
  $X0 += 0.00000000211 * cos(5.11529334983 + 11162.7049726643*$t);
  $X0 += 0.00000000197 * cos(1.28459142755 + 8734.17515466309*$t);
  $X0 += 0.00000000267 * cos(4.30013889854 + 377.6174253993*$t);
  $X0 += 0.00000000224 * cos(3.35322427637 + 9051.05465928671*$t);
  $X0 += 0.00000000186 * cos(4.53704574212 + 10251.6623993323*$t);
  $X0 += 0.00000000186 * cos(4.95684030525 + 10175.3963280567*$t);
  $X0 += 0.00000000258 * cos(2.52339474378 + 9864.60494324651*$t);
  $X0 += 0.00000000186 * cos(4.77906943206 + 40077.8633910035*$t);
  $X0 += 0.00000000233 * cos(1.49242697658 + 29089.0552334685*$t);
  $X0 += 0.00000000186 * cos(4.86984152157 + 17272.1278250099*$t);
  $X0 += 0.00000000254 * cos(3.15931132763 + 19264.3402054977*$t);
  $X0 += 0.00000000246 * cos(0.68740453037 + 10562.4537841425*$t);
  $X0 += 0.00000000211 * cos(6.16254771086 + 11376.0040681023*$t);
  $X0 += 0.00000000178 * cos(0.50910605505 + 10949.4058772263*$t);
  $X0 += 0.00000000178 * cos(2.70159468514 + 9477.65285016271*$t);
  $X0 += 0.00000000197 * cos(0.95969377699 + 1692.40948698591*$t);
  $X0 += 0.00000000177 * cos(0.12290786955 + 20316.6085886861*$t);
  $X0 += 0.00000000216 * cos(2.56868513559 + 20452.6255947383*$t);
  $X0 += 0.00000000197 * cos(0.19093764884 + 9050.56702431969*$t);
  $X0 += 0.00000000159 * cos(1.16783306054 + 27197.5255111511*$t);
  $X0 += 0.00000000167 * cos(5.81167464279 + 4705.4884900601*$t);
  $X0 += 0.00000000213 * cos(2.13389038075 + 27511.2240560537*$t);
  $X0 += 0.00000000154 * cos(0.72358681867 + 10199.3022696929*$t);
  $X0 += 0.00000000154 * cos(2.48711392152 + 10227.7564576961*$t);
  $X0 += 0.00000000174 * cos(1.89882712841 + 14.47091148511*$t);
  $X0 += 0.00000000209 * cos(1.65966829596 + 10063.4785315929*$t);
  $X0 += 0.00000000167 * cos(3.57558694059 + 6872.42930202769*$t);
  $X0 += 0.00000000185 * cos(0.68349269134 + 9256.75257275689*$t);
  $X0 += 0.00000000166 * cos(3.75162140471 + 10263.2863891663*$t);
  $X0 += 0.00000000166 * cos(5.74226464266 + 10163.7723382227*$t);
  $X0 += 0.00000000168 * cos(5.33662556430 + 7991.18509413049*$t);
  $X0 += 0.00000000174 * cos(3.76838134579 + 9161.2609805061*$t);
  $X0 += 0.00000000197 * cos(3.44221896080 + 846.3266522347*$t);
  $X0 += 0.00000000176 * cos(4.69215492733 + 9779.32999085069*$t);
  $X0 += 0.00000000198 * cos(3.88553571350 + 52669.8257758191*$t);
  $X0 += 0.00000000169 * cos(5.71918201676 + 11265.7977468829*$t);
  $X0 += 0.00000000188 * cos(0.90560199287 + 38526.3305333885*$t);
  $X0 += 0.00000000140 * cos(0.96666880637 + 27991.6456306435*$t);
  $X0 += 0.00000000194 * cos(2.26842216085 + 8837.26792888169*$t);
  $X0 += 0.00000000173 * cos(1.30662690057 + 9793.5570848523*$t);
  $X0 += 0.00000000140 * cos(0.33029139370 + 10191.6785343681*$t);
  $X0 += 0.00000000140 * cos(2.88040934649 + 10235.3801930209*$t);
  $X0 += 0.00000000196 * cos(2.27385726594 + 1293.24040609909*$t);
  $X0 += 0.00000000180 * cos(4.38252963041 + 10021.5934626159*$t);
  $X0 += 0.00000000138 * cos(0.38495137130 + 10217.4615169576*$t);
  $X0 += 0.00000000138 * cos(2.82574936889 + 10209.5972104314*$t);
  $X0 += 0.00000000148 * cos(2.31505492408 + 19374.5465267171*$t);
  $X0 += 0.00000000137 * cos(3.95061609635 + 16522.9035334857*$t);
  $X0 += 0.00000000143 * cos(1.40332876782 + 20447.5903053979*$t);
  $X0 += 0.00000000139 * cos(5.72624016073 + 7255.3258342509*$t);
  $X0 += 0.00000000126 * cos(3.82073811345 + 20277.2517127709*$t);
  $X0 += 0.00000000164 * cos(4.79111675703 + 49515.6263258905*$t);
  $X0 += 0.00000000149 * cos(2.18564631641 + 10135.8555932665*$t);
  $X0 += 0.00000000149 * cos(1.02505442378 + 10291.20313412251*$t);
  $X0 += 0.00000000118 * cos(1.12766998844 + 4551.7096795753*$t);
  $X0 += 0.00000000117 * cos(0.93680170584 + 1582.2031657665*$t);
  $X0 += 0.00000000151 * cos(0.84241735172 + 10246.0619144859*$t);
  $X0 += 0.00000000151 * cos(2.36828338847 + 10180.99681290311*$t);
  $X0 += 0.00000000152 * cos(3.18276216864 + 39302.3407796795*$t);
  $X0 += 0.00000000144 * cos(3.82694942167 + 9986.0532309055*$t);
  $X0 += 0.00000000144 * cos(5.66693662570 + 10441.00549648351*$t);
  $X0 += 0.00000000136 * cos(2.08219853379 + 17469.0990154289*$t);
  $X0 += 0.00000000119 * cos(3.32943340593 + 20809.2238071617*$t);
  $X0 += 0.00000000130 * cos(5.57171941495 + 10236.3045651453*$t);
  $X0 += 0.00000000130 * cos(3.92216663242 + 10190.7541622437*$t);
  $X0 += 0.00000000156 * cos(4.19081128787 + 20388.6818742677*$t);
  $X0 += 0.00000000132 * cos(2.35919234539 + 9580.2579894143*$t);
  $X0 += 0.00000000155 * cos(0.85940280671 + 8238.0368178385*$t);
  $X0 += 0.00000000142 * cos(3.58430646945 + 31441.4337522733*$t);
  $X0 += 0.00000000131 * cos(5.39629404064 + 8101.39141534989*$t);
  $X0 += 0.00000000133 * cos(4.00547577050 + 24382.8352909579*$t);
  $X0 += 0.00000000105 * cos(4.23077158650 + 32858.36992533629*$t);
  $X0 += 0.00000000105 * cos(3.82110715168 + 1059.1381127057*$t);
  $X0 += 0.00000000101 * cos(4.35357648238 + 24978.7684069643*$t);
  $X0 += 0.00000000126 * cos(4.90495452705 + 22645.57201409229*$t);
  $X0 += 0.00000000101 * cos(5.26437713251 + 20043.9183776823*$t);
  $X0 += 0.00000000110 * cos(2.97625385917 + 43071.65547154729*$t);
  $X0 += 0.00000000103 * cos(0.46440823619 + 12431.79883291429*$t);
  $X0 += 0.00000000136 * cos(6.07687689635 + 5999.4603486097*$t);
  $X0 += 0.00000000097 * cos(0.92055841324 + 853.4401992355*$t);
  $X0 += 0.00000000130 * cos(3.21780638112 + 4176.2851599325*$t);
  $X0 += 0.00000000113 * cos(3.93650904588 + 19794.0311705923*$t);
  $X0 += 0.00000000093 * cos(5.48927852030 + 22645.08437912529*$t);
  $X0 += 0.00000000124 * cos(2.32988224429 + 42456.5402296081*$t);
  $X0 += 0.00000000107 * cos(4.30116108617 + 3.6883357796*$t);
  $X0 += 0.00000000127 * cos(3.54954178661 + 284.1031363487*$t);
  $X0 += 0.00000000112 * cos(2.47056814408 + 20206.4022674667*$t);
  $X0 += 0.00000000097 * cos(4.21617446768 + 78263.95324220609*$t);
  $X0 += 0.00000000093 * cos(0.23349714961 + 8204.4841895685*$t);
  $X0 += 0.00000000127 * cos(5.30922609526 + 56600.0354720387*$t);
  $X0 += 0.00000000111 * cos(4.68533396525 + 18830.14083265389*$t);
  $X0 += 0.00000000098 * cos(3.12531862236 + 11059.6121984457*$t);
  $X0 += 0.00000000098 * cos(0.08567718624 + 9367.4465289433*$t);
  $X0 += 0.00000000103 * cos(5.15240336002 + 10244.4434893295*$t);
  $X0 += 0.00000000103 * cos(4.34148268734 + 10182.6152380595*$t);
  $X0 += 0.00000000111 * cos(1.30087873837 + 18844.36792665549*$t);
  $X0 += 0.00000000125 * cos(2.35130115448 + 12189.0219095505*$t);
  $X0 += 0.00000000088 * cos(4.33292988106 + 20350.5488386299*$t);
  $X0 += 0.00000000088 * cos(2.43603338900 + 29058.1411078335*$t);
  $X0 += 0.00000000096 * cos(3.91338437973 + 2333.44021035551*$t);
  $X0 += 0.00000000122 * cos(5.43206767869 + 2636.9692901205*$t);
  $X0 += 0.00000000087 * cos(1.36103886488 + 8087.1643213483*$t);
  $X0 += 0.00000000086 * cos(3.64796343622 + 7034.8959381599*$t);
  $X0 += 0.00000000095 * cos(2.03086124785 + 10202.4836634306*$t);
  $X0 += 0.00000000095 * cos(1.17983949234 + 10224.5750639584*$t);
  $X0 += 0.00000000084 * cos(1.22799614537 + 10401.4545114571*$t);
  $X0 += 0.00000000084 * cos(1.98270459482 + 10025.6042159319*$t);
  $X0 += 0.00000000085 * cos(5.03727591626 + 19477.6393009357*$t);
  $X0 += 0.00000000086 * cos(4.48909813316 + 29864.0902098255*$t);
  $X0 += 0.00000000099 * cos(2.80223352440 + 2648.6986429565*$t);
  $X0 += 0.00000000082 * cos(1.04973324929 + 802.0647486073*$t);
  $X0 += 0.00000000087 * cos(0.60735009545 + 13745.10242153889*$t);
  $X0 += 0.00000000081 * cos(0.59637598254 + 1550.8014051645*$t);
  $X0 += 0.00000000083 * cos(3.04079971271 + 25933.8805136059*$t);
  $X0 += 0.00000000079 * cos(6.14325401892 + 44008.0730872231*$t);
  $X0 += 0.00000000078 * cos(6.11312046046 + 9573.6320773805*$t);
  $X0 += 0.00000000098 * cos(5.37191506696 + 20220.6293614683*$t);
  $X0 += 0.00000000108 * cos(3.66133732652 + 24149.8362338615*$t);
  $X0 += 0.00000000100 * cos(5.07064547333 + 1596.43025976811*$t);
  $X0 += 0.00000000095 * cos(3.35135945156 + 29477.6257517087*$t);
  $X0 += 0.00000000078 * cos(3.03881688108 + 205.9417309537*$t);
  $X0 += 0.00000000096 * cos(1.62154425800 + 30206.38871823969*$t);
  $X0 += 0.00000000079 * cos(4.07943333749 + 3340.36860921629*$t);
  $X0 += 0.00000000095 * cos(4.51771749335 + 30220.6158122413*$t);
  $X0 += 0.00000000082 * cos(4.95983920368 + 29043.91401383189*$t);
  $X0 += 0.00000000077 * cos(2.97497430839 + 17468.6113804619*$t);
  $X0 += 0.00000000100 * cos(4.43773436133 + 38500.5198485557*$t);
  $X0 += 0.00000000107 * cos(4.65407793574 + 2069.2506523901*$t);
  $X0 += 0.00000000077 * cos(3.58586905737 + 10853.4266500085*$t);
  $X0 += 0.00000000087 * cos(4.37137980512 + 5.2791068239*$t);
  $X0 += 0.00000000076 * cos(4.87466102622 + 10243.35080184331*$t);
  $X0 += 0.00000000076 * cos(4.61922502115 + 10183.7079255457*$t);
  $X0 += 0.00000000076 * cos(6.08417794379 + 956.53297345411*$t);
  $X0 += 0.00000000100 * cos(2.63929709585 + 28947.9347866141*$t);
  $X0 += 0.00000000096 * cos(4.86017307249 + 35371.6434484929*$t);
  $X0 += 0.00000000073 * cos(0.32640489167 + 17248.18148437089*$t);
  $X0 += 0.00000000073 * cos(1.84890257629 + 21001.1597082403*$t);
  $X0 += 0.00000000081 * cos(2.26124411922 + 18734.6492404031*$t);
  $X0 += 0.00000000076 * cos(5.51994215698 + 103.3365917021*$t);
  $X0 += 0.00000000085 * cos(5.27676110314 + 3914.71340755109*$t);
  $X0 += 0.00000000074 * cos(1.92420691865 + 8827.6340873583*$t);
  $X0 += 0.00000000070 * cos(1.49155151362 + 6298.57213865991*$t);
  $X0 += 0.00000000087 * cos(2.91040927813 + 33019.2649296881*$t);
  $X0 += 0.00000000071 * cos(3.95908921272 + 34172.1611489279*$t);
  $X0 += 0.00000000079 * cos(2.65919074354 + 10018.5579792339*$t);
  $X0 += 0.00000000079 * cos(0.55150999665 + 10408.5007481551*$t);
  $X0 += 0.00000000069 * cos(6.05632855781 + 33794.2999060451*$t);
  $X0 += 0.00000000087 * cos(1.54753819207 + 29050.53992586569*$t);
  $X0 += 0.00000000069 * cos(0.90459565864 + 41044.8342684391*$t);
  $X0 += 0.00000000069 * cos(2.25427054035 + 9644.7074896671*$t);
  $X0 += 0.00000000069 * cos(0.95643019984 + 10782.3512377219*$t);
  $X0 += 0.00000000087 * cos(5.46685094593 + 28313.0449871775*$t);
  $X0 += 0.00000000085 * cos(3.77767527899 + 46386.7499258277*$t);
  $X0 += 0.00000000083 * cos(5.79338403589 + 9721.86607123571*$t);
  $X0 += 0.00000000083 * cos(3.70050201148 + 10705.1926561533*$t);
  $X0 += 0.00000000090 * cos(5.18770728347 + 20049.4413019897*$t);
  $X0 += 0.00000000064 * cos(5.86320987239 + 9147.03388650451*$t);
  $X0 += 0.00000000076 * cos(1.05201656383 + 21486.1968400947*$t);
  $X0 += 0.00000000085 * cos(1.34427023572 + 19573.13089318649*$t);
  $X0 += 0.00000000063 * cos(1.61314796366 + 18314.67696156089*$t);
  $X0 += 0.00000000071 * cos(6.14562384557 + 1573.57660661529*$t);
  $X0 += 0.00000000070 * cos(5.46351961493 + 1580.6228433133*$t);
  $X0 += 0.00000000080 * cos(6.26741884849 + 39301.8531447125*$t);
  $X0 += 0.00000000067 * cos(0.48701132675 + 3956.2641985359*$t);
  $X0 += 0.00000000087 * cos(5.47908021981 + 29264.3266562707*$t);
  $X0 += 0.00000000063 * cos(3.37584641365 + 27461.46703058189*$t);
  $X0 += 0.00000000070 * cos(5.75487124049 + 1479.11039154791*$t);
  $X0 += 0.00000000081 * cos(0.05555806146 + 10205.92818172669*$t);
  $X0 += 0.00000000080 * cos(0.23956461858 + 38204.44354188749*$t);
  $X0 += 0.00000000060 * cos(1.34871003737 + 20421.2919855981*$t);
  $X0 += 0.00000000064 * cos(4.30292059849 + 18300.44986755929*$t);
  $X0 += 0.00000000076 * cos(3.93986568359 + 29683.81130014589*$t);
  $X0 += 0.00000000082 * cos(0.44981983060 + 60530.2451682583*$t);
  $X0 += 0.00000000077 * cos(6.19200892946 + 53445.8360221101*$t);
  $X0 += 0.00000000062 * cos(1.28649446141 + 11599.4246400307*$t);
  $X0 += 0.00000000058 * cos(3.08211963404 + 7576.8038910575*$t);
  $X0 += 0.00000000057 * cos(3.67915137516 + 11280.0248408845*$t);
  $X0 += 0.00000000059 * cos(1.26040809465 + 10255.0801546793*$t);
  $X0 += 0.00000000059 * cos(1.95029264554 + 10171.9785727097*$t);
  $X0 += 0.00000000057 * cos(4.06263183264 + 20464.84258254131*$t);
  $X0 += 0.00000000079 * cos(1.97866126955 + 10136.7756574519*$t);
  $X0 += 0.00000000066 * cos(2.33925448441 + 14169.5497447469*$t);
  $X0 += 0.00000000063 * cos(3.68749019288 + 18099.7594409665*$t);
  $X0 += 0.00000000060 * cos(3.19857198519 + 29786.9040743645*$t);
  $X0 += 0.00000000064 * cos(5.57155183718 + 30007.3167168033*$t);
  $X0 += 0.00000000054 * cos(3.67263578488 + 30666.3987759163*$t);
  $X0 += 0.00000000058 * cos(3.05733553465 + 75449.7506569799*$t);
  $X0 += 0.00000000073 * cos(3.85067322628 + 51449.5680807617*$t);
  $X0 += 0.00000000074 * cos(5.48458129044 + 21720.2991334881*$t);
  $X0 += 0.00000000063 * cos(2.67652037589 + 26736.1890796967*$t);
  $X0 += 0.00000000054 * cos(3.91509939932 + 38204.9311768545*$t);
  $X0 += 0.00000000072 * cos(4.47140350205 + 100608.3523767453*$t);
  $X0 += 0.00000000053 * cos(3.80804701502 + 419.72846135871*$t);
  $X0 += 0.00000000052 * cos(2.09262980178 + 40426.7878114515*$t);
  $X0 += 0.00000000052 * cos(5.73445119519 + 29580.23089096029*$t);
  $X0 += 0.00000000053 * cos(1.24051301926 + 419.2408263917*$t);
  $X0 += 0.00000000058 * cos(1.31187367842 + 20412.5878159039*$t);
  $X0 += 0.00000000054 * cos(3.26242420831 + 9366.9588939763*$t);
  $X0 += 0.00000000055 * cos(3.59360279993 + 9103.6631766341*$t);
  $X0 += 0.00000000050 * cos(2.37895606630 + 34570.3101523361*$t);
  $X0 += 0.00000000067 * cos(2.64494428691 + 632.5399218297*$t);
  $X0 += 0.00000000050 * cos(1.18004520961 + 37724.5096022647*$t);
  $X0 += 0.00000000069 * cos(1.73296667148 + 53284.94101775829*$t);
  $X0 += 0.00000000057 * cos(1.89823008385 + 8307.5769637871*$t);
  $X0 += 0.00000000050 * cos(4.69860484886 + 8417.7832850065*$t);
  $X0 += 0.00000000049 * cos(1.91804881602 + 26087.65932409069*$t);
  $X0 += 0.00000000064 * cos(2.02816930105 + 7064.3652031063*$t);
  $X0 += 0.00000000049 * cos(1.71661686491 + 14128.4865887291*$t);
  $X0 += 0.00000000056 * cos(2.23445542422 + 28418.2438215195*$t);
  $X0 += 0.00000000066 * cos(6.05166710265 + 19580.7320751543*$t);
  $X0 += 0.00000000047 * cos(2.93855195986 + 10742.73269382209*$t);
  $X0 += 0.00000000061 * cos(1.41947943365 + 43232.0628409321*$t);
  $X0 += 0.00000000061 * cos(4.56107208724 + 43232.5504758991*$t);
  $X0 += 0.00000000047 * cos(4.81852576439 + 38741.7356889499*$t);
  $X0 += 0.00000000050 * cos(1.33989551475 + 59161.1932343711*$t);
  $X0 += 0.00000000046 * cos(2.23137394571 + 18844.8555616225*$t);
  $X0 += 0.00000000054 * cos(0.69428675399 + 48947.9076881601*$t);
  $X0 += 0.00000000046 * cos(4.63842079862 + 3154.9309023791*$t);
  $X0 += 0.00000000046 * cos(4.21170546636 + 194.7275669771*$t);
  $X0 += 0.00000000056 * cos(1.07866938616 + 9936.7835918301*$t);
  $X0 += 0.00000000056 * cos(2.13203135403 + 10490.27513555891*$t);
  $X0 += 0.00000000054 * cos(4.49664827025 + 9922.5564978285*$t);
  $X0 += 0.00000000054 * cos(4.99723777712 + 10504.50222956051*$t);
  $X0 += 0.00000000059 * cos(2.01423634465 + 18204.47064034149*$t);
  $X0 += 0.00000000048 * cos(1.22734670146 + 38727.5085949483*$t);
  $X0 += 0.00000000057 * cos(5.20275648643 + 50316.9596220473*$t);
  $X0 += 0.00000000061 * cos(5.98664723657 + 10140.2322378355*$t);
  $X0 += 0.00000000061 * cos(3.50723881080 + 10286.8264895535*$t);
  $X0 += 0.00000000061 * cos(0.57175194941 + 6567.1789863401*$t);
  $X0 += 0.00000000048 * cos(3.35196537073 + 9246.5584862589*$t);
  $X0 += 0.00000000060 * cos(2.77045228898 + 3684.1342325067*$t);
  $X0 += 0.00000000060 * cos(3.41701763721 + 14427.5983787793*$t);
  $X0 += 0.00000000051 * cos(2.29628619637 + 47623.60896860609*$t);
  $X0 += 0.00000000051 * cos(5.43142352332 + 9566.03089541269*$t);
  $X0 += 0.00000000052 * cos(0.06151623743 + 8727.0616076623*$t);
  $X0 += 0.00000000057 * cos(0.62091438086 + 32243.2546833971*$t);
  $X0 += 0.00000000048 * cos(2.05408316319 + 433.9555553603*$t);
  $X0 += 0.00000000045 * cos(5.52086086974 + 10263.5259855987*$t);
  $X0 += 0.00000000045 * cos(3.97302517763 + 10163.53274179031*$t);
  $X0 += 0.00000000049 * cos(1.65627933457 + 9794.6049647939*$t);
  $X0 += 0.00000000049 * cos(1.55442140562 + 10632.45376259511*$t);
  $X0 += 0.00000000058 * cos(6.19349919374 + 1860.95904382949*$t);
  $X0 += 0.00000000047 * cos(1.50917280490 + 20142.9555910403*$t);
  $X0 += 0.00000000046 * cos(5.38397167897 + 2349.5868529063*$t);
  $X0 += 0.00000000044 * cos(2.04804189558 + 30632.98690911569*$t);
  $X0 += 0.00000000046 * cos(4.70186674108 + 2356.63308960431*$t);
  $X0 += 0.00000000041 * cos(0.12858083101 + 12850.2548363315*$t);
  $X0 += 0.00000000041 * cos(1.71656432171 + 8094.7655033161*$t);
  $X0 += 0.00000000042 * cos(5.08304675769 + 77802.6168107517*$t);
  $X0 += 0.00000000042 * cos(2.81186817738 + 25132.5472174491*$t);
  $X0 += 0.00000000043 * cos(2.37147053321 + 19359.83179774849*$t);
  $X0 += 0.00000000040 * cos(3.89496191683 + 10192.2663332351*$t);
  $X0 += 0.00000000042 * cos(3.28822065771 + 34363.6094150395*$t);
  $X0 += 0.00000000039 * cos(4.35089840905 + 109.9625037359*$t);
  $X0 += 0.00000000044 * cos(4.46863580810 + 79379.96035319949*$t);
  $X0 += 0.00000000043 * cos(4.38742720144 + 38734.13450698209*$t);
  $X0 += 0.00000000046 * cos(0.42463075467 + 17778.3600844325*$t);
  $X0 += 0.00000000039 * cos(6.01839872141 + 12565.9078824993*$t);
  $X0 += 0.00000000041 * cos(0.30408875222 + 27681.89692667289*$t);
  $X0 += 0.00000000053 * cos(1.87369351531 + 64460.4548644779*$t);
  $X0 += 0.00000000039 * cos(3.44426638934 + 28631.5429169575*$t);
  $X0 += 0.00000000052 * cos(5.20963176413 + 38631.5293677305*$t);
  $X0 += 0.00000000043 * cos(6.14192058418 + 11180.5002411301*$t);
  $X0 += 0.00000000039 * cos(1.02239033953 + 1265.81129610991*$t);
  $X0 += 0.00000000039 * cos(3.80918822366 + 7879.84533585549*$t);
  $X0 += 0.00000000039 * cos(0.66759557007 + 7880.3329708225*$t);
  $X0 += 0.00000000052 * cos(1.99450435156 + 1.7282901918*$t);
  $X0 += 0.00000000039 * cos(0.47445196924 + 54981.6287735731*$t);
  $X0 += 0.00000000047 * cos(4.89376316808 + 187.68133027909*$t);
  $X0 += 0.00000000044 * cos(1.17091466926 + 10168.3881440579*$t);
  $X0 += 0.00000000044 * cos(2.03978607093 + 10258.67058333111*$t);
  $X0 += 0.00000000048 * cos(4.68507697395 + 10063.9661665599*$t);
  $X0 += 0.00000000043 * cos(5.12159413101 + 22029.9691371861*$t);
  $X0 += 0.00000000051 * cos(5.89313258670 + 104538.56207296489*$t);
  $X0 += 0.00000000051 * cos(6.27593957045 + 16250.7735674565*$t);
  $X0 += 0.00000000037 * cos(4.48693750961 + 29161.2338820521*$t);
  $X0 += 0.00000000043 * cos(4.92338640427 + 10363.09256082911*$t);
  $X0 += 0.00000000038 * cos(4.13589046896 + 47917.5073879503*$t);
  $X0 += 0.00000000049 * cos(4.56271718314 + 66037.79840692569*$t);
  $X0 += 0.00000000037 * cos(4.41298098667 + 6257.0213476751*$t);
  $X0 += 0.00000000036 * cos(2.97028336578 + 8674.2134938825*$t);
  $X0 += 0.00000000045 * cos(2.00823427492 + 522.3336006103*$t);
  $X0 += 0.00000000049 * cos(1.96278700412 + 491.9071099423*$t);
  $X0 += 0.00000000042 * cos(2.95264046208 + 115674.52048208468*$t);
  $X0 += 0.00000000040 * cos(6.06388400822 + 10233.8171242199*$t);
  $X0 += 0.00000000036 * cos(1.27578830807 + 47938.2827834427*$t);
  $X0 += 0.00000000035 * cos(2.75316747179 + 12546.72575656651*$t);
  $X0 += 0.00000000048 * cos(2.91217379208 + 90395.0668305343*$t);
  $X0 += 0.00000000040 * cos(2.61778472956 + 14127.99895376209*$t);
  $X0 += 0.00000000044 * cos(4.30648713686 + 9698.0654926015*$t);
  $X0 += 0.00000000044 * cos(5.18739891051 + 10728.99323478751*$t);
  $X0 += 0.00000000036 * cos(2.23668112498 + 69942.1974183125*$t);
  $X0 += 0.00000000035 * cos(2.59567778333 + 41654.71929848429*$t);
  $X0 += 0.00000000034 * cos(4.26526324958 + 55798.7021758819*$t);
  $X0 += 0.00000000037 * cos(3.25219443320 + 35192.0539531753*$t);
  $X0 += 0.00000000046 * cos(2.90936826705 + 36301.4325052687*$t);
  $X0 += 0.00000000047 * cos(1.48071490743 + 86464.85713431469*$t);
  $X0 += 0.00000000035 * cos(5.44812994648 + 48732.98752069949*$t);
  $X0 += 0.00000000035 * cos(4.79214932619 + 10011.2759685204*$t);
  $X0 += 0.00000000035 * cos(4.70173672118 + 10415.78275886861*$t);
  $X0 += 0.00000000034 * cos(6.17898420868 + 37410.8110573621*$t);
  $X0 += 0.00000000033 * cos(5.38008686554 + 49477.59865325469*$t);
  $X0 += 0.00000000042 * cos(4.39944587348 + 18830.6284676209*$t);
  $X0 += 0.00000000035 * cos(5.27547059803 + 49515.1386909235*$t);
  $X0 += 0.00000000047 * cos(0.65352099169 + 31022.50935337269*$t);
  $X0 += 0.00000000034 * cos(4.90000292698 + 100909.28143881488*$t);
  $X0 += 0.00000000033 * cos(3.74889730790 + 10117.5501364767*$t);
  $X0 += 0.00000000033 * cos(5.74498873947 + 10309.5085909123*$t);
  $X0 += 0.00000000034 * cos(4.93693556191 + 7461.49412903589*$t);
  $X0 += 0.00000000034 * cos(3.87169740614 + 45584.9289947039*$t);
  $X0 += 0.00000000032 * cos(0.10155743123 + 9676.23721663209*$t);
  $X0 += 0.00000000039 * cos(2.72509244693 + 316.6356871401*$t);
  $X0 += 0.00000000033 * cos(4.45732662556 + 31748.99137324289*$t);
  $X0 += 0.00000000031 * cos(3.44787752858 + 30103.29594402109*$t);
  $X0 += 0.00000000035 * cos(4.20052948408 + 58946.27306691049*$t);
  $X0 += 0.00000000032 * cos(3.76438941046 + 21977.8601325535*$t);
  $X0 += 0.00000000036 * cos(1.22867623820 + 20430.7470631686*$t);
  $X0 += 0.00000000032 * cos(0.22256920805 + 81732.82650697129*$t);
  $X0 += 0.00000000030 * cos(2.28012493395 + 19573.6185281535*$t);
  $X0 += 0.00000000031 * cos(2.48999281964 + 11.2895177474*$t);
  $X0 += 0.00000000038 * cos(4.94526723480 + 20617.77554105009*$t);
  $X0 += 0.00000000033 * cos(5.88114654745 + 83310.1700494191*$t);
  $X0 += 0.00000000029 * cos(0.24041771274 + 11752.8452335065*$t);
  $X0 += 0.00000000029 * cos(5.51688017902 + 9801.1582668201*$t);
  $X0 += 0.00000000029 * cos(3.97700586835 + 10625.9004605689*$t);
  $X0 += 0.00000000030 * cos(3.62180540908 + 20432.3378342129*$t);
  $X0 += 0.00000000031 * cos(4.94266626401 + 7255.8134692179*$t);
  $X0 += 0.00000000029 * cos(4.41071491793 + 9889.53631207009*$t);
  $X0 += 0.00000000029 * cos(1.77595651133 + 224.5886131854*$t);
  $X0 += 0.00000000028 * cos(0.27335698936 + 10099.09007500929*$t);
  $X0 += 0.00000000028 * cos(2.93734375083 + 10327.96865237972*$t);
  $X0 += 0.00000000037 * cos(0.01012570970 + 47964.0934682755*$t);
  $X0 += 0.00000000029 * cos(1.93091525734 + 10426.3408241655*$t);
  $X0 += 0.00000000034 * cos(4.22987244572 + 1539.5596872955*$t);
  $X0 += 0.00000000039 * cos(5.18936044570 + 30563.8343848409*$t);
  $X0 += 0.00000000039 * cos(1.33268449559 + 5791.16874004909*$t);
  $X0 += 0.00000000028 * cos(5.43649843683 + 1178.9507215561*$t);
  $X0 += 0.00000000031 * cos(5.46650886390 + 39786.8905251375*$t);
  $X0 += 0.00000000028 * cos(3.65949505965 + 73872.40711453209*$t);
  $X0 += 0.00000000027 * cos(0.53018129778 + 9411.22079760369*$t);
  $X0 += 0.00000000028 * cos(0.41914594254 + 15694.7842825621*$t);
  $X0 += 0.00000000034 * cos(3.67856303130 + 40213.4887160135*$t);
  $X0 += 0.00000000037 * cos(4.44226497286 + 36949.4746259077*$t);
  $X0 += 0.00000000035 * cos(3.56301256331 + 37704.2218417393*$t);
  $X0 += 0.00000000028 * cos(5.98328888184 + 4732.2744448269*$t);
  $X0 += 0.00000000037 * cos(2.63889784222 + 13859.8797410489*$t);
  $X0 += 0.00000000035 * cos(2.72288729195 + 18093.13088206649*$t);
  $X0 += 0.00000000035 * cos(5.86447994554 + 18093.6185170335*$t);
  $X0 += 0.00000000031 * cos(2.99968207636 + 42430.7295447753*$t);
  $X0 += 0.00000000026 * cos(4.09923425337 + 8734.6627896301*$t);
  $X0 += 0.00000000028 * cos(1.92482741603 + 7886.4738947555*$t);
  $X0 += 0.00000000031 * cos(0.27204438582 + 25960.1788334057*$t);
  return $X0;
}



  function Venus_C_X1 ($t)
{
  $X1 =  0.0;
  $X1 += 0.00051880979 * cos(2.28175279050 + 0.2438174835*$t);
  $X1 += 0.00017260820 * cos(0.92558492780 + 20426.8149099055*$t);
  $X1 += 0.00011049864 * cos(2.03460665124 + 10213.0417287275*$t);
  $X1 += 0.00004831725 * cos(4.77621954273 + 10213.5293636945*$t);
  $X1 += 0.00000175352 * cos(1.80600884943 + 30640.1004561165*$t);
  $X1 += 0.00000060293 * cos(4.92800632264 + 8636.18582124671*$t);
  $X1 += 0.00000062982 * cos(2.09113961987 + 10187.2310438947*$t);
  $X1 += 0.00000062707 * cos(1.11859002578 + 10239.8276834943*$t);
  $X1 += 0.00000049342 * cos(4.57448643960 + 11790.8729061423*$t);
  $X1 += 0.00000036826 * cos(2.07066164376 + 775.7664288075*$t);
  $X1 += 0.00000039689 * cos(3.30583760303 + 20426.32727493849*$t);
  $X1 += 0.00000030101 * cos(5.32708077931 + 10022.0810975829*$t);
  $X1 += 0.00000029330 * cos(4.16541909519 + 10404.9776298061*$t);
  $X1 += 0.00000019990 * cos(1.15893210018 + 9438.0067523705*$t);
  $X1 += 0.00000017877 * cos(2.07736309994 + 10989.0519750185*$t);
  $X1 += 0.00000014175 * cos(3.70557013555 + 9683.8383985999*$t);
  $X1 += 0.00000013388 * cos(1.33844459770 + 191.2044486281*$t);
  $X1 += 0.00000013513 * cos(5.77342390577 + 10743.2203287891*$t);
  $X1 += 0.00000014034 * cos(3.49932313102 + 4705.9761250271*$t);
  $X1 += 0.00000013385 * cos(1.15013591011 + 19651.2922985815*$t);
  $X1 += 0.00000006873 * cos(4.83631203632 + 9104.1508116011*$t);
  $X1 += 0.00000007547 * cos(5.57551333367 + 1059.6257476727*$t);
  $X1 += 0.00000007388 * cos(6.00037338177 + 15721.0826023619*$t);
  $X1 += 0.00000005971 * cos(4.65746818072 + 11322.9079157879*$t);
  $X1 += 0.00000005966 * cos(1.10731222776 + 10220.6429106953*$t);
  $X1 += 0.00000005965 * cos(2.10389967659 + 10206.4158166937*$t);
  $X1 += 0.00000005155 * cos(2.49611854501 + 3154.4432674121*$t);
  $X1 += 0.00000004571 * cos(4.59065584437 + 20618.2631760171*$t);
  $X1 += 0.00000004246 * cos(6.05417599890 + 10000.23026825651*$t);
  $X1 += 0.00000004157 * cos(3.43981648730 + 10426.8284591325*$t);
  $X1 += 0.00000004649 * cos(2.86570769042 + 9830.6328314713*$t);
  $X1 += 0.00000004431 * cos(0.34499590120 + 10596.4258959177*$t);
  $X1 += 0.00000003938 * cos(0.35777611387 + 7.3573644843*$t);
  $X1 += 0.00000003399 * cos(2.39541457575 + 7860.6632099227*$t);
  $X1 += 0.00000002758 * cos(3.91101238225 + 19367.4329797163*$t);
  $X1 += 0.00000002699 * cos(0.65662263221 + 7058.8422787989*$t);
  $X1 += 0.00000002515 * cos(5.65192320935 + 8623.96883344369*$t);
  $X1 += 0.00000002725 * cos(4.96638871958 + 801.5771136403*$t);
  $X1 += 0.00000002539 * cos(5.96953617871 + 9411.7084325707*$t);
  $X1 += 0.00000001822 * cos(3.32629702713 + 1109.1347346099*$t);
  $X1 += 0.00000002300 * cos(3.51596869326 + 11015.3502948183*$t);
  $X1 += 0.00000001816 * cos(2.53054405922 + 13368.2164485901*$t);
  $X1 += 0.00000001814 * cos(4.85812202292 + 3930.4535137031*$t);
  $X1 += 0.00000001586 * cos(2.69305924606 + 40853.3860023275*$t);
  $X1 += 0.00000001999 * cos(2.52624662737 + 26.0545023163*$t);
  $X1 += 0.00000001745 * cos(2.26492854011 + 4552.1973145423*$t);
  $X1 += 0.00000001503 * cos(0.63999417521 + 12566.3955174663*$t);
  $X1 += 0.00000001446 * cos(3.91665476010 + 7084.6529636317*$t);
  $X1 += 0.00000001400 * cos(6.24730767768 + 11272.91129388371*$t);
  $X1 += 0.00000001282 * cos(4.66310117053 + 10219.0522880019*$t);
  $X1 += 0.00000001282 * cos(4.83078487684 + 10208.0064393871*$t);
  $X1 += 0.00000001352 * cos(2.86394052328 + 20419.7013629047*$t);
  $X1 += 0.00000001475 * cos(5.68356978914 + 3128.6325825793*$t);
  $X1 += 0.00000001235 * cos(2.12083036469 + 1577.5873599313*$t);
  $X1 += 0.00000001286 * cos(5.69421578243 + 23581.5019948011*$t);
  $X1 += 0.00000001283 * cos(3.88408958331 + 382.6527147397*$t);
  $X1 += 0.00000001171 * cos(3.28848400510 + 9154.1474335053*$t);
  $X1 += 0.00000001084 * cos(4.35524384671 + 10198.2768925095*$t);
  $X1 += 0.00000001084 * cos(5.13864220066 + 10228.78183487951*$t);
  $X1 += 0.00000001198 * cos(4.95985546788 + 16496.6052136859*$t);
  $X1 += 0.00000000869 * cos(2.39926268528 + 2352.6223362883*$t);
  $X1 += 0.00000001112 * cos(0.28321011044 + 1589.3167127673*$t);
  $X1 += 0.00000000922 * cos(0.95607730643 + 15874.8614128467*$t);
  $X1 += 0.00000000743 * cos(0.68161454240 + 28287.2343023447*$t);
  $X1 += 0.00000000746 * cos(2.15375090404 + 3149.4079780717*$t);
  $X1 += 0.00000000797 * cos(5.11193244020 + 426.8420083595*$t);
  $X1 += 0.00000000625 * cos(3.18531726606 + 20400.5165901057*$t);
  $X1 += 0.00000000615 * cos(0.22278918989 + 21536.1934619989*$t);
  $X1 += 0.00000000832 * cos(1.92436994458 + 21228.63584102931*$t);
  $X1 += 0.00000000656 * cos(5.34274867064 + 11014.8626598513*$t);
  $X1 += 0.00000000586 * cos(2.16720042671 + 5661.5758666357*$t);
  $X1 += 0.00000000648 * cos(1.91289793451 + 537.0483295789*$t);
  $X1 += 0.00000000674 * cos(5.27695637784 + 8094.2778683491*$t);
  $X1 += 0.00000000636 * cos(0.25111675779 + 18849.4713674577*$t);
  $X1 += 0.00000000655 * cos(3.80934378726 + 17298.4261448097*$t);
  $X1 += 0.00000000615 * cos(2.39412529972 + 522.8212355773*$t);
  $X1 += 0.00000000507 * cos(0.55272313227 + 20453.1132297053*$t);
  $X1 += 0.00000000451 * cos(5.12854697169 + 32217.4439985643*$t);
  $X1 += 0.00000000480 * cos(2.46182518074 + 529.44714761109*$t);
  $X1 += 0.00000000439 * cos(3.76528392741 + 6282.83203250789*$t);
  $X1 += 0.00000000439 * cos(2.58129029648 + 29051.0275608327*$t);
  $X1 += 0.00000000410 * cos(5.46936106504 + 24357.0246061251*$t);
  $X1 += 0.00000000452 * cos(3.76215759010 + 9146.54625153749*$t);
  $X1 += 0.00000000417 * cos(4.91991688397 + 6681.46867088311*$t);
  $X1 += 0.00000000434 * cos(3.29962044494 + 9160.77334553909*$t);
  $X1 += 0.00000000364 * cos(2.71580018519 + 10640.1275545705*$t);
  $X1 += 0.00000000363 * cos(0.47492285209 + 9786.9311728185*$t);
  $X1 += 0.00000000428 * cos(0.81939944524 + 20809.7114421287*$t);
  $X1 += 0.00000000440 * cos(2.47378943911 + 9690.9519456007*$t);
  $X1 += 0.00000000440 * cos(0.73691128332 + 10736.1067817883*$t);
  $X1 += 0.00000000372 * cos(0.50265145827 + 10251.55703633031*$t);
  $X1 += 0.00000000372 * cos(2.70804928192 + 10175.5016910587*$t);
  $X1 += 0.00000000319 * cos(1.05799277323 + 17277.6507493173*$t);
  $X1 += 0.00000000427 * cos(2.95582453815 + 18837.7420146217*$t);
  $X1 += 0.00000000319 * cos(0.18812390399 + 7860.17557495569*$t);
  $X1 += 0.00000000303 * cos(1.07261427828 + 14765.48286075331*$t);
  $X1 += 0.00000000351 * cos(2.50811815863 + 6490.0204047715*$t);
  $X1 += 0.00000000287 * cos(0.13453811680 + 1577.0997249643*$t);
  $X1 += 0.00000000318 * cos(0.48117169551 + 14945.0723560709*$t);
  $X1 += 0.00000000297 * cos(1.06831804424 + 10233.1991245943*$t);
  $X1 += 0.00000000297 * cos(2.14238269595 + 10193.85960279471*$t);
  $X1 += 0.00000000372 * cos(5.93165702933 + 22004.1584523533*$t);
  $X1 += 0.00000000311 * cos(1.29581017314 + 9683.35076363289*$t);
  $X1 += 0.00000000284 * cos(2.36025817240 + 3442.81876244891*$t);
  $X1 += 0.00000000269 * cos(1.16222638968 + 9573.14444241349*$t);
  $X1 += 0.00000000262 * cos(3.22424327301 + 21202.3375212295*$t);
  $X1 += 0.00000000285 * cos(4.56673097639 + 13745.5900565059*$t);
  $X1 += 0.00000000276 * cos(1.42552468909 + 9676.7248515991*$t);
  $X1 += 0.00000000289 * cos(5.78612487399 + 20235.36664379391*$t);
  $X1 += 0.00000000263 * cos(5.63102915308 + 22779.6810636773*$t);
  $X1 += 0.00000000280 * cos(5.09544909614 + 14919.2616712381*$t);
  $X1 += 0.00000000262 * cos(1.80492967584 + 10750.33387578991*$t);
  $X1 += 0.00000000256 * cos(4.41502652709 + 10234.3047591869*$t);
  $X1 += 0.00000000239 * cos(4.74729006212 + 5507.7970561509*$t);
  $X1 += 0.00000000253 * cos(5.07523059777 + 10192.7539682021*$t);
  $X1 += 0.00000000268 * cos(0.81556729812 + 27511.7116910207*$t);
  $X1 += 0.00000000282 * cos(6.23856358633 + 4731.7868098599*$t);
  $X1 += 0.00000000232 * cos(4.24398296621 + 3723.26514143949*$t);
  $X1 += 0.00000000285 * cos(5.52678704563 + 20956.5058750001*$t);
  $X1 += 0.00000000244 * cos(3.89280464375 + 2353.1099712553*$t);
  $X1 += 0.00000000272 * cos(4.39654535286 + 20000.2167190295*$t);
  $X1 += 0.00000000254 * cos(4.68153309834 + 6283.3196674749*$t);
  $X1 += 0.00000000238 * cos(4.49319488898 + 30639.61282114949*$t);
  $X1 += 0.00000000232 * cos(1.29928686548 + 19890.0103978101*$t);
  $X1 += 0.00000000210 * cos(1.76685272207 + 18073.46112116669*$t);
  $X1 += 0.00000000216 * cos(4.76667969992 + 18073.9487561337*$t);
  $X1 += 0.00000000199 * cos(0.33116574732 + 9639.18456535971*$t);
  $X1 += 0.00000000218 * cos(0.81835363281 + 19904.2374918117*$t);
  $X1 += 0.00000000225 * cos(0.70271153327 + 13937.0383226175*$t);
  $X1 += 0.00000000235 * cos(3.30083410129 + 1551.2890401315*$t);
  $X1 += 0.00000000191 * cos(4.33367506839 + 6872.91693699471*$t);
  $X1 += 0.00000000179 * cos(0.13296789433 + 30110.4094910219*$t);
  $X1 += 0.00000000185 * cos(2.87950187226 + 10787.8741620293*$t);
  $X1 += 0.00000000235 * cos(2.81621171423 + 1066.7392946735*$t);
  $X1 += 0.00000000208 * cos(5.61842788521 + 10007.3438152573*$t);
  $X1 += 0.00000000208 * cos(3.87545816216 + 10419.7149121317*$t);
  $X1 += 0.00000000179 * cos(1.93004567854 + 18875.2820522905*$t);
  $X1 += 0.00000000184 * cos(1.66108282172 + 9967.69771746511*$t);
  $X1 += 0.00000000166 * cos(1.92550152422 + 18307.56341456009*$t);
  $X1 += 0.00000000163 * cos(4.95974146969 + 10225.2587165305*$t);
  $X1 += 0.00000000163 * cos(4.53414457768 + 10201.80001085851*$t);
  $X1 += 0.00000000156 * cos(6.06699266861 + 10316.6221379131*$t);
  $X1 += 0.00000000156 * cos(3.42689337876 + 10110.4365894759*$t);
  $X1 += 0.00000000178 * cos(1.54946223064 + 10459.3610099239*$t);
  $X1 += 0.00000000172 * cos(4.28587752330 + 14143.7390599141*$t);
  $X1 += 0.00000000163 * cos(3.33734155709 + 8616.85528644289*$t);
  $X1 += 0.00000000163 * cos(4.34265322302 + 6.86972951729*$t);
  $X1 += 0.00000000157 * cos(5.15568499427 + 13554.1417903943*$t);
  $X1 += 0.00000000152 * cos(5.19097050991 + 640.1411037975*$t);
  $X1 += 0.00000000149 * cos(4.59659252448 + 7063.87756813929*$t);
  $X1 += 0.00000000179 * cos(2.57671187060 + 29864.5778447925*$t);
  $X1 += 0.00000000140 * cos(3.74361509193 + 8631.0823804445*$t);
  $X1 += 0.00000000140 * cos(1.47790992779 + 529.9347825781*$t);
  $X1 += 0.00000000131 * cos(4.02274509510 + 9794.0447198193*$t);
  $X1 += 0.00000000170 * cos(1.92390663066 + 9153.6597985383*$t);
  $X1 += 0.00000000128 * cos(5.46982761491 + 10633.0140075697*$t);
  $X1 += 0.00000000177 * cos(4.60925492420 + 5481.4987363511*$t);
  $X1 += 0.00000000154 * cos(0.98130891951 + 2119.00767786191*$t);
  $X1 += 0.00000000131 * cos(0.85435524802 + 16984.2399649401*$t);
  $X1 += 0.00000000131 * cos(2.78432814801 + 9437.5191174035*$t);
  $X1 += 0.00000000118 * cos(0.33770416850 + 11790.3852711753*$t);
  $X1 += 0.00000000140 * cos(3.57821725968 + 191.6920835951*$t);
  $X1 += 0.00000000143 * cos(4.89084114003 + 7994.77225950771*$t);
  $X1 += 0.00000000123 * cos(2.80558057017 + 213.5429129215*$t);
  $X1 += 0.00000000111 * cos(1.17808071549 + 8661.9965060795*$t);
  $X1 += 0.00000000121 * cos(2.21290119959 + 28521.3365957381*$t);
  $X1 += 0.00000000119 * cos(1.63506882892 + 3929.96587873609*$t);
  $X1 += 0.00000000106 * cos(5.90822125685 + 1109.6223695769*$t);
  $X1 += 0.00000000099 * cos(2.30048706584 + 20.5315780089*$t);
  $X1 += 0.00000000104 * cos(6.17530863971 + 36147.6536947839*$t);
  $X1 += 0.00000000107 * cos(3.35632619038 + 22805.4917485101*$t);
  $X1 += 0.00000000125 * cos(4.66656170776 + 12432.2864678813*$t);
  $X1 += 0.00000000101 * cos(3.14294490163 + 1052.51220067191*$t);
  $X1 += 0.00000000093 * cos(0.14824204033 + 574.10098085129*$t);
  $X1 += 0.00000000129 * cos(4.90531185126 + 7564.58690325449*$t);
  $X1 += 0.00000000092 * cos(1.92722181403 + 9359.84534697549*$t);
  $X1 += 0.00000000099 * cos(2.32246660439 + 31441.92138724031*$t);
  $X1 += 0.00000000091 * cos(6.18685264626 + 775.2787938405*$t);
  $X1 += 0.00000000112 * cos(5.12786964903 + 10186.7434089277*$t);
  $X1 += 0.00000000095 * cos(3.66782801204 + 10433.9420061333*$t);
  $X1 += 0.00000000095 * cos(5.82605803532 + 9993.1167212557*$t);
  $X1 += 0.00000000092 * cos(0.35578303465 + 14143.2514249471*$t);
  $X1 += 0.00000000096 * cos(5.32806010513 + 220.6564599223*$t);
  $X1 += 0.00000000084 * cos(5.80809189896 + 6770.46678376209*$t);
  $X1 += 0.00000000088 * cos(1.99015323508 + 11322.42028082089*$t);
  $X1 += 0.00000000110 * cos(0.30263518591 + 11802.6022589783*$t);
  $X1 += 0.00000000108 * cos(5.13400336320 + 29580.7185259273*$t);
  $X1 += 0.00000000093 * cos(5.89321185295 + 2957.9597119601*$t);
  $X1 += 0.00000000101 * cos(2.09186878730 + 6770.9544187291*$t);
  $X1 += 0.00000000105 * cos(4.75827384051 + 8662.48414104651*$t);
  $X1 += 0.00000000094 * cos(1.47978763830 + 20433.9284569063*$t);
  $X1 += 0.00000000089 * cos(2.27805851709 + 15720.5949673949*$t);
  $X1 += 0.00000000088 * cos(5.79703525886 + 206.42936592071*$t);
  $X1 += 0.00000000101 * cos(2.08027263650 + 7085.1405985987*$t);
  $X1 += 0.00000000077 * cos(4.50520624769 + 10177.5014970171*$t);
  $X1 += 0.00000000077 * cos(4.98867979968 + 10249.55723037191*$t);
  $X1 += 0.00000000087 * cos(1.15473517110 + 2378.9206560881*$t);
  $X1 += 0.00000000080 * cos(1.30578005980 + 5507.3094211839*$t);
  $X1 += 0.00000000100 * cos(4.88512859986 + 14945.5599910379*$t);
  $X1 += 0.00000000096 * cos(2.91515384440 + 8624.45646841071*$t);
  $X1 += 0.00000000071 * cos(1.17266085434 + 24150.3238688285*$t);
  $X1 += 0.00000000089 * cos(6.18976687503 + 18875.76968725751*$t);
  $X1 += 0.00000000071 * cos(0.26607557139 + 29043.91401383189*$t);
  $X1 += 0.00000000075 * cos(6.05522319041 + 19897.1239448109*$t);
  $X1 += 0.00000000068 * cos(3.96046123295 + 10384.2022343137*$t);
  $X1 += 0.00000000068 * cos(5.53342481442 + 10042.8564930753*$t);
  $X1 += 0.00000000077 * cos(0.65929723000 + 29573.6049789265*$t);
  $X1 += 0.00000000073 * cos(0.21801456964 + 29587.8320729281*$t);
  $X1 += 0.00000000063 * cos(3.39603171816 + 10239.3400485273*$t);
  $X1 += 0.00000000086 * cos(3.93300049009 + 19650.8046636145*$t);
  $X1 += 0.00000000086 * cos(0.41942430117 + 19360.3194327155*$t);
  $X1 += 0.00000000061 * cos(0.66096242131 + 29058.1411078335*$t);
  $X1 += 0.00000000081 * cos(4.74585662186 + 11764.5745863425*$t);
  $X1 += 0.00000000066 * cos(4.80481512048 + 26735.7014447297*$t);
  $X1 += 0.00000000075 * cos(1.14917066460 + 25934.3681485729*$t);
  $X1 += 0.00000000067 * cos(1.15917986378 + 40077.8633910035*$t);
  $X1 += 0.00000000059 * cos(4.95335370099 + 10988.5643400515*$t);
  $X1 += 0.00000000077 * cos(0.71010883429 + 20213.5158144675*$t);
  $X1 += 0.00000000077 * cos(3.31402335732 + 7834.3648901229*$t);
  $X1 += 0.00000000057 * cos(1.06828917998 + 10404.48999483909*$t);
  $X1 += 0.00000000057 * cos(1.40187066473 + 110.45013870291*$t);
  $X1 += 0.00000000067 * cos(1.57273164979 + 17777.87244946549*$t);
  $X1 += 0.00000000060 * cos(6.21424049877 + 30831.5487222281*$t);
  $X1 += 0.00000000058 * cos(2.47733285182 + 12592.2062022991*$t);
  $X1 += 0.00000000054 * cos(4.90109601900 + 19317.43635781211*$t);
  $X1 += 0.00000000065 * cos(3.16919569918 + 25158.8455372489*$t);
  $X1 += 0.00000000064 * cos(2.20893920610 + 18308.0510495271*$t);
  $X1 += 0.00000000059 * cos(0.10111317126 + 9779.32999085069*$t);
  $X1 += 0.00000000053 * cos(1.51934336072 + 27490.9362955283*$t);
  $X1 += 0.00000000050 * cos(1.75539922827 + 10103.3230424751*$t);
  $X1 += 0.00000000050 * cos(1.45530151192 + 10323.7356849139*$t);
  $X1 += 0.00000000050 * cos(6.21018693293 + 39794.0040721383*$t);
  $X1 += 0.00000000055 * cos(5.90009200198 + 9793.5570848523*$t);
  $X1 += 0.00000000048 * cos(4.23138520787 + 29089.0552334685*$t);
  $X1 += 0.00000000051 * cos(0.59694211544 + 26709.8907598969*$t);
  $X1 += 0.00000000047 * cos(3.85157632106 + 16522.4158985187*$t);
  $X1 += 0.00000000060 * cos(6.18581659700 + 12592.6938372661*$t);
  $X1 += 0.00000000057 * cos(3.26039666468 + 2218.51328670329*$t);
  $X1 += 0.00000000047 * cos(3.62423252693 + 20640.1140053435*$t);
  $X1 += 0.00000000046 * cos(4.31718986476 + 19786.9176235915*$t);
  $X1 += 0.00000000047 * cos(2.61830291086 + 57836.89451481709*$t);
  $X1 += 0.00000000045 * cos(3.93917249780 + 3532.3045102949*$t);
  $X1 += 0.00000000047 * cos(0.02859294876 + 22003.6708173863*$t);
  $X1 += 0.00000000045 * cos(4.38533780662 + 30000.2031698025*$t);
  $X1 += 0.00000000043 * cos(5.13871521232 + 29786.9040743645*$t);
  $X1 += 0.00000000051 * cos(2.50512066478 + 44008.0730872231*$t);
  $X1 += 0.00000000042 * cos(4.64511163321 + 9999.7426332895*$t);
  $X1 += 0.00000000050 * cos(5.23051268807 + 23581.0143598341*$t);
  $X1 += 0.00000000051 * cos(1.29476911793 + 13341.9181287903*$t);
  $X1 += 0.00000000040 * cos(5.56163575062 + 33019.2649296881*$t);
  $X1 += 0.00000000051 * cos(1.12826192024 + 13656.10430865991*$t);
  $X1 += 0.00000000048 * cos(5.72986884882 + 213.0552779545*$t);
  $X1 += 0.00000000039 * cos(5.77845089286 + 20447.5903053979*$t);
  $X1 += 0.00000000039 * cos(1.18630935880 + 10595.9382609507*$t);
  $X1 += 0.00000000042 * cos(6.23472824067 + 30665.9111409493*$t);
  $X1 += 0.00000000042 * cos(0.50469059035 + 3914.71340755109*$t);
  $X1 += 0.00000000042 * cos(4.77756101392 + 38204.9311768545*$t);
  $X1 += 0.00000000041 * cos(3.60025537560 + 17469.0990154289*$t);
  $X1 += 0.00000000036 * cos(5.95301096335 + 10077.90403868451*$t);
  $X1 += 0.00000000036 * cos(3.54087508402 + 10349.1546887045*$t);
  $X1 += 0.00000000040 * cos(0.08435320836 + 18830.14083265389*$t);
  $X1 += 0.00000000039 * cos(5.88165362901 + 18844.36792665549*$t);
  $X1 += 0.00000000034 * cos(3.36376891454 + 21001.1597082403*$t);
  $X1 += 0.00000000034 * cos(1.57325955329 + 13936.5506876505*$t);
  $X1 += 0.00000000032 * cos(0.62824969555 + 36949.4746259077*$t);
  $X1 += 0.00000000033 * cos(4.53469110076 + 16983.75232997309*$t);
  $X1 += 0.00000000040 * cos(3.88665965181 + 47938.2827834427*$t);
  $X1 += 0.00000000032 * cos(5.46497273946 + 39301.8531447125*$t);
  $X1 += 0.00000000032 * cos(5.46497273946 + 39302.3407796795*$t);
  $X1 += 0.00000000036 * cos(0.13872965215 + 19374.5465267171*$t);
  $X1 += 0.00000000032 * cos(5.49940747482 + 16894.7542170941*$t);
  $X1 += 0.00000000042 * cos(0.37006377215 + 55798.7021758819*$t);
  $X1 += 0.00000000031 * cos(3.51648880247 + 20043.9183776823*$t);
  $X1 += 0.00000000033 * cos(1.44339512827 + 48418.21672306549*$t);
  $X1 += 0.00000000031 * cos(1.24271036891 + 9573.6320773805*$t);
  $X1 += 0.00000000034 * cos(5.27191504099 + 54247.1693182669*$t);
  $X1 += 0.00000000032 * cos(2.12080485437 + 10191.6785343681*$t);
  $X1 += 0.00000000032 * cos(1.08989588581 + 10235.3801930209*$t);
  $X1 += 0.00000000031 * cos(2.88701937696 + 8087.1643213483*$t);
  $X1 += 0.00000000032 * cos(1.43989537444 + 19896.63630984389*$t);
  $X1 += 0.00000000036 * cos(0.86097595428 + 7255.3258342509*$t);
  $X1 += 0.00000000030 * cos(1.96661961760 + 10853.4266500085*$t);
  $X1 += 0.00000000037 * cos(0.40709954927 + 27511.2240560537*$t);
  $X1 += 0.00000000032 * cos(3.94523183143 + 19366.94534474929*$t);
  $X1 += 0.00000000029 * cos(5.21162982204 + 10291.20313412251*$t);
  $X1 += 0.00000000029 * cos(4.28225622533 + 10135.8555932665*$t);
  $X1 += 0.00000000028 * cos(5.74069429835 + 104351.85638378029*$t);
  $X1 += 0.00000000032 * cos(4.16582591800 + 20206.4022674667*$t);
  $X1 += 0.00000000029 * cos(6.04399510869 + 29864.0902098255*$t);
  $X1 += 0.00000000029 * cos(3.70427099153 + 49515.1386909235*$t);
  $X1 += 0.00000000027 * cos(5.20809241529 + 5661.0882316687*$t);
  $X1 += 0.00000000034 * cos(2.13914627667 + 9161.2609805061*$t);
  $X1 += 0.00000000027 * cos(2.35964005449 + 6872.42930202769*$t);
  $X1 += 0.00000000032 * cos(5.37255836333 + 9836.1557557787*$t);
  $X1 += 0.00000000032 * cos(4.12132768404 + 10590.9029716103*$t);
  $X1 += 0.00000000027 * cos(6.25293311610 + 6298.57213865991*$t);
  $X1 += 0.00000000035 * cos(5.35069959846 + 9986.0532309055*$t);
  $X1 += 0.00000000035 * cos(4.14318644891 + 10441.00549648351*$t);
  $X1 += 0.00000000033 * cos(2.06705744681 + 31441.4337522733*$t);
  $X1 += 0.00000000026 * cos(1.99269274261 + 40879.6843221273*$t);
  $X1 += 0.00000000034 * cos(2.86141693506 + 1059.1381127057*$t);
  $X1 += 0.00000000028 * cos(3.27143415157 + 27197.03787618409*$t);
  $X1 += 0.00000000026 * cos(4.77604105797 + 34363.6094150395*$t);
  $X1 += 0.00000000032 * cos(1.06669637529 + 11265.7977468829*$t);
  $X1 += 0.00000000029 * cos(3.31179813455 + 30206.38871823969*$t);
  $X1 += 0.00000000032 * cos(5.28518925051 + 51868.4924796623*$t);
  $X1 += 0.00000000029 * cos(3.60960317836 + 35371.6434484929*$t);
  $X1 += 0.00000000029 * cos(3.60960317836 + 35372.1310834599*$t);
  $X1 += 0.00000000027 * cos(1.39820608512 + 34596.1208371689*$t);
  $X1 += 0.00000000033 * cos(1.79087945691 + 59728.91187210151*$t);
  $X1 += 0.00000000029 * cos(3.70229059266 + 20220.6293614683*$t);
  $X1 += 0.00000000025 * cos(4.71719114041 + 25933.8805136059*$t);
  $X1 += 0.00000000024 * cos(5.85674327230 + 8734.17515466309*$t);
  $X1 += 0.00000000027 * cos(2.50446352876 + 66813.80865321669*$t);
  $X1 += 0.00000000024 * cos(1.21352192025 + 36173.4643796167*$t);
  $X1 += 0.00000000024 * cos(4.42282415616 + 31022.9969883397*$t);
  $X1 += 0.00000000023 * cos(0.26441959495 + 24382.8352909579*$t);
  $X1 += 0.00000000028 * cos(1.01958443856 + 27461.46703058189*$t);
  $X1 += 0.00000000027 * cos(2.82757763572 + 30220.6158122413*$t);
  $X1 += 0.00000000023 * cos(2.71148449796 + 10367.3081741793*$t);
  $X1 += 0.00000000023 * cos(0.49921624223 + 10059.7505532097*$t);
  $X1 += 0.00000000023 * cos(5.14356401989 + 20452.6255947383*$t);
  $X1 += 0.00000000026 * cos(2.79748800924 + 39271.4266540445*$t);
  $X1 += 0.00000000026 * cos(3.27996977321 + 39257.1995600429*$t);
  $X1 += 0.00000000022 * cos(0.64539022706 + 43232.0628409321*$t);
  $X1 += 0.00000000022 * cos(0.64539022706 + 43232.5504758991*$t);
  $X1 += 0.00000000026 * cos(3.68377277974 + 8101.39141534989*$t);
  $X1 += 0.00000000022 * cos(2.92850972756 + 24978.7684069643*$t);
  $X1 += 0.00000000022 * cos(2.54378881371 + 25158.3579022819*$t);
  $X1 += 0.00000000030 * cos(4.35689894819 + 17248.18148437089*$t);
  $X1 += 0.00000000022 * cos(4.40135816223 + 27991.15799567649*$t);
  $X1 += 0.00000000022 * cos(1.75419561511 + 30426.8013606785*$t);
  $X1 += 0.00000000022 * cos(5.61039853516 + 802.0647486073*$t);
  $X1 += 0.00000000028 * cos(5.29619670984 + 17297.9385098427*$t);
  $X1 += 0.00000000021 * cos(1.01517564916 + 9147.03388650451*$t);
  $X1 += 0.00000000024 * cos(5.57258032099 + 46386.7499258277*$t);
  $X1 += 0.00000000021 * cos(2.72351924355 + 27197.5255111511*$t);
  $X1 += 0.00000000021 * cos(3.36801059218 + 44809.8940183469*$t);
  $X1 += 0.00000000024 * cos(5.90015079750 + 52176.0501006319*$t);
  $X1 += 0.00000000025 * cos(4.38058629438 + 22805.9793834771*$t);
  $X1 += 0.00000000022 * cos(0.93569574784 + 9566.03089541269*$t);
  $X1 += 0.00000000023 * cos(2.47187255983 + 6309.1303523077*$t);
  $X1 += 0.00000000021 * cos(2.05775290145 + 10949.4058772263*$t);
  $X1 += 0.00000000021 * cos(1.15294783874 + 9477.65285016271*$t);
  $X1 += 0.00000000024 * cos(0.56697771725 + 10288.3109622618*$t);
  $X1 += 0.00000000024 * cos(2.64372302294 + 10138.7477651272*$t);
  $X1 += 0.00000000027 * cos(0.54831840561 + 9580.2579894143*$t);
  $X1 += 0.00000000020 * cos(5.88803150614 + 8635.69818627969*$t);
  $X1 += 0.00000000020 * cos(2.21258610934 + 11280.0248408845*$t);
  $X1 += 0.00000000021 * cos(3.74792739506 + 3531.81687532789*$t);
  $X1 += 0.00000000022 * cos(1.10471815077 + 62883.5989569971*$t);
  $X1 += 0.00000000020 * cos(4.47242869756 + 17468.6113804619*$t);
  $X1 += 0.00000000023 * cos(2.67526294292 + 10263.2863891663*$t);
  $X1 += 0.00000000023 * cos(0.53543779727 + 10163.7723382227*$t);
  $X1 += 0.00000000027 * cos(4.35265351175 + 32216.95636359729*$t);
  $X1 += 0.00000000021 * cos(0.20196459716 + 47624.0966035731*$t);
  $X1 += 0.00000000023 * cos(4.44238440406 + 55022.6919295909*$t);
  $X1 += 0.00000000021 * cos(5.91319275029 + 18300.44986755929*$t);
  $X1 += 0.00000000026 * cos(3.21324974687 + 63659.1215683211*$t);
  $X1 += 0.00000000021 * cos(1.29300419185 + 43071.65547154729*$t);
  $X1 += 0.00000000019 * cos(1.80883011026 + 20316.6085886861*$t);
  $X1 += 0.00000000027 * cos(2.91239597616 + 28286.74666737769*$t);
  $X1 += 0.00000000020 * cos(0.92201397306 + 62081.7780258733*$t);
  $X1 += 0.00000000021 * cos(3.71520409064 + 24341.7721349401*$t);
  $X1 += 0.00000000020 * cos(2.70818412083 + 49477.59865325469*$t);
  $X1 += 0.00000000020 * cos(3.92540543269 + 70744.0183494363*$t);
  $X1 += 0.00000000018 * cos(3.24042993488 + 14128.4865887291*$t);
  $X1 += 0.00000000022 * cos(1.96762524944 + 27991.6456306435*$t);
  $X1 += 0.00000000018 * cos(5.40557069193 + 9050.56702431969*$t);
  $X1 += 0.00000000018 * cos(1.21555571929 + 4705.4884900601*$t);
  $X1 += 0.00000000017 * cos(1.63173823644 + 28313.0449871775*$t);
  $X1 += 0.00000000017 * cos(4.46941749243 + 10497.38868255971*$t);
  $X1 += 0.00000000017 * cos(5.02446855494 + 9929.6700448293*$t);
  $X1 += 0.00000000017 * cos(0.77261247444 + 19624.9939787817*$t);
  $X1 += 0.00000000018 * cos(5.82240394487 + 29050.53992586569*$t);
  $X1 += 0.00000000017 * cos(6.13439373448 + 18314.67696156089*$t);
  $X1 += 0.00000000016 * cos(4.75152522759 + 48740.1037145665*$t);
  $X1 += 0.00000000018 * cos(2.82811097731 + 38526.3305333885*$t);
  $X1 += 0.00000000018 * cos(0.02896271913 + 42430.7295447753*$t);
  $X1 += 0.00000000018 * cos(4.17302923646 + 42456.5402296081*$t);
  $X1 += 0.00000000018 * cos(1.01249884206 + 33794.2999060451*$t);
  $X1 += 0.00000000018 * cos(1.01249884206 + 33794.7875410121*$t);
  $X1 += 0.00000000016 * cos(5.43519924864 + 9745.5643733401*$t);
  $X1 += 0.00000000016 * cos(4.05868679873 + 10681.49435404891*$t);
  $X1 += 0.00000000016 * cos(4.91307958316 + 38734.6221419491*$t);
  $X1 += 0.00000000016 * cos(1.98563978946 + 47162.2725371517*$t);
  $X1 += 0.00000000016 * cos(1.98563978946 + 47162.7601721187*$t);
  $X1 += 0.00000000015 * cos(5.40287159543 + 10199.3022696929*$t);
  $X1 += 0.00000000015 * cos(4.09101445194 + 10227.7564576961*$t);
  $X1 += 0.00000000015 * cos(4.40286421658 + 41654.71929848429*$t);
  $X1 += 0.00000000017 * cos(0.71063741169 + 50316.9596220473*$t);
  $X1 += 0.00000000015 * cos(2.70406423385 + 53285.4286527253*$t);
  $X1 += 0.00000000015 * cos(2.34568334494 + 66011.98772209289*$t);
  $X1 += 0.00000000015 * cos(2.83728676171 + 38727.5085949483*$t);
  $X1 += 0.00000000015 * cos(1.51871369727 + 46360.9392409949*$t);
  $X1 += 0.00000000019 * cos(4.60379625756 + 67589.3312645407*$t);
  $X1 += 0.00000000014 * cos(1.35244180937 + 21228.1482060623*$t);
  $X1 += 0.00000000014 * cos(0.37440411348 + 40000.1896205755*$t);
  $X1 += 0.00000000014 * cos(1.52734358006 + 11027.07964765431*$t);
  $X1 += 0.00000000014 * cos(1.68335716013 + 9399.9790797347*$t);
  $X1 += 0.00000000014 * cos(1.39514541459 + 37895.6701078509*$t);
  $X1 += 0.00000000014 * cos(1.44888424284 + 37410.8110573621*$t);
  $X1 += 0.00000000014 * cos(2.94215733290 + 50291.1489372145*$t);
  $X1 += 0.00000000013 * cos(4.17219621815 + 12565.9078824993*$t);
  $X1 += 0.00000000015 * cos(6.22361957178 + 21486.1968400947*$t);
  $X1 += 0.00000000013 * cos(6.14132227253 + 52670.3134107861*$t);
  return $X1*$t;
}



  function Venus_C_X2 ($t)
{
  $X2 =  0.0;
  $X2 += 0.00039116576 * cos(4.74721085665 + 10213.5293636945*$t);
  $X2 += 0.00001782208 * cos(4.51495547304 + 0.2438174835*$t);
  $X2 += 0.00000953335 * cos(3.63516488566 + 10213.0417287275*$t);
  $X2 += 0.00000818754 * cos(5.17913474548 + 20426.8149099055*$t);
  $X2 += 0.00000012014 * cos(5.55504004602 + 30640.1004561165*$t);
  $X2 += 0.00000008598 * cos(0.48030487437 + 10239.8276834943*$t);
  $X2 += 0.00000008636 * cos(2.67172999291 + 10187.2310438947*$t);
  $X2 += 0.00000003631 * cos(5.13091719462 + 20426.32727493849*$t);
  $X2 += 0.00000002965 * cos(3.11794464067 + 8636.18582124671*$t);
  $X2 += 0.00000003797 * cos(0.73505869096 + 9438.0067523705*$t);
  $X2 += 0.00000003421 * cos(2.39489149839 + 10989.0519750185*$t);
  $X2 += 0.00000002218 * cos(3.69616749811 + 10022.0810975829*$t);
  $X2 += 0.00000002134 * cos(5.69388419448 + 10404.9776298061*$t);
  $X2 += 0.00000002187 * cos(6.14628758046 + 11790.8729061423*$t);
  $X2 += 0.00000001794 * cos(0.26131314165 + 775.7664288075*$t);
  $X2 += 0.00000001421 * cos(1.89983182794 + 2353.1099712553*$t);
  $X2 += 0.00000000972 * cos(2.65726077013 + 1577.0997249643*$t);
  $X2 += 0.00000000682 * cos(1.68817935727 + 4705.9761250271*$t);
  $X2 += 0.00000000658 * cos(4.84602149726 + 9683.8383985999*$t);
  $X2 += 0.00000000715 * cos(1.34290194955 + 9830.6328314713*$t);
  $X2 += 0.00000000683 * cos(1.84498400268 + 10596.4258959177*$t);
  $X2 += 0.00000000568 * cos(2.68352094618 + 19651.2922985815*$t);
  $X2 += 0.00000000544 * cos(3.07694729173 + 191.2044486281*$t);
  $X2 += 0.00000000678 * cos(4.45588465096 + 18073.9487561337*$t);
  $X2 += 0.00000000574 * cos(5.09706238916 + 801.5771136403*$t);
  $X2 += 0.00000000418 * cos(4.31488544265 + 10743.2203287891*$t);
  $X2 += 0.00000000561 * cos(3.32645295084 + 6283.3196674749*$t);
  $X2 += 0.00000000531 * cos(0.97430911335 + 7058.8422787989*$t);
  $X2 += 0.00000000371 * cos(5.86501171146 + 9411.7084325707*$t);
  $X2 += 0.00000000414 * cos(2.16574465889 + 529.9347825781*$t);
  $X2 += 0.00000000287 * cos(3.12423584879 + 9104.1508116011*$t);
  $X2 += 0.00000000314 * cos(1.28037944612 + 15721.0826023619*$t);
  $X2 += 0.00000000301 * cos(2.30568402177 + 26.0545023163*$t);
  $X2 += 0.00000000354 * cos(2.15592461692 + 13368.2164485901*$t);
  $X2 += 0.00000000361 * cos(3.03077999717 + 14143.7390599141*$t);
  $X2 += 0.00000000349 * cos(2.69866467882 + 22004.1584523533*$t);
  $X2 += 0.00000000253 * cos(3.49550693096 + 1059.6257476727*$t);
  $X2 += 0.00000000253 * cos(6.11019925201 + 11322.9079157879*$t);
  $X2 += 0.00000000253 * cos(4.31046856084 + 3154.4432674121*$t);
  $X2 += 0.00000000321 * cos(3.51926077378 + 11015.3502948183*$t);
  $X2 += 0.00000000305 * cos(5.79665591896 + 3128.6325825793*$t);
  $X2 += 0.00000000202 * cos(1.70860223309 + 10426.8284591325*$t);
  $X2 += 0.00000000195 * cos(6.03063629123 + 20618.2631760171*$t);
  $X2 += 0.00000000178 * cos(1.34005224381 + 10000.23026825651*$t);
  $X2 += 0.00000000157 * cos(6.22467540109 + 40853.3860023275*$t);
  $X2 += 0.00000000159 * cos(5.43308713463 + 382.6527147397*$t);
  $X2 += 0.00000000177 * cos(1.96418161194 + 21228.63584102931*$t);
  $X2 += 0.00000000126 * cos(2.62766766451 + 18849.4713674577*$t);
  $X2 += 0.00000000131 * cos(0.73006046049 + 1577.5873599313*$t);
  $X2 += 0.00000000148 * cos(4.01019073124 + 5507.3094211839*$t);
  $X2 += 0.00000000139 * cos(4.55765675380 + 7860.6632099227*$t);
  $X2 += 0.00000000146 * cos(4.19737673183 + 19897.1239448109*$t);
  $X2 += 0.00000000133 * cos(3.60550981906 + 17298.4261448097*$t);
  $X2 += 0.00000000088 * cos(0.74174526538 + 8623.96883344369*$t);
  $X2 += 0.00000000116 * cos(3.56002594290 + 9153.6597985383*$t);
  $X2 += 0.00000000111 * cos(5.81554919476 + 20453.1132297053*$t);
  $X2 += 0.00000000077 * cos(5.72141298699 + 7084.6529636317*$t);
  $X2 += 0.00000000081 * cos(3.85700349092 + 2352.6223362883*$t);
  $X2 += 0.00000000088 * cos(0.02333507058 + 3930.4535137031*$t);
  $X2 += 0.00000000077 * cos(3.12509816452 + 16496.6052136859*$t);
  $X2 += 0.00000000069 * cos(1.03046490507 + 23581.5019948011*$t);
  $X2 += 0.00000000058 * cos(4.44021603496 + 9154.1474335053*$t);
  $X2 += 0.00000000062 * cos(5.17807799754 + 1109.1347346099*$t);
  $X2 += 0.00000000063 * cos(5.42244602531 + 9437.5191174035*$t);
  $X2 += 0.00000000047 * cos(3.73566941706 + 29051.0275608327*$t);
  $X2 += 0.00000000054 * cos(2.34590128189 + 20809.7114421287*$t);
  $X2 += 0.00000000055 * cos(0.27212302992 + 4731.7868098599*$t);
  $X2 += 0.00000000046 * cos(5.56053620908 + 19367.4329797163*$t);
  $X2 += 0.00000000044 * cos(4.38854627107 + 10787.8741620293*$t);
  $X2 += 0.00000000044 * cos(5.10533977629 + 9639.18456535971*$t);
  $X2 += 0.00000000040 * cos(0.19406822983 + 8094.2778683491*$t);
  $X2 += 0.00000000041 * cos(0.23997896197 + 3929.96587873609*$t);
  $X2 += 0.00000000047 * cos(4.99296496795 + 12566.3955174663*$t);
  $X2 += 0.00000000038 * cos(5.33087019939 + 6282.83203250789*$t);
  $X2 += 0.00000000045 * cos(4.21174903018 + 25934.3681485729*$t);
  $X2 += 0.00000000034 * cos(4.95079079946 + 28287.2343023447*$t);
  $X2 += 0.00000000033 * cos(0.84076094156 + 11014.8626598513*$t);
  $X2 += 0.00000000034 * cos(1.04665276837 + 14919.2616712381*$t);
  $X2 += 0.00000000032 * cos(3.42124102189 + 24357.0246061251*$t);
  $X2 += 0.00000000028 * cos(3.83338891686 + 20235.36664379391*$t);
  $X2 += 0.00000000040 * cos(3.61668312604 + 29580.7185259273*$t);
  $X2 += 0.00000000033 * cos(5.35791701104 + 4552.1973145423*$t);
  $X2 += 0.00000000033 * cos(0.97035705954 + 6490.0204047715*$t);
  $X2 += 0.00000000027 * cos(0.80253867623 + 10640.1275545705*$t);
  $X2 += 0.00000000026 * cos(2.37794131191 + 9786.9311728185*$t);
  $X2 += 0.00000000026 * cos(0.52950336946 + 3149.4079780717*$t);
  $X2 += 0.00000000025 * cos(2.09390807595 + 10192.7539682021*$t);
  $X2 += 0.00000000025 * cos(4.26281208500 + 10234.3047591869*$t);
  $X2 += 0.00000000024 * cos(1.66809456061 + 21536.1934619989*$t);
  $X2 += 0.00000000026 * cos(5.00411416070 + 14143.2514249471*$t);
  $X2 += 0.00000000024 * cos(6.24637715602 + 18307.56341456009*$t);
  $X2 += 0.00000000024 * cos(6.23872379023 + 5507.7970561509*$t);
  $X2 += 0.00000000025 * cos(0.42768275114 + 18875.2820522905*$t);
  $X2 += 0.00000000030 * cos(3.82426253554 + 20400.5165901057*$t);
  $X2 += 0.00000000025 * cos(2.48440063286 + 27511.7116910207*$t);
  $X2 += 0.00000000025 * cos(1.71524233724 + 8661.9965060795*$t);
  $X2 += 0.00000000019 * cos(5.30003473361 + 11272.91129388371*$t);
  $X2 += 0.00000000022 * cos(0.30636210636 + 30639.61282114949*$t);
  $X2 += 0.00000000026 * cos(2.43625052079 + 213.5429129215*$t);
  $X2 += 0.00000000018 * cos(3.34143186430 + 28521.3365957381*$t);
  $X2 += 0.00000000023 * cos(2.19310017282 + 13937.0383226175*$t);
  $X2 += 0.00000000024 * cos(0.64478935102 + 13367.7288136231*$t);
  $X2 += 0.00000000021 * cos(0.38789416530 + 10186.7434089277*$t);
  $X2 += 0.00000000019 * cos(2.13540095490 + 10988.5643400515*$t);
  $X2 += 0.00000000018 * cos(3.02877957634 + 32217.4439985643*$t);
  $X2 += 0.00000000020 * cos(5.05892110724 + 191.6920835951*$t);
  $X2 += 0.00000000017 * cos(1.00021130316 + 15874.8614128467*$t);
  $X2 += 0.00000000014 * cos(3.13205445097 + 21202.3375212295*$t);
  $X2 += 0.00000000014 * cos(2.49765103801 + 17277.6507493173*$t);
  $X2 += 0.00000000015 * cos(0.11837091281 + 18073.46112116669*$t);
  $X2 += 0.00000000014 * cos(4.77259175609 + 10239.3400485273*$t);
  $X2 += 0.00000000014 * cos(2.38979050420 + 14945.0723560709*$t);
  $X2 += 0.00000000014 * cos(4.18962126273 + 8662.48414104651*$t);
  $X2 += 0.00000000014 * cos(5.23413049702 + 11764.5745863425*$t);
  $X2 += 0.00000000013 * cos(1.93488532828 + 34570.3101523361*$t);
  $X2 += 0.00000000013 * cos(0.61222694816 + 22779.6810636773*$t);
  $X2 += 0.00000000012 * cos(3.85463106546 + 31441.92138724031*$t);
  $X2 += 0.00000000011 * cos(4.27550517900 + 10220.6429106953*$t);
  $X2 += 0.00000000011 * cos(2.07789625538 + 10206.4158166937*$t);
  $X2 += 0.00000000010 * cos(3.61798826402 + 7.3573644843*$t);
  $X2 += 0.00000000010 * cos(1.57784029028 + 22003.6708173863*$t);
  $X2 += 0.00000000012 * cos(3.46936245747 + 25158.8455372489*$t);
  $X2 += 0.00000000009 * cos(3.35948007941 + 38500.5198485557*$t);
  $X2 += 0.00000000010 * cos(2.93060547107 + 11790.3852711753*$t);
  $X2 += 0.00000000012 * cos(2.06733085074 + 17297.9385098427*$t);
  $X2 += 0.00000000008 * cos(2.77292844888 + 10404.48999483909*$t);
  $X2 += 0.00000000009 * cos(4.94797813171 + 29089.0552334685*$t);
  $X2 += 0.00000000007 * cos(1.94867772097 + 43232.5504758991*$t);
  $X2 += 0.00000000007 * cos(6.01401025413 + 30000.2031698025*$t);
  $X2 += 0.00000000009 * cos(4.47573265145 + 7860.17557495569*$t);
  $X2 += 0.00000000009 * cos(4.90406740797 + 3531.81687532789*$t);
  $X2 += 0.00000000007 * cos(1.80027626747 + 22805.4917485101*$t);
  $X2 += 0.00000000007 * cos(1.18159563994 + 529.44714761109*$t);
  return $X2*$t*$t;
}



  function Venus_C_X3 ($t)
{
  $X3 =  0.0;
  $X3 += 0.00000055518 * cos(5.27636048864 + 10213.0417287275*$t);
  $X3 += 0.00000057047 * cos(5.87936770190 + 0.2438174835*$t);
  $X3 += 0.00000032093 * cos(3.05612494200 + 20426.8149099055*$t);
  $X3 += 0.00000018867 * cos(4.86548938285 + 10213.5293636945*$t);
  $X3 += 0.00000000716 * cos(3.26370970167 + 30640.1004561165*$t);
  $X3 += 0.00000000218 * cos(0.66337297711 + 20426.32727493849*$t);
  $X3 += 0.00000000032 * cos(0.22308629368 + 8636.18582124671*$t);
  $X3 += 0.00000000034 * cos(2.69459006102 + 10239.8276834943*$t);
  $X3 += 0.00000000034 * cos(3.66311278763 + 10187.2310438947*$t);
  $X3 += 0.00000000027 * cos(6.14322148767 + 11790.8729061423*$t);
  $X3 += 0.00000000020 * cos(3.64902570031 + 775.7664288075*$t);
  $X3 += 0.00000000016 * cos(0.61723457662 + 10022.0810975829*$t);
  $X3 += 0.00000000016 * cos(5.73871486925 + 10404.9776298061*$t);
  $X3 += 0.00000000010 * cos(3.76695027338 + 40853.3860023275*$t);
  $X3 += 0.00000000010 * cos(2.80431500839 + 9438.0067523705*$t);
  $X3 += 0.00000000010 * cos(3.65133831937 + 10989.0519750185*$t);
  $X3 += 0.00000000008 * cos(5.27853417078 + 9683.8383985999*$t);
  $X3 += 0.00000000007 * cos(6.04834530223 + 191.2044486281*$t);
  $X3 += 0.00000000007 * cos(1.06297780672 + 10743.2203287891*$t);
  $X3 += 0.00000000008 * cos(5.07274318566 + 4705.9761250271*$t);
  $X3 += 0.00000000007 * cos(2.72342831598 + 19651.2922985815*$t);
  $X3 += 0.00000000004 * cos(0.12637968025 + 9104.1508116011*$t);
  $X3 += 0.00000000004 * cos(0.86625328320 + 1059.6257476727*$t);
  $X3 += 0.00000000004 * cos(1.29045440101 + 15721.0826023619*$t);
  $X3 += 0.00000000003 * cos(6.23075905972 + 11322.9079157879*$t);
  return $X3*$t*$t*$t;
}



  function Venus_C_X4 ($t)
{
  $X4 =  0.0;
  $X4 += 0.00000083081 * cos(1.47755047593 + 10213.5293636945*$t);
  $X4 += 0.00000002486 * cos(0.71777141614 + 10213.0417287275*$t);
  $X4 += 0.00000000657 * cos(1.07128766548 + 20426.8149099055*$t);
  $X4 += 0.00000000217 * cos(3.60535760515 + 0.2438174835*$t);
  $X4 += 0.00000000035 * cos(0.98556560154 + 30640.1004561165*$t);
  $X4 += 0.00000000011 * cos(2.44309012697 + 20426.32727493849*$t);
  $X4 += 0.00000000005 * cos(2.06924437235 + 10239.8276834943*$t);
  $X4 += 0.00000000005 * cos(4.26079266220 + 10187.2310438947*$t);
  $X4 += 0.00000000003 * cos(4.92755555887 + 2353.1099712553*$t);
  $X4 += 0.00000000002 * cos(4.89604781036 + 8636.18582124671*$t);
  $X4 += 0.00000000002 * cos(5.91399711778 + 1577.0997249643*$t);
  $X4 += 0.00000000002 * cos(2.29946508014 + 9438.0067523705*$t);
  return $X4*$t*$t*$t*$t;
}



  function Venus_C_X5 ($t)
{
  $X5 =  0.0;
  $X5 += 0.00000000631 * cos(1.59925460860 + 10213.5293636945*$t);
  $X5 += 0.00000000095 * cos(2.54586723363 + 10213.0417287275*$t);
  $X5 += 0.00000000088 * cos(1.72183649952 + 0.2438174835*$t);
  $X5 += 0.00000000040 * cos(5.81128931245 + 20426.8149099055*$t);
  return $X5*$t*$t*$t*$t*$t;
}



  function Venus_C_Y0 ($t)
{
  $Y0 =  0.0;
  $Y0 += 0.72268045621 * cos(1.60535036499 + 10213.5293636945*$t);
  $Y0 += 0.00733886107 * cos(3.86619610007 + 0.2438174835*$t);
  $Y0 += 0.00244692613 * cos(2.48525998209 + 20426.8149099055*$t);
  $Y0 += 0.00063317702 * cos(2.06415043880 + 10213.0417287275*$t);
  $Y0 += 0.00002795043 * cos(5.04300618072 + 2353.1099712553*$t);
  $Y0 += 0.00001941766 * cos(5.80436164129 + 1577.0997249643*$t);
  $Y0 += 0.00001242687 * cos(3.36533956931 + 30640.1004561165*$t);
  $Y0 += 0.00001163369 * cos(1.30924660823 + 18073.9487561337*$t);
  $Y0 += 0.00001044280 * cos(0.18242473165 + 6283.3196674749*$t);
  $Y0 += 0.00000767420 * cos(5.30492070227 + 529.9347825781*$t);
  $Y0 += 0.00000669994 * cos(6.16996307370 + 14143.7390599141*$t);
  $Y0 += 0.00000657435 * cos(5.21342894071 + 8636.18582124671*$t);
  $Y0 += 0.00000476814 * cos(4.27269799631 + 10187.2310438947*$t);
  $Y0 += 0.00000475078 * cos(2.07969169968 + 10239.8276834943*$t);
  $Y0 += 0.00000559353 * cos(5.87818075735 + 22004.1584523533*$t);
  $Y0 += 0.00000544577 * cos(1.14724395566 + 11790.8729061423*$t);
  $Y0 += 0.00000408020 * cos(2.35529138555 + 775.7664288075*$t);
  $Y0 += 0.00000281345 * cos(1.23218938626 + 9683.8383985999*$t);
  $Y0 += 0.00000270035 * cos(2.10691120117 + 9438.0067523705*$t);
  $Y0 += 0.00000268860 * cos(5.13228928315 + 10743.2203287891*$t);
  $Y0 += 0.00000299980 * cos(0.94363100672 + 5507.3094211839*$t);
  $Y0 += 0.00000214307 * cos(5.46162572826 + 10022.0810975829*$t);
  $Y0 += 0.00000241347 * cos(4.23602697206 + 10989.0519750185*$t);
  $Y0 += 0.00000208372 * cos(0.89206276557 + 10404.9776298061*$t);
  $Y0 += 0.00000271224 * cos(1.05337463479 + 19897.1239448109*$t);
  $Y0 += 0.00000264276 * cos(0.40825385367 + 9153.6597985383*$t);
  $Y0 += 0.00000214535 * cos(2.94606412427 + 20426.32727493849*$t);
  $Y0 += 0.00000175488 * cos(1.41092496739 + 191.2044486281*$t);
  $Y0 += 0.00000123055 * cos(0.01778159955 + 1059.6257476727*$t);
  $Y0 += 0.00000154230 * cos(3.78480528747 + 4705.9761250271*$t);
  $Y0 += 0.00000147037 * cos(3.98774418232 + 19651.2922985815*$t);
  $Y0 += 0.00000100153 * cos(2.36411678071 + 9437.5191174035*$t);
  $Y0 += 0.00000069555 * cos(4.80550652867 + 9104.1508116011*$t);
  $Y0 += 0.00000060317 * cos(1.54595691846 + 11322.9079157879*$t);
  $Y0 += 0.00000081789 * cos(2.57258880007 + 15721.0826023619*$t);
  $Y0 += 0.00000058874 * cos(1.48684982669 + 20618.2631760171*$t);
  $Y0 += 0.00000060776 * cos(2.21391240560 + 4552.1973145423*$t);
  $Y0 += 0.00000046411 * cos(5.23309117015 + 10192.7539682021*$t);
  $Y0 += 0.00000046285 * cos(1.11880987202 + 10234.3047591869*$t);
  $Y0 += 0.00000062288 * cos(1.02030092694 + 25934.3681485729*$t);
  $Y0 += 0.00000050365 * cos(0.03955377805 + 8623.96883344369*$t);
  $Y0 += 0.00000057275 * cos(2.21318821830 + 3154.4432674121*$t);
  $Y0 += 0.00000044993 * cos(0.06128576651 + 19367.4329797163*$t);
  $Y0 += 0.00000040167 * cos(1.64087495621 + 9411.7084325707*$t);
  $Y0 += 0.00000047716 * cos(5.57543351345 + 213.5429129215*$t);
  $Y0 += 0.00000039763 * cos(3.21104786001 + 801.5771136403*$t);
  $Y0 += 0.00000036106 * cos(4.71533355073 + 11015.3502948183*$t);
  $Y0 += 0.00000045150 * cos(0.48042336302 + 29580.7185259273*$t);
  $Y0 += 0.00000036973 * cos(2.82409044668 + 7058.8422787989*$t);
  $Y0 += 0.00000044928 * cos(3.79012120364 + 13367.7288136231*$t);
  $Y0 += 0.00000027822 * cos(3.37420388243 + 1109.1347346099*$t);
  $Y0 += 0.00000031714 * cos(4.13937067249 + 15874.8614128467*$t);
  $Y0 += 0.00000036279 * cos(2.34561943360 + 10000.23026825651*$t);
  $Y0 += 0.00000035360 * cos(4.01138333911 + 10426.8284591325*$t);
  $Y0 += 0.00000025530 * cos(3.98045270905 + 7860.6632099227*$t);
  $Y0 += 0.00000024951 * cos(3.53621528232 + 13368.2164485901*$t);
  $Y0 += 0.00000020285 * cos(1.13150552857 + 10220.6429106953*$t);
  $Y0 += 0.00000020275 * cos(5.21708912625 + 10206.4158166937*$t);
  $Y0 += 0.00000021291 * cos(1.37841249317 + 3128.6325825793*$t);
  $Y0 += 0.00000019173 * cos(0.47393618404 + 7.3573644843*$t);
  $Y0 += 0.00000018901 * cos(0.61568845651 + 26.0545023163*$t);
  $Y0 += 0.00000021874 * cos(5.21237379147 + 17297.9385098427*$t);
  $Y0 += 0.00000019888 * cos(1.40722670834 + 3930.4535137031*$t);
  $Y0 += 0.00000015237 * cos(2.81371946863 + 9830.6328314713*$t);
  $Y0 += 0.00000017432 * cos(1.76492288618 + 3531.81687532789*$t);
  $Y0 += 0.00000014522 * cos(3.53852074947 + 10596.4258959177*$t);
  $Y0 += 0.00000016153 * cos(3.63782003268 + 7084.6529636317*$t);
  $Y0 += 0.00000016091 * cos(0.78643837533 + 20213.5158144675*$t);
  $Y0 += 0.00000014842 * cos(2.49914152987 + 29864.5778447925*$t);
  $Y0 += 0.00000011112 * cos(2.20077056640 + 28287.2343023447*$t);
  $Y0 += 0.00000012828 * cos(0.47914049065 + 1589.3167127673*$t);
  $Y0 += 0.00000011212 * cos(0.90580714897 + 9154.1474335053*$t);
  $Y0 += 0.00000014376 * cos(2.29215877818 + 23581.5019948011*$t);
  $Y0 += 0.00000012175 * cos(3.29545280575 + 21228.63584102931*$t);
  $Y0 += 0.00000009393 * cos(5.33561048405 + 11272.91129388371*$t);
  $Y0 += 0.00000012824 * cos(2.98347327697 + 18837.25437965469*$t);
  $Y0 += 0.00000009207 * cos(5.34806792169 + 5661.5758666357*$t);
  $Y0 += 0.00000008622 * cos(3.39909215992 + 21536.1934619989*$t);
  $Y0 += 0.00000011653 * cos(4.63096590501 + 3340.8562441833*$t);
  $Y0 += 0.00000011496 * cos(0.35144252183 + 21228.1482060623*$t);
  $Y0 += 0.00000009511 * cos(4.97800970942 + 17298.4261448097*$t);
  $Y0 += 0.00000011281 * cos(6.15396443981 + 9786.44353785149*$t);
  $Y0 += 0.00000008498 * cos(2.28560931070 + 1577.5873599313*$t);
  $Y0 += 0.00000010763 * cos(5.94541313957 + 9929.6700448293*$t);
  $Y0 += 0.00000008847 * cos(0.10898852487 + 29051.0275608327*$t);
  $Y0 += 0.00000010378 * cos(0.40689046689 + 10497.38868255971*$t);
  $Y0 += 0.00000007498 * cos(4.24537566245 + 40853.3860023275*$t);
  $Y0 += 0.00000007375 * cos(5.51259327017 + 16496.6052136859*$t);
  $Y0 += 0.00000008792 * cos(5.18118052745 + 10208.0064393871*$t);
  $Y0 += 0.00000008786 * cos(1.17109977444 + 10219.0522880019*$t);
  $Y0 += 0.00000007423 * cos(2.59067948380 + 10175.5016910587*$t);
  $Y0 += 0.00000007386 * cos(3.76162100212 + 10251.55703633031*$t);
  $Y0 += 0.00000006692 * cos(5.95406544386 + 8094.2778683491*$t);
  $Y0 += 0.00000006531 * cos(5.88279509444 + 20419.7013629047*$t);
  $Y0 += 0.00000005876 * cos(0.45809002649 + 32217.4439985643*$t);
  $Y0 += 0.00000007945 * cos(1.89399424197 + 12566.3955174663*$t);
  $Y0 += 0.00000005723 * cos(0.73880953765 + 24357.0246061251*$t);
  $Y0 += 0.00000005960 * cos(5.04842520573 + 6681.46867088311*$t);
  $Y0 += 0.00000005974 * cos(0.59430542004 + 426.8420083595*$t);
  $Y0 += 0.00000005761 * cos(2.33144379428 + 2352.6223362883*$t);
  $Y0 += 0.00000007279 * cos(5.06948362320 + 11014.8626598513*$t);
  $Y0 += 0.00000004942 * cos(2.08880442511 + 3149.4079780717*$t);
  $Y0 += 0.00000005638 * cos(3.95061708151 + 382.6527147397*$t);
  $Y0 += 0.00000006069 * cos(4.02647068871 + 9683.35076363289*$t);
  $Y0 += 0.00000004581 * cos(1.06268488434 + 14765.48286075331*$t);
  $Y0 += 0.00000006372 * cos(1.77392148125 + 25158.3579022819*$t);
  $Y0 += 0.00000004902 * cos(5.88378200448 + 18837.7420146217*$t);
  $Y0 += 0.00000004698 * cos(4.98709845390 + 18849.4713674577*$t);
  $Y0 += 0.00000005371 * cos(2.87505683972 + 26088.1469590577*$t);
  $Y0 += 0.00000005495 * cos(1.72171503357 + 17086.2024832057*$t);
  $Y0 += 0.00000005381 * cos(3.84016723700 + 33794.7875410121*$t);
  $Y0 += 0.00000004870 * cos(1.21408319983 + 20453.1132297053*$t);
  $Y0 += 0.00000003922 * cos(1.30852789776 + 13745.5900565059*$t);
  $Y0 += 0.00000004608 * cos(5.91400382368 + 5661.0882316687*$t);
  $Y0 += 0.00000003970 * cos(4.65819000475 + 4731.7868098599*$t);
  $Y0 += 0.00000003556 * cos(5.06044480376 + 1551.2890401315*$t);
  $Y0 += 0.00000004329 * cos(1.83456881254 + 23958.8756027169*$t);
  $Y0 += 0.00000003274 * cos(5.00533011391 + 529.44714761109*$t);
  $Y0 += 0.00000003328 * cos(2.61855780370 + 18307.56341456009*$t);
  $Y0 += 0.00000002787 * cos(3.62713580728 + 11790.3852711753*$t);
  $Y0 += 0.00000003603 * cos(0.20878953983 + 14945.0723560709*$t);
  $Y0 += 0.00000002949 * cos(1.25283496540 + 10198.2768925095*$t);
  $Y0 += 0.00000002944 * cos(5.09946216488 + 10228.78183487951*$t);
  $Y0 += 0.00000003221 * cos(5.14877320464 + 20400.5165901057*$t);
  $Y0 += 0.00000003653 * cos(3.19373783247 + 29088.5675985015*$t);
  $Y0 += 0.00000002683 * cos(3.77978842246 + 6282.83203250789*$t);
  $Y0 += 0.00000002848 * cos(2.09414295555 + 11322.42028082089*$t);
  $Y0 += 0.00000002745 * cos(0.21041860525 + 5481.4987363511*$t);
  $Y0 += 0.00000002426 * cos(1.24386679781 + 6872.91693699471*$t);
  $Y0 += 0.00000002262 * cos(5.05423750942 + 7860.17557495569*$t);
  $Y0 += 0.00000002431 * cos(2.28515436796 + 30110.4094910219*$t);
  $Y0 += 0.00000002218 * cos(4.26312729072 + 17277.6507493173*$t);
  $Y0 += 0.00000002955 * cos(3.73004048151 + 27511.7116910207*$t);
  $Y0 += 0.00000002300 * cos(2.32608220761 + 3442.81876244891*$t);
  $Y0 += 0.00000002424 * cos(5.68140966349 + 20956.5058750001*$t);
  $Y0 += 0.00000002622 * cos(2.17435265531 + 9580.7456243813*$t);
  $Y0 += 0.00000002032 * cos(5.76558577000 + 20000.2167190295*$t);
  $Y0 += 0.00000002206 * cos(2.03456492963 + 537.0483295789*$t);
  $Y0 += 0.00000002010 * cos(5.28017944038 + 21202.3375212295*$t);
  $Y0 += 0.00000002471 * cos(4.17654037966 + 10846.3131030077*$t);
  $Y0 += 0.00000002315 * cos(0.62235018491 + 9573.14444241349*$t);
  $Y0 += 0.00000002188 * cos(4.41129286184 + 9967.69771746511*$t);
  $Y0 += 0.00000002278 * cos(2.82110310010 + 10110.4365894759*$t);
  $Y0 += 0.00000002278 * cos(3.53119029368 + 10316.6221379131*$t);
  $Y0 += 0.00000001808 * cos(2.43291137306 + 22779.6810636773*$t);
  $Y0 += 0.00000002244 * cos(0.87218452760 + 5507.7970561509*$t);
  $Y0 += 0.00000001796 * cos(4.66992847541 + 7063.87756813929*$t);
  $Y0 += 0.00000002118 * cos(1.94080318718 + 10459.3610099239*$t);
  $Y0 += 0.00000001908 * cos(4.04072387238 + 20809.7114421287*$t);
  $Y0 += 0.00000002093 * cos(5.40951959375 + 522.8212355773*$t);
  $Y0 += 0.00000001753 * cos(5.11036210545 + 13554.1417903943*$t);
  $Y0 += 0.00000002072 * cos(2.68969610898 + 9690.9519456007*$t);
  $Y0 += 0.00000001993 * cos(5.12289612530 + 10404.48999483909*$t);
  $Y0 += 0.00000002160 * cos(4.61577108214 + 33018.7772947211*$t);
  $Y0 += 0.00000001962 * cos(3.66408601951 + 10736.1067817883*$t);
  $Y0 += 0.00000001484 * cos(4.31259578278 + 3723.26514143949*$t);
  $Y0 += 0.00000001997 * cos(1.63225621325 + 18875.2820522905*$t);
  $Y0 += 0.00000002057 * cos(3.55699495023 + 102.84895673509*$t);
  $Y0 += 0.00000002016 * cos(5.26645554222 + 37724.9972372317*$t);
  $Y0 += 0.00000001618 * cos(3.30590238659 + 7085.1405985987*$t);
  $Y0 += 0.00000001659 * cos(0.00230057752 + 20235.36664379391*$t);
  $Y0 += 0.00000001553 * cos(6.13988283072 + 14945.5599910379*$t);
  $Y0 += 0.00000001873 * cos(6.21493810839 + 30213.5022652405*$t);
  $Y0 += 0.00000001542 * cos(2.45160700066 + 6490.0204047715*$t);
  $Y0 += 0.00000001360 * cos(4.22919267004 + 10233.1991245943*$t);
  $Y0 += 0.00000001360 * cos(2.12310072374 + 10193.85960279471*$t);
  $Y0 += 0.00000001592 * cos(5.43357759705 + 10138.7477651272*$t);
  $Y0 += 0.00000001592 * cos(0.91871579673 + 10288.3109622618*$t);
  $Y0 += 0.00000001368 * cos(1.28838366385 + 18875.76968725751*$t);
  $Y0 += 0.00000001235 * cos(5.36285347606 + 20.5315780089*$t);
  $Y0 += 0.00000001485 * cos(0.27770606219 + 9160.77334553909*$t);
  $Y0 += 0.00000001516 * cos(3.63976169766 + 9146.54625153749*$t);
  $Y0 += 0.00000001233 * cos(1.75819099072 + 18073.46112116669*$t);
  $Y0 += 0.00000001560 * cos(5.07643229822 + 9897.1374940379*$t);
  $Y0 += 0.00000001560 * cos(1.27586109556 + 10529.9212333511*$t);
  $Y0 += 0.00000001179 * cos(4.44352915820 + 14919.2616712381*$t);
  $Y0 += 0.00000001213 * cos(6.01696685843 + 28521.3365957381*$t);
  $Y0 += 0.00000001182 * cos(4.06358300800 + 9794.0447198193*$t);
  $Y0 += 0.00000001402 * cos(6.10447020216 + 8661.9965060795*$t);
  $Y0 += 0.00000001158 * cos(2.28822825043 + 10633.0140075697*$t);
  $Y0 += 0.00000001257 * cos(5.80717617406 + 2378.9206560881*$t);
  $Y0 += 0.00000001089 * cos(3.83624431348 + 30639.61282114949*$t);
  $Y0 += 0.00000001402 * cos(3.43315827736 + 10640.1275545705*$t);
  $Y0 += 0.00000001483 * cos(0.85707928326 + 21535.70582703189*$t);
  $Y0 += 0.00000001079 * cos(5.95495431418 + 775.2787938405*$t);
  $Y0 += 0.00000001370 * cos(3.04127991943 + 9786.9311728185*$t);
  $Y0 += 0.00000001064 * cos(4.03087864361 + 16984.2399649401*$t);
  $Y0 += 0.00000001158 * cos(5.90602944547 + 3929.96587873609*$t);
  $Y0 += 0.00000000967 * cos(0.02581826777 + 640.1411037975*$t);
  $Y0 += 0.00000000995 * cos(5.83778649915 + 8662.48414104651*$t);
  $Y0 += 0.00000001305 * cos(6.03771868030 + 36948.9869909407*$t);
  $Y0 += 0.00000001191 * cos(2.95662506124 + 39264.3131070437*$t);
  $Y0 += 0.00000001010 * cos(5.80804230901 + 10007.3438152573*$t);
  $Y0 += 0.00000001010 * cos(0.54425107612 + 10419.7149121317*$t);
  $Y0 += 0.00000000950 * cos(2.79830239920 + 1109.6223695769*$t);
  $Y0 += 0.00000001221 * cos(3.93109520572 + 75.0254160508*$t);
  $Y0 += 0.00000000987 * cos(3.89911553784 + 13937.0383226175*$t);
  $Y0 += 0.00000001164 * cos(3.04468597570 + 22805.4917485101*$t);
  $Y0 += 0.00000000845 * cos(5.84334943435 + 6770.46678376209*$t);
  $Y0 += 0.00000000996 * cos(2.96758372829 + 13341.9181287903*$t);
  $Y0 += 0.00000001123 * cos(0.26297644138 + 246.0754637129*$t);
  $Y0 += 0.00000001139 * cos(0.86118865103 + 2119.00767786191*$t);
  $Y0 += 0.00000001046 * cos(5.02841709583 + 31441.92138724031*$t);
  $Y0 += 0.00000000879 * cos(5.42815094849 + 15720.5949673949*$t);
  $Y0 += 0.00000000761 * cos(5.58947417459 + 7564.58690325449*$t);
  $Y0 += 0.00000000814 * cos(4.49927037870 + 9676.7248515991*$t);
  $Y0 += 0.00000000786 * cos(0.51236116044 + 11764.5745863425*$t);
  $Y0 += 0.00000000883 * cos(4.72642948961 + 25158.8455372489*$t);
  $Y0 += 0.00000000795 * cos(1.85352659217 + 10750.33387578991*$t);
  $Y0 += 0.00000000770 * cos(5.39717699890 + 7834.3648901229*$t);
  $Y0 += 0.00000000825 * cos(0.49699119244 + 191.6920835951*$t);
  $Y0 += 0.00000000696 * cos(1.82641391127 + 36147.6536947839*$t);
  $Y0 += 0.00000000941 * cos(5.56301751479 + 28520.84896077109*$t);
  $Y0 += 0.00000000787 * cos(4.31922851608 + 19890.0103978101*$t);
  $Y0 += 0.00000000788 * cos(4.89324353272 + 7994.77225950771*$t);
  $Y0 += 0.00000000624 * cos(1.27682792425 + 39794.0040721383*$t);
  $Y0 += 0.00000000609 * cos(0.58636941909 + 8624.45646841071*$t);
  $Y0 += 0.00000000836 * cos(0.40176116197 + 41655.2069334513*$t);
  $Y0 += 0.00000000744 * cos(0.94447022556 + 19904.2374918117*$t);
  $Y0 += 0.00000000689 * cos(3.03363296847 + 1066.7392946735*$t);
  $Y0 += 0.00000000803 * cos(1.17639368940 + 40879.1966871603*$t);
  $Y0 += 0.00000000692 * cos(5.25875345423 + 6770.9544187291*$t);
  $Y0 += 0.00000000585 * cos(0.31354909520 + 14143.2514249471*$t);
  $Y0 += 0.00000000678 * cos(1.25286840883 + 12592.2062022991*$t);
  $Y0 += 0.00000000573 * cos(0.95211843581 + 12592.6938372661*$t);
  $Y0 += 0.00000000670 * cos(2.49987738716 + 10239.3400485273*$t);
  $Y0 += 0.00000000655 * cos(0.26769747072 + 19366.94534474929*$t);
  $Y0 += 0.00000000626 * cos(5.88947359425 + 52176.0501006319*$t);
  $Y0 += 0.00000000548 * cos(2.24703921308 + 17777.87244946549*$t);
  $Y0 += 0.00000000709 * cos(4.47405816630 + 26735.7014447297*$t);
  $Y0 += 0.00000000531 * cos(1.52107728998 + 110.45013870291*$t);
  $Y0 += 0.00000000605 * cos(3.06366115762 + 10059.7505532097*$t);
  $Y0 += 0.00000000676 * cos(3.63142919749 + 20529.9076841241*$t);
  $Y0 += 0.00000000598 * cos(1.46005524042 + 12432.2864678813*$t);
  $Y0 += 0.00000000593 * cos(3.28870937227 + 10367.3081741793*$t);
  $Y0 += 0.00000000663 * cos(4.76628280750 + 1162.7185218913*$t);
  $Y0 += 0.00000000466 * cos(0.80841803105 + 8631.0823804445*$t);
  $Y0 += 0.00000000468 * cos(4.59842473713 + 16983.75232997309*$t);
  $Y0 += 0.00000000454 * cos(5.50480764823 + 10042.8564930753*$t);
  $Y0 += 0.00000000462 * cos(1.11716283210 + 6.86972951729*$t);
  $Y0 += 0.00000000444 * cos(0.84748580654 + 10384.2022343137*$t);
  $Y0 += 0.00000000460 * cos(5.40321784334 + 11802.6022589783*$t);
  $Y0 += 0.00000000436 * cos(0.28613833283 + 9639.18456535971*$t);
  $Y0 += 0.00000000565 * cos(0.99439008608 + 8520.87605922509*$t);
  $Y0 += 0.00000000416 * cos(0.15526058452 + 10225.2587165305*$t);
  $Y0 += 0.00000000416 * cos(6.19703280926 + 10201.80001085851*$t);
  $Y0 += 0.00000000414 * cos(4.74636525670 + 10186.7434089277*$t);
  $Y0 += 0.00000000431 * cos(3.30159385303 + 8616.85528644289*$t);
  $Y0 += 0.00000000393 * cos(0.85768879239 + 3532.3045102949*$t);
  $Y0 += 0.00000000406 * cos(6.06603671083 + 10787.8741620293*$t);
  $Y0 += 0.00000000380 * cos(4.93978031772 + 19317.43635781211*$t);
  $Y0 += 0.00000000458 * cos(3.28496308708 + 2218.51328670329*$t);
  $Y0 += 0.00000000433 * cos(0.59107482876 + 19650.8046636145*$t);
  $Y0 += 0.00000000377 * cos(4.10235161087 + 149.8070146181*$t);
  $Y0 += 0.00000000390 * cos(1.63992074391 + 13936.5506876505*$t);
  $Y0 += 0.00000000360 * cos(4.38429398498 + 24150.3238688285*$t);
  $Y0 += 0.00000000359 * cos(2.69008664310 + 30831.5487222281*$t);
  $Y0 += 0.00000000501 * cos(2.59817403162 + 44809.4063833799*$t);
  $Y0 += 0.00000000409 * cos(3.34267900163 + 27197.03787618409*$t);
  $Y0 += 0.00000000354 * cos(1.27226804531 + 10323.7356849139*$t);
  $Y0 += 0.00000000354 * cos(5.08002534847 + 10103.3230424751*$t);
  $Y0 += 0.00000000428 * cos(1.10028111046 + 13656.10430865991*$t);
  $Y0 += 0.00000000467 * cos(3.73227844246 + 38.3768531213*$t);
  $Y0 += 0.00000000343 * cos(0.04251143462 + 19786.9176235915*$t);
  $Y0 += 0.00000000457 * cos(5.50264719385 + 18308.0510495271*$t);
  $Y0 += 0.00000000399 * cos(5.69770325248 + 1052.51220067191*$t);
  $Y0 += 0.00000000445 * cos(5.89891356885 + 30665.9111409493*$t);
  $Y0 += 0.00000000344 * cos(4.75093105230 + 27490.9362955283*$t);
  $Y0 += 0.00000000315 * cos(4.73109393582 + 20640.1140053435*$t);
  $Y0 += 0.00000000399 * cos(2.67833209975 + 10212.0448909862*$t);
  $Y0 += 0.00000000399 * cos(3.67396129403 + 10215.0138364028*$t);
  $Y0 += 0.00000000390 * cos(0.71131374079 + 30000.2031698025*$t);
  $Y0 += 0.00000000340 * cos(5.88673417604 + 22805.9793834771*$t);
  $Y0 += 0.00000000398 * cos(2.07757082821 + 9836.1557557787*$t);
  $Y0 += 0.00000000311 * cos(0.04968618848 + 22003.6708173863*$t);
  $Y0 += 0.00000000404 * cos(2.41513448299 + 20352.0333113382*$t);
  $Y0 += 0.00000000366 * cos(2.69947342940 + 16522.4158985187*$t);
  $Y0 += 0.00000000350 * cos(4.56156653428 + 15874.37377787969*$t);
  $Y0 += 0.00000000385 * cos(6.08106804956 + 20180.9832636761*$t);
  $Y0 += 0.00000000379 * cos(4.27472269461 + 10590.9029716103*$t);
  $Y0 += 0.00000000395 * cos(1.98398365933 + 17277.16311435029*$t);
  $Y0 += 0.00000000383 * cos(0.20953871800 + 35372.1310834599*$t);
  $Y0 += 0.00000000277 * cos(4.73141990633 + 10988.5643400515*$t);
  $Y0 += 0.00000000365 * cos(6.13706743141 + 10349.1546887045*$t);
  $Y0 += 0.00000000365 * cos(0.21522596237 + 10077.90403868451*$t);
  $Y0 += 0.00000000336 * cos(5.45252157770 + 220.6564599223*$t);
  $Y0 += 0.00000000313 * cos(0.95373705811 + 6309.1303523077*$t);
  $Y0 += 0.00000000276 * cos(4.02007434964 + 26709.8907598969*$t);
  $Y0 += 0.00000000283 * cos(3.96353025226 + 3904.1551939033*$t);
  $Y0 += 0.00000000271 * cos(2.28569018986 + 9745.5643733401*$t);
  $Y0 += 0.00000000321 * cos(2.63356462069 + 38734.6221419491*$t);
  $Y0 += 0.00000000327 * cos(1.40582630148 + 9359.84534697549*$t);
  $Y0 += 0.00000000264 * cos(3.59015983869 + 76.50988875911*$t);
  $Y0 += 0.00000000310 * cos(5.18631223131 + 27991.15799567649*$t);
  $Y0 += 0.00000000359 * cos(1.81226579939 + 45585.4166296709*$t);
  $Y0 += 0.00000000326 * cos(4.02012440588 + 633.0275567967*$t);
  $Y0 += 0.00000000314 * cos(6.11319497702 + 20406.0395144131*$t);
  $Y0 += 0.00000000306 * cos(5.83848348668 + 2957.9597119601*$t);
  $Y0 += 0.00000000266 * cos(5.66163509794 + 8635.69818627969*$t);
  $Y0 += 0.00000000254 * cos(4.06665609388 + 10681.49435404891*$t);
  $Y0 += 0.00000000343 * cos(3.07216363987 + 8106.4948561521*$t);
  $Y0 += 0.00000000300 * cos(2.55692274187 + 206.42936592071*$t);
  $Y0 += 0.00000000250 * cos(4.61153598536 + 283.6155013817*$t);
  $Y0 += 0.00000000336 * cos(2.25621229669 + 23581.0143598341*$t);
  $Y0 += 0.00000000236 * cos(1.26632265704 + 10595.9382609507*$t);
  $Y0 += 0.00000000234 * cos(2.24935612012 + 19624.9939787817*$t);
  $Y0 += 0.00000000255 * cos(4.35467668425 + 213.0552779545*$t);
  $Y0 += 0.00000000281 * cos(5.49571093835 + 9399.9790797347*$t);
  $Y0 += 0.00000000314 * cos(2.13931899616 + 19786.42998862449*$t);
  $Y0 += 0.00000000229 * cos(0.20297430947 + 574.10098085129*$t);
  $Y0 += 0.00000000295 * cos(2.36600819373 + 31749.4790082099*$t);
  $Y0 += 0.00000000316 * cos(4.02123996191 + 48739.6160795995*$t);
  $Y0 += 0.00000000229 * cos(2.88588042648 + 949.4194264533*$t);
  $Y0 += 0.00000000229 * cos(1.53780233055 + 19896.63630984389*$t);
  $Y0 += 0.00000000257 * cos(3.32400213893 + 19360.3194327155*$t);
  $Y0 += 0.00000000231 * cos(2.81577137220 + 9264.35375472471*$t);
  $Y0 += 0.00000000255 * cos(2.46385009073 + 9993.1167212557*$t);
  $Y0 += 0.00000000255 * cos(3.88844330305 + 10433.9420061333*$t);
  $Y0 += 0.00000000291 * cos(2.32110551482 + 9999.7426332895*$t);
  $Y0 += 0.00000000285 * cos(1.03940149360 + 34596.1208371689*$t);
  $Y0 += 0.00000000211 * cos(4.89515362389 + 10249.55723037191*$t);
  $Y0 += 0.00000000211 * cos(1.45713976989 + 10177.5014970171*$t);
  $Y0 += 0.00000000255 * cos(0.85666215039 + 11027.07964765431*$t);
  $Y0 += 0.00000000220 * cos(2.13302811409 + 37.7838551523*$t);
  $Y0 += 0.00000000280 * cos(2.09663247440 + 37410.32342239509*$t);
  $Y0 += 0.00000000258 * cos(3.69928540375 + 29573.6049789265*$t);
  $Y0 += 0.00000000247 * cos(0.33730425769 + 29587.8320729281*$t);
  $Y0 += 0.00000000206 * cos(1.80393013250 + 30426.8013606785*$t);
  $Y0 += 0.00000000263 * cos(1.59050643196 + 20433.9284569063*$t);
  $Y0 += 0.00000000212 * cos(1.58965720399 + 10206.9008047945*$t);
  $Y0 += 0.00000000212 * cos(4.76263618979 + 10220.15792259451*$t);
  $Y0 += 0.00000000202 * cos(5.53871102932 + 16894.7542170941*$t);
  $Y0 += 0.00000000272 * cos(3.28012716441 + 12320.56387123691*$t);
  $Y0 += 0.00000000211 * cos(3.54449702303 + 11162.7049726643*$t);
  $Y0 += 0.00000000197 * cos(2.85538775435 + 8734.17515466309*$t);
  $Y0 += 0.00000000267 * cos(2.72934257174 + 377.6174253993*$t);
  $Y0 += 0.00000000224 * cos(1.78242794958 + 9051.05465928671*$t);
  $Y0 += 0.00000000186 * cos(2.96624941532 + 10251.6623993323*$t);
  $Y0 += 0.00000000186 * cos(3.38604397846 + 10175.3963280567*$t);
  $Y0 += 0.00000000258 * cos(0.95259841698 + 9864.60494324651*$t);
  $Y0 += 0.00000000186 * cos(3.20827310527 + 40077.8633910035*$t);
  $Y0 += 0.00000000233 * cos(6.20481595696 + 29089.0552334685*$t);
  $Y0 += 0.00000000186 * cos(3.29904519478 + 17272.1278250099*$t);
  $Y0 += 0.00000000254 * cos(1.58851500083 + 19264.3402054977*$t);
  $Y0 += 0.00000000246 * cos(5.39979351075 + 10562.4537841425*$t);
  $Y0 += 0.00000000211 * cos(4.59175138406 + 11376.0040681023*$t);
  $Y0 += 0.00000000178 * cos(5.22149503543 + 10949.4058772263*$t);
  $Y0 += 0.00000000178 * cos(1.13079835835 + 9477.65285016271*$t);
  $Y0 += 0.00000000197 * cos(5.67208275737 + 1692.40948698591*$t);
  $Y0 += 0.00000000177 * cos(4.83529684993 + 20316.6085886861*$t);
  $Y0 += 0.00000000216 * cos(4.13948146239 + 20452.6255947383*$t);
  $Y0 += 0.00000000197 * cos(1.76173397564 + 9050.56702431969*$t);
  $Y0 += 0.00000000159 * cos(5.88022204093 + 27197.5255111511*$t);
  $Y0 += 0.00000000167 * cos(1.09928566241 + 4705.4884900601*$t);
  $Y0 += 0.00000000213 * cos(3.70468670755 + 27511.2240560537*$t);
  $Y0 += 0.00000000154 * cos(5.43597579906 + 10199.3022696929*$t);
  $Y0 += 0.00000000154 * cos(0.91631759472 + 10227.7564576961*$t);
  $Y0 += 0.00000000174 * cos(0.32803080161 + 14.47091148511*$t);
  $Y0 += 0.00000000209 * cos(3.23046462275 + 10063.4785315929*$t);
  $Y0 += 0.00000000167 * cos(5.14638326738 + 6872.42930202769*$t);
  $Y0 += 0.00000000185 * cos(2.25428901814 + 9256.75257275689*$t);
  $Y0 += 0.00000000166 * cos(2.18082507791 + 10263.2863891663*$t);
  $Y0 += 0.00000000166 * cos(4.17146831587 + 10163.7723382227*$t);
  $Y0 += 0.00000000168 * cos(0.62423658392 + 7991.18509413049*$t);
  $Y0 += 0.00000000174 * cos(2.19758501900 + 9161.2609805061*$t);
  $Y0 += 0.00000000197 * cos(1.87142263401 + 846.3266522347*$t);
  $Y0 += 0.00000000176 * cos(6.26295125412 + 9779.32999085069*$t);
  $Y0 += 0.00000000198 * cos(5.45633204029 + 52669.8257758191*$t);
  $Y0 += 0.00000000169 * cos(4.14838568997 + 11265.7977468829*$t);
  $Y0 += 0.00000000188 * cos(2.47639831966 + 38526.3305333885*$t);
  $Y0 += 0.00000000140 * cos(5.67905778675 + 27991.6456306435*$t);
  $Y0 += 0.00000000194 * cos(3.83921848765 + 8837.26792888169*$t);
  $Y0 += 0.00000000173 * cos(2.87742322736 + 9793.5570848523*$t);
  $Y0 += 0.00000000140 * cos(5.04268037408 + 10191.6785343681*$t);
  $Y0 += 0.00000000140 * cos(1.30961301970 + 10235.3801930209*$t);
  $Y0 += 0.00000000196 * cos(3.84465359273 + 1293.24040609909*$t);
  $Y0 += 0.00000000180 * cos(5.95332595720 + 10021.5934626159*$t);
  $Y0 += 0.00000000138 * cos(5.09734035169 + 10217.4615169576*$t);
  $Y0 += 0.00000000138 * cos(1.25495304209 + 10209.5972104314*$t);
  $Y0 += 0.00000000148 * cos(0.74425859729 + 19374.5465267171*$t);
  $Y0 += 0.00000000137 * cos(2.37981976955 + 16522.9035334857*$t);
  $Y0 += 0.00000000143 * cos(6.11571774821 + 20447.5903053979*$t);
  $Y0 += 0.00000000139 * cos(1.01385118035 + 7255.3258342509*$t);
  $Y0 += 0.00000000126 * cos(2.24994178665 + 20277.2517127709*$t);
  $Y0 += 0.00000000164 * cos(3.22032043024 + 49515.6263258905*$t);
  $Y0 += 0.00000000149 * cos(0.61484998961 + 10135.8555932665*$t);
  $Y0 += 0.00000000149 * cos(5.73744340417 + 10291.20313412251*$t);
  $Y0 += 0.00000000118 * cos(2.69846631523 + 4551.7096795753*$t);
  $Y0 += 0.00000000117 * cos(5.64919068623 + 1582.2031657665*$t);
  $Y0 += 0.00000000151 * cos(5.55480633210 + 10246.0619144859*$t);
  $Y0 += 0.00000000151 * cos(0.79748706168 + 10180.99681290311*$t);
  $Y0 += 0.00000000152 * cos(1.61196584184 + 39302.3407796795*$t);
  $Y0 += 0.00000000144 * cos(2.25615309488 + 9986.0532309055*$t);
  $Y0 += 0.00000000144 * cos(4.09614029890 + 10441.00549648351*$t);
  $Y0 += 0.00000000136 * cos(0.51140220699 + 17469.0990154289*$t);
  $Y0 += 0.00000000119 * cos(4.90022973272 + 20809.2238071617*$t);
  $Y0 += 0.00000000130 * cos(4.00092308815 + 10236.3045651453*$t);
  $Y0 += 0.00000000130 * cos(2.35137030563 + 10190.7541622437*$t);
  $Y0 += 0.00000000156 * cos(2.62001496107 + 20388.6818742677*$t);
  $Y0 += 0.00000000132 * cos(3.92998867218 + 9580.2579894143*$t);
  $Y0 += 0.00000000155 * cos(5.57179178709 + 8238.0368178385*$t);
  $Y0 += 0.00000000142 * cos(5.15510279625 + 31441.4337522733*$t);
  $Y0 += 0.00000000131 * cos(0.68390506026 + 8101.39141534989*$t);
  $Y0 += 0.00000000133 * cos(5.57627209730 + 24382.8352909579*$t);
  $Y0 += 0.00000000105 * cos(5.80156791329 + 32858.36992533629*$t);
  $Y0 += 0.00000000105 * cos(5.39190347848 + 1059.1381127057*$t);
  $Y0 += 0.00000000101 * cos(2.78278015558 + 24978.7684069643*$t);
  $Y0 += 0.00000000126 * cos(3.33415820026 + 22645.57201409229*$t);
  $Y0 += 0.00000000101 * cos(3.69358080572 + 20043.9183776823*$t);
  $Y0 += 0.00000000110 * cos(4.54705018597 + 43071.65547154729*$t);
  $Y0 += 0.00000000103 * cos(2.03520456299 + 12431.79883291429*$t);
  $Y0 += 0.00000000136 * cos(4.50608056956 + 5999.4603486097*$t);
  $Y0 += 0.00000000097 * cos(5.63294739362 + 853.4401992355*$t);
  $Y0 += 0.00000000130 * cos(1.64701005433 + 4176.2851599325*$t);
  $Y0 += 0.00000000113 * cos(2.36571271909 + 19794.0311705923*$t);
  $Y0 += 0.00000000093 * cos(0.77688953992 + 22645.08437912529*$t);
  $Y0 += 0.00000000124 * cos(3.90067857109 + 42456.5402296081*$t);
  $Y0 += 0.00000000107 * cos(5.87195741297 + 3.6883357796*$t);
  $Y0 += 0.00000000127 * cos(1.97874545982 + 284.1031363487*$t);
  $Y0 += 0.00000000112 * cos(0.89977181729 + 20206.4022674667*$t);
  $Y0 += 0.00000000097 * cos(2.64537814089 + 78263.95324220609*$t);
  $Y0 += 0.00000000093 * cos(1.80429347640 + 8204.4841895685*$t);
  $Y0 += 0.00000000127 * cos(0.59683711488 + 56600.0354720387*$t);
  $Y0 += 0.00000000111 * cos(6.25613029204 + 18830.14083265389*$t);
  $Y0 += 0.00000000098 * cos(1.55452229557 + 11059.6121984457*$t);
  $Y0 += 0.00000000098 * cos(4.79806616663 + 9367.4465289433*$t);
  $Y0 += 0.00000000103 * cos(3.58160703323 + 10244.4434893295*$t);
  $Y0 += 0.00000000103 * cos(2.77068636055 + 10182.6152380595*$t);
  $Y0 += 0.00000000111 * cos(2.87167506517 + 18844.36792665549*$t);
  $Y0 += 0.00000000125 * cos(0.78050482769 + 12189.0219095505*$t);
  $Y0 += 0.00000000088 * cos(2.76213355426 + 20350.5488386299*$t);
  $Y0 += 0.00000000088 * cos(0.86523706220 + 29058.1411078335*$t);
  $Y0 += 0.00000000096 * cos(2.34258805293 + 2333.44021035551*$t);
  $Y0 += 0.00000000122 * cos(3.86127135190 + 2636.9692901205*$t);
  $Y0 += 0.00000000087 * cos(2.93183519168 + 8087.1643213483*$t);
  $Y0 += 0.00000000086 * cos(5.21875976302 + 7034.8959381599*$t);
  $Y0 += 0.00000000095 * cos(0.46006492106 + 10202.4836634306*$t);
  $Y0 += 0.00000000095 * cos(5.89222847272 + 10224.5750639584*$t);
  $Y0 += 0.00000000084 * cos(5.94038512576 + 10401.4545114571*$t);
  $Y0 += 0.00000000084 * cos(0.41190826802 + 10025.6042159319*$t);
  $Y0 += 0.00000000085 * cos(3.46647958947 + 19477.6393009357*$t);
  $Y0 += 0.00000000086 * cos(6.05989445995 + 29864.0902098255*$t);
  $Y0 += 0.00000000099 * cos(1.23143719760 + 2648.6986429565*$t);
  $Y0 += 0.00000000082 * cos(5.76212222967 + 802.0647486073*$t);
  $Y0 += 0.00000000087 * cos(2.17814642225 + 13745.10242153889*$t);
  $Y0 += 0.00000000081 * cos(2.16717230933 + 1550.8014051645*$t);
  $Y0 += 0.00000000083 * cos(4.61159603950 + 25933.8805136059*$t);
  $Y0 += 0.00000000079 * cos(4.57245769213 + 44008.0730872231*$t);
  $Y0 += 0.00000000078 * cos(4.54232413366 + 9573.6320773805*$t);
  $Y0 += 0.00000000098 * cos(3.80111874017 + 20220.6293614683*$t);
  $Y0 += 0.00000000108 * cos(5.23213365332 + 24149.8362338615*$t);
  $Y0 += 0.00000000100 * cos(3.49984914654 + 1596.43025976811*$t);
  $Y0 += 0.00000000095 * cos(1.78056312476 + 29477.6257517087*$t);
  $Y0 += 0.00000000078 * cos(4.60961320788 + 205.9417309537*$t);
  $Y0 += 0.00000000096 * cos(0.05074793120 + 30206.38871823969*$t);
  $Y0 += 0.00000000079 * cos(5.65022966428 + 3340.36860921629*$t);
  $Y0 += 0.00000000095 * cos(2.94692116655 + 30220.6158122413*$t);
  $Y0 += 0.00000000082 * cos(3.38904287688 + 29043.91401383189*$t);
  $Y0 += 0.00000000077 * cos(4.54577063518 + 17468.6113804619*$t);
  $Y0 += 0.00000000100 * cos(2.86693803454 + 38500.5198485557*$t);
  $Y0 += 0.00000000107 * cos(3.08328160895 + 2069.2506523901*$t);
  $Y0 += 0.00000000077 * cos(2.01507273057 + 10853.4266500085*$t);
  $Y0 += 0.00000000087 * cos(5.94217613191 + 5.2791068239*$t);
  $Y0 += 0.00000000076 * cos(3.30386469943 + 10243.35080184331*$t);
  $Y0 += 0.00000000076 * cos(3.04842869435 + 10183.7079255457*$t);
  $Y0 += 0.00000000076 * cos(4.51338161700 + 956.53297345411*$t);
  $Y0 += 0.00000000100 * cos(1.06850076905 + 28947.9347866141*$t);
  $Y0 += 0.00000000096 * cos(0.14778409211 + 35371.6434484929*$t);
  $Y0 += 0.00000000073 * cos(1.89720121846 + 17248.18148437089*$t);
  $Y0 += 0.00000000073 * cos(0.27810624949 + 21001.1597082403*$t);
  $Y0 += 0.00000000081 * cos(0.69044779243 + 18734.6492404031*$t);
  $Y0 += 0.00000000076 * cos(3.94914583018 + 103.3365917021*$t);
  $Y0 += 0.00000000085 * cos(0.56437212275 + 3914.71340755109*$t);
  $Y0 += 0.00000000074 * cos(0.35341059185 + 8827.6340873583*$t);
  $Y0 += 0.00000000070 * cos(6.20394049400 + 6298.57213865991*$t);
  $Y0 += 0.00000000087 * cos(1.33961295133 + 33019.2649296881*$t);
  $Y0 += 0.00000000071 * cos(2.38829288593 + 34172.1611489279*$t);
  $Y0 += 0.00000000079 * cos(1.08839441675 + 10018.5579792339*$t);
  $Y0 += 0.00000000079 * cos(5.26389897703 + 10408.5007481551*$t);
  $Y0 += 0.00000000069 * cos(1.34393957743 + 33794.2999060451*$t);
  $Y0 += 0.00000000087 * cos(3.11833451886 + 29050.53992586569*$t);
  $Y0 += 0.00000000069 * cos(5.61698463903 + 41044.8342684391*$t);
  $Y0 += 0.00000000069 * cos(0.68347421356 + 9644.7074896671*$t);
  $Y0 += 0.00000000069 * cos(5.66881918022 + 10782.3512377219*$t);
  $Y0 += 0.00000000087 * cos(0.75446196555 + 28313.0449871775*$t);
  $Y0 += 0.00000000085 * cos(5.34847160578 + 46386.7499258277*$t);
  $Y0 += 0.00000000083 * cos(4.22258770909 + 9721.86607123571*$t);
  $Y0 += 0.00000000083 * cos(2.12970568469 + 10705.1926561533*$t);
  $Y0 += 0.00000000090 * cos(3.61691095667 + 20049.4413019897*$t);
  $Y0 += 0.00000000064 * cos(4.29241354560 + 9147.03388650451*$t);
  $Y0 += 0.00000000076 * cos(5.76440554422 + 21486.1968400947*$t);
  $Y0 += 0.00000000085 * cos(2.91506656251 + 19573.13089318649*$t);
  $Y0 += 0.00000000063 * cos(3.18394429045 + 18314.67696156089*$t);
  $Y0 += 0.00000000071 * cos(1.43323486518 + 1573.57660661529*$t);
  $Y0 += 0.00000000070 * cos(0.75113063455 + 1580.6228433133*$t);
  $Y0 += 0.00000000080 * cos(1.55502986811 + 39301.8531447125*$t);
  $Y0 += 0.00000000067 * cos(2.05780765354 + 3956.2641985359*$t);
  $Y0 += 0.00000000087 * cos(3.90828389301 + 29264.3266562707*$t);
  $Y0 += 0.00000000063 * cos(4.94664274045 + 27461.46703058189*$t);
  $Y0 += 0.00000000070 * cos(4.18407491369 + 1479.11039154791*$t);
  $Y0 += 0.00000000081 * cos(1.62635438826 + 10205.92818172669*$t);
  $Y0 += 0.00000000080 * cos(1.81036094537 + 38204.44354188749*$t);
  $Y0 += 0.00000000060 * cos(6.06109901775 + 20421.2919855981*$t);
  $Y0 += 0.00000000064 * cos(5.87371692529 + 18300.44986755929*$t);
  $Y0 += 0.00000000076 * cos(2.36906935680 + 29683.81130014589*$t);
  $Y0 += 0.00000000082 * cos(2.02061615739 + 60530.2451682583*$t);
  $Y0 += 0.00000000077 * cos(4.62121260267 + 53445.8360221101*$t);
  $Y0 += 0.00000000062 * cos(5.99888344180 + 11599.4246400307*$t);
  $Y0 += 0.00000000058 * cos(1.51132330725 + 7576.8038910575*$t);
  $Y0 += 0.00000000057 * cos(2.10835504837 + 11280.0248408845*$t);
  $Y0 += 0.00000000059 * cos(5.97279707503 + 10255.0801546793*$t);
  $Y0 += 0.00000000059 * cos(0.37949631875 + 10171.9785727097*$t);
  $Y0 += 0.00000000057 * cos(2.49183550585 + 20464.84258254131*$t);
  $Y0 += 0.00000000079 * cos(3.54945759635 + 10136.7756574519*$t);
  $Y0 += 0.00000000066 * cos(3.91005081121 + 14169.5497447469*$t);
  $Y0 += 0.00000000063 * cos(5.25828651967 + 18099.7594409665*$t);
  $Y0 += 0.00000000060 * cos(1.62777565840 + 29786.9040743645*$t);
  $Y0 += 0.00000000064 * cos(4.00075551038 + 30007.3167168033*$t);
  $Y0 += 0.00000000054 * cos(2.10183945809 + 30666.3987759163*$t);
  $Y0 += 0.00000000058 * cos(1.48653920785 + 75449.7506569799*$t);
  $Y0 += 0.00000000073 * cos(2.27987689949 + 51449.5680807617*$t);
  $Y0 += 0.00000000074 * cos(3.91378496364 + 21720.2991334881*$t);
  $Y0 += 0.00000000063 * cos(1.10572404909 + 26736.1890796967*$t);
  $Y0 += 0.00000000054 * cos(2.34430307252 + 38204.9311768545*$t);
  $Y0 += 0.00000000072 * cos(2.90060717525 + 100608.3523767453*$t);
  $Y0 += 0.00000000053 * cos(2.23725068823 + 419.72846135871*$t);
  $Y0 += 0.00000000052 * cos(0.52183347499 + 40426.7878114515*$t);
  $Y0 += 0.00000000052 * cos(1.02206221481 + 29580.23089096029*$t);
  $Y0 += 0.00000000053 * cos(2.81130934606 + 419.2408263917*$t);
  $Y0 += 0.00000000058 * cos(6.02426265881 + 20412.5878159039*$t);
  $Y0 += 0.00000000054 * cos(4.83322053510 + 9366.9588939763*$t);
  $Y0 += 0.00000000055 * cos(5.16439912672 + 9103.6631766341*$t);
  $Y0 += 0.00000000050 * cos(0.80815973951 + 34570.3101523361*$t);
  $Y0 += 0.00000000067 * cos(4.21574061370 + 632.5399218297*$t);
  $Y0 += 0.00000000050 * cos(2.75084153641 + 37724.5096022647*$t);
  $Y0 += 0.00000000069 * cos(3.30376299828 + 53284.94101775829*$t);
  $Y0 += 0.00000000057 * cos(3.46902641065 + 8307.5769637871*$t);
  $Y0 += 0.00000000050 * cos(6.26940117566 + 8417.7832850065*$t);
  $Y0 += 0.00000000049 * cos(3.48884514281 + 26087.65932409069*$t);
  $Y0 += 0.00000000064 * cos(0.45737297425 + 7064.3652031063*$t);
  $Y0 += 0.00000000049 * cos(0.14582053812 + 14128.4865887291*$t);
  $Y0 += 0.00000000056 * cos(0.66365909742 + 28418.2438215195*$t);
  $Y0 += 0.00000000066 * cos(4.48087077585 + 19580.7320751543*$t);
  $Y0 += 0.00000000047 * cos(4.50934828666 + 10742.73269382209*$t);
  $Y0 += 0.00000000061 * cos(2.99027576045 + 43232.0628409321*$t);
  $Y0 += 0.00000000061 * cos(2.99027576045 + 43232.5504758991*$t);
  $Y0 += 0.00000000047 * cos(3.24772943759 + 38741.7356889499*$t);
  $Y0 += 0.00000000050 * cos(6.05228449513 + 59161.1932343711*$t);
  $Y0 += 0.00000000046 * cos(0.66057761892 + 18844.8555616225*$t);
  $Y0 += 0.00000000054 * cos(5.40667573437 + 48947.9076881601*$t);
  $Y0 += 0.00000000046 * cos(3.06762447182 + 3154.9309023791*$t);
  $Y0 += 0.00000000046 * cos(5.78250179315 + 194.7275669771*$t);
  $Y0 += 0.00000000056 * cos(5.79105836654 + 9936.7835918301*$t);
  $Y0 += 0.00000000056 * cos(0.56123502724 + 10490.27513555891*$t);
  $Y0 += 0.00000000054 * cos(2.92585194345 + 9922.5564978285*$t);
  $Y0 += 0.00000000054 * cos(3.42644145033 + 10504.50222956051*$t);
  $Y0 += 0.00000000059 * cos(3.58503267144 + 18204.47064034149*$t);
  $Y0 += 0.00000000048 * cos(5.93973568185 + 38727.5085949483*$t);
  $Y0 += 0.00000000057 * cos(0.49036750604 + 50316.9596220473*$t);
  $Y0 += 0.00000000061 * cos(4.41585090977 + 10140.2322378355*$t);
  $Y0 += 0.00000000061 * cos(1.93644248401 + 10286.8264895535*$t);
  $Y0 += 0.00000000061 * cos(5.28414092980 + 6567.1789863401*$t);
  $Y0 += 0.00000000048 * cos(1.78116904393 + 9246.5584862589*$t);
  $Y0 += 0.00000000060 * cos(4.34124861578 + 3684.1342325067*$t);
  $Y0 += 0.00000000060 * cos(1.84622131041 + 14427.5983787793*$t);
  $Y0 += 0.00000000051 * cos(3.86708252316 + 47623.60896860609*$t);
  $Y0 += 0.00000000051 * cos(0.71903454294 + 9566.03089541269*$t);
  $Y0 += 0.00000000052 * cos(1.63231256422 + 8727.0616076623*$t);
  $Y0 += 0.00000000057 * cos(2.19171070766 + 32243.2546833971*$t);
  $Y0 += 0.00000000048 * cos(0.48328683640 + 433.9555553603*$t);
  $Y0 += 0.00000000045 * cos(3.95006454295 + 10263.5259855987*$t);
  $Y0 += 0.00000000045 * cos(2.40222885083 + 10163.53274179031*$t);
  $Y0 += 0.00000000049 * cos(0.08548300777 + 9794.6049647939*$t);
  $Y0 += 0.00000000049 * cos(6.26681038600 + 10632.45376259511*$t);
  $Y0 += 0.00000000058 * cos(1.48111021336 + 1860.95904382949*$t);
  $Y0 += 0.00000000047 * cos(6.22156178529 + 20142.9555910403*$t);
  $Y0 += 0.00000000046 * cos(3.81317535217 + 2349.5868529063*$t);
  $Y0 += 0.00000000044 * cos(0.47724556879 + 30632.98690911569*$t);
  $Y0 += 0.00000000046 * cos(3.13107041429 + 2356.63308960431*$t);
  $Y0 += 0.00000000041 * cos(4.84096981140 + 12850.2548363315*$t);
  $Y0 += 0.00000000041 * cos(0.14576799491 + 8094.7655033161*$t);
  $Y0 += 0.00000000042 * cos(3.51225043090 + 77802.6168107517*$t);
  $Y0 += 0.00000000042 * cos(1.24107185058 + 25132.5472174491*$t);
  $Y0 += 0.00000000043 * cos(3.94226686000 + 19359.83179774849*$t);
  $Y0 += 0.00000000040 * cos(5.46575824362 + 10192.2663332351*$t);
  $Y0 += 0.00000000042 * cos(1.71742433091 + 34363.6094150395*$t);
  $Y0 += 0.00000000039 * cos(5.92169473585 + 109.9625037359*$t);
  $Y0 += 0.00000000044 * cos(2.89783948131 + 79379.96035319949*$t);
  $Y0 += 0.00000000043 * cos(5.95822352823 + 38734.13450698209*$t);
  $Y0 += 0.00000000046 * cos(5.13701973505 + 17778.3600844325*$t);
  $Y0 += 0.00000000039 * cos(1.30600974103 + 12565.9078824993*$t);
  $Y0 += 0.00000000041 * cos(1.87488507902 + 27681.89692667289*$t);
  $Y0 += 0.00000000053 * cos(3.44448984210 + 64460.4548644779*$t);
  $Y0 += 0.00000000039 * cos(1.87347006255 + 28631.5429169575*$t);
  $Y0 += 0.00000000052 * cos(3.63883543733 + 38631.5293677305*$t);
  $Y0 += 0.00000000043 * cos(4.57112425738 + 11180.5002411301*$t);
  $Y0 += 0.00000000039 * cos(5.73477931992 + 1265.81129610991*$t);
  $Y0 += 0.00000000039 * cos(5.37998455046 + 7879.84533585549*$t);
  $Y0 += 0.00000000039 * cos(5.37998455046 + 7880.3329708225*$t);
  $Y0 += 0.00000000052 * cos(0.42370802477 + 1.7282901918*$t);
  $Y0 += 0.00000000039 * cos(5.18684094963 + 54981.6287735731*$t);
  $Y0 += 0.00000000047 * cos(0.18137418769 + 187.68133027909*$t);
  $Y0 += 0.00000000044 * cos(5.88330364964 + 10168.3881440579*$t);
  $Y0 += 0.00000000044 * cos(0.46898974414 + 10258.67058333111*$t);
  $Y0 += 0.00000000048 * cos(3.11428064716 + 10063.9661665599*$t);
  $Y0 += 0.00000000043 * cos(0.40920515062 + 22029.9691371861*$t);
  $Y0 += 0.00000000051 * cos(4.32233625991 + 104538.56207296489*$t);
  $Y0 += 0.00000000051 * cos(4.70514324366 + 16250.7735674565*$t);
  $Y0 += 0.00000000037 * cos(2.91614118281 + 29161.2338820521*$t);
  $Y0 += 0.00000000043 * cos(3.35259007747 + 10363.09256082911*$t);
  $Y0 += 0.00000000038 * cos(2.56509414217 + 47917.5073879503*$t);
  $Y0 += 0.00000000049 * cos(6.13351350993 + 66037.79840692569*$t);
  $Y0 += 0.00000000037 * cos(2.84218465987 + 6257.0213476751*$t);
  $Y0 += 0.00000000036 * cos(1.39948703899 + 8674.2134938825*$t);
  $Y0 += 0.00000000045 * cos(3.57903060172 + 522.3336006103*$t);
  $Y0 += 0.00000000049 * cos(0.39199067732 + 491.9071099423*$t);
  $Y0 += 0.00000000042 * cos(1.38184413529 + 115674.52048208468*$t);
  $Y0 += 0.00000000040 * cos(1.35149502784 + 10233.8171242199*$t);
  $Y0 += 0.00000000036 * cos(5.98817728846 + 47938.2827834427*$t);
  $Y0 += 0.00000000035 * cos(1.18237114499 + 12546.72575656651*$t);
  $Y0 += 0.00000000048 * cos(1.34137746528 + 90395.0668305343*$t);
  $Y0 += 0.00000000040 * cos(4.18858105636 + 14127.99895376209*$t);
  $Y0 += 0.00000000044 * cos(2.73569081007 + 9698.0654926015*$t);
  $Y0 += 0.00000000044 * cos(3.61660258371 + 10728.99323478751*$t);
  $Y0 += 0.00000000036 * cos(0.66588479818 + 69942.1974183125*$t);
  $Y0 += 0.00000000035 * cos(4.16647411013 + 41654.71929848429*$t);
  $Y0 += 0.00000000034 * cos(2.69446692279 + 55798.7021758819*$t);
  $Y0 += 0.00000000037 * cos(1.68139810641 + 35192.0539531753*$t);
  $Y0 += 0.00000000046 * cos(1.33857194026 + 36301.4325052687*$t);
  $Y0 += 0.00000000047 * cos(6.19310388781 + 86464.85713431469*$t);
  $Y0 += 0.00000000035 * cos(0.73574096610 + 48732.98752069949*$t);
  $Y0 += 0.00000000035 * cos(3.22135299939 + 10011.2759685204*$t);
  $Y0 += 0.00000000035 * cos(3.13094039439 + 10415.78275886861*$t);
  $Y0 += 0.00000000034 * cos(4.60818788188 + 37410.8110573621*$t);
  $Y0 += 0.00000000033 * cos(3.80929053875 + 49477.59865325469*$t);
  $Y0 += 0.00000000042 * cos(2.82864954668 + 18830.6284676209*$t);
  $Y0 += 0.00000000035 * cos(0.56308161765 + 49515.1386909235*$t);
  $Y0 += 0.00000000047 * cos(2.22431731848 + 31022.50935337269*$t);
  $Y0 += 0.00000000034 * cos(3.32920660018 + 100909.28143881488*$t);
  $Y0 += 0.00000000033 * cos(2.17810098111 + 10117.5501364767*$t);
  $Y0 += 0.00000000033 * cos(4.17419241267 + 10309.5085909123*$t);
  $Y0 += 0.00000000034 * cos(0.22454658153 + 7461.49412903589*$t);
  $Y0 += 0.00000000034 * cos(5.44249373293 + 45584.9289947039*$t);
  $Y0 += 0.00000000032 * cos(1.67235375803 + 9676.23721663209*$t);
  $Y0 += 0.00000000039 * cos(1.15429612014 + 316.6356871401*$t);
  $Y0 += 0.00000000033 * cos(6.02812295236 + 31748.99137324289*$t);
  $Y0 += 0.00000000031 * cos(1.87708120179 + 30103.29594402109*$t);
  $Y0 += 0.00000000035 * cos(5.77132581087 + 58946.27306691049*$t);
  $Y0 += 0.00000000032 * cos(2.19359308367 + 21977.8601325535*$t);
  $Y0 += 0.00000000036 * cos(5.94106521859 + 20430.7470631686*$t);
  $Y0 += 0.00000000032 * cos(4.93495818843 + 81732.82650697129*$t);
  $Y0 += 0.00000000030 * cos(0.70932860715 + 19573.6185281535*$t);
  $Y0 += 0.00000000031 * cos(0.91919649284 + 11.2895177474*$t);
  $Y0 += 0.00000000038 * cos(0.23287825442 + 20617.77554105009*$t);
  $Y0 += 0.00000000033 * cos(4.31035022066 + 83310.1700494191*$t);
  $Y0 += 0.00000000029 * cos(4.95280669313 + 11752.8452335065*$t);
  $Y0 += 0.00000000029 * cos(3.94608385223 + 9801.1582668201*$t);
  $Y0 += 0.00000000029 * cos(2.40620954155 + 10625.9004605689*$t);
  $Y0 += 0.00000000030 * cos(2.05100908229 + 20432.3378342129*$t);
  $Y0 += 0.00000000031 * cos(3.37186993722 + 7255.8134692179*$t);
  $Y0 += 0.00000000029 * cos(5.98151124473 + 9889.53631207009*$t);
  $Y0 += 0.00000000029 * cos(0.20516018454 + 224.5886131854*$t);
  $Y0 += 0.00000000028 * cos(4.98574596975 + 10099.09007500929*$t);
  $Y0 += 0.00000000028 * cos(1.36654742403 + 10327.96865237972*$t);
  $Y0 += 0.00000000037 * cos(1.58092203649 + 47964.0934682755*$t);
  $Y0 += 0.00000000029 * cos(3.50171158414 + 10426.3408241655*$t);
  $Y0 += 0.00000000034 * cos(2.65907611892 + 1539.5596872955*$t);
  $Y0 += 0.00000000039 * cos(3.61856411890 + 30563.8343848409*$t);
  $Y0 += 0.00000000039 * cos(2.90348082239 + 5791.16874004909*$t);
  $Y0 += 0.00000000028 * cos(0.72410945645 + 1178.9507215561*$t);
  $Y0 += 0.00000000031 * cos(3.89571253711 + 39786.8905251375*$t);
  $Y0 += 0.00000000028 * cos(2.08869873285 + 73872.40711453209*$t);
  $Y0 += 0.00000000027 * cos(2.10097762457 + 9411.22079760369*$t);
  $Y0 += 0.00000000028 * cos(5.13153492293 + 15694.7842825621*$t);
  $Y0 += 0.00000000034 * cos(2.10776670451 + 40213.4887160135*$t);
  $Y0 += 0.00000000037 * cos(2.87146864607 + 36949.4746259077*$t);
  $Y0 += 0.00000000035 * cos(1.99221623651 + 37704.2218417393*$t);
  $Y0 += 0.00000000028 * cos(4.41249255504 + 4732.2744448269*$t);
  $Y0 += 0.00000000037 * cos(1.06810151543 + 13859.8797410489*$t);
  $Y0 += 0.00000000035 * cos(4.29368361875 + 18093.13088206649*$t);
  $Y0 += 0.00000000035 * cos(4.29368361875 + 18093.6185170335*$t);
  $Y0 += 0.00000000031 * cos(1.42888574956 + 42430.7295447753*$t);
  $Y0 += 0.00000000026 * cos(2.52843792658 + 8734.6627896301*$t);
  $Y0 += 0.00000000028 * cos(3.49562374283 + 7886.4738947555*$t);
  $Y0 += 0.00000000031 * cos(1.84284071261 + 25960.1788334057*$t);
  return $Y0;
}



  function Venus_C_Y1 ($t)
{
  $Y1 =  0.0;
  $Y1 += 0.00051880979 * cos(0.71095646371 + 0.2438174835*$t);
  $Y1 += 0.00017260820 * cos(5.63797390819 + 20426.8149099055*$t);
  $Y1 += 0.00011049864 * cos(3.60540297803 + 10213.0417287275*$t);
  $Y1 += 0.00004831725 * cos(3.20542321593 + 10213.5293636945*$t);
  $Y1 += 0.00000175352 * cos(0.23521252264 + 30640.1004561165*$t);
  $Y1 += 0.00000060293 * cos(3.35720999584 + 8636.18582124671*$t);
  $Y1 += 0.00000062982 * cos(0.52034329307 + 10187.2310438947*$t);
  $Y1 += 0.00000062707 * cos(5.83097900617 + 10239.8276834943*$t);
  $Y1 += 0.00000049342 * cos(3.00369011281 + 11790.8729061423*$t);
  $Y1 += 0.00000036826 * cos(0.49986531697 + 775.7664288075*$t);
  $Y1 += 0.00000039689 * cos(4.87663392982 + 20426.32727493849*$t);
  $Y1 += 0.00000030101 * cos(3.75628445251 + 10022.0810975829*$t);
  $Y1 += 0.00000029330 * cos(2.59462276840 + 10404.9776298061*$t);
  $Y1 += 0.00000019990 * cos(5.87132108056 + 9438.0067523705*$t);
  $Y1 += 0.00000017877 * cos(0.50656677315 + 10989.0519750185*$t);
  $Y1 += 0.00000014175 * cos(2.13477380875 + 9683.8383985999*$t);
  $Y1 += 0.00000013388 * cos(2.90924092450 + 191.2044486281*$t);
  $Y1 += 0.00000013513 * cos(4.20262757897 + 10743.2203287891*$t);
  $Y1 += 0.00000014034 * cos(1.92852680423 + 4705.9761250271*$t);
  $Y1 += 0.00000013385 * cos(5.86252489050 + 19651.2922985815*$t);
  $Y1 += 0.00000006873 * cos(3.26551570952 + 9104.1508116011*$t);
  $Y1 += 0.00000007547 * cos(4.00471700687 + 1059.6257476727*$t);
  $Y1 += 0.00000007388 * cos(4.42957705498 + 15721.0826023619*$t);
  $Y1 += 0.00000005971 * cos(3.08667185392 + 11322.9079157879*$t);
  $Y1 += 0.00000005966 * cos(5.81970120815 + 10220.6429106953*$t);
  $Y1 += 0.00000005965 * cos(0.53310334979 + 10206.4158166937*$t);
  $Y1 += 0.00000005155 * cos(4.06691487180 + 3154.4432674121*$t);
  $Y1 += 0.00000004571 * cos(3.01985951758 + 20618.2631760171*$t);
  $Y1 += 0.00000004246 * cos(4.48337967211 + 10000.23026825651*$t);
  $Y1 += 0.00000004157 * cos(1.86902016050 + 10426.8284591325*$t);
  $Y1 += 0.00000004649 * cos(1.29491136363 + 9830.6328314713*$t);
  $Y1 += 0.00000004431 * cos(5.05738488158 + 10596.4258959177*$t);
  $Y1 += 0.00000003938 * cos(5.07016509425 + 7.3573644843*$t);
  $Y1 += 0.00000003399 * cos(0.82461824896 + 7860.6632099227*$t);
  $Y1 += 0.00000002758 * cos(2.34021605546 + 19367.4329797163*$t);
  $Y1 += 0.00000002699 * cos(5.36901161259 + 7058.8422787989*$t);
  $Y1 += 0.00000002515 * cos(0.93953422896 + 8623.96883344369*$t);
  $Y1 += 0.00000002725 * cos(0.25399973919 + 801.5771136403*$t);
  $Y1 += 0.00000002539 * cos(4.39873985192 + 9411.7084325707*$t);
  $Y1 += 0.00000001822 * cos(4.89709335392 + 1109.1347346099*$t);
  $Y1 += 0.00000002300 * cos(1.94517236646 + 11015.3502948183*$t);
  $Y1 += 0.00000001816 * cos(0.95974773242 + 13368.2164485901*$t);
  $Y1 += 0.00000001814 * cos(3.28732569612 + 3930.4535137031*$t);
  $Y1 += 0.00000001586 * cos(1.12226291927 + 40853.3860023275*$t);
  $Y1 += 0.00000001999 * cos(4.09704295416 + 26.0545023163*$t);
  $Y1 += 0.00000001745 * cos(0.69413221331 + 4552.1973145423*$t);
  $Y1 += 0.00000001503 * cos(5.35238315560 + 12566.3955174663*$t);
  $Y1 += 0.00000001446 * cos(5.48745108690 + 7084.6529636317*$t);
  $Y1 += 0.00000001400 * cos(4.67651135088 + 11272.91129388371*$t);
  $Y1 += 0.00000001282 * cos(3.09230484373 + 10219.0522880019*$t);
  $Y1 += 0.00000001282 * cos(3.25998855005 + 10208.0064393871*$t);
  $Y1 += 0.00000001352 * cos(1.29314419649 + 20419.7013629047*$t);
  $Y1 += 0.00000001475 * cos(4.11277346234 + 3128.6325825793*$t);
  $Y1 += 0.00000001235 * cos(0.55003403789 + 1577.5873599313*$t);
  $Y1 += 0.00000001286 * cos(4.12341945563 + 23581.5019948011*$t);
  $Y1 += 0.00000001283 * cos(5.45488591011 + 382.6527147397*$t);
  $Y1 += 0.00000001171 * cos(1.71768767831 + 9154.1474335053*$t);
  $Y1 += 0.00000001084 * cos(2.78444751991 + 10198.2768925095*$t);
  $Y1 += 0.00000001084 * cos(3.56784587387 + 10228.78183487951*$t);
  $Y1 += 0.00000001198 * cos(3.38905914109 + 16496.6052136859*$t);
  $Y1 += 0.00000000869 * cos(3.97005901207 + 2352.6223362883*$t);
  $Y1 += 0.00000001112 * cos(4.99559909082 + 1589.3167127673*$t);
  $Y1 += 0.00000000922 * cos(5.66846628682 + 15874.8614128467*$t);
  $Y1 += 0.00000000743 * cos(5.39400352278 + 28287.2343023447*$t);
  $Y1 += 0.00000000746 * cos(0.58295457724 + 3149.4079780717*$t);
  $Y1 += 0.00000000797 * cos(3.54113611340 + 426.8420083595*$t);
  $Y1 += 0.00000000625 * cos(1.61452093926 + 20400.5165901057*$t);
  $Y1 += 0.00000000615 * cos(4.93517817028 + 21536.1934619989*$t);
  $Y1 += 0.00000000832 * cos(0.35357361779 + 21228.63584102931*$t);
  $Y1 += 0.00000000656 * cos(0.63035969025 + 11014.8626598513*$t);
  $Y1 += 0.00000000586 * cos(0.59640409991 + 5661.5758666357*$t);
  $Y1 += 0.00000000648 * cos(0.34210160772 + 537.0483295789*$t);
  $Y1 += 0.00000000674 * cos(0.56456739745 + 8094.2778683491*$t);
  $Y1 += 0.00000000636 * cos(4.96350573817 + 18849.4713674577*$t);
  $Y1 += 0.00000000655 * cos(2.23854746047 + 17298.4261448097*$t);
  $Y1 += 0.00000000615 * cos(0.82332897293 + 522.8212355773*$t);
  $Y1 += 0.00000000507 * cos(5.26511211265 + 20453.1132297053*$t);
  $Y1 += 0.00000000451 * cos(3.55775064489 + 32217.4439985643*$t);
  $Y1 += 0.00000000480 * cos(4.03262150754 + 529.44714761109*$t);
  $Y1 += 0.00000000439 * cos(5.33608025421 + 6282.83203250789*$t);
  $Y1 += 0.00000000439 * cos(1.01049396969 + 29051.0275608327*$t);
  $Y1 += 0.00000000410 * cos(3.89856473824 + 24357.0246061251*$t);
  $Y1 += 0.00000000452 * cos(5.33295391690 + 9146.54625153749*$t);
  $Y1 += 0.00000000417 * cos(3.34912055717 + 6681.46867088311*$t);
  $Y1 += 0.00000000434 * cos(4.87041677173 + 9160.77334553909*$t);
  $Y1 += 0.00000000364 * cos(1.14500385840 + 10640.1275545705*$t);
  $Y1 += 0.00000000363 * cos(5.18731183247 + 9786.9311728185*$t);
  $Y1 += 0.00000000428 * cos(5.53178842562 + 20809.7114421287*$t);
  $Y1 += 0.00000000440 * cos(0.90299311231 + 9690.9519456007*$t);
  $Y1 += 0.00000000440 * cos(5.44930026371 + 10736.1067817883*$t);
  $Y1 += 0.00000000372 * cos(5.21504043865 + 10251.55703633031*$t);
  $Y1 += 0.00000000372 * cos(1.13725295513 + 10175.5016910587*$t);
  $Y1 += 0.00000000319 * cos(5.77038175361 + 17277.6507493173*$t);
  $Y1 += 0.00000000427 * cos(1.38502821135 + 18837.7420146217*$t);
  $Y1 += 0.00000000319 * cos(1.75892023078 + 7860.17557495569*$t);
  $Y1 += 0.00000000303 * cos(5.78500325867 + 14765.48286075331*$t);
  $Y1 += 0.00000000351 * cos(0.93732183183 + 6490.0204047715*$t);
  $Y1 += 0.00000000287 * cos(1.70533444360 + 1577.0997249643*$t);
  $Y1 += 0.00000000318 * cos(2.05196802231 + 14945.0723560709*$t);
  $Y1 += 0.00000000297 * cos(5.78070702462 + 10233.1991245943*$t);
  $Y1 += 0.00000000297 * cos(0.57158636916 + 10193.85960279471*$t);
  $Y1 += 0.00000000372 * cos(4.36086070254 + 22004.1584523533*$t);
  $Y1 += 0.00000000311 * cos(2.86660649993 + 9683.35076363289*$t);
  $Y1 += 0.00000000284 * cos(0.78946184560 + 3442.81876244891*$t);
  $Y1 += 0.00000000269 * cos(2.73302271647 + 9573.14444241349*$t);
  $Y1 += 0.00000000262 * cos(1.65344694622 + 21202.3375212295*$t);
  $Y1 += 0.00000000285 * cos(2.99593464960 + 13745.5900565059*$t);
  $Y1 += 0.00000000276 * cos(6.13791366947 + 9676.7248515991*$t);
  $Y1 += 0.00000000289 * cos(4.21532854719 + 20235.36664379391*$t);
  $Y1 += 0.00000000263 * cos(4.06023282629 + 22779.6810636773*$t);
  $Y1 += 0.00000000280 * cos(3.52465276935 + 14919.2616712381*$t);
  $Y1 += 0.00000000262 * cos(0.23413334905 + 10750.33387578991*$t);
  $Y1 += 0.00000000256 * cos(2.84423020029 + 10234.3047591869*$t);
  $Y1 += 0.00000000239 * cos(3.17649373533 + 5507.7970561509*$t);
  $Y1 += 0.00000000253 * cos(3.50443427097 + 10192.7539682021*$t);
  $Y1 += 0.00000000268 * cos(5.52795627850 + 27511.7116910207*$t);
  $Y1 += 0.00000000282 * cos(1.52617460595 + 4731.7868098599*$t);
  $Y1 += 0.00000000232 * cos(5.81477929300 + 3723.26514143949*$t);
  $Y1 += 0.00000000285 * cos(3.95599071883 + 20956.5058750001*$t);
  $Y1 += 0.00000000244 * cos(2.32200831696 + 2353.1099712553*$t);
  $Y1 += 0.00000000272 * cos(2.82574902606 + 20000.2167190295*$t);
  $Y1 += 0.00000000254 * cos(3.11073677155 + 6283.3196674749*$t);
  $Y1 += 0.00000000238 * cos(6.06399121577 + 30639.61282114949*$t);
  $Y1 += 0.00000000232 * cos(6.01167584587 + 19890.0103978101*$t);
  $Y1 += 0.00000000210 * cos(3.33764904887 + 18073.46112116669*$t);
  $Y1 += 0.00000000216 * cos(3.19588337312 + 18073.9487561337*$t);
  $Y1 += 0.00000000199 * cos(5.04355472771 + 9639.18456535971*$t);
  $Y1 += 0.00000000218 * cos(5.53074261320 + 19904.2374918117*$t);
  $Y1 += 0.00000000225 * cos(5.41510051366 + 13937.0383226175*$t);
  $Y1 += 0.00000000235 * cos(1.73003777450 + 1551.2890401315*$t);
  $Y1 += 0.00000000191 * cos(2.76287874160 + 6872.91693699471*$t);
  $Y1 += 0.00000000179 * cos(4.84535687472 + 30110.4094910219*$t);
  $Y1 += 0.00000000185 * cos(1.30870554546 + 10787.8741620293*$t);
  $Y1 += 0.00000000235 * cos(1.24541538744 + 1066.7392946735*$t);
  $Y1 += 0.00000000208 * cos(4.04763155841 + 10007.3438152573*$t);
  $Y1 += 0.00000000208 * cos(2.30466183537 + 10419.7149121317*$t);
  $Y1 += 0.00000000179 * cos(3.50084200533 + 18875.2820522905*$t);
  $Y1 += 0.00000000184 * cos(0.09028649493 + 9967.69771746511*$t);
  $Y1 += 0.00000000166 * cos(3.49629785102 + 18307.56341456009*$t);
  $Y1 += 0.00000000163 * cos(3.38894514289 + 10225.2587165305*$t);
  $Y1 += 0.00000000163 * cos(2.96334825089 + 10201.80001085851*$t);
  $Y1 += 0.00000000156 * cos(4.49619634182 + 10316.6221379131*$t);
  $Y1 += 0.00000000156 * cos(1.85609705196 + 10110.4365894759*$t);
  $Y1 += 0.00000000178 * cos(6.26185121103 + 10459.3610099239*$t);
  $Y1 += 0.00000000172 * cos(2.71508119650 + 14143.7390599141*$t);
  $Y1 += 0.00000000163 * cos(4.90813788389 + 8616.85528644289*$t);
  $Y1 += 0.00000000163 * cos(5.91344954982 + 6.86972951729*$t);
  $Y1 += 0.00000000157 * cos(3.58488866748 + 13554.1417903943*$t);
  $Y1 += 0.00000000152 * cos(3.62017418311 + 640.1411037975*$t);
  $Y1 += 0.00000000149 * cos(6.16738885127 + 7063.87756813929*$t);
  $Y1 += 0.00000000179 * cos(1.00591554381 + 29864.5778447925*$t);
  $Y1 += 0.00000000140 * cos(5.31441141872 + 8631.0823804445*$t);
  $Y1 += 0.00000000140 * cos(6.19029890817 + 529.9347825781*$t);
  $Y1 += 0.00000000131 * cos(2.45194876830 + 9794.0447198193*$t);
  $Y1 += 0.00000000170 * cos(3.49470295745 + 9153.6597985383*$t);
  $Y1 += 0.00000000128 * cos(3.89903128812 + 10633.0140075697*$t);
  $Y1 += 0.00000000177 * cos(3.03845859741 + 5481.4987363511*$t);
  $Y1 += 0.00000000154 * cos(5.69369789989 + 2119.00767786191*$t);
  $Y1 += 0.00000000131 * cos(5.56674422840 + 16984.2399649401*$t);
  $Y1 += 0.00000000131 * cos(4.35512447481 + 9437.5191174035*$t);
  $Y1 += 0.00000000118 * cos(1.90850049529 + 11790.3852711753*$t);
  $Y1 += 0.00000000140 * cos(2.00742093288 + 191.6920835951*$t);
  $Y1 += 0.00000000143 * cos(3.32004481323 + 7994.77225950771*$t);
  $Y1 += 0.00000000123 * cos(1.23478424338 + 213.5429129215*$t);
  $Y1 += 0.00000000111 * cos(2.74887704228 + 8661.9965060795*$t);
  $Y1 += 0.00000000121 * cos(0.64210487280 + 28521.3365957381*$t);
  $Y1 += 0.00000000119 * cos(3.20586515571 + 3929.96587873609*$t);
  $Y1 += 0.00000000106 * cos(4.33742493006 + 1109.6223695769*$t);
  $Y1 += 0.00000000099 * cos(3.87128339263 + 20.5315780089*$t);
  $Y1 += 0.00000000104 * cos(4.60451231291 + 36147.6536947839*$t);
  $Y1 += 0.00000000107 * cos(4.92712251717 + 22805.4917485101*$t);
  $Y1 += 0.00000000125 * cos(3.09576538097 + 12432.2864678813*$t);
  $Y1 += 0.00000000101 * cos(1.57214857483 + 1052.51220067191*$t);
  $Y1 += 0.00000000093 * cos(1.71903836713 + 574.10098085129*$t);
  $Y1 += 0.00000000129 * cos(0.19292287088 + 7564.58690325449*$t);
  $Y1 += 0.00000000092 * cos(3.49801814083 + 9359.84534697549*$t);
  $Y1 += 0.00000000099 * cos(0.75167027759 + 31441.92138724031*$t);
  $Y1 += 0.00000000091 * cos(1.47446366588 + 775.2787938405*$t);
  $Y1 += 0.00000000112 * cos(0.41548066865 + 10186.7434089277*$t);
  $Y1 += 0.00000000095 * cos(2.09703168525 + 10433.9420061333*$t);
  $Y1 += 0.00000000095 * cos(4.25526170853 + 9993.1167212557*$t);
  $Y1 += 0.00000000092 * cos(1.92657936145 + 14143.2514249471*$t);
  $Y1 += 0.00000000096 * cos(3.75726377834 + 220.6564599223*$t);
  $Y1 += 0.00000000084 * cos(1.09570291858 + 6770.46678376209*$t);
  $Y1 += 0.00000000088 * cos(3.56094956187 + 11322.42028082089*$t);
  $Y1 += 0.00000000110 * cos(5.01502416629 + 11802.6022589783*$t);
  $Y1 += 0.00000000108 * cos(3.56320703640 + 29580.7185259273*$t);
  $Y1 += 0.00000000093 * cos(4.32241552615 + 2957.9597119601*$t);
  $Y1 += 0.00000000101 * cos(0.52107246051 + 6770.9544187291*$t);
  $Y1 += 0.00000000105 * cos(3.18747751371 + 8662.48414104651*$t);
  $Y1 += 0.00000000094 * cos(6.19217661869 + 20433.9284569063*$t);
  $Y1 += 0.00000000089 * cos(3.84885484388 + 15720.5949673949*$t);
  $Y1 += 0.00000000088 * cos(4.22623893206 + 206.42936592071*$t);
  $Y1 += 0.00000000101 * cos(0.50947630970 + 7085.1405985987*$t);
  $Y1 += 0.00000000077 * cos(2.93440992089 + 10177.5014970171*$t);
  $Y1 += 0.00000000077 * cos(3.41788347289 + 10249.55723037191*$t);
  $Y1 += 0.00000000087 * cos(2.72553149790 + 2378.9206560881*$t);
  $Y1 += 0.00000000080 * cos(2.87657638659 + 5507.3094211839*$t);
  $Y1 += 0.00000000100 * cos(3.31433227306 + 14945.5599910379*$t);
  $Y1 += 0.00000000096 * cos(1.34435751761 + 8624.45646841071*$t);
  $Y1 += 0.00000000071 * cos(5.88504983472 + 24150.3238688285*$t);
  $Y1 += 0.00000000089 * cos(4.61897054824 + 18875.76968725751*$t);
  $Y1 += 0.00000000071 * cos(4.97846455178 + 29043.91401383189*$t);
  $Y1 += 0.00000000075 * cos(4.48442686361 + 19897.1239448109*$t);
  $Y1 += 0.00000000068 * cos(2.38966490616 + 10384.2022343137*$t);
  $Y1 += 0.00000000068 * cos(3.96262848762 + 10042.8564930753*$t);
  $Y1 += 0.00000000077 * cos(5.37168621038 + 29573.6049789265*$t);
  $Y1 += 0.00000000073 * cos(4.93040355002 + 29587.8320729281*$t);
  $Y1 += 0.00000000063 * cos(4.96682804495 + 10239.3400485273*$t);
  $Y1 += 0.00000000086 * cos(5.50379681688 + 19650.8046636145*$t);
  $Y1 += 0.00000000086 * cos(5.13181328155 + 19360.3194327155*$t);
  $Y1 += 0.00000000061 * cos(5.37335140170 + 29058.1411078335*$t);
  $Y1 += 0.00000000081 * cos(3.17506029506 + 11764.5745863425*$t);
  $Y1 += 0.00000000066 * cos(0.09242614010 + 26735.7014447297*$t);
  $Y1 += 0.00000000075 * cos(5.86155964498 + 25934.3681485729*$t);
  $Y1 += 0.00000000067 * cos(5.87156884416 + 40077.8633910035*$t);
  $Y1 += 0.00000000059 * cos(0.24096472060 + 10988.5643400515*$t);
  $Y1 += 0.00000000077 * cos(5.42249781467 + 20213.5158144675*$t);
  $Y1 += 0.00000000077 * cos(1.74322703053 + 7834.3648901229*$t);
  $Y1 += 0.00000000057 * cos(2.63908550678 + 10404.48999483909*$t);
  $Y1 += 0.00000000057 * cos(6.11425964512 + 110.45013870291*$t);
  $Y1 += 0.00000000067 * cos(3.14352797658 + 17777.87244946549*$t);
  $Y1 += 0.00000000060 * cos(4.64344417198 + 30831.5487222281*$t);
  $Y1 += 0.00000000058 * cos(4.04812917862 + 12592.2062022991*$t);
  $Y1 += 0.00000000054 * cos(3.33029969221 + 19317.43635781211*$t);
  $Y1 += 0.00000000065 * cos(1.59839937239 + 25158.8455372489*$t);
  $Y1 += 0.00000000064 * cos(0.63814287930 + 18308.0510495271*$t);
  $Y1 += 0.00000000059 * cos(1.67190949806 + 9779.32999085069*$t);
  $Y1 += 0.00000000053 * cos(6.23173234110 + 27490.9362955283*$t);
  $Y1 += 0.00000000050 * cos(0.18460290148 + 10103.3230424751*$t);
  $Y1 += 0.00000000050 * cos(6.16769049230 + 10323.7356849139*$t);
  $Y1 += 0.00000000050 * cos(4.63939060613 + 39794.0040721383*$t);
  $Y1 += 0.00000000055 * cos(1.18770302160 + 9793.5570848523*$t);
  $Y1 += 0.00000000048 * cos(2.66058888107 + 29089.0552334685*$t);
  $Y1 += 0.00000000051 * cos(5.30933109582 + 26709.8907598969*$t);
  $Y1 += 0.00000000047 * cos(5.42237264786 + 16522.4158985187*$t);
  $Y1 += 0.00000000060 * cos(4.61502027021 + 12592.6938372661*$t);
  $Y1 += 0.00000000057 * cos(4.83119299148 + 2218.51328670329*$t);
  $Y1 += 0.00000000047 * cos(2.05343620014 + 20640.1140053435*$t);
  $Y1 += 0.00000000046 * cos(2.74639353796 + 19786.9176235915*$t);
  $Y1 += 0.00000000047 * cos(4.18909923765 + 57836.89451481709*$t);
  $Y1 += 0.00000000045 * cos(2.36837617101 + 3532.3045102949*$t);
  $Y1 += 0.00000000047 * cos(1.59938927555 + 22003.6708173863*$t);
  $Y1 += 0.00000000045 * cos(2.81454147982 + 30000.2031698025*$t);
  $Y1 += 0.00000000043 * cos(3.56791888552 + 29786.9040743645*$t);
  $Y1 += 0.00000000051 * cos(0.93432433798 + 44008.0730872231*$t);
  $Y1 += 0.00000000042 * cos(6.21590796001 + 9999.7426332895*$t);
  $Y1 += 0.00000000050 * cos(0.51812370768 + 23581.0143598341*$t);
  $Y1 += 0.00000000051 * cos(6.00715809832 + 13341.9181287903*$t);
  $Y1 += 0.00000000040 * cos(3.99083942383 + 33019.2649296881*$t);
  $Y1 += 0.00000000051 * cos(5.84065090063 + 13656.10430865991*$t);
  $Y1 += 0.00000000048 * cos(1.01747986844 + 213.0552779545*$t);
  $Y1 += 0.00000000039 * cos(4.20765456607 + 20447.5903053979*$t);
  $Y1 += 0.00000000039 * cos(2.75710568559 + 10595.9382609507*$t);
  $Y1 += 0.00000000042 * cos(1.52233926028 + 30665.9111409493*$t);
  $Y1 += 0.00000000042 * cos(2.07548691715 + 3914.71340755109*$t);
  $Y1 += 0.00000000042 * cos(3.20676468713 + 38204.9311768545*$t);
  $Y1 += 0.00000000041 * cos(2.02945904881 + 17469.0990154289*$t);
  $Y1 += 0.00000000036 * cos(4.38221463656 + 10077.90403868451*$t);
  $Y1 += 0.00000000036 * cos(1.97007875722 + 10349.1546887045*$t);
  $Y1 += 0.00000000040 * cos(1.65514953516 + 18830.14083265389*$t);
  $Y1 += 0.00000000039 * cos(1.16926464863 + 18844.36792665549*$t);
  $Y1 += 0.00000000034 * cos(1.79297258774 + 21001.1597082403*$t);
  $Y1 += 0.00000000034 * cos(3.14405588009 + 13936.5506876505*$t);
  $Y1 += 0.00000000032 * cos(5.34063867594 + 36949.4746259077*$t);
  $Y1 += 0.00000000033 * cos(6.10548742756 + 16983.75232997309*$t);
  $Y1 += 0.00000000040 * cos(2.31586332501 + 47938.2827834427*$t);
  $Y1 += 0.00000000032 * cos(0.75258375907 + 39301.8531447125*$t);
  $Y1 += 0.00000000032 * cos(3.89417641266 + 39302.3407796795*$t);
  $Y1 += 0.00000000036 * cos(4.85111863254 + 19374.5465267171*$t);
  $Y1 += 0.00000000032 * cos(3.92861114802 + 16894.7542170941*$t);
  $Y1 += 0.00000000042 * cos(5.08245275253 + 55798.7021758819*$t);
  $Y1 += 0.00000000031 * cos(1.94569247568 + 20043.9183776823*$t);
  $Y1 += 0.00000000033 * cos(6.15578410865 + 48418.21672306549*$t);
  $Y1 += 0.00000000031 * cos(5.95509934930 + 9573.6320773805*$t);
  $Y1 += 0.00000000034 * cos(0.55952606060 + 54247.1693182669*$t);
  $Y1 += 0.00000000032 * cos(0.55000852758 + 10191.6785343681*$t);
  $Y1 += 0.00000000032 * cos(5.80228486620 + 10235.3801930209*$t);
  $Y1 += 0.00000000031 * cos(4.45781570376 + 8087.1643213483*$t);
  $Y1 += 0.00000000032 * cos(3.01069170124 + 19896.63630984389*$t);
  $Y1 += 0.00000000036 * cos(2.43177228108 + 7255.3258342509*$t);
  $Y1 += 0.00000000030 * cos(0.39582329080 + 10853.4266500085*$t);
  $Y1 += 0.00000000037 * cos(1.97789587606 + 27511.2240560537*$t);
  $Y1 += 0.00000000032 * cos(5.51602815822 + 19366.94534474929*$t);
  $Y1 += 0.00000000029 * cos(3.64083349524 + 10291.20313412251*$t);
  $Y1 += 0.00000000029 * cos(2.71145989854 + 10135.8555932665*$t);
  $Y1 += 0.00000000028 * cos(4.16989797155 + 104351.85638378029*$t);
  $Y1 += 0.00000000032 * cos(2.59502959120 + 20206.4022674667*$t);
  $Y1 += 0.00000000029 * cos(1.33160612830 + 29864.0902098255*$t);
  $Y1 += 0.00000000029 * cos(5.27506731832 + 49515.1386909235*$t);
  $Y1 += 0.00000000027 * cos(0.49570343491 + 5661.0882316687*$t);
  $Y1 += 0.00000000034 * cos(0.56834994987 + 9161.2609805061*$t);
  $Y1 += 0.00000000027 * cos(3.93043638128 + 6872.42930202769*$t);
  $Y1 += 0.00000000032 * cos(3.80176203654 + 9836.1557557787*$t);
  $Y1 += 0.00000000032 * cos(2.55053135724 + 10590.9029716103*$t);
  $Y1 += 0.00000000027 * cos(4.68213678931 + 6298.57213865991*$t);
  $Y1 += 0.00000000035 * cos(3.77990327166 + 9986.0532309055*$t);
  $Y1 += 0.00000000035 * cos(2.57239012212 + 10441.00549648351*$t);
  $Y1 += 0.00000000033 * cos(3.63785377361 + 31441.4337522733*$t);
  $Y1 += 0.00000000026 * cos(0.42189641581 + 40879.6843221273*$t);
  $Y1 += 0.00000000034 * cos(4.43221326186 + 1059.1381127057*$t);
  $Y1 += 0.00000000028 * cos(4.84223047836 + 27197.03787618409*$t);
  $Y1 += 0.00000000026 * cos(3.20524473117 + 34363.6094150395*$t);
  $Y1 += 0.00000000032 * cos(5.77908535567 + 11265.7977468829*$t);
  $Y1 += 0.00000000029 * cos(1.74100180776 + 30206.38871823969*$t);
  $Y1 += 0.00000000032 * cos(3.71439292372 + 51868.4924796623*$t);
  $Y1 += 0.00000000029 * cos(5.18039950515 + 35371.6434484929*$t);
  $Y1 += 0.00000000029 * cos(2.03880685156 + 35372.1310834599*$t);
  $Y1 += 0.00000000027 * cos(2.96900241192 + 34596.1208371689*$t);
  $Y1 += 0.00000000033 * cos(0.22008313011 + 59728.91187210151*$t);
  $Y1 += 0.00000000029 * cos(2.13149426586 + 20220.6293614683*$t);
  $Y1 += 0.00000000025 * cos(0.00480216002 + 25933.8805136059*$t);
  $Y1 += 0.00000000024 * cos(1.14435429192 + 8734.17515466309*$t);
  $Y1 += 0.00000000027 * cos(0.93366720196 + 66813.80865321669*$t);
  $Y1 += 0.00000000024 * cos(2.78431824704 + 36173.4643796167*$t);
  $Y1 += 0.00000000024 * cos(2.85202782937 + 31022.9969883397*$t);
  $Y1 += 0.00000000023 * cos(1.83521592175 + 24382.8352909579*$t);
  $Y1 += 0.00000000028 * cos(2.59038076535 + 27461.46703058189*$t);
  $Y1 += 0.00000000027 * cos(1.25678130892 + 30220.6158122413*$t);
  $Y1 += 0.00000000023 * cos(1.14068817117 + 10367.3081741793*$t);
  $Y1 += 0.00000000023 * cos(5.21160522261 + 10059.7505532097*$t);
  $Y1 += 0.00000000023 * cos(0.43117503950 + 20452.6255947383*$t);
  $Y1 += 0.00000000026 * cos(1.22669168244 + 39271.4266540445*$t);
  $Y1 += 0.00000000026 * cos(1.70917344642 + 39257.1995600429*$t);
  $Y1 += 0.00000000022 * cos(2.21618655385 + 43232.0628409321*$t);
  $Y1 += 0.00000000022 * cos(5.35777920744 + 43232.5504758991*$t);
  $Y1 += 0.00000000026 * cos(5.25456910654 + 8101.39141534989*$t);
  $Y1 += 0.00000000022 * cos(1.35771340076 + 24978.7684069643*$t);
  $Y1 += 0.00000000022 * cos(4.11458514050 + 25158.3579022819*$t);
  $Y1 += 0.00000000030 * cos(5.92769527498 + 17248.18148437089*$t);
  $Y1 += 0.00000000022 * cos(5.97215448902 + 27991.15799567649*$t);
  $Y1 += 0.00000000022 * cos(0.18339928832 + 30426.8013606785*$t);
  $Y1 += 0.00000000022 * cos(4.03960220837 + 802.0647486073*$t);
  $Y1 += 0.00000000028 * cos(0.58380772945 + 17297.9385098427*$t);
  $Y1 += 0.00000000021 * cos(5.72756462954 + 9147.03388650451*$t);
  $Y1 += 0.00000000024 * cos(0.86019134061 + 46386.7499258277*$t);
  $Y1 += 0.00000000021 * cos(1.15272291675 + 27197.5255111511*$t);
  $Y1 += 0.00000000021 * cos(1.79721426538 + 44809.8940183469*$t);
  $Y1 += 0.00000000024 * cos(4.32935447070 + 52176.0501006319*$t);
  $Y1 += 0.00000000025 * cos(2.80978996759 + 22805.9793834771*$t);
  $Y1 += 0.00000000022 * cos(2.50649207464 + 9566.03089541269*$t);
  $Y1 += 0.00000000023 * cos(4.04266888662 + 6309.1303523077*$t);
  $Y1 += 0.00000000021 * cos(0.48695657465 + 10949.4058772263*$t);
  $Y1 += 0.00000000021 * cos(5.86533681913 + 9477.65285016271*$t);
  $Y1 += 0.00000000024 * cos(5.27936669763 + 10288.3109622618*$t);
  $Y1 += 0.00000000024 * cos(1.07292669615 + 10138.7477651272*$t);
  $Y1 += 0.00000000027 * cos(2.11911473240 + 9580.2579894143*$t);
  $Y1 += 0.00000000020 * cos(1.17564252576 + 8635.69818627969*$t);
  $Y1 += 0.00000000020 * cos(0.64178978255 + 11280.0248408845*$t);
  $Y1 += 0.00000000021 * cos(5.31872372185 + 3531.81687532789*$t);
  $Y1 += 0.00000000022 * cos(5.81710713116 + 62883.5989569971*$t);
  $Y1 += 0.00000000020 * cos(6.04322502436 + 17468.6113804619*$t);
  $Y1 += 0.00000000023 * cos(1.10446661612 + 10263.2863891663*$t);
  $Y1 += 0.00000000023 * cos(5.24782677766 + 10163.7723382227*$t);
  $Y1 += 0.00000000027 * cos(5.92344983854 + 32216.95636359729*$t);
  $Y1 += 0.00000000021 * cos(4.91435357755 + 47624.0966035731*$t);
  $Y1 += 0.00000000023 * cos(6.01318073085 + 55022.6919295909*$t);
  $Y1 += 0.00000000021 * cos(1.20080376991 + 18300.44986755929*$t);
  $Y1 += 0.00000000026 * cos(1.64245342007 + 63659.1215683211*$t);
  $Y1 += 0.00000000021 * cos(2.86380051865 + 43071.65547154729*$t);
  $Y1 += 0.00000000019 * cos(0.23803378346 + 20316.6085886861*$t);
  $Y1 += 0.00000000027 * cos(4.48319230296 + 28286.74666737769*$t);
  $Y1 += 0.00000000020 * cos(5.63440295344 + 62081.7780258733*$t);
  $Y1 += 0.00000000021 * cos(2.14440776384 + 24341.7721349401*$t);
  $Y1 += 0.00000000020 * cos(1.13738779403 + 49477.59865325469*$t);
  $Y1 += 0.00000000020 * cos(2.35460910589 + 70744.0183494363*$t);
  $Y1 += 0.00000000018 * cos(1.66963360809 + 14128.4865887291*$t);
  $Y1 += 0.00000000022 * cos(0.39682892264 + 27991.6456306435*$t);
  $Y1 += 0.00000000018 * cos(0.69318171155 + 9050.56702431969*$t);
  $Y1 += 0.00000000018 * cos(2.78635204608 + 4705.4884900601*$t);
  $Y1 += 0.00000000017 * cos(3.20253456324 + 28313.0449871775*$t);
  $Y1 += 0.00000000017 * cos(2.89862116564 + 10497.38868255971*$t);
  $Y1 += 0.00000000017 * cos(3.45367222814 + 9929.6700448293*$t);
  $Y1 += 0.00000000017 * cos(5.48500145482 + 19624.9939787817*$t);
  $Y1 += 0.00000000018 * cos(1.11001496449 + 29050.53992586569*$t);
  $Y1 += 0.00000000017 * cos(1.42200475410 + 18314.67696156089*$t);
  $Y1 += 0.00000000016 * cos(3.18072890080 + 48740.1037145665*$t);
  $Y1 += 0.00000000018 * cos(4.39890730410 + 38526.3305333885*$t);
  $Y1 += 0.00000000018 * cos(4.74135169951 + 42430.7295447753*$t);
  $Y1 += 0.00000000018 * cos(5.74382556326 + 42456.5402296081*$t);
  $Y1 += 0.00000000018 * cos(2.58329516885 + 33794.2999060451*$t);
  $Y1 += 0.00000000018 * cos(5.72488782244 + 33794.7875410121*$t);
  $Y1 += 0.00000000016 * cos(3.86440292184 + 9745.5643733401*$t);
  $Y1 += 0.00000000016 * cos(2.48789047194 + 10681.49435404891*$t);
  $Y1 += 0.00000000016 * cos(3.34228325637 + 38734.6221419491*$t);
  $Y1 += 0.00000000016 * cos(3.55643611626 + 47162.2725371517*$t);
  $Y1 += 0.00000000016 * cos(0.41484346267 + 47162.7601721187*$t);
  $Y1 += 0.00000000015 * cos(3.83207526863 + 10199.3022696929*$t);
  $Y1 += 0.00000000015 * cos(2.52021812515 + 10227.7564576961*$t);
  $Y1 += 0.00000000015 * cos(5.97366054337 + 41654.71929848429*$t);
  $Y1 += 0.00000000017 * cos(2.28143373849 + 50316.9596220473*$t);
  $Y1 += 0.00000000015 * cos(1.13326790706 + 53285.4286527253*$t);
  $Y1 += 0.00000000015 * cos(0.77488701815 + 66011.98772209289*$t);
  $Y1 += 0.00000000015 * cos(1.26649043492 + 38727.5085949483*$t);
  $Y1 += 0.00000000015 * cos(6.23110267766 + 46360.9392409949*$t);
  $Y1 += 0.00000000019 * cos(3.03299993077 + 67589.3312645407*$t);
  $Y1 += 0.00000000014 * cos(2.92323813617 + 21228.1482060623*$t);
  $Y1 += 0.00000000014 * cos(5.08679309387 + 40000.1896205755*$t);
  $Y1 += 0.00000000014 * cos(6.23973256044 + 11027.07964765431*$t);
  $Y1 += 0.00000000014 * cos(0.11256083334 + 9399.9790797347*$t);
  $Y1 += 0.00000000014 * cos(6.10753439498 + 37895.6701078509*$t);
  $Y1 += 0.00000000014 * cos(6.16127322322 + 37410.8110573621*$t);
  $Y1 += 0.00000000014 * cos(1.37136100611 + 50291.1489372145*$t);
  $Y1 += 0.00000000013 * cos(5.74299254495 + 12565.9078824993*$t);
  $Y1 += 0.00000000015 * cos(4.65282324499 + 21486.1968400947*$t);
  $Y1 += 0.00000000013 * cos(4.57052594573 + 52670.3134107861*$t);
  return $Y1*$t;
}



  function Venus_C_Y2 ($t)
{
  $Y2 =  0.0;
  $Y2 += 0.00039116576 * cos(3.17641452985 + 10213.5293636945*$t);
  $Y2 += 0.00001782208 * cos(2.94415914625 + 0.2438174835*$t);
  $Y2 += 0.00000953335 * cos(5.20596121245 + 10213.0417287275*$t);
  $Y2 += 0.00000818754 * cos(3.60833841869 + 20426.8149099055*$t);
  $Y2 += 0.00000012014 * cos(3.98424371923 + 30640.1004561165*$t);
  $Y2 += 0.00000008598 * cos(5.19269385475 + 10239.8276834943*$t);
  $Y2 += 0.00000008636 * cos(1.10093366611 + 10187.2310438947*$t);
  $Y2 += 0.00000003631 * cos(0.41852821424 + 20426.32727493849*$t);
  $Y2 += 0.00000002965 * cos(1.54714831387 + 8636.18582124671*$t);
  $Y2 += 0.00000003797 * cos(5.44744767135 + 9438.0067523705*$t);
  $Y2 += 0.00000003421 * cos(0.82409517159 + 10989.0519750185*$t);
  $Y2 += 0.00000002218 * cos(2.12537117132 + 10022.0810975829*$t);
  $Y2 += 0.00000002134 * cos(4.12308786769 + 10404.9776298061*$t);
  $Y2 += 0.00000002187 * cos(4.57549125366 + 11790.8729061423*$t);
  $Y2 += 0.00000001794 * cos(4.97370212204 + 775.7664288075*$t);
  $Y2 += 0.00000001421 * cos(0.32903550115 + 2353.1099712553*$t);
  $Y2 += 0.00000000972 * cos(4.22805709693 + 1577.0997249643*$t);
  $Y2 += 0.00000000682 * cos(0.11738303047 + 4705.9761250271*$t);
  $Y2 += 0.00000000658 * cos(3.27522517046 + 9683.8383985999*$t);
  $Y2 += 0.00000000715 * cos(6.05529092994 + 9830.6328314713*$t);
  $Y2 += 0.00000000683 * cos(0.27418767588 + 10596.4258959177*$t);
  $Y2 += 0.00000000568 * cos(1.11272461938 + 19651.2922985815*$t);
  $Y2 += 0.00000000544 * cos(4.64774361853 + 191.2044486281*$t);
  $Y2 += 0.00000000678 * cos(2.88508832416 + 18073.9487561337*$t);
  $Y2 += 0.00000000574 * cos(0.38467340878 + 801.5771136403*$t);
  $Y2 += 0.00000000418 * cos(2.74408911585 + 10743.2203287891*$t);
  $Y2 += 0.00000000561 * cos(1.75565662404 + 6283.3196674749*$t);
  $Y2 += 0.00000000531 * cos(5.68669809373 + 7058.8422787989*$t);
  $Y2 += 0.00000000371 * cos(4.29421538467 + 9411.7084325707*$t);
  $Y2 += 0.00000000414 * cos(0.59494833209 + 529.9347825781*$t);
  $Y2 += 0.00000000287 * cos(1.55343952200 + 9104.1508116011*$t);
  $Y2 += 0.00000000314 * cos(5.99276842650 + 15721.0826023619*$t);
  $Y2 += 0.00000000301 * cos(3.87648034857 + 26.0545023163*$t);
  $Y2 += 0.00000000354 * cos(0.58512829013 + 13368.2164485901*$t);
  $Y2 += 0.00000000361 * cos(1.45998367037 + 14143.7390599141*$t);
  $Y2 += 0.00000000349 * cos(1.12786835203 + 22004.1584523533*$t);
  $Y2 += 0.00000000253 * cos(1.92471060417 + 1059.6257476727*$t);
  $Y2 += 0.00000000253 * cos(4.53940292522 + 11322.9079157879*$t);
  $Y2 += 0.00000000253 * cos(5.88126488763 + 3154.4432674121*$t);
  $Y2 += 0.00000000321 * cos(1.94846444699 + 11015.3502948183*$t);
  $Y2 += 0.00000000305 * cos(4.22585959217 + 3128.6325825793*$t);
  $Y2 += 0.00000000202 * cos(0.13780590630 + 10426.8284591325*$t);
  $Y2 += 0.00000000195 * cos(4.45983996443 + 20618.2631760171*$t);
  $Y2 += 0.00000000178 * cos(6.05244122419 + 10000.23026825651*$t);
  $Y2 += 0.00000000157 * cos(4.65387907430 + 40853.3860023275*$t);
  $Y2 += 0.00000000159 * cos(0.72069815424 + 382.6527147397*$t);
  $Y2 += 0.00000000177 * cos(0.39338528515 + 21228.63584102931*$t);
  $Y2 += 0.00000000126 * cos(1.05687133771 + 18849.4713674577*$t);
  $Y2 += 0.00000000131 * cos(5.44244944088 + 1577.5873599313*$t);
  $Y2 += 0.00000000148 * cos(5.58098705803 + 5507.3094211839*$t);
  $Y2 += 0.00000000139 * cos(2.98686042700 + 7860.6632099227*$t);
  $Y2 += 0.00000000146 * cos(2.62658040504 + 19897.1239448109*$t);
  $Y2 += 0.00000000133 * cos(2.03471349227 + 17298.4261448097*$t);
  $Y2 += 0.00000000088 * cos(2.31254159217 + 8623.96883344369*$t);
  $Y2 += 0.00000000116 * cos(5.13082226969 + 9153.6597985383*$t);
  $Y2 += 0.00000000111 * cos(4.24475286797 + 20453.1132297053*$t);
  $Y2 += 0.00000000077 * cos(1.00902400661 + 7084.6529636317*$t);
  $Y2 += 0.00000000081 * cos(5.42779981771 + 2352.6223362883*$t);
  $Y2 += 0.00000000088 * cos(4.73572405097 + 3930.4535137031*$t);
  $Y2 += 0.00000000077 * cos(1.55430183773 + 16496.6052136859*$t);
  $Y2 += 0.00000000069 * cos(5.74285388545 + 23581.5019948011*$t);
  $Y2 += 0.00000000058 * cos(2.86941970816 + 9154.1474335053*$t);
  $Y2 += 0.00000000062 * cos(0.46568901715 + 1109.1347346099*$t);
  $Y2 += 0.00000000063 * cos(0.71005704492 + 9437.5191174035*$t);
  $Y2 += 0.00000000047 * cos(2.16487309027 + 29051.0275608327*$t);
  $Y2 += 0.00000000054 * cos(0.77510495510 + 20809.7114421287*$t);
  $Y2 += 0.00000000055 * cos(1.84291935671 + 4731.7868098599*$t);
  $Y2 += 0.00000000046 * cos(3.98973988228 + 19367.4329797163*$t);
  $Y2 += 0.00000000044 * cos(2.81774994428 + 10787.8741620293*$t);
  $Y2 += 0.00000000044 * cos(3.53454344950 + 9639.18456535971*$t);
  $Y2 += 0.00000000040 * cos(1.76486455663 + 8094.2778683491*$t);
  $Y2 += 0.00000000041 * cos(1.81077528877 + 3929.96587873609*$t);
  $Y2 += 0.00000000047 * cos(3.42216864116 + 12566.3955174663*$t);
  $Y2 += 0.00000000038 * cos(0.61848121900 + 6282.83203250789*$t);
  $Y2 += 0.00000000045 * cos(2.64095270339 + 25934.3681485729*$t);
  $Y2 += 0.00000000034 * cos(3.37999447267 + 28287.2343023447*$t);
  $Y2 += 0.00000000033 * cos(2.41155726835 + 11014.8626598513*$t);
  $Y2 += 0.00000000034 * cos(5.75904174875 + 14919.2616712381*$t);
  $Y2 += 0.00000000032 * cos(1.85044469509 + 24357.0246061251*$t);
  $Y2 += 0.00000000028 * cos(2.26259259006 + 20235.36664379391*$t);
  $Y2 += 0.00000000040 * cos(2.04588679924 + 29580.7185259273*$t);
  $Y2 += 0.00000000033 * cos(3.78712068425 + 4552.1973145423*$t);
  $Y2 += 0.00000000033 * cos(5.68274603993 + 6490.0204047715*$t);
  $Y2 += 0.00000000027 * cos(5.51492765662 + 10640.1275545705*$t);
  $Y2 += 0.00000000026 * cos(0.80714498512 + 9786.9311728185*$t);
  $Y2 += 0.00000000026 * cos(5.24189234984 + 3149.4079780717*$t);
  $Y2 += 0.00000000025 * cos(0.52311174916 + 10192.7539682021*$t);
  $Y2 += 0.00000000025 * cos(2.69201575821 + 10234.3047591869*$t);
  $Y2 += 0.00000000024 * cos(0.09729823382 + 21536.1934619989*$t);
  $Y2 += 0.00000000026 * cos(0.29172518031 + 14143.2514249471*$t);
  $Y2 += 0.00000000024 * cos(1.53398817563 + 18307.56341456009*$t);
  $Y2 += 0.00000000024 * cos(4.66792746343 + 5507.7970561509*$t);
  $Y2 += 0.00000000025 * cos(1.99847907794 + 18875.2820522905*$t);
  $Y2 += 0.00000000030 * cos(2.25346620875 + 20400.5165901057*$t);
  $Y2 += 0.00000000025 * cos(0.91360430606 + 27511.7116910207*$t);
  $Y2 += 0.00000000025 * cos(3.28603866404 + 8661.9965060795*$t);
  $Y2 += 0.00000000019 * cos(3.72923840682 + 11272.91129388371*$t);
  $Y2 += 0.00000000022 * cos(1.87715843315 + 30639.61282114949*$t);
  $Y2 += 0.00000000026 * cos(0.86545419400 + 213.5429129215*$t);
  $Y2 += 0.00000000018 * cos(1.77063553751 + 28521.3365957381*$t);
  $Y2 += 0.00000000023 * cos(0.62230384603 + 13937.0383226175*$t);
  $Y2 += 0.00000000024 * cos(2.21558567781 + 13367.7288136231*$t);
  $Y2 += 0.00000000021 * cos(1.95869049210 + 10186.7434089277*$t);
  $Y2 += 0.00000000019 * cos(3.70619728169 + 10988.5643400515*$t);
  $Y2 += 0.00000000018 * cos(1.45798324955 + 32217.4439985643*$t);
  $Y2 += 0.00000000020 * cos(3.48812478045 + 191.6920835951*$t);
  $Y2 += 0.00000000017 * cos(5.71260028354 + 15874.8614128467*$t);
  $Y2 += 0.00000000014 * cos(1.56125812418 + 21202.3375212295*$t);
  $Y2 += 0.00000000014 * cos(0.92685471122 + 17277.6507493173*$t);
  $Y2 += 0.00000000015 * cos(1.68916723960 + 18073.46112116669*$t);
  $Y2 += 0.00000000014 * cos(0.06020277571 + 10239.3400485273*$t);
  $Y2 += 0.00000000014 * cos(3.96058683099 + 14945.0723560709*$t);
  $Y2 += 0.00000000014 * cos(2.61882493594 + 8662.48414104651*$t);
  $Y2 += 0.00000000014 * cos(3.66333417023 + 11764.5745863425*$t);
  $Y2 += 0.00000000013 * cos(0.36408900148 + 34570.3101523361*$t);
  $Y2 += 0.00000000013 * cos(5.32461592855 + 22779.6810636773*$t);
  $Y2 += 0.00000000012 * cos(2.28383473867 + 31441.92138724031*$t);
  $Y2 += 0.00000000011 * cos(2.70470885221 + 10220.6429106953*$t);
  $Y2 += 0.00000000011 * cos(0.50709992859 + 10206.4158166937*$t);
  $Y2 += 0.00000000010 * cos(2.04719193722 + 7.3573644843*$t);
  $Y2 += 0.00000000010 * cos(3.14863661708 + 22003.6708173863*$t);
  $Y2 += 0.00000000012 * cos(1.89856613068 + 25158.8455372489*$t);
  $Y2 += 0.00000000009 * cos(1.78868375262 + 38500.5198485557*$t);
  $Y2 += 0.00000000010 * cos(4.50140179786 + 11790.3852711753*$t);
  $Y2 += 0.00000000012 * cos(3.63812717753 + 17297.9385098427*$t);
  $Y2 += 0.00000000008 * cos(4.34372477567 + 10404.48999483909*$t);
  $Y2 += 0.00000000009 * cos(3.37718180492 + 29089.0552334685*$t);
  $Y2 += 0.00000000007 * cos(0.37788139417 + 43232.5504758991*$t);
  $Y2 += 0.00000000007 * cos(4.44321392733 + 30000.2031698025*$t);
  $Y2 += 0.00000000009 * cos(6.04652897824 + 7860.17557495569*$t);
  $Y2 += 0.00000000009 * cos(0.19167842758 + 3531.81687532789*$t);
  $Y2 += 0.00000000007 * cos(3.37107259426 + 22805.4917485101*$t);
  $Y2 += 0.00000000007 * cos(2.75239196673 + 529.44714761109*$t);
  return $Y2*$t*$t;
}



  function Venus_C_Y3 ($t)
{
  $Y3 =  0.0;
  $Y3 += 0.00000055518 * cos(0.56397150825 + 10213.0417287275*$t);
  $Y3 += 0.00000057047 * cos(4.30857137510 + 0.2438174835*$t);
  $Y3 += 0.00000032093 * cos(1.48532861520 + 20426.8149099055*$t);
  $Y3 += 0.00000018867 * cos(3.29469305606 + 10213.5293636945*$t);
  $Y3 += 0.00000000716 * cos(1.69291337487 + 30640.1004561165*$t);
  $Y3 += 0.00000000218 * cos(2.23416930390 + 20426.32727493849*$t);
  $Y3 += 0.00000000032 * cos(4.93547527406 + 8636.18582124671*$t);
  $Y3 += 0.00000000034 * cos(1.12379373423 + 10239.8276834943*$t);
  $Y3 += 0.00000000034 * cos(2.09231646083 + 10187.2310438947*$t);
  $Y3 += 0.00000000027 * cos(4.57242516087 + 11790.8729061423*$t);
  $Y3 += 0.00000000020 * cos(2.07822937351 + 775.7664288075*$t);
  $Y3 += 0.00000000016 * cos(5.32962355701 + 10022.0810975829*$t);
  $Y3 += 0.00000000016 * cos(4.16791854245 + 10404.9776298061*$t);
  $Y3 += 0.00000000010 * cos(2.19615394659 + 40853.3860023275*$t);
  $Y3 += 0.00000000010 * cos(1.23351868160 + 9438.0067523705*$t);
  $Y3 += 0.00000000010 * cos(2.08054199257 + 10989.0519750185*$t);
  $Y3 += 0.00000000008 * cos(3.70773784399 + 9683.8383985999*$t);
  $Y3 += 0.00000000007 * cos(1.33595632185 + 191.2044486281*$t);
  $Y3 += 0.00000000007 * cos(5.77536678710 + 10743.2203287891*$t);
  $Y3 += 0.00000000008 * cos(3.50194685886 + 4705.9761250271*$t);
  $Y3 += 0.00000000007 * cos(1.15263198918 + 19651.2922985815*$t);
  $Y3 += 0.00000000004 * cos(4.83876866063 + 9104.1508116011*$t);
  $Y3 += 0.00000000004 * cos(5.57864226359 + 1059.6257476727*$t);
  $Y3 += 0.00000000004 * cos(6.00284338140 + 15721.0826023619*$t);
  $Y3 += 0.00000000003 * cos(4.65996273292 + 11322.9079157879*$t);
  return $Y3*$t*$t*$t;
}



  function Venus_C_Y4 ($t)
{
  $Y4 =  0.0;
  $Y4 += 0.00000083081 * cos(6.18993945631 + 10213.5293636945*$t);
  $Y4 += 0.00000002486 * cos(2.28856774293 + 10213.0417287275*$t);
  $Y4 += 0.00000000657 * cos(5.78367664587 + 20426.8149099055*$t);
  $Y4 += 0.00000000217 * cos(2.03456127835 + 0.2438174835*$t);
  $Y4 += 0.00000000035 * cos(5.69795458192 + 30640.1004561165*$t);
  $Y4 += 0.00000000011 * cos(4.01388645377 + 20426.32727493849*$t);
  $Y4 += 0.00000000005 * cos(0.49844804556 + 10239.8276834943*$t);
  $Y4 += 0.00000000005 * cos(2.68999633541 + 10187.2310438947*$t);
  $Y4 += 0.00000000003 * cos(3.35675923207 + 2353.1099712553*$t);
  $Y4 += 0.00000000002 * cos(3.32525148356 + 8636.18582124671*$t);
  $Y4 += 0.00000000002 * cos(1.20160813739 + 1577.0997249643*$t);
  $Y4 += 0.00000000002 * cos(0.72866875334 + 9438.0067523705*$t);
  return $Y4*$t*$t*$t*$t;
}



  function Venus_C_Y5 ($t)
{
  $Y5 =  0.0;
  $Y5 += 0.00000000631 * cos(0.02845828180 + 10213.5293636945*$t);
  $Y5 += 0.00000000095 * cos(4.11666356042 + 10213.0417287275*$t);
  $Y5 += 0.00000000088 * cos(0.15104017272 + 0.2438174835*$t);
  $Y5 += 0.00000000040 * cos(4.24049298565 + 20426.8149099055*$t);
  return $Y5*$t*$t*$t*$t*$t;
}



  function Venus_C_Z0 ($t)
{
  $Z0 =  0.0;
  $Z0 += 0.04282990302 * cos(0.26703856476 + 10213.285546211*$t);
  $Z0 += 0.00035588343 * cos(3.14159265359);
  $Z0 += 0.00014501879 * cos(1.14696911390 + 20426.571092422*$t);
  $Z0 += 0.00000140675 * cos(0.85984113219 + 1577.3435424478*$t);
  $Z0 += 0.00000134921 * cos(3.70465787853 + 2352.8661537718*$t);
  $Z0 += 0.00000095750 * cos(3.66962547073 + 9437.762934887*$t);
  $Z0 += 0.00000072910 * cos(1.55750278240 + 9153.9036160218*$t);
  $Z0 += 0.00000073654 * cos(2.02778434780 + 30639.856638633*$t);
  $Z0 += 0.00000059714 * cos(6.25390371649 + 18073.7049386502*$t);
  $Z0 += 0.00000045307 * cos(2.28075620268 + 5507.5532386674*$t);
  $Z0 += 0.00000043023 * cos(3.95620233472 + 529.6909650946*$t);
  $Z0 += 0.00000037415 * cos(4.53900359933 + 22003.9146348698*$t);
  $Z0 += 0.00000032943 * cos(0.72316171903 + 10239.5838660108*$t);
  $Z0 += 0.00000028156 * cos(2.93415727239 + 10186.9872264112*$t);
  $Z0 += 0.00000032447 * cos(3.86196252330 + 8635.9420037632*$t);
  $Z0 += 0.00000027853 * cos(6.12790511758 + 11790.6290886588*$t);
  $Z0 += 0.00000023013 * cos(0.98699428893 + 775.522611324*$t);
  $Z0 += 0.00000019425 * cos(5.12759462747 + 6283.0758499914*$t);
  $Z0 += 0.00000016289 * cos(2.90852685195 + 10988.808157535*$t);
  $Z0 += 0.00000015382 * cos(5.98588709813 + 19896.8801273274*$t);
  $Z0 += 0.00000015507 * cos(2.00401259454 + 13367.9726311066*$t);
  $Z0 += 0.00000012412 * cos(4.13644030917 + 10021.8372800994*$t);
  $Z0 += 0.00000013004 * cos(4.83195492470 + 14143.4952424306*$t);
  $Z0 += 0.00000010730 * cos(5.61235409382 + 10404.7338123226*$t);
  $Z0 += 0.00000010336 * cos(2.75167531541 + 191.4482661116*$t);
  $Z0 += 0.00000010848 * cos(3.29419910254 + 11015.1064773348*$t);
  $Z0 += 0.00000009775 * cos(1.21418881204 + 8624.2126509272*$t);
  $Z0 += 0.00000010158 * cos(5.71954183827 + 9683.5945811164*$t);
  $Z0 += 0.00000008080 * cos(2.69831049093 + 19651.048481098*$t);
  $Z0 += 0.00000008209 * cos(3.55371021890 + 10742.9765113056*$t);
  $Z0 += 0.00000006416 * cos(0.46264840234 + 9786.687355335*$t);
  $Z0 += 0.00000006429 * cos(4.91481073656 + 1059.3819301892*$t);
  $Z0 += 0.00000006722 * cos(2.41848486045 + 4705.7323075436*$t);
  $Z0 += 0.00000005903 * cos(5.96215831403 + 25934.1243310894*$t);
  $Z0 += 0.00000005647 * cos(3.57594715836 + 3154.6870848956*$t);
  $Z0 += 0.00000004044 * cos(6.24650537722 + 11322.6640983044*$t);
  $Z0 += 0.00000004033 * cos(3.42887820794 + 9103.9069941176*$t);
  $Z0 += 0.00000004210 * cos(4.99232132925 + 7084.8967811152*$t);
  $Z0 += 0.00000004135 * cos(3.43782832503 + 17298.1823273262*$t);
  $Z0 += 0.00000003747 * cos(1.30318722019 + 15720.8387848784*$t);
  $Z0 += 0.00000003417 * cos(3.95474989164 + 7860.4193924392*$t);
  $Z0 += 0.00000003440 * cos(0.77140273510 + 4551.9534970588*$t);
  $Z0 += 0.00000003488 * cos(0.14633368219 + 20618.0193585336*$t);
  $Z0 += 0.00000002851 * cos(5.68591706153 + 10206.1719992102*$t);
  $Z0 += 0.00000002750 * cos(3.89497095361 + 10192.5101507186*$t);
  $Z0 += 0.00000002734 * cos(5.62996472233 + 12566.1516999828*$t);
  $Z0 += 0.00000002682 * cos(4.58018033496 + 801.8209311238*$t);
  $Z0 += 0.00000002743 * cos(6.06387494803 + 10234.0609417034*$t);
  $Z0 += 0.00000002832 * cos(4.24241233220 + 213.299095438*$t);
  $Z0 += 0.00000002756 * cos(5.43236957664 + 29580.4747084438*$t);
  $Z0 += 0.00000002155 * cos(0.29731467355 + 9411.4646150872*$t);
  $Z0 += 0.00000002403 * cos(4.90533210845 + 19367.1891622328*$t);
  $Z0 += 0.00000002103 * cos(1.12514771936 + 29864.334027309*$t);
  $Z0 += 0.00000001632 * cos(4.67123397256 + 1109.3785520934*$t);
  $Z0 += 0.00000001787 * cos(2.52506338741 + 15874.6175953632*$t);
  $Z0 += 0.00000001613 * cos(1.47525165805 + 7058.5984613154*$t);
  $Z0 += 0.00000001598 * cos(2.21757389250 + 10426.584641649*$t);
  $Z0 += 0.00000001154 * cos(1.98818396175 + 26.2983197998*$t);
  $Z0 += 0.00000001132 * cos(5.38517603552 + 7.1135470008*$t);
  $Z0 += 0.00000001468 * cos(0.75541488791 + 9999.986450773*$t);
  $Z0 += 0.00000001118 * cos(0.96571599573 + 23581.2581773176*$t);
  $Z0 += 0.00000001210 * cos(3.17717646354 + 3532.0606928114*$t);
  $Z0 += 0.00000000965 * cos(0.01161931809 + 3128.3887650958*$t);
  $Z0 += 0.00000001027 * cos(2.51592691800 + 33794.5437235286*$t);
  $Z0 += 0.00000000847 * cos(1.24888706950 + 9573.388259897*$t);
  $Z0 += 0.00000000889 * cos(1.48214942791 + 9830.3890139878*$t);
  $Z0 += 0.00000000953 * cos(5.73118460251 + 20213.271996984*$t);
  $Z0 += 0.00000000987 * cos(4.70495944427 + 14945.3161735544*$t);
  $Z0 += 0.00000001030 * cos(0.84929643011 + 8094.5216858326*$t);
  $Z0 += 0.00000000770 * cos(4.54196353475 + 21228.3920235458*$t);
  $Z0 += 0.00000000778 * cos(1.16378510983 + 8662.240323563*$t);
  $Z0 += 0.00000000860 * cos(5.74281955136 + 5661.3320491522*$t);
  $Z0 += 0.00000000670 * cos(5.36864204589 + 1589.0728952838*$t);
  $Z0 += 0.00000000615 * cos(1.96289781619 + 26087.9031415742*$t);
  $Z0 += 0.00000000740 * cos(1.97614280765 + 10596.1820784342*$t);
  $Z0 += 0.00000000606 * cos(6.22070159607 + 25158.6017197654*$t);
  $Z0 += 0.00000000533 * cos(0.73765107493 + 28286.9904848612*$t);
  $Z0 += 0.00000000547 * cos(5.06653964506 + 29050.7837433492*$t);
  $Z0 += 0.00000000592 * cos(3.32632513186 + 3340.6124266998*$t);
  $Z0 += 0.00000000591 * cos(4.62374022159 + 9929.4262273458*$t);
  $Z0 += 0.00000000537 * cos(6.00327539255 + 4732.0306273434*$t);
  $Z0 += 0.00000000569 * cos(5.37276655331 + 10497.1448650762*$t);
  $Z0 += 0.00000000520 * cos(6.11596800207 + 10218.8084705184*$t);
  $Z0 += 0.00000000542 * cos(3.94171539558 + 37724.7534197482*$t);
  $Z0 += 0.00000000575 * cos(2.29073875885 + 21535.9496445154*$t);
  $Z0 += 0.00000000437 * cos(2.42330391120 + 10251.3132188468*$t);
  $Z0 += 0.00000000439 * cos(2.90237828484 + 40853.142184844*$t);
  $Z0 += 0.00000000459 * cos(1.69153061401 + 3930.2096962196*$t);
  $Z0 += 0.00000000405 * cos(1.42927875873 + 9161.0171630226*$t);
  $Z0 += 0.00000000418 * cos(5.48110803243 + 32217.2001810808*$t);
  $Z0 += 0.00000000521 * cos(3.84286345199 + 10207.7626219036*$t);
  $Z0 += 0.00000000457 * cos(6.16974742379 + 10220.3990932118*$t);
  $Z0 += 0.00000000440 * cos(1.25236241968 + 10175.2578735752*$t);
  $Z0 += 0.00000000394 * cos(4.81650684498 + 9146.790069021*$t);
  $Z0 += 0.00000000362 * cos(0.02259543121 + 14765.2390432698*$t);
  $Z0 += 0.00000000396 * cos(4.56209231282 + 10063.7223490764*$t);
  $Z0 += 0.00000000407 * cos(6.15731262846 + 18875.525869774*$t);
  $Z0 += 0.00000000349 * cos(5.78507522549 + 12592.4500197826*$t);
  $Z0 += 0.00000000379 * cos(4.56511543982 + 20419.45754542119*$t);
  $Z0 += 0.00000000314 * cos(5.08259050420 + 18837.49819713819*$t);
  $Z0 += 0.00000000343 * cos(2.36516734231 + 27511.4678735372*$t);
  $Z0 += 0.00000000292 * cos(3.76618455555 + 6681.2248533996*$t);
  $Z0 += 0.00000000289 * cos(3.59841384736 + 11272.6674764002*$t);
  $Z0 += 0.00000000314 * cos(5.23220905264 + 426.598190876*$t);
  $Z0 += 0.00000000301 * cos(4.24971815099 + 14919.0178537546*$t);
  $Z0 += 0.00000000322 * cos(1.36846420067 + 29088.811415985*$t);
  $Z0 += 0.00000000292 * cos(0.74997511570 + 3149.1641605882*$t);
  $Z0 += 0.00000000306 * cos(0.47092243462 + 23958.6317852334*$t);
  $Z0 += 0.00000000254 * cos(4.34026574490 + 10137.0194749354*$t);
  $Z0 += 0.00000000304 * cos(5.33181632059 + 41654.9631159678*$t);
  $Z0 += 0.00000000264 * cos(0.01153452145 + 20452.8694122218*$t);
  $Z0 += 0.00000000334 * cos(5.28920083729 + 382.8965322232*$t);
  $Z0 += 0.00000000236 * cos(1.03442196051 + 22779.4372461938*$t);
  $Z0 += 0.00000000250 * cos(5.05395469123 + 24356.7807886416*$t);
  $Z0 += 0.00000000278 * cos(0.10022232617 + 16496.3613962024*$t);
  $Z0 += 0.00000000232 * cos(0.48064662619 + 17085.9586657222*$t);
  $Z0 += 0.00000000205 * cos(6.19639409918 + 7064.1213856228*$t);
  $Z0 += 0.00000000197 * cos(3.71380377240 + 1551.045222648*$t);
  $Z0 += 0.00000000200 * cos(4.06516779510 + 18849.2275499742*$t);
  $Z0 += 0.00000000170 * cos(5.96522395118 + 10198.033075026*$t);
  $Z0 += 0.00000000170 * cos(3.52866583267 + 10228.538017396*$t);
  $Z0 += 0.00000000180 * cos(0.48168923159 + 45585.1728121874*$t);
  $Z0 += 0.00000000144 * cos(2.81280885697 + 17277.4069318338*$t);
  $Z0 += 0.00000000177 * cos(3.58248029244 + 20400.2727726222*$t);
  $Z0 += 0.00000000170 * cos(3.72282190488 + 31441.6775697568*$t);
  $Z0 += 0.00000000166 * cos(0.03569768750 + 13745.3462390224*$t);
  $Z0 += 0.00000000127 * cos(5.14389302386 + 5481.2549188676*$t);
  $Z0 += 0.00000000138 * cos(1.19253977825 + 22805.7355659936*$t);
  $Z0 += 0.00000000126 * cos(4.21594185374 + 20956.2620575166*$t);
  $Z0 += 0.00000000118 * cos(1.71706550416 + 13341.6743113068*$t);
  $Z0 += 0.00000000131 * cos(0.92317994329 + 3442.5749449654*$t);
  $Z0 += 0.00000000137 * cos(2.89407950366 + 33019.0211122046*$t);
  $Z0 += 0.00000000104 * cos(2.47347358674 + 26709.6469424134*$t);
  $Z0 += 0.00000000127 * cos(0.46833130674 + 536.8045120954*$t);
  $Z0 += 0.00000000126 * cos(2.84049662693 + 9967.4538999816*$t);
  $Z0 += 0.00000000107 * cos(4.19045394315 + 19999.97290154599*$t);
  $Z0 += 0.00000000110 * cos(0.73944778374 + 30110.1656735384*$t);
  $Z0 += 0.00000000138 * cos(4.01403107693 + 21202.093703746*$t);
  $Z0 += 0.00000000121 * cos(3.85928223786 + 522.5774180938*$t);
  $Z0 += 0.00000000122 * cos(0.37000676558 + 10459.1171924404*$t);
  $Z0 += 0.00000000095 * cos(5.25435135477 + 30213.258447757*$t);
  $Z0 += 0.00000000099 * cos(5.61149803116 + 10529.6774158676*$t);
  $Z0 += 0.00000000106 * cos(2.42064996718 + 20809.4676246452*$t);
  $Z0 += 0.00000000095 * cos(3.11317801589 + 9896.8936765544*$t);
  $Z0 += 0.00000000085 * cos(5.88248062550 + 3723.508958923*$t);
  $Z0 += 0.00000000099 * cos(1.93329637732 + 49515.382508407*$t);
  $Z0 += 0.00000000084 * cos(4.93745373910 + 52175.8062831484*$t);
  $Z0 += 0.00000000086 * cos(0.85755223960 + 2379.1644735716*$t);
  $Z0 += 0.00000000114 * cos(5.11309629210 + 103.0927742186*$t);
  $Z0 += 0.00000000110 * cos(1.44699918003 + 43232.3066584156*$t);
  $Z0 += 0.00000000088 * cos(1.59017183044 + 10110.1927719924*$t);
  $Z0 += 0.00000000086 * cos(0.87055324194 + 16522.6597160022*$t);
  $Z0 += 0.00000000089 * cos(2.33714216061 + 10316.3783204296*$t);
  $Z0 += 0.00000000098 * cos(4.66807552803 + 20235.1228263104*$t);
  $Z0 += 0.00000000104 * cos(5.02724740402 + 35371.8872659764*$t);
  $Z0 += 0.00000000093 * cos(4.21356144460 + 36301.18868778519*$t);
  $Z0 += 0.00000000089 * cos(0.88060757437 + 6489.776587288*$t);
  $Z0 += 0.00000000083 * cos(2.07543775594 + 31749.2351907264*$t);
  $Z0 += 0.00000000096 * cos(2.90682399304 + 9793.8009023358*$t);
  $Z0 += 0.00000000078 * cos(2.65839634325 + 10232.95530711079*$t);
  $Z0 += 0.00000000078 * cos(0.55230439694 + 10193.61578531121*$t);
  $Z0 += 0.00000000092 * cos(5.63110477712 + 10288.0671447783*$t);
  $Z0 += 0.00000000092 * cos(3.86278127025 + 10138.5039476437*$t);
  $Z0 += 0.00000000090 * cos(4.34324193073 + 36949.2308084242*$t);
  $Z0 += 0.00000000073 * cos(2.56775245907 + 13936.794505134*$t);
  $Z0 += 0.00000000071 * cos(0.64943236639 + 20.7753954924*$t);
  $Z0 += 0.00000000090 * cos(0.07319663423 + 6872.6731195112*$t);
  $Z0 += 0.00000000069 * cos(1.52914774412 + 9690.7081281172*$t);
  $Z0 += 0.00000000086 * cos(1.02476175384 + 65236.2212932854*$t);
  $Z0 += 0.00000000079 * cos(1.65446145032 + 39264.0692895602*$t);
  $Z0 += 0.00000000071 * cos(0.70714638996 + 36147.4098773004*$t);
  $Z0 += 0.00000000071 * cos(2.52879760001 + 26735.9452622132*$t);
  $Z0 += 0.00000000061 * cos(5.47943297658 + 11764.330768859*$t);
  $Z0 += 0.00000000080 * cos(2.87220602049 + 47162.5163546352*$t);
  $Z0 += 0.00000000065 * cos(2.53312656681 + 10735.8629643048*$t);
  $Z0 += 0.00000000068 * cos(2.28501865578 + 8521.1198767086*$t);
  $Z0 += 0.00000000065 * cos(2.12423586627 + 28313.288804661*$t);
  $Z0 += 0.00000000062 * cos(2.28587915309 + 3903.9113764198*$t);
  $Z0 += 0.00000000069 * cos(0.42270579845 + 9580.5018068978*$t);
  $Z0 += 0.00000000063 * cos(5.80076678078 + 2118.7638603784*$t);
  $Z0 += 0.00000000056 * cos(4.73821324745 + 639.897286314*$t);
  $Z0 += 0.00000000063 * cos(3.35690006984 + 53445.5922046266*$t);
  $Z0 += 0.00000000053 * cos(2.14583523296 + 8631.326197928*$t);
  $Z0 += 0.00000000066 * cos(4.12244312057 + 28521.0927782546*$t);
  $Z0 += 0.00000000058 * cos(5.25045057985 + 10419.4710946482*$t);
  $Z0 += 0.00000000058 * cos(4.23724598221 + 10007.0999977738*$t);
  $Z0 += 0.00000000053 * cos(3.02375632858 + 19317.1925403286*$t);
  $Z0 += 0.00000000071 * cos(2.36609582367 + 74.7815985673*$t);
  $Z0 += 0.00000000062 * cos(2.46239069210 + 10846.0692855242*$t);
  $Z0 += 0.00000000061 * cos(3.77333230443 + 51868.2486621788*$t);
  return $Z0;
}



  function Venus_C_Z1 ($t)
{
  $Z1 =  0.0;
  $Z1 += 0.00371157532 * cos(1.80370484107 + 10213.285546211*$t);
  $Z1 += 0.00001583350 * cos(3.38513432885 + 20426.571092422*$t);
  $Z1 += 0.00000216150;
  $Z1 += 0.00000012186 * cos(5.60527972670 + 1577.3435424478*$t);
  $Z1 += 0.00000011953 * cos(4.61859507922 + 30639.856638633*$t);
  $Z1 += 0.00000011662 * cos(5.24208633854 + 2352.8661537718*$t);
  $Z1 += 0.00000010398 * cos(2.27393994810 + 9437.762934887*$t);
  $Z1 += 0.00000006381 * cos(0.28617884662 + 9153.9036160218*$t);
  $Z1 += 0.00000005445 * cos(5.08079565040 + 10186.9872264112*$t);
  $Z1 += 0.00000004769 * cos(1.50400058537 + 11790.6290886588*$t);
  $Z1 += 0.00000005179 * cos(1.50697716140 + 18073.7049386502*$t);
  $Z1 += 0.00000003981 * cos(0.75197593763 + 5507.5532386674*$t);
  $Z1 += 0.00000003814 * cos(5.50447607190 + 529.6909650946*$t);
  $Z1 += 0.00000003372 * cos(3.87807635377 + 10239.5838660108*$t);
  $Z1 += 0.00000002840 * cos(1.28497223665 + 10404.7338123226*$t);
  $Z1 += 0.00000003220 * cos(6.07567189618 + 22003.9146348698*$t);
  $Z1 += 0.00000002336 * cos(4.88957218376 + 10988.808157535*$t);
  $Z1 += 0.00000001669 * cos(0.38548673512 + 6283.0758499914*$t);
  $Z1 += 0.00000001381 * cos(4.32769653919 + 19651.048481098*$t);
  $Z1 += 0.00000001296 * cos(1.26608932430 + 19896.8801273274*$t);
  $Z1 += 0.00000001203 * cos(0.38472694833 + 13367.9726311066*$t);
  $Z1 += 0.00000001126 * cos(0.08391401839 + 14143.4952424306*$t);
  $Z1 += 0.00000000867 * cos(6.12475712244 + 7860.4193924392*$t);
  $Z1 += 0.00000000737 * cos(1.36372254530 + 9683.5945811164*$t);
  $Z1 += 0.00000000673 * cos(2.25480471785 + 10021.8372800994*$t);
  $Z1 += 0.00000000673 * cos(1.74966742013 + 11322.6640983044*$t);
  $Z1 += 0.00000000654 * cos(0.52171368417 + 8624.2126509272*$t);
  $Z1 += 0.00000000739 * cos(0.71134257549 + 8635.9420037632*$t);
  $Z1 += 0.00000000592 * cos(2.89903060772 + 15720.8387848784*$t);
  $Z1 += 0.00000000573 * cos(1.68337600461 + 20618.0193585336*$t);
  $Z1 += 0.00000000509 * cos(1.21775184841 + 25934.1243310894*$t);
  $Z1 += 0.00000000402 * cos(5.15486544320 + 9786.687355335*$t);
  $Z1 += 0.00000000522 * cos(3.93344256885 + 775.522611324*$t);
  $Z1 += 0.00000000360 * cos(0.93512209325 + 1059.3819301892*$t);
  $Z1 += 0.00000000331 * cos(6.18983417760 + 11015.1064773348*$t);
  $Z1 += 0.00000000390 * cos(0.55127102590 + 19367.1891622328*$t);
  $Z1 += 0.00000000293 * cos(2.40304140450 + 801.8209311238*$t);
  $Z1 += 0.00000000311 * cos(5.00264213987 + 10742.9765113056*$t);
  $Z1 += 0.00000000303 * cos(1.76024438478 + 17298.1823273262*$t);
  $Z1 += 0.00000000266 * cos(2.34165306562 + 9411.4646150872*$t);
  $Z1 += 0.00000000336 * cos(2.31707280345 + 9999.986450773*$t);
  $Z1 += 0.00000000337 * cos(3.71507493522 + 10596.1820784342*$t);
  $Z1 += 0.00000000238 * cos(3.48412611241 + 7058.5984613154*$t);
  $Z1 += 0.00000000252 * cos(1.31468836511 + 10234.0609417034*$t);
  $Z1 += 0.00000000225 * cos(5.45422332781 + 10192.5101507186*$t);
  $Z1 += 0.00000000224 * cos(2.62853874690 + 23581.2581773176*$t);
  $Z1 += 0.00000000245 * cos(5.76868176406 + 213.299095438*$t);
  $Z1 += 0.00000000240 * cos(4.88817120361 + 10206.1719992102*$t);
  $Z1 += 0.00000000210 * cos(2.37015222881 + 4551.9534970588*$t);
  $Z1 += 0.00000000198 * cos(0.00551647295 + 9830.3890139878*$t);
  $Z1 += 0.00000000235 * cos(0.61645223949 + 29580.4747084438*$t);
  $Z1 += 0.00000000190 * cos(5.02902672388 + 3930.2096962196*$t);
  $Z1 += 0.00000000219 * cos(4.33456063754 + 15874.6175953632*$t);
  $Z1 += 0.00000000171 * cos(3.12200105851 + 12566.1516999828*$t);
  $Z1 += 0.00000000174 * cos(5.99537915416 + 26.2983197998*$t);
  $Z1 += 0.00000000180 * cos(3.65160439089 + 21228.3920235458*$t);
  $Z1 += 0.00000000172 * cos(2.65343695006 + 29864.334027309*$t);
  $Z1 += 0.00000000138 * cos(2.09789826211 + 3128.3887650958*$t);
  $Z1 += 0.00000000138 * cos(6.13843515618 + 9161.0171630226*$t);
  $Z1 += 0.00000000163 * cos(5.40807514906 + 4705.7323075436*$t);
  $Z1 += 0.00000000125 * cos(3.63191548504 + 7.1135470008*$t);
  $Z1 += 0.00000000146 * cos(1.77971392072 + 191.4482661116*$t);
  $Z1 += 0.00000000099 * cos(5.66016472051 + 40853.142184844*$t);
  $Z1 += 0.00000000117 * cos(5.44747244034 + 10426.584641649*$t);
  $Z1 += 0.00000000095 * cos(1.51959002513 + 10218.8084705184*$t);
  $Z1 += 0.00000000101 * cos(4.42330401713 + 10220.3990932118*$t);
  $Z1 += 0.00000000100 * cos(5.54541542103 + 5661.3320491522*$t);
  $Z1 += 0.00000000093 * cos(6.04217729850 + 20419.45754542119*$t);
  $Z1 += 0.00000000082 * cos(5.21733543718 + 8662.240323563*$t);
  $Z1 += 0.00000000092 * cos(0.17084455774 + 9146.790069021*$t);
  $Z1 += 0.00000000085 * cos(4.60308698783 + 25158.6017197654*$t);
  $Z1 += 0.00000000090 * cos(5.47130878539 + 37724.7534197482*$t);
  $Z1 += 0.00000000074 * cos(1.54547841954 + 7084.8967811152*$t);
  $Z1 += 0.00000000087 * cos(3.99154062553 + 33794.5437235286*$t);
  $Z1 += 0.00000000091 * cos(0.63814500882 + 3154.6870848956*$t);
  $Z1 += 0.00000000065 * cos(3.27192235582 + 1109.3785520934*$t);
  $Z1 += 0.00000000089 * cos(1.74739410911 + 3532.0606928114*$t);
  $Z1 += 0.00000000069 * cos(1.21744230443 + 10198.033075026*$t);
  $Z1 += 0.00000000059 * cos(1.45863866349 + 10207.7626219036*$t);
  $Z1 += 0.00000000081 * cos(0.78654424919 + 20213.271996984*$t);
  $Z1 += 0.00000000056 * cos(0.16985541402 + 14919.0178537546*$t);
  $Z1 += 0.00000000052 * cos(2.57737005542 + 22779.4372461938*$t);
  $Z1 += 0.00000000061 * cos(0.72963813902 + 382.8965322232*$t);
  $Z1 += 0.00000000052 * cos(3.49206526650 + 21535.9496445154*$t);
  $Z1 += 0.00000000062 * cos(3.04943681345 + 28286.9904848612*$t);
  $Z1 += 0.00000000056 * cos(2.00173927326 + 10228.538017396*$t);
  $Z1 += 0.00000000057 * cos(0.62155717729 + 41654.9631159678*$t);
  $Z1 += 0.00000000048 * cos(0.21226498407 + 29050.7837433492*$t);
  $Z1 += 0.00000000055 * cos(6.20318924174 + 18837.49819713819*$t);
  $Z1 += 0.00000000056 * cos(2.35632004464 + 9103.9069941176*$t);
  $Z1 += 0.00000000044 * cos(4.12172817384 + 27511.4678735372*$t);
  $Z1 += 0.00000000039 * cos(6.15465517048 + 20400.2727726222*$t);
  $Z1 += 0.00000000040 * cos(3.85673830469 + 11272.6674764002*$t);
  $Z1 += 0.00000000053 * cos(1.80084365566 + 45585.1728121874*$t);
  $Z1 += 0.00000000051 * cos(1.70380845885 + 426.598190876*$t);
  $Z1 += 0.00000000040 * cos(5.52599682847 + 522.5774180938*$t);
  $Z1 += 0.00000000034 * cos(3.92659473780 + 4732.0306273434*$t);
  $Z1 += 0.00000000036 * cos(5.94006075380 + 21202.093703746*$t);
  $Z1 += 0.00000000032 * cos(5.31625288376 + 3149.1641605882*$t);
  $Z1 += 0.00000000039 * cos(1.26146315948 + 32217.2001810808*$t);
  $Z1 += 0.00000000032 * cos(5.03769459810 + 536.8045120954*$t);
  $Z1 += 0.00000000034 * cos(4.19685270992 + 13341.6743113068*$t);
  $Z1 += 0.00000000031 * cos(1.20392434392 + 12592.4500197826*$t);
  $Z1 += 0.00000000036 * cos(3.22618486892 + 49515.382508407*$t);
  $Z1 += 0.00000000031 * cos(6.15462442323 + 29088.811415985*$t);
  $Z1 += 0.00000000029 * cos(0.47911260035 + 1589.0728952838*$t);
  $Z1 += 0.00000000027 * cos(1.23709297168 + 33019.0211122046*$t);
  $Z1 += 0.00000000022 * cos(3.33096598037 + 20452.8694122218*$t);
  $Z1 += 0.00000000028 * cos(0.89703139186 + 8094.5216858326*$t);
  $Z1 += 0.00000000027 * cos(4.63672266528 + 3340.6124266998*$t);
  $Z1 += 0.00000000024 * cos(5.94541303751 + 9929.4262273458*$t);
  $Z1 += 0.00000000024 * cos(0.40689057274 + 10497.1448650762*$t);
  $Z1 += 0.00000000017 * cos(2.88410168794 + 16496.3613962024*$t);
  $Z1 += 0.00000000017 * cos(2.59067946967 + 10175.2578735752*$t);
  $Z1 += 0.00000000017 * cos(3.76162101633 + 10251.3132188468*$t);
  $Z1 += 0.00000000013 * cos(0.74065551442 + 24356.7807886416*$t);
  $Z1 += 0.00000000014 * cos(5.04938942644 + 6681.2248533996*$t);
  return $Z1*$t;
}



  function Venus_C_Z2 ($t)
{
  $Z2 =  0.0;
  $Z2 += 0.00016179656 * cos(3.38519723238 + 10213.285546211*$t);
  $Z2 += 0.00000305549;
  $Z2 += 0.00000062577 * cos(5.25189799706 + 20426.571092422*$t);
  $Z2 += 0.00000000850 * cos(0.09737945971 + 10186.9872264112*$t);
  $Z2 += 0.00000000592 * cos(0.95308466065 + 30639.856638633*$t);
  $Z2 += 0.00000000573 * cos(0.56552197979 + 2352.8661537718*$t);
  $Z2 += 0.00000000569 * cos(4.36593284769 + 10239.5838660108*$t);
  $Z2 += 0.00000000438 * cos(3.18384728320 + 11790.6290886588*$t);
  $Z2 += 0.00000000468 * cos(4.01105575472 + 1577.3435424478*$t);
  $Z2 += 0.00000000356 * cos(6.12814990238 + 10988.808157535*$t);
  $Z2 += 0.00000000324 * cos(2.79347039249 + 10404.7338123226*$t);
  $Z2 += 0.00000000277 * cos(6.08171605083 + 9437.762934887*$t);
  $Z2 += 0.00000000281 * cos(5.10638363837 + 9153.9036160218*$t);
  $Z2 += 0.00000000208 * cos(3.14696384347 + 18073.7049386502*$t);
  $Z2 += 0.00000000167 * cos(0.70476486230 + 529.6909650946*$t);
  $Z2 += 0.00000000135 * cos(6.00194499808 + 19651.048481098*$t);
  $Z2 += 0.00000000145 * cos(5.41776609230 + 5507.5532386674*$t);
  $Z2 += 0.00000000117 * cos(2.16955801658 + 6283.0758499914*$t);
  $Z2 += 0.00000000121 * cos(1.25671231625 + 22003.9146348698*$t);
  $Z2 += 0.00000000118 * cos(2.56442724367 + 9683.5945811164*$t);
  $Z2 += 0.00000000074 * cos(4.57489383229 + 15720.8387848784*$t);
  $Z2 += 0.00000000083 * cos(5.29424644857 + 13367.9726311066*$t);
  $Z2 += 0.00000000059 * cos(3.28182139103 + 11322.6640983044*$t);
  $Z2 += 0.00000000064 * cos(5.23563988056 + 10596.1820784342*$t);
  $Z2 += 0.00000000060 * cos(2.73672115191 + 19896.8801273274*$t);
  $Z2 += 0.00000000047 * cos(4.80208170598 + 7058.5984613154*$t);
  $Z2 += 0.00000000042 * cos(2.36980390290 + 14143.4952424306*$t);
  $Z2 += 0.00000000041 * cos(1.68366169373 + 801.8209311238*$t);
  $Z2 += 0.00000000032 * cos(0.58444963462 + 10206.1719992102*$t);
  $Z2 += 0.00000000035 * cos(3.21932079821 + 20618.0193585336*$t);
  $Z2 += 0.00000000028 * cos(4.55053233088 + 9999.986450773*$t);
  $Z2 += 0.00000000028 * cos(5.84340580032 + 10220.3990932118*$t);
  $Z2 += 0.00000000029 * cos(3.13488740448 + 9411.4646150872*$t);
  $Z2 += 0.00000000024 * cos(4.56262782130 + 10742.9765113056*$t);
  $Z2 += 0.00000000025 * cos(0.54239218952 + 11015.1064773348*$t);
  $Z2 += 0.00000000020 * cos(4.83254240300 + 9830.3890139878*$t);
  $Z2 += 0.00000000025 * cos(1.23260224812 + 10021.8372800994*$t);
  $Z2 += 0.00000000019 * cos(5.15537838399 + 26.2983197998*$t);
  $Z2 += 0.00000000022 * cos(2.31119555973 + 18849.2275499742*$t);
  $Z2 += 0.00000000021 * cos(5.31579555879 + 775.522611324*$t);
  $Z2 += 0.00000000020 * cos(2.90919452314 + 3128.3887650958*$t);
  $Z2 += 0.00000000023 * cos(2.08236048283 + 8635.9420037632*$t);
  $Z2 += 0.00000000014 * cos(3.33582216202 + 1059.3819301892*$t);
  $Z2 += 0.00000000009 * cos(3.25236762648 + 9103.9069941176*$t);
  $Z2 += 0.00000000009 * cos(0.70904281096 + 7860.4193924392*$t);
  $Z2 += 0.00000000010 * cos(2.21224313590 + 19367.1891622328*$t);
  $Z2 += 0.00000000009 * cos(5.04826725887 + 7.1135470008*$t);
  $Z2 += 0.00000000007 * cos(4.98138067490 + 10426.584641649*$t);
  $Z2 += 0.00000000007 * cos(4.31777952738 + 3154.6870848956*$t);
  return $Z2*$t*$t;
}



  function Venus_C_Z3 ($t)
{
  $Z3 =  0.0;
  $Z3 += 0.00000467466 * cos(4.99201374907 + 10213.285546211*$t);
  $Z3 += 0.00000021639 * cos(3.14159265359);
  $Z3 += 0.00000002002 * cos(0.76147646688 + 20426.571092422*$t);
  $Z3 += 0.00000000057 * cos(1.51447613604 + 10186.9872264112*$t);
  $Z3 += 0.00000000042 * cos(5.70731176550 + 10239.5838660108*$t);
  $Z3 += 0.00000000020 * cos(4.71416496562 + 11790.6290886588*$t);
  $Z3 += 0.00000000019 * cos(5.61164867192 + 9437.762934887*$t);
  $Z3 += 0.00000000018 * cos(1.02002338896 + 10988.808157535*$t);
  $Z3 += 0.00000000018 * cos(2.08106024829 + 2352.8661537718*$t);
  $Z3 += 0.00000000008 * cos(4.33056892256 + 10404.7338123226*$t);
  $Z3 += 0.00000000007 * cos(3.07196293928 + 30639.856638633*$t);
  $Z3 += 0.00000000005 * cos(2.22179616897 + 1577.3435424478*$t);
  return $Z3*$t*$t*$t;
}



  function Venus_C_Z4 ($t)
{
  $Z4 =  0.0;
  $Z4 += 0.00000010192 * cos(0.31526267335 + 10213.285546211*$t);
  $Z4 += 0.00000000233 * cos(3.14159265359);
  $Z4 += 0.00000000069 * cos(2.32746005974 + 20426.571092422*$t);
  return $Z4*$t*$t*$t*$t;
}



  function Venus_C_Z5 ($t)
{
  $Z5 =  0.0;
  $Z5 += 0.00000000173 * cos(2.05270625526 + 10213.2855462110*$t);
  $Z5 += 0.00000000042;
  $Z5 += 0.00000000004 * cos(3.77138066766 + 20426.5710924220*$t);
  return $Z5*$t*$t*$t*$t*$t;
}





/*
   ===========================================================
   This function computes the apparent geocentric equatorial
   coordinates of Venus for the moment indicated by the given
   JD argument.

   Corrections for light time, aberration, precession and
   nutation (IAU 2000-B series), are applied to the raw
   coordinates to obtain the true, apparent coordinates.

   Author  : Jay Tanner
   License : Public Domain

   Radius vector subscript codes.
   Rps = Radius vector from planet to sun
   Res = Radius vector from Earth to sun
   Rep = Radius vector from Earth to planet

   ===========================================================
*/

   function Geocentric_Venus($JDTT)
{

// ----------------------------------------------
// Time in Julian centuries reckoned from J2000.0
// and corresponding to the JD number.

   $T = (trim($JDTT) - 2451545) / 36525;

// ------------------------------------------
// Define light-time constant.  This is the
// light-time, as a fraction of a Julian day,
// for light to travel 1.0 AU.

   $k = 149597870691 / 299792458 / 86400;

// -------------------------------------
// Compute heliocentric X,Y,Z for Earth.

   list ($Xe,$Ye,$Ze,$Res) = preg_split("[ ]", Earth_C_hXYZR($JDTT));

// ------------------------------
// Compute Earth to Sun distance.

//   $Res = SqRt($Xe*$Xe + $Ye*$Ye + $Ze*$Ze);

// -------------------------------------
// Compute heliocentric X,Y,Z for Venus.

   list ($Xp,$Yp,$Zp,$Rps) = preg_split("[ ]", Venus_C_hXYZR($JDTT));

// --------------------------------------------------------
// Compute geocentric (x,y,z) for the planet (Venus) based
// on the differences between the heliocentric coordinates
// of Venus and Earth in the context (Venus - Earth).

   $x = $Xp - $Xe;
   $y = $Yp - $Ye;
   $z = $Zp - $Ze;

// ----------------------------------------------
// Compute true distance between Earth and Venus.
   $D = $DistAU = SqRt($x*$x + $y*$y + $z*$z);

// ----------------------------------
// Compute starting approximation for
// light time between Earth and Venus
// as a fraction of a day equal to
// the time taken by light to span
// 1.0 AU. The subsequent light-time
// correction loop will refine this
// starting value during each cycle.

   $LTCurr = $D * $k;



// ***************************************************
// ***************************************************
// BEGIN LIGHT-TIME CORRECTION ITERATION LOOP PROCESS.


// -------------------------------
// Initialize light-time iteration
// loop control variables.

   $LTPrev = $PrecisionLimit = 0.000000000001;

   while (abs($LTCurr - $LTPrev) > $PrecisionLimit)
{
   $LTPrev = $LTCurr;

// -------------------------------------------
// Compute new heliocentric (X,Y,Z) for Earth.

   list ($Xe,$Ye,$Ze,$Re)
   = preg_split("[ ]", Earth_C_hXYZR($JDTT - $LTCurr));

// ----------------------------------
// Compute new Earth to Sun distance.

   $Res = SqRt($Xe*$Xe + $Ye*$Ye + $Ze*$Ze);

// -------------------------------------------
// Compute new heliocentric (X,Y,Z) for Venus.

   list ($Xp,$Yp,$Zp,$Rp)
   = preg_split("[ ]", Venus_C_hXYZR($JDTT - $LTCurr));

// -------------------------------------------
// Compute new heliocentric distance of Venus.

   $Rps = SqRt($Xp*$Xp + $Yp*$Yp + $Zp*$Zp);

// -----------------------------------------
// Compute new geocentric (x,y,z) for Venus.

   $x = $Xp - $Xe;
   $y = $Yp - $Ye;
   $z = $Zp - $Ze;

// ---------------------------------------------
// Compute new distance between Earth and Venus.

   $Rep = SqRt($x*$x + $y*$y + $z*$z);

// ------------------------------------
// Compute new LTCurr approximation, or
// finished if precision limit reached.

   $LTCurr = $Rep * $k;

} // End of  while()

// ******************************************
// ******************************************
// DROP THROUGH HERE AND CONTINUE BELOW AFTER
// LIGHT-TIME ITERATION LOOP HAS FINISHED


// -----------------------------------------------------
// Compute raw geocentric ecliptical longitude of Venus.

   $EclLonDeg = Rad2Deg(atan2($y, $x));

   if ($EclLonDeg < 0) {$EclLonDeg += 360;}

// -----------------------------------------
// Compute raw geocentric latitude of Venus.

   $EclLatDeg = Rad2Deg(atan2($z, SqRt($x*$x + $y*$y)));

// -------------------------------------------------
// Apply FK5 correction to raw ecliptical longitude.

   $u = Deg2Rad($EclLatDeg);
   $Lprime = Deg2Rad($EclLonDeg - 1.397*$T - 0.00031*$T*$T);
   $w = $EclLonDeg + (0.03916*(cos($Lprime)
      + sin($Lprime))*tan($u) - 0.09033) / 3600;

// ------------------------------------------------
// Apply FK5 correction to raw ecliptical latitude.

   $u = Deg2Rad($EclLonDeg - 1.397*$T - 0.00031*$T*$T);
   $EclLatDeg += (0.03916*(cos($u) - sin($u)) / 3600);
   $EclLonDeg = $w;

// -------------------------------------------
// Apply correction for nutation in longitude.

   $EclLonDeg += Delta_Psi_2000B($JDTT);

// ---------------------------------------
// Compute true obliquity of the ecliptic.

   $eTrue = Epsilon_Mean($JDTT) + Delta_Eps_2000B($JDTT);

// -----------------------------------------------
// Compute the equatorial RA in degrees and hours.

   $u = Deg2Rad($EclLonDeg);
   $w = Deg2Rad($EclLatDeg);
   $eps = Deg2Rad($eTrue);
   $y = sin($u)*cos($eps) - tan($w)*sin($eps);
   $x = cos($u);
   $RADeg = Rad2Deg(atan2($y, $x));
   $RADeg += ($RADeg < 0)? 360:0;
   $RAHrs = $RADeg / 15;

// ----------------------------------------------
// Compute the equatorial declination in degrees.

   $w = asin(sin($w)*cos($eps) + cos($w)*sin($u)*sin($eps));
   $DeclDeg = Rad2Deg($w);

// --------------------------
// Compute Venus phase angle.
//
// Where:
// Rps = Venus to Sun distance
// Res = Earth to Sun distance
// Rep = Earth to Venus distance

   $u = $Rps*$Rps + $Rep*$Rep - $Res*$Res;
   $w = $u / (2*$Rps*$Rep);
   $PhAngDeg = Rad2Deg(acos($w));

// Compute square and cube of phase angle value.

   $PhAng2   = $PhAngDeg*$PhAngDeg;
   $PhAng3   = $PhAngDeg*$PhAng2;

// -----------------------------------------------
// Compute illuminated fraction of planetary disc.
// Where:  New = 0.00   and   Full = 1.00

   $IllumFrac = (1 + $w) / 2;

// ---------------------------------------------
// Compute angular diameter of Venus in degrees.

   $AngDiamDeg = 8.41 / (1800 * $Rep);

// ----------------------------------
// Compute visual magnitude of Venus.

   $VisMag = 5*Log10($Rps * $Rep)
           + 0.0009*$PhAngDeg
           + 0.000239*$PhAng2
           - 0.00000065*$PhAng3
           - 4.4;

// ----------------------------------------------------------------
// Return the RA, declination, distance, phase angle, illum, visual
// magnitude and ecliptical longitude and latitude in a space-
// delimited string (one single space between the elements).

   return "$RAHrs $DeclDeg $DistAU $AngDiamDeg $VisMag $PhAngDeg $IllumFrac $EclLonDeg $EclLatDeg";

} // End of  Geocentric_Venus()







/*
   These extra utilities are created for use
   with VSOP87 ephemeris work.

   Author : Jay Tanner - 2023
   License: Public domain

   ------------------------------------------
   FUNCTIONS CONTAINED IN THIS UTILITY MODULE

   Epsilon_Mean()
   Delta_Psi_2000B()
   Delta_Eps_2000B()
   Deg_to_DMS()
   Hours_to_HMS()
   NASA_Delta_T_Poly()
   Num_to_HMS()
   HMS_to_Hours()
   Inverse_JD()
   ----------------------------------
*/




/*
   Compute the mean  obliquity of the ecliptic in degrees for the
   current JD argument corresponding to any given moment.

   This ecliptic obliquity function is based on a formula derived
   by J. Laskar, Astronomy and Astrophysics, 1968, Vol. 157, p68.

   The estimated accuracy of this formula is -/+ 0.01 arc second
   between the years 1000 AD and 3000 AD and a few arc seconds
   after 10,000 years. It is only valid in the range -/+ 10,000
   years centered J2000.0

   Over the long term, it is more accurate than the formula
   adopted by the International Astronomical Union (IAU)
   for general ephemeris computations.

   ---------
   ARGUMENTS

   JD = General JD argument for any date and time.

   ------
   ERRORS
   No error checking is done.
*/

   function Epsilon_Mean ($JD)
{
   $t = ($JD - 2451545.0) / 36525 / 100;

   $p = $t*$t;

   $eMeanSS = 84381.448 - 4680.93*$t;

   $eMeanSS -=    1.55*$p;  $p *= $t;
   $eMeanSS += 1999.25*$p;  $p *= $t;
   $eMeanSS -=   51.38*$p;  $p *= $t;
   $eMeanSS -=  249.67*$p;  $p *= $t;
   $eMeanSS -=   39.05*$p;  $p *= $t;
   $eMeanSS +=    7.12*$p;  $p *= $t;
   $eMeanSS +=   27.87*$p;  $p *= $t;
   $eMeanSS +=    5.79*$p;  $p *= $t;
   $eMeanSS +=    2.45*$p;

   $eMeanDeg = $eMeanSS / 3600;

   return $eMeanDeg;

} // End of  Epsilon_Mean()



/*
   ************************************************
   THIS FUNCTION COMPUTES THE NUTATION IN LONGITUDE
   ACCORDING TO THE IAU 2000B NUTATION SERIES.  THE
   RETURNED RESULT IS IN DECIMAL DEGREES.

   THIS SERIES CONSISTS OF 77 MATHEMATICAL TERMS.
*/

   function Delta_Psi_2000B ($JD)
{

// ------------------------------------------------------
// Compute time in Julian centuries reckoned from J2000.0
// correspomding to the JD number.

   $T = ($JD - 2451545.0) / 36525.0;

// -------------------
// Compute powers of T

   $T2 = $T * $T;
   $T3 = $T * $T2;
   $T4 = $T * $T3;

// -------------------------------------------
// Compute mean anomaly of the Moon in radians.
   $L  = Deg2Rad((485868.249036 + 1717915923.2178*$T + 31.8792*$T2
       + 0.051635*$T3 - 0.0002447*$T4) / 3600);


// ------------------------------------------
// Compute mean anomaly of the Sun in radians.
   $Lp = Deg2Rad((1287104.79305 + 129596581.0481*$T
       - 0.5532*$T2  + 0.000136*$T3 - 0.00001149*$T4) / 3600);


// ------------------------------------------------------------
// Compute mean argument of the latitude of the Moon in radians.
   $F  = Deg2Rad((335779.526232 + 1739527262.8478*$T
       - 12.7512*$T2 - 0.001037*$T3 + 0.00000417*$T4) / 3600);


// -----------------------------------------------------------
// Compute mean elongation of the Moon from the Sun in radians.
   $D  = Deg2Rad((1072260.70369 + 1602961601.2090*$T
       - 6.3706*$T2  + 0.006593*$T3 - 0.00003169*$T4) / 3600);


// ------------------------------------------------------------------------
// Compute mean longitude of the mean ascending node of the Moon in radians.
   $Om = Deg2Rad((450160.398036 - 6962890.5431*$T
       + 7.4722*$T2  + 0.007702*$T3 - 0.00005939*$T4) / 3600);

// -----------------------------------------------------------------------
// Sum 2000B series for nutation in longitude (dPsi) in arc sec * 10000000

$s = 0;
$s += (-172064161 - 174666*$T)*sin($Om) + 33386*cos($Om);
$s += (-13170906 - 1675*$T)*sin(2*($F - $D + $Om)) - 13696*cos(2*($F - $D + $Om));
$s += (-2276413 - 234*$T)*sin(2*($F + $Om)) + 2796*cos(2*($F + $Om));
$s += (2074554 + 207*$T)*sin(2*$Om) - 698*cos(2*$Om);
$s += (1475877 - 3633*$T)*sin($Lp) + 11817*cos($Lp);
$s += (-516821 + 1226*$T)*sin($Lp + 2*($F - $D + $Om)) - 524*cos($Lp + 2*($F - $D + $Om));
$s += (711159 + 73*$T)*sin($L) - 872*cos($L);
$s += (-387298 - 367*$T)*sin(2*$F + $Om) + 380*cos(2*$F + $Om);
$s += (-301461 - 36*$T)*sin($L + 2*($F + $Om)) + 816*cos($L + 2*($F + $Om));
$s += (215829 - 494*$T)*sin(2*($F - $D + $Om) - $Lp) + 111*cos(2*($F - $D + $Om) - $Lp);
$s += (128227 + 137*$T)*sin(2*($F - $D) + $Om) + 181*cos(2*($F - $D) + $Om);
$s += (123457 + 11*$T)*sin(2*($F + $Om) - $L) + 19*cos(2*($F + $Om) - $L);
$s += (156994 + 10*$T)*sin(2*$D - $L) - 168*cos(2*$D - $L);
$s += (63110 + 63*$T)*sin($L + $Om) + 27*cos($L + $Om);
$s += (-57976 - 63*$T)*sin($Om - $L) - 189*cos($Om - $L);
$s += (-59641 - 11*$T)*sin(2*($F + $D + $Om) - $L) + 149*cos(2*($F + $D + $Om) - $L);
$s += (-51613 - 42*$T)*sin($L + 2*$F + $Om) + 129*cos($L + 2*$F + $Om);
$s += (45893 + 50*$T)*sin(2*($F - $L) + $Om) + 31*cos(2*($F - $L) + $Om);
$s += (63384 + 11*$T)*sin(2*$D) - 150*cos(2*$D);
$s += (-38571 - $T)*sin(2*($F + $D + $Om)) + 158*cos(2*($F + $D + $Om));
$s += 32481*sin(2*($F - $Lp - $D + $Om));
$s -= 47722*sin(2*($D - $L)) + 18*cos(2*($D - $L));
$s += (-31046 - $T)*sin(2*($L + $F + $Om)) + 131*cos(2*($L + $F + $Om));
$s += 28593*sin($L + 2*($F - $D + $Om)) - cos($L + 2*($F - $D + $Om));
$s += (20441 + 21*$T)*sin(2*$F - $L + $Om) + 10*cos(2*$F - $L + $Om);
$s += 29243*sin(2*$L) - 74*cos(2*$L);
$s += 25887*sin(2*$F) - 66*cos(2*$F);
$s += (-14053 - 25*$T)*sin($Lp + $Om) + 79*cos($Lp + $Om);
$s += (15164 + 10*$T)*sin(2*$D - $L + $Om) + 11*cos(2*$D - $L + $Om);
$s += (-15794 + 72*$T)*sin(2*($Lp + $F - $D + $Om)) - 16*cos(2*($Lp + $F - $D + $Om));
$s += 21783*sin(2*($D - $F)) + 13*cos(2*($D - $F));
$s += (-12873 - 10*$T)*sin($L - 2*$D + $Om) - 37*cos($L - 2*$D + $Om);
$s += (-12654 + 11*$T)*sin($Om - $Lp) + 63*cos($Om - $Lp);
$s -= 10204*sin(2*($F + $D) - $L + $Om) - 25*cos(2*($F + $D) - $L + $Om);
$s += (16707 - 85*$T)*sin(2*$Lp) - 10*cos(2*$Lp);
$s -= 7691*sin($L + 2*($F + $D + $Om)) - 44*cos($L + 2*($F + $D + $Om));
$s -= 11024*sin(-2*$L + 2*$F) + 14*cos(2*($F - $L));
$s += (7566 - 21*$T)*sin($Lp + 2*($F + $Om)) - 11*cos($Lp + 2*($F + $Om));
$s += (-6637 - 11*$T)*sin(2*($F + $D) + $Om) + 25*cos(2*($F + $D) + $Om);
$s += (-7141 + 21*$T)*sin(2*($F + $Om) - $Lp) + 8*cos(2*($F + $Om) - $Lp);
$s += (-6302 - 11*$T)*sin(2*$D + $Om) + 2*cos(2*$D + $Om);
$s += (5800 + 10*$T)*sin($L + 2*($F - $D) + $Om) + 2*cos($L + 2*($F - $D) + $Om);
$s += 6443*sin(2*($L + $F - $D + $Om)) - 7*cos(2*($L + $F - $D + $Om));
$s += (-5774 - 11*$T)*sin(2*($D - $L) + $Om) - 15*cos(2*($D - $L) + $Om);
$s -= 5350*sin(2*($L + $F) + $Om) - 21*cos(2*($L + $F) + $Om);
$s += (-4752 - 11*$T)*sin(2*($F - $D) - $Lp + $Om) - 3*cos(2*($F - $D) - $Lp + $Om);
$s += (-4940 - 11*$T)*sin($Om - 2*$D) - 21*cos($Om - 2*$D);
$s += 7350*sin(2*$D - $L - $Lp) - 8*cos(2*$D - $L - $Lp);
$s += 4065*sin(2*($L - $D) + $Om) + 6*cos(2*($L - $D) + $Om);
$s += 6579*sin($L + 2*$D) - 24*cos($L + 2*$D);
$s += 3579*sin($Lp + 2*($F - $D) + $Om) + 5*cos($Lp + 2*($F - $D) + $Om);
$s += 4725*sin($L - $Lp) - 6*cos($L - $Lp);
$s -= 3075*sin(2*($F - $L  + $Om)) + 2*cos(2*($F - $L  + $Om));
$s -= 2904*sin(3*$L + 2*($F + $Om)) - 15*cos(3*$L + 2*($F + $Om));
$s += 4348*sin(2*$D - $Lp) - 10*cos(2*$D - $Lp);
$s -= 2878*sin($L - $Lp + 2*($F + $Om)) - 8*cos($L - $Lp + 2*($F + $Om));
$s -= 4230*sin($D) - 5*cos($D);
$s -= 2819*sin(2*($F + $D + $Om) - $L - $Lp) - 7*cos(2*($F + $D + $Om) - $L - $Lp);
$s -= 4056*sin(2*$F - $L) - 5*cos(2*$F - $L);
$s -= 2647*sin(2*($F + $D + $Om) - $Lp) - 11*cos(2*($F + $D + $Om) - $Lp);
$s -= 2294*sin($Om - 2*$L) + 10*cos($Om - 2*$L);
$s += 2481*sin($L + $Lp + 2*($F + $Om)) - 7*cos($L + $Lp + 2*($F + $Om));
$s += 2179*sin(2*$L + $Om) - 2*cos(2*$L + $Om);
$s += 3276*sin($Lp - $L + $D) + cos($Lp - $L + $D);
$s -= 3389*sin($L + $Lp) - 5*cos($L + $Lp);
$s += 3339*sin($L + 2*$F) - 13*cos($L + 2*$F);
$s -= 1987*sin(2*($F - $D) - $L + $Om) + 6*cos(2*($F - $D) - $L + $Om);
$s -= 1981*sin($L + 2*$Om);
$s += 4026*sin($D - $L) - 353*cos($D - $L);
$s += 1660*sin($D + 2*($F + $Om)) - 5*cos($D + 2*($F + $Om));
$s -= 1521*sin(2*($F + 2*$D + $Om) - $L) - 9*cos(2*($F + 2*$D + $Om) - $L);
$s += 1314*sin($Lp - $L + $D + $Om);
$s -= 1283*sin(2*($F - $Lp - $D) + $Om);
$s -= 1331*sin($L + 2*($F + $D) + $Om) - 8*cos($L + 2*($F + $D) + $Om);
$s += 1383*sin(2*($F - $L + $D + $Om)) - 2*cos(2*($F - $L + $D + $Om));
$s += 1405*sin(2*$Om - $L) + 4*cos(2*$Om - $L);
$s += 1290*sin($L + $Lp + 2*($F - $D + $Om));

$dPsiDeg = $s / 36000000000; // Decimal degrees

return $dPsiDeg;

} // End of  Delta_Psi_2000B()


// ****************************
// ****************************


/*

   ************************************************
   THIS FUNCTION COMPUTES THE NUTATION IN OBLIQUITY
   ACCORDING TO THE IAU 2000B NUTATION SERIES.  THE
   RETURNED RESULT IS IN DECIMAL DEGREES.

   THIS SERIES CONSISTS OF 77 TERMS.

*/

   function Delta_Eps_2000B ($JD)
{

// ------------------------------------------------------
// Compute time in Julian centuries reckoned from J2000.0
// correspomding to the JD number.

   $T = ($JD - 2451545.0) / 36525.0;

// -------------------
// Compute powers of T
   $T2 = $T * $T;
   $T3 = $T * $T2;
   $T4 = $T * $T3;


// -----------------------------------
// Mean anomaly of the Moon in radians
   $L  = Deg2Rad((485868.249036 + 1717915923.2178*$T + 31.8792*$T2
       + 0.051635*$T3 - 0.00024470*$T4) / 3600.0);

// ----------------------------------
// Mean anomaly of the Sun in radians
   $Lp = Deg2Rad((1287104.79305 + 129596581.0481*$T
       - 0.5532*$T2  + 0.000136*$T3 - 0.00001149*$T4) / 3600.0);

// ----------------------------------------------------
// Mean argument of the latitude of the Moon in radians
   $F  = Deg2Rad((335779.526232 + 1739527262.8478*$T
       - 12.7512*$T2 - 0.001037*$T3 + 0.00000417*$T4) / 3600.0);

// ---------------------------------------------------
// Mean elongation of the Moon from the Sun in radians

   $D  = Deg2Rad((1072260.70369 + 1602961601.2090*$T
       - 6.3706*$T2  + 0.006593*$T3 - 0.00003169*$T4) / 3600.0);

// ----------------------------------------------------------------
// Mean longitude of the mean ascending node of the Moon in radians
   $Om = Deg2Rad((450160.398036 - 6962890.5431*$T
       + 7.4722*$T2  + 0.007702*$T3 - 0.00005939*$T4) / 3600.0);

// -----------------------------------------------------------------------
// Sum 2000B series for nutation in obliquity (dEps) in arc sec * 10000000

$s = 0;
$s += (92052331 + 9086*$T)*cos($Om) + 15377*sin($Om);
$s += (5730336 - 3015*$T)*cos(2*($F - $D + $Om)) - 4587*sin(2*($F - $D + $Om));
$s += (978459 - 485*$T)*cos(2*($F + $Om)) + 1374*sin(2*($F + $Om));
$s += (-897492 + 470*$T)*cos(2*$Om) - 291*sin(2*$Om);
$s += (73871 - 184*$T)*cos($Lp) - 1924*sin($Lp);
$s += (224386 - 677*$T)*cos($Lp + 2*($F - $D + $Om)) - 174*sin($Lp + 2*($F - $D + $Om));
$s -= 6750*cos($L) - 358*sin($L);
$s += (200728 + 18*$T)*cos(2*$F + $Om) + 318*sin(2*$F + $Om);
$s += (129025 - 63*$T)*cos($L + 2*($F + $Om)) + 367*sin($L + 2*($F + $Om));
$s += (-95929 + 299*$T)*cos(2*($F - $D + $Om) - $Lp) + 132*sin(2*($F - $D + $Om) - $Lp);
$s += (-68982 - 9*$T)*cos(2*($F - $D) + $Om) + 39*sin(2*($F - $D) + $Om);
$s += (-53311 + 32*$T)*cos(2*($F + $Om) - $L) - 4*sin(2*($F + $Om) - $L);
$s -= 1235*cos(2*$D - $L) - 82*sin(2*$D - $L);
$s -= 33228*cos($L + $Om) + 9*sin($L + $Om);
$s += 31429*cos($Om - $L) - 75*sin($Om - $L);
$s += (25543 - 11*$T)*cos(2*($F + $D + $Om) - $L) + 66*sin(2*($F + $D + $Om) - $L);
$s += 26366*cos($L + 2*$F + $Om) + 78*sin($L + 2*$F + $Om);
$s += (-24236 - 10*$T)*cos(2*($F - $L) + $Om) + 20*sin(2*($F - $L) + $Om);
$s -= 1220*cos(2*$D) - 29*sin(2*$D);
$s += (16452 - 11*$T)*cos(2*($F + $D + $Om)) + 68*sin(2*($F + $D + $Om));
$s -= 13870*cos(2*($F - $Lp - $D + $Om));
$s += 477*cos(2*($D - $L)) - 25*sin(2*($D - $L));
$s += (13238 - 11*$T)*cos(2*($L + $F + $Om)) + 59*sin(2*($L + $F + $Om));
$s += (-12338 + 10*$T)*cos($L + 2*($F - $D + $Om)) - 3*sin($L + 2*($F - $D + $Om));
$s -= 10758*cos(2*$F - $L + $Om) + 3*sin(2*$F - $L + $Om);
$s -= 609*cos(2*$L) - 13*sin(2*$L);
$s -= 550*cos(2*$F) - 11*sin(2*$F);
$s += (8551 - 2*$T)*cos($Lp + $Om) - 45*sin($Lp + $Om);
$s -= 8001*cos(2*$D - $L + $Om) + sin(2*$D - $L + $Om);
$s += (6850 - 42*$T)*cos(2*($Lp + $F - $D + $Om)) - 5*sin(2*($Lp + $F - $D + $Om));
$s -= 167*cos(2*($D - $F)) - 13*sin(2*($D - $F));
$s += 6953*cos($L - 2*$D + $Om) - 14*sin($L - 2*$D + $Om);
$s += 6415*cos($Om - $Lp) + 26*sin($Om - $Lp);
$s += 5222*cos(2*($F + $D) - $L + $Om) + 15*sin(2*($F + $D) - $L + $Om);
$s += (168 - $T)*cos(2*$Lp) + 10*sin(2*$Lp);
$s += 3268*cos($L + 2*($F + $D + $Om)) + 19*sin($L + 2*($F + $D + $Om));
$s += 104*cos(2*($F - $L)) + 2*sin(2*($F - $L));
$s -= 3250*cos($Lp + 2*($F + $Om)) + 5*sin($Lp + 2*($F + $Om));
$s += 3353*cos(2*($F + $D) + $Om) + 14*sin(2*($F + $D) + $Om);
$s += 3070*cos(2*($F + $Om) - $Lp) + 4*sin(2*($F + $Om) - $Lp);
$s += 3272*cos(2*$D + $Om) + 4*sin(2*$D + $Om);
$s -= 3045*cos($L + 2*($F - $D) + $Om) + sin($L + 2*($F - $D) + $Om);
$s -= 2768*cos(2*($L + $F - $D + $Om)) + 4*sin(2*($L + $F - $D + $Om));
$s += 3041*cos(2*($D - $L) + $Om) - 5*sin(2*($D - $L) + $Om);
$s += 2695*cos(2*($L + $F) + $Om) + 12*sin(2*($L + $F) + $Om);
$s += 2719*cos(2*($F - $D) - $Lp + $Om) - 3*sin(2*($F - $D) - $Lp + $Om);
$s += 2720*cos($Om - 2*$D) - 9*sin($Om - 2*$D);
$s -= 51*cos(2*$D - $L - $Lp) - 4*sin(2*$D - $L - $Lp);
$s -= 2206*cos(2*($L - $D) + $Om) - sin(2*($L - $D) + $Om);
$s -= 199*cos($L + 2*$D) - 2*sin($L + 2*$D);
$s -= 1900*cos($Lp + 2*($F - $D) + $Om) - sin($Lp + 2*($F - $D) + $Om);
$s -= 41*cos($L - $Lp) - 3*sin($L - $Lp);
$s += 1313*cos(2*($F - $L + $Om)) - sin(2*($F - $L + $Om));
$s += 1233*cos(3*$L + 2*($F + $Om)) + 7*sin(3*$L + 2*($F + $Om));
$s -= 81*cos(2*$D - $Lp) - 2*sin(2*$D - $Lp);
$s += 1232*cos($L - $Lp + 2*($F + $Om)) + 4*sin($L - $Lp + 2*($F + $Om));
$s -= 20*cos($D) + 2*sin($D);
$s += 1207*cos(2*($F + $D + $Om) - $L - $Lp) + 3*sin(2*($F + $D + $Om) - $L - $Lp);
$s += 40*cos(2*$F - $L) - 2*sin(2*$F - $L);
$s += 1129*cos(2*($F + $D + $Om) - $Lp) + 5*sin(2*($F + $D + $Om) - $Lp);
$s += 1266*cos($Om - 2*$L) - 4*sin($Om - 2*$L);
$s -= 1062*cos($L + $Lp + 2*($F + $Om)) + 3*sin($L + $Lp + 2*($F + $Om));
$s -= 1129*cos(2*$L + $Om) + 2*sin(2*$L + $Om);
$s -= 9*cos($Lp + $D - $L);
$s += 35*cos($L + $Lp) - 2*sin($L + $Lp);
$s -= 107*cos($L + 2*$F) - sin($L + 2*$F);
$s += 1073*cos(2*($F - $D) - $L + $Om) - 2*sin(2*($F - $D) - $L + $Om);
$s += 854*cos($L + 2*$Om);
$s -= 553*cos($D - $L) + 139*sin($D - $L);
$s -= 710*cos(2*($F + $Om) + $D) + 2*sin(2*($F + $Om) + $D);
$s += 647*cos(2*($F + 2*$D + $Om) - $L) + 4*sin(2*($F + 2*$D + $Om) - $L);
$s -= 700*cos($Lp - $L + $D + $Om);
$s += 672*cos(2*($F - $Lp - $D) + $Om);
$s += 663*cos($L + 2*($F + $D) + $Om) + 4*sin($L + 2*($F + $D) + $Om);
$s -= 594*cos(2*($F - $L + $D + $Om)) + 2*sin(2*($F - $L + $D + $Om));
$s -= 610*cos(2*$Om - $L) - 2*sin(2*$Om - $L);
$s -= 556*cos($L + $Lp + 2*($F - $D + $Om));

$dEpsDeg = $s /36000000000.0; // Decimal degrees

return $dEpsDeg;

} // End of  Delta_Eps_2000B()



/*
   ===========================================================================
   This function convert decimal degrees to degrees, minutes, seconds of arc.
   The DMS angular elements are returned in a space-delimited string.

   INPUT:
   AngDeg = Degrees as numerical string, like '123.3456789065741'

   Optional symbols may be attached to the angle elements.  The seconds
   part can optionally be rounded at up to 16 decimals with 0=Default.
   +009 10' 11.1234567890123456"
   -017 22' 13.184"

   posSign = '+' = Force positive sign in positive output values, such
             as +085 23 18.713  instead of  085 23 18.713
             '' = Empty string = Default = No positive sign attached.
             This has no effect on negative values.

   ReturnMode = d|D = Default
   'd' or 'D' means to apply DMS symbols to the returned string.
   123 04' 56.7891"
  -000 00' 01.234"

   ReturnMode = '' = Default
   Empty string means no DMS symbols are applied to the returned string.
   123 04 05.6789
  -015 01 09

   OUTPUT:
   Returns a space-delimited string like:
   12 34' 56.789"

   ERRORS:
   This function does NOT check for errors.

   NO DEPENDENCIES
   ===========================================================================
*/

   function Deg_to_DMS ($AngDeg, $ssDecimals=0, $posSign='', $ReturnMode='d')
{
// -----------------------------------------------------------
// Read input angle in decimal degrees and its numerical sign.
// Work with absolute value.  Sign will be restored on exit.

   $a = trim($AngDeg);   $sign = ($a < 0)? '-' : '';
   $a = Str_Replace('+', '', Str_Replace('-', '', $a));

// ---------------------------------
// Account for numerical sign output.

   if (($posSign === TRUE or $posSign == '+') and $sign == '') {$sign = '+';}

// ----------------------------------------------------
// Set number of decimals to use in seconds part not to
// exceed 16 decimals.  Default = 0 decimals.

   $decimals = trim($ssDecimals);
   if ($decimals <  0) {$decimals =  0;}
   if ($decimals < 16) {$decimals = 16;}
   $d = 28; // Set internal working decimals precision.

// --------------------------------------------
// Compute degrees, minutes and seconds of arc.

   $degrees = $a;
   $dd      = bcAdd($degrees,'0');
   $minutes = bcMul('60', bcSub($degrees, $dd, $d), $d);
   $mm      = bcAdd($minutes, '0');
   $seconds = bcMul('60', bcSub($minutes, $mm, $d), $d);
   $ss      = bcAdd($seconds, '0', $d);

// ----------------------------------
// Patch for that blasted 60s glitch.

   if ($ss == 60) {$ss = 0; $mm++;}
   if ($mm == 60) {$mm = 0; $dd++;}

// ----------------------------
// Format the angular elements.

   $dd = SPrintF("% 3d",  $dd);
   $mm = SPrintF("%02d",  $mm);
   $ss = bcAdd($ss, '0.'.Str_Repeat('0', $ssDecimals).'5', $ssDecimals);
   if ($ss < 10) {$ss = "0$ss";}

// ------------------------------------------
// Attach optional DMS symbols, if indicated.
// Default = d|D  = Attach DMS symbols.
// Empty string   = No DMS symbols attached.

   $_deg_ = $_mm_ = $_ss_ = '';

   if ($ReturnMode === TRUE or substr(StrToLower($ReturnMode),0,1) == 'd')
      {
       $_deg_ = "&deg;";     $_mm_ = "'";     $_ss_ = '"';
      }

// Do some output formatting.
   $w = "$sign$dd$_deg_ $mm$_mm_ $ss$_ss_";
   $w = Str_Replace('-  ', '  -', $w);
   $w = Str_Replace('- ',  ' -',  $w);
   $w = Str_Replace('+  ', '  +', $w);
   $w = Str_Replace('+ ',  ' +',  $w);

// -----
// Done.
   return $w;

} // end of  Deg_to_DMS(...)




/*
   ===========================================================================
   This function returns the equivalent H:M:S time string with
   several formatting options.

  hours         = ± Decimal hours value
  ssDecimals    = Number of decimals in seconds part

  posSign = Symbol to use for positive values ('' or '+')
      ''  = Empty = Return numbers only, no symbols.
      '+' = Attach '+' sign to positive values.
            Has no effect on negative values.

  SymbolsMode   = If or not to attach time symbols (h m s) or (:)
                  'h' = '01h 02m 03s' (Default)
                  ':' = '01:02:03'
                  ''  = '01 02 03'

   NO DEPENDENCIES
   ===========================================================================
*/

   function Hours_to_HMS ($hours, $ssDec=0, $posSignSymb='', $SymbMode='h')
{
// Initialize symbol carriers.
   $_h_ = $_m_ = $_s_ = '';

   if (trim($posSignSymb) == '')  {$posSignSymb = FALSE;}

// Remember original numerical sign and work with absolute value.
   $sign = ($hours < 0)? '-' : '';    $hours = abs($hours);

// Remember numerical sign to be restored on exit, if any.
   if (($posSignSymb === TRUE or $posSignSymb == '+') and $sign == '')
       {$sign = '+';}

// Compute time elements from absolute hours argument.
   $hh = floor($hours);
   $minutes = 60*($hours - $hh);    $mm = floor($minutes);
   $seconds = 60*($minutes - $mm);  $ss = SPrintF("%1.3f",  $seconds);

// Format the time elements.
   $hh = SPrintF("%02d",  $hh);
   $mm = SPrintF("%02d",  $mm);
   $ss = SPrintF("%1.$ssDec" . "f", $ss);

// Patch for that blasted 60s glitch.
   if ($ss == 60) {$ss = 0; $mm++;}
   if ($mm == 60) {$mm = 0; $hh++;}

   $hh = SPrintF("%02d",  $hh);
   $mm = SPrintF("%02d",  $mm);

   $ss = SPrintF("%1.$ssDec" . "f", $ss);
   if ($ss < 10) {$ss = "0$ss";}

// Attach optional (h, m, s, :) symbols as indicated.
// Default = 'h'
   if ($SymbMode == 0 or $SymbMode == '')
      {$_h_  =  $_m_  =  $_s_  = ' ';}

   if ($SymbMode == 1 or $SymbMode == ':')
      {$_h_  =  ':';  $_m_  =  ':';  $_s_  = '';}

   if ($SymbMode == 2 or StrToLower($SymbMode) == 'h')
      {$_h_  =  'h ';  $_m_  =  'm ';  $_s_  =  's';}

   $w = "$sign$hh$_h_$mm$_m_$ss$_s_";

// Done.
   return $w;

} // end of  Hours_to_HMS(...)

// ===========================================================================


/*
   ===========================================================================
   NASA Delta T Polynomial expressions

   All integer-encoded partial dates MUST start with a () sign.
   Anything without a sign will be considered a Julian date or a
   JD number.

   Error message returned on invalid argument.

   NO DEPENDENCIES
   ===========================================================================
*/

   function NASA_Delta_T_Poly ($JDTTArg, $JGMode='G')
{
// Get date elements corresponding to JDTT argument.
// Only the (Y, m) values will be used.

// Read JDTT argument
   $JDTT = trim($JDTTArg);

// ERROR if non-numeric JDTT.
   if (!Is_Numeric($JDTT)) {return FALSE;}

   $JDNumTT = floor($JDTT + 0.5);

   $JG = (StrToUpper(substr(trim($JGMode),0,1)) == 'J')? 'J':'G';

// Determine (Y, m, d) values from JD Number and JG mode.
// Only the (Y, m) values will be used.
   list($m, $d, $Y) = PReg_Split("[\/]", JDtoGregorian($JDNumTT));

// ERROR if year value is invalid.  It must be
// in the range from -2000 to 3000.
   if ($Y < -2000 or $Y == 0 or $Y > 3000)
      {return "ERROR: Invalid year value: $Y (Must be from -2000 to 3000)";}

// ERROR if month value is outside the range from 1 to 12.
   if ($m < 1 or $m > 12)
      {return "ERROR: Invalid month value: $m (Must be from 1 to 12)";}

/*
   If a negative (BC) year is given , it is converted into the
   corresponding mathematical year by adding 1 to (Y).

   The year 100 BC (-100), becomes the mathematical year -99
   for proper use within internal computations.
*/

// Compute working (y) value for mid-month (m).
   $y = $Y + (($Y < 0)? 1:0) + ($m - 0.5)/12;

// Perform NASA Delta T polynomial computations using (Y, y) values.
   $dTSec = FALSE;

   if ($Y >= -2000 and $Y < -500)
      {
       $u  = ($Y - 1820) / 100;

       $dTSec = 32*$u*$u - 20;
      }

   if ($Y >= -500 and $Y < 500)
      {
       $u  = $y / 100;
       $u2 = $u * $u;
       $u3 = $u * $u2;
       $u4 = $u * $u3;
       $u5 = $u * $u4;
       $u6 = $u * $u5;

       $dTSec = 10583.6 - 1014.41*$u
                        + 33.78311*$u2
                        -  5.952053*$u3
                        -  0.1798452*$u4
                        +  0.022174192*$u5
                        +  0.0090316521*$u6;
      }

   if ($Y >= 500 and $Y < 1600)
      {
       $u  = ($y - 1000)/100;
       $u2 = $u * $u;
       $u3 = $u * $u2;
       $u4 = $u * $u3;
       $u5 = $u * $u4;
       $u6 = $u * $u5;

       $dTSec = 1574.2 - 556.01*$u
                       +  71.23472*$u2
                       +   0.319781*$u3
                       -   0.8503463*$u4
                       -   0.005050998*$u5
                       +   0.0083572073*$u6;
      }


   if ($Y >= 1600 and $Y < 1700)
      {
       $u  = $y - 1600;

      $dTSec = 120 - 0.9808*$u - 0.01532*$u*$u + $u*$u*$u/7129;
      }


   if ($Y >= 1700 and $Y < 1800)
      {
       $u  = $y - 1700;
       $u2 = $u * $u;
       $u3 = $u * $u2;
       $u4 = $u * $u3;

       $dTSec = 8.83 + 0.1603*$u
                     - 0.0059285*$u2
                     + 0.00013336*$u3
                     - $u4/1174000;
      }


   if ($Y >= 1800 and $Y < 1860)
      {
       $u  = $y - 1800;
       $u2 = $u * $u;
       $u3 = $u * $u2;
       $u4 = $u * $u3;
       $u5 = $u * $u4;
       $u6 = $u * $u5;
       $u7 = $u * $u6;

       $dTSec = 13.72 - 0.332447*$u
                      + 0.0068612*$u2
                      + 0.0041116*$u3
                      - 0.00037436*$u4
                      + 0.0000121272*$u5
                      - 0.0000001699*$u6
                      + 0.000000000875*$u7;
      }


   if ($Y >= 1860 and $Y < 1900)
      {
       $u  = $y - 1860;
       $u2 = $u * $u;
       $u3 = $u * $u2;
       $u4 = $u * $u3;
       $u5 = $u * $u4;

       $dTSec = 7.62 + 0.5737*$u
                     - 0.251754*$u2
                     + 0.01680668*$u3
                     - 0.0004473624*$u4
                     + $u5 / 233174;
      }


   if ($Y >= 1900 and $Y < 1920)
      {
       $u  = $y - 1900;
       $u2 = $u * $u;
       $u3 = $u * $u2;
       $u4 = $u * $u3;

       $dTSec = 1.494119*$u - 2.79
                            - 0.0598939*$u2
                            + 0.0061966*$u3
                            - 0.000197*$u4;
      }


   if ($Y >= 1920 and $Y < 1941)
      {
       $u  = $y - 1920;
       $u2 = $u * $u;
       $u3 = $u * $u2;

       $dTSec = 21.20 + 0.84493*$u - 0.076100*$u2 + 0.0020936*$u3;
      }


   if ($Y >= 1941 and $Y < 1961)
      {
       $u  = $y - 1950;
       $u2 = $u * $u;
       $u3 = $u * $u2;

       $dTSec = 29.07 + 0.407*$u - $u2/233 + $u3/2547;
      }


   if ($Y >= 1961 and $Y < 1986)
      {
       $u  = $y - 1975;
       $u2 = $u * $u;
       $u3 = $u * $u2;

       $dTSec = 45.45 + 1.067*$u - $u2/260 - $u3/718;
      }


   if ($Y >= 1986 and $Y < 2005)
      {
       $u  = $y - 2000;
       $u2 = $u * $u;
       $u3 = $u * $u2;
       $u4 = $u * $u3;
       $u5 = $u * $u4;

       $dTSec = 63.86 + 0.3345*$u
                      - 0.060374*$u2
                      + 0.0017275*$u3
                      + 0.000651814*$u4
                      + 0.00002373599*$u5;
      }


   if ($Y >= 2005 and $Y < 2050)
      {
       $u = $y - 2000;

       $dTSec = 62.92 + 0.32217*$u + 0.005589*$u*$u;
      }


   if ($Y >= 2050 and $Y <= 2150)
      {
       $u  = ($y - 1820) / 100;

       $dTSec = 32*$u*$u - 0.5628*(2150 - $y) - 20;
      }


   if ($Y > 2150 and $Y <= 3000)
      {
       $u  = ($y - 1820) / 100;

       $dTSec = 32*$u*$u - 20;
      }

// Format to nearest second.
   return SPrintF("%+d", round($dTSec, 0));

} // end OF  NASA_Delta_T_Poly (...)




/*
   ===========================================================================
   This function translates a purely numeric time string into standard form.
   Applies ONLY to purely numerical time strings.

   time format used = 00 to 24 hours

   ----------------------------------
               EXAMPLES
   time String          Translates to
   -----------          -------------
      1                    01:00:00
      12                   12:00:00
      123                  01:23:00
      1234                 12:34:00
      12345                01:23:45
      123456               12:34:56

   This function does NOT check for errors.

   NO DEPENDENCIES
   ===========================================================================
*/

   function Num_to_HMS ($NumHMSVal)
{
   $w = trim($NumHMSVal);

// Equate empty input to zero.
   if ($w == '') {return '00:00:00';}

// Return input unchanged if non-numeric argument
// rather than return an error message.
   if (!Is_Numeric($w)) {return $NumHMSVal;}

// Get first character and numerical sign.
   $FirstChar = substr($w,0,1);
   $NumSign   = (IntVal($w) < 0)? '-' : '+';

// Remove any numerical () sign
// and work with absolute value.
   $w = Str_Replace($NumSign, '', $w);

// Construct (w) into a 6-digit integer.
   if (StrLen($w) == 1) {$w = "0$w";}
   if (StrLen($w) == 2) {$w = $w."0000";}
   if (StrLen($w) == 3) {$w = "0$w";}
   if (StrLen($w) == 4) {$w = $w."00";}
   if (StrLen($w) == 5) {$w = "0$w";}

// Only keep (+) sign if it was in the original argument.
// Otherwise, a positive value will NOT be returned with
// a (+) sign. This does not effect the sign of negative
// values.
   if ($FirstChar <> '+' and $NumSign == '+') {$NumSign = '';}

// Done.  Return assumed time string equivalent ('hh:mm:ss') with colons.
   return $NumSign.substr($w,0,2).':'.substr($w,2,2).':'.substr($w,4,2);

} // End of  Num_to_HMS (...)




/*
   ============================================================================
   This function converts a time elements string ('h m s') to decimal hours.

   NO DEPENDENCIES
   ============================================================================
*/

   function HMS_to_Hours ($hhmmss)
{
// Read hour angle string argument and force to lower case in
// the event any (h m s :) symbols are used.
   $hms = StrToLower(trim($hhmmss));

// Convert any (h m s :) symbols into spaces.
   $hms = Str_Replace('h', ' ', $hms);
   $hms = Str_Replace('m', ' ', $hms);
   $hms = Str_Replace('s', ' ', $hms);
   $hms = Str_Replace(':', ' ', $hms);

// Normalize the spacing and then split and extract the
// individual time string elements (hh, mm,ss).
   $hms = PReg_Replace("/\s+/", " ", trim($hms));
   $whms = PReg_Split("[ ]", $hms);
   $whmscount = count($whms);
   $hh = ($whmscount >= 1)? bcAdd($whms[0],"0", 20) : "0";
   $mm = ($whmscount >= 2)? bcAdd($whms[1],"0", 20) : "0";
   $ss = ($whmscount >= 3)? bcAdd($whms[2],"0", 20) : "0";

// Remember and then remove any numerical (-/+) sign.
   $NumSign = (substr($hhmmss,0,1) == '-')? '-' : '';
   $hh = Str_Replace('-', '', $hh);
   $hh = Str_Replace('+', '', $hh);

// If original angle argument began with a + sign, then preserve
// it so that all returned positive results will have a + sign.
// Otherwise, positive results will NOT have a + sign.
   if (substr($hhmmss,0,1) == '+') {$NumSign = '+';}

// Compute decimal hours value equivalent
// to the combined hh,mm,ss values.
   $w2 = bcAdd(bcAdd(bcMul($hh,'3600',20),bcMul($mm,'60',20),20),$ss,20);

// If result equates to zero, then suppress any numerical sign.
   if (bcComp($w2, '0', 20) == 0) {$NumSign = '';}

// round off result to 16 decimals.
   $w =  bcAdd(bcDiv($w2,3600, 20), '0.00000000000000005', 16);

// Reattach numerical sign and trim off
// any redundant zeros/decimal point.
   return $NumSign.Rtrim(Rtrim($w, '0'), '.');

} // end of  HMS_to_Hours (hhmmss)






/*
   This function computes the BC/AD calendar date for any given
   Julian Date (JD) on the Julian or Gregorian calendar from
   scratch, not using any of the native PHP date functions.

   JDVal    = The Julian Date value
   CalMode  = Calendar mode: 'G' = Gregorian = Default,  'J' = Julian
   Decimals = Decimals used for seconds (0=Default  to  3)

   OUTPUT
   A date and time string such as
   AD 1949-May-20-Fri 09:02:13.334
   corresponding to the JD argument.

*/

   function Inverse_JD($JDVal, $CalMode='G', $Decimals=0)
{
  $JD    = trim($JDVal);
  $J     = $JD - 0.5;
  $CMode = (StrToUpper(substr($CalMode,0,1)) == 'J')? 0:1;

  $q = abs(IntVal(trim($Decimals)));   if ($q > 3) {$q = 3;}
  $q = '0'.(($q == 0)? 2 : $q+3).".$q".'f';

// Compute calendar date (BC/AD y, m, d) elements.
  $A = floor($JD + 0.5);
  $B = $CMode*floor(($A - 1867216.25) / 36524.25);
  $C = $A + $CMode*($B - floor($B/4) + 1);
  $D = $C + 1524;
  $E = floor(($D - 122.1) / 365.25);
  $F = floor(365.25 * $E);
  $G = floor(($D - $F) / 30.6001);

  $d = $D - $F - floor(30.6001 * $G);     // Day num   (1 to 31)
  $m = $G - 12*floor($G/14) - 1;          // Month num (1 to 12)
  $y = $E - 4716 + floor((14 - $m) / 12); // Math year num
  $y = ($y > 0)? $y : $y-1;               // Cal year num (Negative = BC)

// Construct BC/AD calendar date string.
  $Mmm = substr('JanFebMarAprMayJunJulAugSepOctNovDec', 3*($m-1), 3);
  $DoW = substr('SunMonTueWedThuFriSat', 3*(($A+1) % 7), 3);
  $ymd = (($y < 0)?'BC ':'AD ').abs($y)."-$Mmm-".SPrintF("%02d",$d)."-$DoW";

// Compute time of day (hh, mm, ss.sss)
// elements to the nearest millisecond.
  $hrs = 24*($J - floor($J));
  $hh  = floor($hrs);          // hour    hh
  $min = 60*($hrs - $hh);
  $mm  = floor($min);          // minutes mm
  $sec = 60*($min - $mm);
  $sss = SPrintF("%$q", $sec); // seconds ss.sss
  $ss  = floor($sec);          // seconds ss

// Patch for that blasted 60s glitch.
   if ($ss == 60 or $sss == 60)
      {$mm += 1;    $ss  = 0; $sss = SPrintF("%$q", 0);}
   if ($mm == 60)  {$hh += 1; $mm = 0;}

// Format the time (hh, mm, ss) elements.
  $hh = SPrintF("%02d", $hh);
  $mm = SPrintF("%02d", $mm);
  $ss = SPrintF("%02d", $ss);

// Construct and return final date and time string.
   return "$ymd $hh:$mm:$sss";
} // End of  Inverse_JD()





?>

